--[[
-- For all Indents and Purposes
-- Copyright (c) 2007 Kristofer Karlsson <kristofer.karlsson@gmail.com>
--
-- Permission is hereby granted, free of charge, to any person obtaining a copy
-- of this software and associated documentation files (the "Software"), to deal
-- in the Software without restriction, including without limitation the rights
-- to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-- copies of the Software, and to permit persons to whom the Software is
-- furnished to do so, subject to the following conditions:
-- 
-- The above copyright notice and this permission notice shall be included in
-- all copies or substantial portions of the Software.
-- 
-- THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-- IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-- FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-- AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-- LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-- OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-- THE SOFTWARE.
--]]

-- For All Indents And Purposes -
-- a indentation + syntax highlighting library
-- All valid lua code should be processed correctly.

-- For both variants:
-- 2) hook the editboxes that you want to have indentation like this:
-- IndentationLib.enable(editbox [, colorTable [, tabWidth] ])
-- if you don't select a color table, it will use the default.
-- Read through this code for further usage help.
-- (The documentation IS the code)

-- Lots of keywords added by Bill Lafreniere 10/13/2013

IndentationLib = {}

local lib = IndentationLib
lib.revision = revision

local stringlen = string.len
local stringformat = string.format
local stringfind = string.find
local stringsub = string.sub
local stringbyte = string.byte
local stringchar = string.char
local stringrep = string.rep
local stringgsub = string.gsub

local workingTable = {}
local workingTable2 = {}
local function tableclear(t)
	for k in next,t do
		t[k] = nil
	end
end

local function stringinsert(s, pos, insertStr)
	return stringsub(s, 1, pos) .. insertStr .. stringsub(s, pos + 1)
end
lib.stringinsert = stringinsert

local function stringdelete(s, pos1, pos2)
	return stringsub(s, 1, pos1 - 1) .. stringsub(s, pos2 + 1)
end
lib.stringdelete = stringdelete

-- token types
local tokens = {}
lib.tokens = tokens

tokens.TOKEN_UNKNOWN = 0
tokens.TOKEN_NUMBER = 1
tokens.TOKEN_LINEBREAK = 2
tokens.TOKEN_WHITESPACE = 3
tokens.TOKEN_IDENTIFIER = 4
tokens.TOKEN_ASSIGNMENT = 5
tokens.TOKEN_EQUALITY = 6
tokens.TOKEN_MINUS = 7
tokens.TOKEN_COMMENT_SHORT = 8
tokens.TOKEN_COMMENT_LONG = 9
tokens.TOKEN_STRING = 10
tokens.TOKEN_LEFTBRACKET = 11
tokens.TOKEN_PERIOD = 12
tokens.TOKEN_DOUBLEPERIOD = 13
tokens.TOKEN_TRIPLEPERIOD = 14
tokens.TOKEN_LTE = 15
tokens.TOKEN_LT = 16
tokens.TOKEN_GTE = 17
tokens.TOKEN_GT = 18
tokens.TOKEN_NOTEQUAL = 19
tokens.TOKEN_COMMA = 20
tokens.TOKEN_SEMICOLON = 21
tokens.TOKEN_COLON = 22
tokens.TOKEN_LEFTPAREN = 23
tokens.TOKEN_RIGHTPAREN = 24
tokens.TOKEN_PLUS = 25
tokens.TOKEN_SLASH = 27
tokens.TOKEN_LEFTWING = 28
tokens.TOKEN_RIGHTWING = 29
tokens.TOKEN_CIRCUMFLEX = 30
tokens.TOKEN_ASTERISK = 31
tokens.TOKEN_RIGHTBRACKET = 32
tokens.TOKEN_KEYWORD = 33
tokens.TOKEN_SPECIAL = 34
tokens.TOKEN_VERTICAL = 35
tokens.TOKEN_TILDE = 36

-- WoW specific tokens
tokens.TOKEN_COLORCODE_START = 37
tokens.TOKEN_COLORCODE_STOP = 38

-- new as of lua 5.1
tokens.TOKEN_HASH = 39
tokens.TOKEN_PERCENT = 40


-- ascii codes
local bytes = {}
lib.bytes = bytes
bytes.BYTE_LINEBREAK_UNIX = stringbyte("\n")
bytes.BYTE_LINEBREAK_MAC = stringbyte("\r")
bytes.BYTE_SINGLE_QUOTE = stringbyte("'")
bytes.BYTE_DOUBLE_QUOTE = stringbyte('"')
bytes.BYTE_0 = stringbyte("0")
bytes.BYTE_9 = stringbyte("9")
bytes.BYTE_PERIOD = stringbyte(".")
bytes.BYTE_SPACE = stringbyte(" ")
bytes.BYTE_TAB = stringbyte("\t")
bytes.BYTE_E = stringbyte("E")
bytes.BYTE_e = stringbyte("e")
bytes.BYTE_MINUS = stringbyte("-")
bytes.BYTE_EQUALS = stringbyte("=")
bytes.BYTE_LEFTBRACKET = stringbyte("[")
bytes.BYTE_RIGHTBRACKET = stringbyte("]")
bytes.BYTE_BACKSLASH = stringbyte("\\")
bytes.BYTE_COMMA = stringbyte(",")
bytes.BYTE_SEMICOLON = stringbyte(";")
bytes.BYTE_COLON = stringbyte(":")
bytes.BYTE_LEFTPAREN = stringbyte("(")
bytes.BYTE_RIGHTPAREN = stringbyte(")")
bytes.BYTE_TILDE = stringbyte("~")
bytes.BYTE_PLUS = stringbyte("+")
bytes.BYTE_SLASH = stringbyte("/")
bytes.BYTE_LEFTWING = stringbyte("{")
bytes.BYTE_RIGHTWING = stringbyte("}")
bytes.BYTE_CIRCUMFLEX = stringbyte("^")
bytes.BYTE_ASTERISK = stringbyte("*")
bytes.BYTE_LESSTHAN = stringbyte("<")
bytes.BYTE_GREATERTHAN = stringbyte(">")
-- WoW specific chars
bytes.BYTE_VERTICAL = stringbyte("|")
bytes.BYTE_r = stringbyte("r")
bytes.BYTE_c = stringbyte("c")

-- new as of lua 5.1
bytes.BYTE_HASH = stringbyte("#")
bytes.BYTE_PERCENT = stringbyte("%")


local linebreakCharacters = {}
lib.linebreakCharacters = linebreakCharacters
linebreakCharacters[bytes.BYTE_LINEBREAK_UNIX] = 1
linebreakCharacters[bytes.BYTE_LINEBREAK_MAC] = 1

local whitespaceCharacters = {}
lib.whitespaceCharacters = whitespaceCharacters
whitespaceCharacters[bytes.BYTE_SPACE] = 1
whitespaceCharacters[bytes.BYTE_TAB] = 1

local specialCharacters = {}
lib.specialCharacters = specialCharacters
specialCharacters[bytes.BYTE_PERIOD] = -1
specialCharacters[bytes.BYTE_LESSTHAN] = -1
specialCharacters[bytes.BYTE_GREATERTHAN] = -1
specialCharacters[bytes.BYTE_LEFTBRACKET] = -1
specialCharacters[bytes.BYTE_EQUALS] = -1
specialCharacters[bytes.BYTE_MINUS] = -1
specialCharacters[bytes.BYTE_SINGLE_QUOTE] = -1
specialCharacters[bytes.BYTE_DOUBLE_QUOTE] = -1
specialCharacters[bytes.BYTE_TILDE] = -1
specialCharacters[bytes.BYTE_RIGHTBRACKET] = tokens.TOKEN_RIGHTBRACKET
specialCharacters[bytes.BYTE_COMMA] = tokens.TOKEN_COMMA
specialCharacters[bytes.BYTE_COLON] = tokens.TOKEN_COLON
specialCharacters[bytes.BYTE_SEMICOLON] = tokens.TOKEN_SEMICOLON
specialCharacters[bytes.BYTE_LEFTPAREN] = tokens.TOKEN_LEFTPAREN
specialCharacters[bytes.BYTE_RIGHTPAREN] = tokens.TOKEN_RIGHTPAREN
specialCharacters[bytes.BYTE_PLUS] = tokens.TOKEN_PLUS
specialCharacters[bytes.BYTE_SLASH] = tokens.TOKEN_SLASH
specialCharacters[bytes.BYTE_LEFTWING] = tokens.TOKEN_LEFTWING
specialCharacters[bytes.BYTE_RIGHTWING] = tokens.TOKEN_RIGHTWING
specialCharacters[bytes.BYTE_CIRCUMFLEX] = tokens.TOKEN_CIRCUMFLEX
specialCharacters[bytes.BYTE_ASTERISK] = tokens.TOKEN_ASTERISK
-- WoW specific
specialCharacters[bytes.BYTE_VERTICAL] = -1
-- new as of lua 5.1
specialCharacters[bytes.BYTE_HASH] = tokens.TOKEN_HASH
specialCharacters[bytes.BYTE_PERCENT] = tokens.TOKEN_PERCENT

local function nextNumberExponentPartInt(text, pos)
	while true do
		local byte = stringbyte(text, pos)
		if not byte then
			return tokens.TOKEN_NUMBER, pos
		end
		
		if byte >= bytes.BYTE_0 and byte <= bytes.BYTE_9 then	
			pos = pos + 1
		else
			return tokens.TOKEN_NUMBER, pos 
		end
	end
end

local function nextNumberExponentPart(text, pos)
	local byte = stringbyte(text, pos)
	if not byte then
		return tokens.TOKEN_NUMBER, pos
	end
	
	if byte == bytes.BYTE_MINUS then
		-- handle this case: a = 1.2e-- some comment
		-- i decide to let 1.2e be parsed as a a number
		byte = stringbyte(text, pos + 1)
		if byte == bytes.BYTE_MINUS then
			return tokens.TOKEN_NUMBER, pos
		end
		return nextNumberExponentPartInt(text, pos + 1)
	end
	
	return nextNumberExponentPartInt(text, pos)
end

local function nextNumberFractionPart(text, pos)
	while true do
		local byte = stringbyte(text, pos)
		if not byte then
			return tokens.TOKEN_NUMBER, pos
		end
		
		if byte >= bytes.BYTE_0 and byte <= bytes.BYTE_9 then	
			pos = pos + 1
		elseif byte == bytes.BYTE_E or byte == bytes.BYTE_e then
			return nextNumberExponentPart(text, pos + 1)
		else
			return tokens.TOKEN_NUMBER, pos 
		end
	end
end

local function nextNumberIntPart(text, pos)
	while true do
		local byte = stringbyte(text, pos)
		if not byte then
			return tokens.TOKEN_NUMBER, pos
		end
		
		if byte >= bytes.BYTE_0 and byte <= bytes.BYTE_9 then	
			pos = pos + 1
		elseif byte == bytes.BYTE_PERIOD then
			return nextNumberFractionPart(text, pos + 1)
		elseif byte == bytes.BYTE_E or byte == bytes.BYTE_e then
			return nextNumberExponentPart(text, pos + 1)
		else
			return tokens.TOKEN_NUMBER, pos
		end
	end
end

local function nextIdentifier(text, pos)
	while true do
		local byte = stringbyte(text, pos)
		
		if not byte or
			linebreakCharacters[byte] or
			whitespaceCharacters[byte] or
			specialCharacters[byte] then
			return tokens.TOKEN_IDENTIFIER, pos
		end
		pos = pos + 1
	end
end

-- returns false or: true, nextPos, equalsCount
local function isBracketStringNext(text, pos)
	local byte = stringbyte(text, pos)
	if byte == bytes.BYTE_LEFTBRACKET then
		local pos2 = pos + 1
		byte = stringbyte(text, pos2)
		while byte == bytes.BYTE_EQUALS do
			pos2 = pos2 + 1
			byte = stringbyte(text, pos2)
		end
		if byte == bytes.BYTE_LEFTBRACKET then
			return true, pos2 + 1, (pos2 - 1) - pos
		else
			return false
		end
	else
		return false
	end
end


-- Already parsed the [==[ part when get here
local function nextBracketString(text, pos, equalsCount)
	local state = 0
	while true do
		local byte = stringbyte(text, pos)
		if not byte then
			return tokens.TOKEN_STRING, pos
		end
		
		if byte == bytes.BYTE_RIGHTBRACKET then
			if state == 0 then
				state = 1
			elseif state == equalsCount + 1 then
				return tokens.TOKEN_STRING, pos + 1
			else
				state = 0
			end
		elseif byte == bytes.BYTE_EQUALS then
			if state > 0 then
				state = state + 1
			end
		else
			state = 0
		end
		pos = pos + 1
	end
end

local function nextComment(text, pos)
	-- When we get here we have already parsed the "--"
	-- Check for long comment
	local isBracketString, nextPos, equalsCount = isBracketStringNext(text, pos)
	if isBracketString then
		local tokenType, nextPos2 = nextBracketString(text, nextPos, equalsCount)
		return tokens.TOKEN_COMMENT_LONG, nextPos2
	end

	local byte = stringbyte(text, pos)

	-- Short comment, find the first linebreak
	while true do
		byte = stringbyte(text, pos)
		if not byte then
			return tokens.TOKEN_COMMENT_SHORT, pos
		end
		if linebreakCharacters[byte] then
			return tokens.TOKEN_COMMENT_SHORT, pos
		end
		pos = pos + 1
	end
end

local function nextString(text, pos, character)
	local even = true
	while true do
		local byte = stringbyte(text, pos)
		if not byte then
			return tokens.TOKEN_STRING, pos
		end
		
		if byte == character then
			if even then
				return tokens.TOKEN_STRING, pos + 1
			end
		end
		if byte == bytes.BYTE_BACKSLASH then
			even = not even
		else
			even = true
		end
		
		pos = pos + 1
	end
end

-- INPUT
-- 1: text: text to search in
-- 2: tokenPos:  where to start searching
-- OUTPUT
-- 1: token type
-- 2: position after the last character of the token
function lib.nextToken(text, pos)
	local byte = stringbyte(text, pos)
	if not byte then
		return nil
	end
	
	if linebreakCharacters[byte] then
		return tokens.TOKEN_LINEBREAK, pos + 1
	end
	
	if whitespaceCharacters[byte] then
		while true do
			pos = pos + 1
			byte = stringbyte(text, pos)
			if not byte or not whitespaceCharacters[byte] then
				return tokens.TOKEN_WHITESPACE, pos
			end
		end
	end
	
	local token = specialCharacters[byte]
	if token then
		if token ~= -1 then
			return token, pos + 1
		end
		
		-- WoW specific (for color codes)
		if byte == bytes.BYTE_VERTICAL then
			byte = stringbyte(text, pos + 1)
			if byte == bytes.BYTE_VERTICAL then
				return tokens.TOKEN_VERTICAL, pos + 2
			end
			if byte == bytes.BYTE_c then
				return tokens.TOKEN_COLORCODE_START, pos + 10
			end
			if byte == bytes.BYTE_r then
				return tokens.TOKEN_COLORCODE_STOP, pos + 2
			end
			return tokens.TOKEN_UNKNOWN, pos + 1
		end
		
		if byte == bytes.BYTE_MINUS then
			byte = stringbyte(text, pos + 1)
			if byte == bytes.BYTE_MINUS then
				return nextComment(text, pos + 2)
			end
			return tokens.TOKEN_MINUS, pos + 1
		end
		
		if byte == bytes.BYTE_SINGLE_QUOTE then
			return nextString(text, pos + 1, bytes.BYTE_SINGLE_QUOTE)
		end
		
		if byte == bytes.BYTE_DOUBLE_QUOTE then
			return nextString(text, pos + 1, bytes.BYTE_DOUBLE_QUOTE)
		end

		if byte == bytes.BYTE_LEFTBRACKET then
			local isBracketString, nextPos, equalsCount = isBracketStringNext(text, pos)
			if isBracketString then
				return nextBracketString(text, nextPos, equalsCount)
			else
				return tokens.TOKEN_LEFTBRACKET, pos + 1
			end
		end
		
		if byte == bytes.BYTE_EQUALS then
			byte = stringbyte(text, pos + 1)
			if not byte then
				return tokens.TOKEN_ASSIGNMENT, pos + 1
			end
			if byte == bytes.BYTE_EQUALS then
				return tokens.TOKEN_EQUALITY, pos + 2
			end
			return tokens.TOKEN_ASSIGNMENT, pos + 1
		end
		
		if byte == bytes.BYTE_PERIOD then
			byte = stringbyte(text, pos + 1)
			if not byte then
				return tokens.TOKEN_PERIOD, pos + 1
			end
			if byte == bytes.BYTE_PERIOD then
				byte = stringbyte(text, pos + 2)
				if byte == bytes.BYTE_PERIOD then
					return tokens.TOKEN_TRIPLEPERIOD, pos + 3
				end
				return tokens.TOKEN_DOUBLEPERIOD, pos + 2
			elseif byte >= bytes.BYTE_0 and byte <= bytes.BYTE_9 then
				return nextNumberFractionPart(text, pos + 2)
			end
			return tokens.TOKEN_PERIOD, pos + 1
		end
		
		if byte == bytes.BYTE_LESSTHAN then
			byte = stringbyte(text, pos + 1)
			if byte == bytes.BYTE_EQUALS then
				return tokens.TOKEN_LTE, pos + 2
			end
			return tokens.TOKEN_LT, pos + 1
		end
		
		if byte == bytes.BYTE_GREATERTHAN then
			byte = stringbyte(text, pos + 1)
			if byte == bytes.BYTE_EQUALS then
				return tokens.TOKEN_GTE, pos + 2
			end
			return tokens.TOKEN_GT, pos + 1
		end
		
		if byte == bytes.BYTE_TILDE then
			byte = stringbyte(text, pos + 1)
			if byte == bytes.BYTE_EQUALS then
				return tokens.TOKEN_NOTEQUAL, pos + 2
			end
			return tokens.TOKEN_TILDE, pos + 1
		end
		
		return tokens.TOKEN_UNKNOWN, pos + 1
	elseif byte >= bytes.BYTE_0 and byte <= bytes.BYTE_9 then
		return nextNumberIntPart(text, pos + 1)
	else
		return nextIdentifier(text, pos + 1)
	end
end

-- Cool stuff begins here! (indentation and highlighting)
local stringColor = "|c00ffff77"
local tableColor = "|c00ff9900"
local arithmeticColor = "|c0033ff55"
local logicColor1 = "|c0055ff88"
local logicColor2 = "|c0088ffbb"
local LuaColor = "|c00ff0033"
local WoWColor = "|c000099ff"
local methodColor = "|c0000ffff"
local eventColor = "|c00cc66ff"
local AceColor = "|c00ff00ff"


local noIndentEffect = {0, 0}
local indentLeft = {-1, 0}
local indentRight = {0, 1}
local indentBoth = {-1, 1}

local noIndentEffectLuaColor = {0, 0, LuaColor}
local noIndentEffectWoWColor = {0, 0, WoWColor}
local noIndentEffectMethodColor = {0, 0, methodColor}
local noIndentEffectEventColor = {0, 0, eventColor}
local noIndentEffectAceColor = {0, 0, AceColor}

local keywords = {
	["and"] = noIndentEffect,
	["break"] = noIndentEffect,
	["false"] = noIndentEffect,
	["for"] = noIndentEffect,
	["if"] = noIndentEffect,
	["in"] = noIndentEffect,
	["local"] = noIndentEffect,
	["nil"] = noIndentEffect,
	["not"] = noIndentEffect,
	["or"] = noIndentEffect,
	["return"] = noIndentEffect,
	["true"] = noIndentEffect,
	["while"] = noIndentEffect,
	["until"] = indentLeft,
	["elseif"] = indentLeft,
	["end"] = indentLeft,
	["do"] = indentRight,
	["then"] = indentRight,
	["repeat"] = indentRight,
	["function"] = indentRight,
	["else"] = indentBoth,
	-- new stuff here
	-- Standard Lua Stuff
	["_ALERT"] = noIndentEffectLuaColor,
	["_ERRORMESSAGE"] = noIndentEffectLuaColor,
	["_G"] = noIndentEffectLuaColor,
	["_INPUT"] = noIndentEffectLuaColor,
	["_OUTPUT"] = noIndentEffectLuaColor,
	["_PROMPT"] = noIndentEffectLuaColor,
	["_STDERR"] = noIndentEffectLuaColor,
	["_STDIN"] = noIndentEffectLuaColor,
	["_STDOUT"] = noIndentEffectLuaColor,
	["_VERSION"] = noIndentEffectLuaColor,
	["abs"] = noIndentEffectLuaColor,
	["acos"] = noIndentEffectLuaColor,
	["asin"] = noIndentEffectLuaColor,
	["assert"] = noIndentEffectLuaColor,
	["atan"] = noIndentEffectLuaColor,
	["atan2"] = noIndentEffectLuaColor,
	["band"] = noIndentEffectLuaColor,
	["bit"] = noIndentEffectLuaColor,
	["bit.band"] = noIndentEffectLuaColor,
	["bit.bor"] = noIndentEffectLuaColor,
	["bnot"] = noIndentEffectLuaColor,
	["bor"] = noIndentEffectLuaColor,
	["bxor"] = noIndentEffectLuaColor,
	["byte"] = noIndentEffectLuaColor,
	["call"] = noIndentEffectLuaColor,
	["ceil"] = noIndentEffectLuaColor,
	["char"] = noIndentEffectLuaColor,
	["clock"] = noIndentEffectLuaColor,
	["close"] = noIndentEffectLuaColor,
	["collectgarbage"] = noIndentEffectLuaColor,
	["concat"] = noIndentEffectLuaColor,
	["coroutine"] = noIndentEffectLuaColor,
	["coroutine.create"] = noIndentEffectLuaColor,
	["coroutine.resume"] = noIndentEffectLuaColor,
	["coroutine.running"] = noIndentEffectLuaColor,
	["coroutine.status"] = noIndentEffectLuaColor,
	["coroutine.wrap"] = noIndentEffectLuaColor,
	["coroutine.yield"] = noIndentEffectLuaColor,
	["cos"] = noIndentEffectLuaColor,
	["cosh"] = noIndentEffectLuaColor,
	["cpath"] = noIndentEffectLuaColor,
	["create"] = noIndentEffectLuaColor,
	["date"] = noIndentEffectLuaColor,
	["debug"] = noIndentEffectLuaColor,
	["debug.debug"] = noIndentEffectLuaColor,
	["debug.getfenv"] = noIndentEffectLuaColor,
	["debug.gethook"] = noIndentEffectLuaColor,
	["debug.getinfo"] = noIndentEffectLuaColor,
	["debug.getlocal"] = noIndentEffectLuaColor,
	["debug.getmetatable"] = noIndentEffectLuaColor,
	["debug.getregistry"] = noIndentEffectLuaColor,
	["debug.getupvalue"] = noIndentEffectLuaColor,
	["debug.setfenv"] = noIndentEffectLuaColor,
	["debug.sethook"] = noIndentEffectLuaColor,
	["debug.setlocal"] = noIndentEffectLuaColor,
	["debug.setmetatable"] = noIndentEffectLuaColor,
	["debug.setupvalue"] = noIndentEffectLuaColor,
	["debug.traceback"] = noIndentEffectLuaColor,
	["deg"] = noIndentEffectLuaColor,
	["difftime"] = noIndentEffectLuaColor,
	["dofile"] = noIndentEffectLuaColor,
	["dostring"] = noIndentEffectLuaColor,
	["dump"] = noIndentEffectLuaColor,
	["error"] = noIndentEffectLuaColor,
	["execute"] = noIndentEffectLuaColor,
	["exit"] = noIndentEffectLuaColor,
	["exp"] = noIndentEffectLuaColor,
	["file"] = noIndentEffectLuaColor,
	["file.close"] = noIndentEffectLuaColor,
	["file.flush"] = noIndentEffectLuaColor,
	["file.lines"] = noIndentEffectLuaColor,
	["file.read"] = noIndentEffectLuaColor,
	["file.seek"] = noIndentEffectLuaColor,
	["file.setvbuf"] = noIndentEffectLuaColor,
	["file.write"] = noIndentEffectLuaColor,
	["find"] = noIndentEffectLuaColor,
	["floor"] = noIndentEffectLuaColor,
	["flush"] = noIndentEffectLuaColor,
	["fmod"] = noIndentEffectLuaColor,
	["foreach"] = noIndentEffectLuaColor,
	["foreachi"] = noIndentEffectLuaColor,
	["format"] = noIndentEffectLuaColor,
	["frexp"] = noIndentEffectLuaColor,
	["gcinfo"] = noIndentEffectLuaColor,
	["getenv"] = noIndentEffectLuaColor,
	["getfenv"] = noIndentEffectLuaColor,
	["gethook"] = noIndentEffectLuaColor,
	["getinfo"] = noIndentEffectLuaColor,
	["getlocal"] = noIndentEffectLuaColor,
	["getmetatable"] = noIndentEffectLuaColor,
	["getn"] = noIndentEffectLuaColor,
	["getregistry"] = noIndentEffectLuaColor,
	["getupvalue"] = noIndentEffectLuaColor,
	["gfind"] = noIndentEffectLuaColor,
	["globals"] = noIndentEffectLuaColor,
	["gmatch"] = noIndentEffectLuaColor,
	["gsub"] = noIndentEffectLuaColor,
	["huge"] = noIndentEffectLuaColor,
	["input"] = noIndentEffectLuaColor,
	["insert"] = noIndentEffectLuaColor,
	["io"] = noIndentEffectLuaColor,
	["io.close"] = noIndentEffectLuaColor,
	["io.flush"] = noIndentEffectLuaColor,
	["io.input"] = noIndentEffectLuaColor,
	["io.lines"] = noIndentEffectLuaColor,
	["io.open"] = noIndentEffectLuaColor,
	["io.output"] = noIndentEffectLuaColor,
	["io.popen"] = noIndentEffectLuaColor,
	["io.read"] = noIndentEffectLuaColor,
	["io.stderr"] = noIndentEffectLuaColor,
	["io.stdin"] = noIndentEffectLuaColor,
	["io.stdout"] = noIndentEffectLuaColor,
	["io.tmpfile"] = noIndentEffectLuaColor,
	["io.type"] = noIndentEffectLuaColor,
	["io.write"] = noIndentEffectLuaColor,
	["ipairs"] = noIndentEffectLuaColor,
	["join"] = noIndentEffectLuaColor,
	["ldexp"] = noIndentEffectLuaColor,
	["len"] = noIndentEffectLuaColor,
	["lines"] = noIndentEffectLuaColor,
	["load"] = noIndentEffectLuaColor,
	["loaded"] = noIndentEffectLuaColor,
	["loaders"] = noIndentEffectLuaColor,
	["loadfile"] = noIndentEffectLuaColor,
	["loadlib"] = noIndentEffectLuaColor,
	["loadstring"] = noIndentEffectLuaColor,
	["log"] = noIndentEffectLuaColor,
	["log10"] = noIndentEffectLuaColor,
	["lower"] = noIndentEffectLuaColor,
	["lshift"] = noIndentEffectLuaColor,
	["match"] = noIndentEffectLuaColor,
	["math"] = noIndentEffectLuaColor,
	["math.abs"] = noIndentEffectLuaColor,
	["math.acos"] = noIndentEffectLuaColor,
	["math.asin"] = noIndentEffectLuaColor,
	["math.atan"] = noIndentEffectLuaColor,
	["math.atan2"] = noIndentEffectLuaColor,
	["math.ceil"] = noIndentEffectLuaColor,
	["math.cos"] = noIndentEffectLuaColor,
	["math.cosh"] = noIndentEffectLuaColor,
	["math.deg"] = noIndentEffectLuaColor,
	["math.exp"] = noIndentEffectLuaColor,
	["math.floor"] = noIndentEffectLuaColor,
	["math.fmod"] = noIndentEffectLuaColor,
	["math.frexp"] = noIndentEffectLuaColor,
	["math.huge"] = noIndentEffectLuaColor,
	["math.ldexp"] = noIndentEffectLuaColor,
	["math.log"] = noIndentEffectLuaColor,
	["math.log10"] = noIndentEffectLuaColor,
	["math.max"] = noIndentEffectLuaColor,
	["math.min"] = noIndentEffectLuaColor,
	["math.modf"] = noIndentEffectLuaColor,
	["math.pi"] = noIndentEffectLuaColor,
	["math.pow"] = noIndentEffectLuaColor,
	["math.rad"] = noIndentEffectLuaColor,
	["math.random"] = noIndentEffectLuaColor,
	["math.randomseed"] = noIndentEffectLuaColor,
	["math.sin"] = noIndentEffectLuaColor,
	["math.sinh"] = noIndentEffectLuaColor,
	["math.sqrt"] = noIndentEffectLuaColor,
	["math.tan"] = noIndentEffectLuaColor,
	["math.tanh"] = noIndentEffectLuaColor,
	["max"] = noIndentEffectLuaColor,
	["maxn"] = noIndentEffectLuaColor,
	["min"] = noIndentEffectLuaColor,
	["mod"] = noIndentEffectLuaColor,
	["modf"] = noIndentEffectLuaColor,
	["module"] = noIndentEffectLuaColor,
	["new"] = noIndentEffectLuaColor,
	["newtable"] = noIndentEffectLuaColor,
	["newtype"] = noIndentEffectLuaColor,
	["next"] = noIndentEffectLuaColor,
	["open"] = noIndentEffectLuaColor,
	["os"] = noIndentEffectLuaColor,
	["os_clock"] = noIndentEffectLuaColor,
	["os.date"] = noIndentEffectLuaColor,
	["os.difftime"] = noIndentEffectLuaColor,
	["os.execute"] = noIndentEffectLuaColor,
	["os.exit"] = noIndentEffectLuaColor,
	["os.getenv"] = noIndentEffectLuaColor,
	["os.remove"] = noIndentEffectLuaColor,
	["os.rename"] = noIndentEffectLuaColor,
	["os.setlocale"] = noIndentEffectLuaColor,
	["os.time"] = noIndentEffectLuaColor,
	["os.tmpname"] = noIndentEffectLuaColor,
	["output"] = noIndentEffectLuaColor,
	["package"] = noIndentEffectLuaColor,
	["package.cpath"] = noIndentEffectLuaColor,
	["package.loaded"] = noIndentEffectLuaColor,
	["package.loaders"] = noIndentEffectLuaColor,
	["package.loadlib"] = noIndentEffectLuaColor,
	["package.path"] = noIndentEffectLuaColor,
	["package.preload"] = noIndentEffectLuaColor,
	["package.seeall"] = noIndentEffectLuaColor,
	["pairs"] = noIndentEffectLuaColor,
	["path"] = noIndentEffectLuaColor,
	["pcall"] = noIndentEffectLuaColor,
	["pi"] = noIndentEffectLuaColor,
	["popen"] = noIndentEffectLuaColor,
	["pow"] = noIndentEffectLuaColor,
	["preload"] = noIndentEffectLuaColor,
	["print"] = noIndentEffectLuaColor,
	["rad"] = noIndentEffectLuaColor,
	["random"] = noIndentEffectLuaColor,
	["randomseed"] = noIndentEffectLuaColor,
	["rawegal"] = noIndentEffectLuaColor,
	["rawequal"] = noIndentEffectLuaColor,
	["rawget"] = noIndentEffectLuaColor,
	["rawset"] = noIndentEffectLuaColor,
	["read"] = noIndentEffectLuaColor,
	["remove"] = noIndentEffectLuaColor,
	["rename"] = noIndentEffectLuaColor,
	["rep"] = noIndentEffectLuaColor,
	["require"] = noIndentEffectLuaColor,
	["resume"] = noIndentEffectLuaColor,
	["reverse"] = noIndentEffectLuaColor,
	["rshift"] = noIndentEffectLuaColor,
	["rtgsub"] = noIndentEffectLuaColor,
	["running"] = noIndentEffectLuaColor,
	["seeall"] = noIndentEffectLuaColor,
	["seek"] = noIndentEffectLuaColor,
	["select"] = noIndentEffectLuaColor,
	["setfenv"] = noIndentEffectLuaColor,
	["sethook"] = noIndentEffectLuaColor,
	["setlocal"] = noIndentEffectLuaColor,
	["setlocale"] = noIndentEffectLuaColor,
	["setmetatable"] = noIndentEffectLuaColor,
	["setupvalue"] = noIndentEffectLuaColor,
	["setvbuf"] = noIndentEffectLuaColor,
	["sin"] = noIndentEffectLuaColor,
	["sinh"] = noIndentEffectLuaColor,
	["sort"] = noIndentEffectLuaColor,
	["split"] = noIndentEffectLuaColor,
	["sqrt"] = noIndentEffectLuaColor,
	["status"] = noIndentEffectLuaColor,
	["stderr"] = noIndentEffectLuaColor,
	["stdin"] = noIndentEffectLuaColor,
	["stdout"] = noIndentEffectLuaColor,
	["strbyte"] = noIndentEffectLuaColor,
	["strchar"] = noIndentEffectLuaColor,
	["strconcat"] = noIndentEffectLuaColor,
	["strdump"] = noIndentEffectLuaColor,
	["strfind"] = noIndentEffectLuaColor,
	["strformat"] = noIndentEffectLuaColor,
	["strgmatch"] = noIndentEffectLuaColor,
	["strgsub"] = noIndentEffectLuaColor,
	["string"] = noIndentEffectLuaColor,
	["string_byte"] = noIndentEffectLuaColor,
	["string_char"] = noIndentEffectLuaColor,
	["string_dump"] = noIndentEffectLuaColor,
	["string_find"] = noIndentEffectLuaColor,
	["string_format"] = noIndentEffectLuaColor,
	["string_gmatch"] = noIndentEffectLuaColor,
	["string_gsub"] = noIndentEffectLuaColor,
	["string_len"] = noIndentEffectLuaColor,
	["string_lower"] = noIndentEffectLuaColor,
	["string_match"] = noIndentEffectLuaColor,
	["string_rep"] = noIndentEffectLuaColor,
	["string_reverse"] = noIndentEffectLuaColor,
	["string_sub"] = noIndentEffectLuaColor,
	["string_upper"] = noIndentEffectLuaColor,
	["strlen"] = noIndentEffectLuaColor,
	["strlower"] = noIndentEffectLuaColor,
	["strmatch"] = noIndentEffectLuaColor,
	["strrep"] = noIndentEffectLuaColor,
	["strreverse"] = noIndentEffectLuaColor,
	["strsub"] = noIndentEffectLuaColor,
	["strupper"] = noIndentEffectLuaColor,
	["sub"] = noIndentEffectLuaColor,
	["table"] = noIndentEffectLuaColor,
	["table.concat"] = noIndentEffectLuaColor,
	["table.insert"] = noIndentEffectLuaColor,
	["table.maxn"] = noIndentEffectLuaColor,
	["table.remove"] = noIndentEffectLuaColor,
	["table.sort"] = noIndentEffectLuaColor,
	["tan"] = noIndentEffectLuaColor,
	["tanh"] = noIndentEffectLuaColor,
	["time"] = noIndentEffectLuaColor,
	["tinsert"] = noIndentEffectLuaColor,
	["tmpfile"] = noIndentEffectLuaColor,
	["tmpname"] = noIndentEffectLuaColor,
	["tonumber"] = noIndentEffectLuaColor,
	["tostring"] = noIndentEffectLuaColor,
	["tostringall"] = noIndentEffectLuaColor,
	["traceback"] = noIndentEffectLuaColor,
	["tremove"] = noIndentEffectLuaColor,
	["trim"] = noIndentEffectLuaColor,
	["type"] = noIndentEffectLuaColor,
	["unpack"] = noIndentEffectLuaColor,
	["upper"] = noIndentEffectLuaColor,
	["wrap"] = noIndentEffectLuaColor,
	["write"] = noIndentEffectLuaColor,
	["xpcall"] = noIndentEffectLuaColor,
	["yield"] = noIndentEffectLuaColor,
	-- WoW Functions
	["AbandonQuest"] = noIndentEffectWoWColor,
	["AbandonSkill"] = noIndentEffectWoWColor,
	["AcceptAreaSpiritHeal"] = noIndentEffectWoWColor,
	["AcceptArenaTeam"] = noIndentEffectWoWColor,
	["AcceptBattlefieldPort"] = noIndentEffectWoWColor,
	["AcceptDuel"] = noIndentEffectWoWColor,
	["AcceptGroup"] = noIndentEffectWoWColor,
	["AcceptGuild"] = noIndentEffectWoWColor,
	["AcceptLevelGrant"] = noIndentEffectWoWColor,
	["AcceptProposal"] = noIndentEffectWoWColor,
	["AcceptQuest"] = noIndentEffectWoWColor,
	["AcceptResurrect"] = noIndentEffectWoWColor,
	["AcceptSkillUps"] = noIndentEffectWoWColor,
	["AcceptSockets"] = noIndentEffectWoWColor,
	["AcceptTrade"] = noIndentEffectWoWColor,
	["AcceptXPLoss"] = noIndentEffectWoWColor,
	["AchievementAlertFrame_FixAnchors"] = noIndentEffectWoWColor,
	["AchievementAlertFrame_GetAlertFrame"] = noIndentEffectWoWColor,
	["AchievementAlertFrame_OnClick"] = noIndentEffectWoWColor,
	["AchievementAlertFrame_OnHide"] = noIndentEffectWoWColor,
	["AchievementAlertFrame_OnLoad"] = noIndentEffectWoWColor,
	["AchievementAlertFrame_ShowAlert"] = noIndentEffectWoWColor,
	["AchievementFrame_LoadUI"] = noIndentEffectWoWColor,
	["AchievementMicroButton_OnEvent"] = noIndentEffectWoWColor,
	["ActionBar_PageDown"] = noIndentEffectWoWColor,
	["ActionBar_PageUp"] = noIndentEffectWoWColor,
	["ActionButtonDown"] = noIndentEffectWoWColor,
	["ActionButtonUp"] = noIndentEffectWoWColor,
	["ActionButton_CalculateAction"] = noIndentEffectWoWColor,
	["ActionButton_GetPagedID"] = noIndentEffectWoWColor,
	["ActionButton_HideGrid"] = noIndentEffectWoWColor,
	["ActionButton_IsFlashing"] = noIndentEffectWoWColor,
	["ActionButton_OnEvent"] = noIndentEffectWoWColor,
	["ActionButton_OnLoad"] = noIndentEffectWoWColor,
	["ActionButton_OnUpdate"] = noIndentEffectWoWColor,
	["ActionButton_SetTooltip"] = noIndentEffectWoWColor,
	["ActionButton_ShowGrid"] = noIndentEffectWoWColor,
	["ActionButton_StartFlash"] = noIndentEffectWoWColor,
	["ActionButton_StopFlash"] = noIndentEffectWoWColor,
	["ActionButton_Update"] = noIndentEffectWoWColor,
	["ActionButton_UpdateAction"] = noIndentEffectWoWColor,
	["ActionButton_UpdateCooldown"] = noIndentEffectWoWColor,
	["ActionButton_UpdateCount"] = noIndentEffectWoWColor,
	["ActionButton_UpdateFlash"] = noIndentEffectWoWColor,
	["ActionButton_UpdateHotkeys"] = noIndentEffectWoWColor,
	["ActionButton_UpdateState"] = noIndentEffectWoWColor,
	["ActionButton_UpdateUsable"] = noIndentEffectWoWColor,
	["ActionHasRange"] = noIndentEffectWoWColor,
	["ActionStatus_DisplayMessage"] = noIndentEffectWoWColor,
	["ActionStatus_OnEvent"] = noIndentEffectWoWColor,
	["ActionStatus_OnLoad"] = noIndentEffectWoWColor,
	["ActionStatus_OnUpdate"] = noIndentEffectWoWColor,
	["AddChatWindowChannel"] = noIndentEffectWoWColor,
	["AddChatWindowMessages"] = noIndentEffectWoWColor,
	["AddFriend"] = noIndentEffectWoWColor,
	["AddFriendEntryFrame_Collapse"] = noIndentEffectWoWColor,
	["AddFriendEntryFrame_Expand"] = noIndentEffectWoWColor,
	["AddFriendFrame_Accept"] = noIndentEffectWoWColor,
	["AddFriendFrame_OnShow"] = noIndentEffectWoWColor,
	["AddFriendFrame_ShowEntry"] = noIndentEffectWoWColor,
	["AddFriendFrame_ShowInfo"] = noIndentEffectWoWColor,
	["AddFriendNameEditBox_OnTextChanged"] = noIndentEffectWoWColor,
	["AddIgnore"] = noIndentEffectWoWColor,
	["AddMute"] = noIndentEffectWoWColor,
	["AddOrDelIgnore"] = noIndentEffectWoWColor,
	["AddOrDelMute"] = noIndentEffectWoWColor,
	["AddOrRemoveFriend"] = noIndentEffectWoWColor,
	["AddPreviewTalentPoints"] = noIndentEffectWoWColor,
	["AddQuestWatch"] = noIndentEffectWoWColor,
	["AddSkillUp"] = noIndentEffectWoWColor,
	["AddToAutoHide"] = noIndentEffectWoWColor,
	["AddTrackedAchievement"] = noIndentEffectWoWColor,
	["AddTradeMoney"] = noIndentEffectWoWColor,
	["AlertFrame_AnimateIn"] = noIndentEffectWoWColor,
	["AlertFrame_FixAnchors"] = noIndentEffectWoWColor,
	["AlertFrame_OnEvent"] = noIndentEffectWoWColor,
	["AlertFrame_OnLoad"] = noIndentEffectWoWColor,
	["AlertFrame_ResumeOutAnimation"] = noIndentEffectWoWColor,
	["AlertFrame_StopOutAnimation"] = noIndentEffectWoWColor,
	["AltCurrencyFrame_PointsUpdate"] = noIndentEffectWoWColor,
	["AltCurrencyFrame_Update"] = noIndentEffectWoWColor,
	["AlternatePowerBar_Initialize"] = noIndentEffectWoWColor,
	["AlternatePowerBar_OnEvent"] = noIndentEffectWoWColor,
	["AlternatePowerBar_OnLoad"] = noIndentEffectWoWColor,
	["AlternatePowerBar_OnUpdate"] = noIndentEffectWoWColor,
	["AlternatePowerBar_UpdateMaxValues"] = noIndentEffectWoWColor,
	["AlternatePowerBar_UpdatePowerType"] = noIndentEffectWoWColor,
	["AlternatePowerBar_UpdateValue"] = noIndentEffectWoWColor,
	["AnimateTexCoords"] = noIndentEffectWoWColor,
	["AnimatedShine_OnUpdate"] = noIndentEffectWoWColor,
	["AnimatedShine_Start"] = noIndentEffectWoWColor,
	["AnimatedShine_Stop"] = noIndentEffectWoWColor,
	["AppendToFile"] = noIndentEffectWoWColor,
	["ApplyBarberShopStyle"] = noIndentEffectWoWColor,
	["ApplyUnitButtonConfiguration"] = noIndentEffectWoWColor,
	["ArenaButton_OnClick"] = noIndentEffectWoWColor,
	["ArenaFrameJoinButton_OnClick"] = noIndentEffectWoWColor,
	["ArenaFrame_OnEvent"] = noIndentEffectWoWColor,
	["ArenaFrame_OnLoad"] = noIndentEffectWoWColor,
	["ArenaFrame_Update"] = noIndentEffectWoWColor,
	["ArenaRegistrar_OnEvent"] = noIndentEffectWoWColor,
	["ArenaRegistrar_OnLoad"] = noIndentEffectWoWColor,
	["ArenaRegistrar_OnShow"] = noIndentEffectWoWColor,
	["ArenaRegistrar_ShowPurchaseFrame"] = noIndentEffectWoWColor,
	["ArenaRegistrar_TurnInPetition"] = noIndentEffectWoWColor,
	["ArenaRegistrar_UpdatePrice"] = noIndentEffectWoWColor,
	["ArenaTeamDisband"] = noIndentEffectWoWColor,
	["ArenaTeamInviteByName"] = noIndentEffectWoWColor,
	["ArenaTeamLeave"] = noIndentEffectWoWColor,
	["ArenaTeamRoster"] = noIndentEffectWoWColor,
	["ArenaTeamSetLeaderByName"] = noIndentEffectWoWColor,
	["ArenaTeamUninviteByName"] = noIndentEffectWoWColor,
	["ArenaTeam_GetTeamSizeID"] = noIndentEffectWoWColor,
	["Arena_LoadUI"] = noIndentEffectWoWColor,
	["AscendStop"] = noIndentEffectWoWColor,
	["AssistUnit"] = noIndentEffectWoWColor,
	["AttackTarget"] = noIndentEffectWoWColor,
	["AuctionFrame_LoadUI"] = noIndentEffectWoWColor,
	["AudioOptionsFrameCancel_OnClick"] = noIndentEffectWoWColor,
	["AudioOptionsFrameDefault_OnClick"] = noIndentEffectWoWColor,
	["AudioOptionsFrameOkay_OnClick"] = noIndentEffectWoWColor,
	["AudioOptionsFrame_AudioRestart"] = noIndentEffectWoWColor,
	["AudioOptionsFrame_OnEvent"] = noIndentEffectWoWColor,
	["AudioOptionsFrame_OnHide"] = noIndentEffectWoWColor,
	["AudioOptionsFrame_OnLoad"] = noIndentEffectWoWColor,
	["AudioOptionsFrame_SetAllToDefaults"] = noIndentEffectWoWColor,
	["AudioOptionsFrame_SetCurrentToDefaults"] = noIndentEffectWoWColor,
	["AudioOptionsFrame_Toggle"] = noIndentEffectWoWColor,
	["AudioOptionsPanel_CheckButton_OnClick"] = noIndentEffectWoWColor,
	["AudioOptionsSoundPanelHardwareDropDown_Initialize"] = noIndentEffectWoWColor,
	["AudioOptionsSoundPanelHardwareDropDown_OnClick"] = noIndentEffectWoWColor,
	["AudioOptionsSoundPanelHardwareDropDown_OnLoad"] = noIndentEffectWoWColor,
	["AudioOptionsSoundPanel_OnLoad"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanelBindingOutput_OnUpdate"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanelBindingType_Update"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanelChatModeDropDown_Initialize"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanelChatModeDropDown_OnClick"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanelChatModeDropDown_OnLoad"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanelEnableMicrophone_UpdateControls"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanelEnableVoice_UpdateControls"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanelInputDeviceDropDown_Initialize"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanelInputDeviceDropDown_OnClick"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanelInputDeviceDropDown_OnLoad"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanelKeyBindingButton_BindButton"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanelKeyBindingButton_CancelBinding"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanelKeyBindingButton_OnClick"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanelKeyBindingButton_OnEnter"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanelKeyBindingButton_OnKeyDown"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanelKeyBindingButton_OnKeyUp"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanelKeyBindingButton_Refresh"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanelKeyBindingButton_SetTooltip"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanelOutputDeviceDropDown_Initialize"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanelOutputDeviceDropDown_OnClick"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanelOutputDeviceDropDown_OnEvent"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanelOutputDeviceDropDown_OnLoad"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanel_DisableMicrophoneControls"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanel_EnableMicrophoneControls"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanel_OnEvent"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanel_OnHide"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanel_OnLoad"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanel_OnShow"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanel_Refresh"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanel_SetInputDevice"] = noIndentEffectWoWColor,
	["AudioOptionsVoicePanel_SetOutputDevice"] = noIndentEffectWoWColor,
	["AuraButton_OnUpdate"] = noIndentEffectWoWColor,
	["AuraButton_Update"] = noIndentEffectWoWColor,
	["AuraButton_UpdateDuration"] = noIndentEffectWoWColor,
	["AutoCastShine_AutoCastStart"] = noIndentEffectWoWColor,
	["AutoCastShine_AutoCastStop"] = noIndentEffectWoWColor,
	["AutoCastShine_OnLoad"] = noIndentEffectWoWColor,
	["AutoCastShine_OnUpdate"] = noIndentEffectWoWColor,
	["AutoCompleteButton_OnClick"] = noIndentEffectWoWColor,
	["AutoCompleteEditBox_AddHighlightedText"] = noIndentEffectWoWColor,
	["AutoCompleteEditBox_OnChar"] = noIndentEffectWoWColor,
	["AutoCompleteEditBox_OnEditFocusLost"] = noIndentEffectWoWColor,
	["AutoCompleteEditBox_OnEnterPressed"] = noIndentEffectWoWColor,
	["AutoCompleteEditBox_OnEscapePressed"] = noIndentEffectWoWColor,
	["AutoCompleteEditBox_OnTabPressed"] = noIndentEffectWoWColor,
	["AutoCompleteEditBox_OnTextChanged"] = noIndentEffectWoWColor,
	["AutoComplete_GetNumResults"] = noIndentEffectWoWColor,
	["AutoComplete_GetSelectedIndex"] = noIndentEffectWoWColor,
	["AutoComplete_HideIfAttachedTo"] = noIndentEffectWoWColor,
	["AutoComplete_OnLoad"] = noIndentEffectWoWColor,
	["AutoComplete_SetSelectedIndex"] = noIndentEffectWoWColor,
	["AutoComplete_Update"] = noIndentEffectWoWColor,
	["AutoComplete_UpdateResults"] = noIndentEffectWoWColor,
	["AutoEquipCursorItem"] = noIndentEffectWoWColor,
	["AutoFollowStatus_OnEvent"] = noIndentEffectWoWColor,
	["AutoFollowStatus_OnLoad"] = noIndentEffectWoWColor,
	["AutoFollowStatus_OnUpdate"] = noIndentEffectWoWColor,
	["AutoLootMailItem"] = noIndentEffectWoWColor,
	["AutoStoreGuildBankItem"] = noIndentEffectWoWColor,
	["BNAcceptFriendInvite"] = noIndentEffectWoWColor,
	["BNConnected"] = noIndentEffectWoWColor,
	["BNConversationButton_OnClick"] = noIndentEffectWoWColor,
	["BNConversationButton_OnEnter"] = noIndentEffectWoWColor,
	["BNConversationButton_OnEvent"] = noIndentEffectWoWColor,
	["BNConversationButton_OnLeave"] = noIndentEffectWoWColor,
	["BNConversationButton_OnLoad"] = noIndentEffectWoWColor,
	["BNConversationButton_UpdateAttachmentPoint"] = noIndentEffectWoWColor,
	["BNConversationButton_UpdateEnabledState"] = noIndentEffectWoWColor,
	["BNConversationButton_UpdateTarget"] = noIndentEffectWoWColor,
	["BNConversationInviteDialogInviteButton_OnClick"] = noIndentEffectWoWColor,
	["BNConversationInviteDialog_OnEvent"] = noIndentEffectWoWColor,
	["BNConversationInviteDialog_OnLoad"] = noIndentEffectWoWColor,
	["BNConversationInviteListCheckButton_OnClick"] = noIndentEffectWoWColor,
	["BNConversationInvite_Deselect"] = noIndentEffectWoWColor,
	["BNConversationInvite_Lock"] = noIndentEffectWoWColor,
	["BNConversationInvite_LockActions"] = noIndentEffectWoWColor,
	["BNConversationInvite_NewConversation"] = noIndentEffectWoWColor,
	["BNConversationInvite_Reset"] = noIndentEffectWoWColor,
	["BNConversationInvite_Select"] = noIndentEffectWoWColor,
	["BNConversationInvite_SelectPlayers"] = noIndentEffectWoWColor,
	["BNConversationInvite_SetMinMaxInvites"] = noIndentEffectWoWColor,
	["BNConversationInvite_SetMode"] = noIndentEffectWoWColor,
	["BNConversationInvite_Unlock"] = noIndentEffectWoWColor,
	["BNConversationInvite_UnlockActions"] = noIndentEffectWoWColor,
	["BNConversationInvite_Update"] = noIndentEffectWoWColor,
	["BNConversationInvite_UpdateInviteButtonState"] = noIndentEffectWoWColor,
	["BNConversation_DisplayConversationTooltip"] = noIndentEffectWoWColor,
	["BNCreateConversation"] = noIndentEffectWoWColor,
	["BNDeclineFriendInvite"] = noIndentEffectWoWColor,
	["BNFeaturesEnabled"] = noIndentEffectWoWColor,
	["BNFeaturesEnabledAndConnected"] = noIndentEffectWoWColor,
	["BNGetBlockedInfo"] = noIndentEffectWoWColor,
	["BNGetBlockedToonInfo"] = noIndentEffectWoWColor,
	["BNGetConversationInfo"] = noIndentEffectWoWColor,
	["BNGetConversationMemberInfo"] = noIndentEffectWoWColor,
	["BNGetCustomMessageTable"] = noIndentEffectWoWColor,
	["BNGetFOFInfo"] = noIndentEffectWoWColor,
	["BNGetFriendInfo"] = noIndentEffectWoWColor,
	["BNGetFriendInfoByID"] = noIndentEffectWoWColor,
	["BNGetFriendInviteInfo"] = noIndentEffectWoWColor,
	["BNGetFriendToonInfo"] = noIndentEffectWoWColor,
	["BNGetInfo"] = noIndentEffectWoWColor,
	["BNGetMatureLanguageFilter"] = noIndentEffectWoWColor,
	["BNGetMaxPlayersInConversation"] = noIndentEffectWoWColor,
	["BNGetNumBlocked"] = noIndentEffectWoWColor,
	["BNGetNumBlockedToons"] = noIndentEffectWoWColor,
	["BNGetNumConversationMembers"] = noIndentEffectWoWColor,
	["BNGetNumFOF"] = noIndentEffectWoWColor,
	["BNGetNumFriendInvites"] = noIndentEffectWoWColor,
	["BNGetNumFriendToons"] = noIndentEffectWoWColor,
	["BNGetNumFriends"] = noIndentEffectWoWColor,
	["BNGetSelectedBlock"] = noIndentEffectWoWColor,
	["BNGetSelectedFriend"] = noIndentEffectWoWColor,
	["BNGetSelectedToonBlock"] = noIndentEffectWoWColor,
	["BNGetToonInfo"] = noIndentEffectWoWColor,
	["BNInviteToConversation"] = noIndentEffectWoWColor,
	["BNIsBlocked"] = noIndentEffectWoWColor,
	["BNIsFriend"] = noIndentEffectWoWColor,
	["BNIsSelf"] = noIndentEffectWoWColor,
	["BNIsToonBlocked"] = noIndentEffectWoWColor,
	["BNLeaveConversation"] = noIndentEffectWoWColor,
	["BNListConversation"] = noIndentEffectWoWColor,
	["BNRemoveFriend"] = noIndentEffectWoWColor,
	["BNReportFriendInvite"] = noIndentEffectWoWColor,
	["BNReportPlayer"] = noIndentEffectWoWColor,
	["BNRequestFOFInfo"] = noIndentEffectWoWColor,
	["BNSendConversationMessage"] = noIndentEffectWoWColor,
	["BNSendFriendInvite"] = noIndentEffectWoWColor,
	["BNSendFriendInviteByID"] = noIndentEffectWoWColor,
	["BNSendWhisper"] = noIndentEffectWoWColor,
	["BNSetAFK"] = noIndentEffectWoWColor,
	["BNSetBlocked"] = noIndentEffectWoWColor,
	["BNSetCustomMessage"] = noIndentEffectWoWColor,
	["BNSetDND"] = noIndentEffectWoWColor,
	["BNSetFocus"] = noIndentEffectWoWColor,
	["BNSetFriendNote"] = noIndentEffectWoWColor,
	["BNSetMatureLanguageFilter"] = noIndentEffectWoWColor,
	["BNSetSelectedBlock"] = noIndentEffectWoWColor,
	["BNSetSelectedFriend"] = noIndentEffectWoWColor,
	["BNSetSelectedToonBlock"] = noIndentEffectWoWColor,
	["BNSetToonBlocked"] = noIndentEffectWoWColor,
	["BNToastFrame_AddToast"] = noIndentEffectWoWColor,
	["BNToastFrame_Close"] = noIndentEffectWoWColor,
	["BNToastFrame_OnClick"] = noIndentEffectWoWColor,
	["BNToastFrame_OnEvent"] = noIndentEffectWoWColor,
	["BNToastFrame_OnUpdate"] = noIndentEffectWoWColor,
	["BNToastFrame_RemoveToast"] = noIndentEffectWoWColor,
	["BNToastFrame_Show"] = noIndentEffectWoWColor,
	["BNToastFrame_UpdateAnchor"] = noIndentEffectWoWColor,
	["BNet_ConfirmReport"] = noIndentEffectWoWColor,
	["BNet_DisableToasts"] = noIndentEffectWoWColor,
	["BNet_EnableToasts"] = noIndentEffectWoWColor,
	["BNet_GetPresenceID"] = noIndentEffectWoWColor,
	["BNet_InitiateReport"] = noIndentEffectWoWColor,
	["BNet_OnEvent"] = noIndentEffectWoWColor,
	["BNet_OnLoad"] = noIndentEffectWoWColor,
	["BNet_SendReport"] = noIndentEffectWoWColor,
	["BNet_SetToastDuration"] = noIndentEffectWoWColor,
	["BNet_UpdateToastEvent"] = noIndentEffectWoWColor,
	["BackpackButton_OnClick"] = noIndentEffectWoWColor,
	["BackpackButton_OnModifiedClick"] = noIndentEffectWoWColor,
	["BackpackButton_UpdateChecked"] = noIndentEffectWoWColor,
	["BackpackTokenButton_OnClick"] = noIndentEffectWoWColor,
	["BackpackTokenFrame_IsShown"] = noIndentEffectWoWColor,
	["BackpackTokenFrame_Update"] = noIndentEffectWoWColor,
	["BagSlotButton_OnClick"] = noIndentEffectWoWColor,
	["BagSlotButton_OnDrag"] = noIndentEffectWoWColor,
	["BagSlotButton_OnEnter"] = noIndentEffectWoWColor,
	["BagSlotButton_OnModifiedClick"] = noIndentEffectWoWColor,
	["BagSlotButton_UpdateChecked"] = noIndentEffectWoWColor,
	["BankButtonIDToInvSlotID"] = noIndentEffectWoWColor,
	["BankFrameBagButton_OnLoad"] = noIndentEffectWoWColor,
	["BankFrameBaseButton_OnLoad"] = noIndentEffectWoWColor,
	["BankFrameItemButtonBag_OnClick"] = noIndentEffectWoWColor,
	["BankFrameItemButtonBag_Pickup"] = noIndentEffectWoWColor,
	["BankFrameItemButtonGeneric_OnClick"] = noIndentEffectWoWColor,
	["BankFrameItemButtonGeneric_OnModifiedClick"] = noIndentEffectWoWColor,
	["BankFrameItemButton_OnEnter"] = noIndentEffectWoWColor,
	["BankFrameItemButton_OnLoad"] = noIndentEffectWoWColor,
	["BankFrameItemButton_Update"] = noIndentEffectWoWColor,
	["BankFrameItemButton_UpdateLocked"] = noIndentEffectWoWColor,
	["BankFrame_OnEvent"] = noIndentEffectWoWColor,
	["BankFrame_OnHide"] = noIndentEffectWoWColor,
	["BankFrame_OnLoad"] = noIndentEffectWoWColor,
	["BankFrame_OnShow"] = noIndentEffectWoWColor,
	["BankFrame_UpdateCooldown"] = noIndentEffectWoWColor,
	["BarberShopFrame_LoadUI"] = noIndentEffectWoWColor,
	["BarberShopReset"] = noIndentEffectWoWColor,
	["BattlefieldButton_OnClick"] = noIndentEffectWoWColor,
	["BattlefieldFrameJoinButton_OnClick"] = noIndentEffectWoWColor,
	["BattlefieldFrame_GetSelectedBattlegroundInfo"] = noIndentEffectWoWColor,
	["BattlefieldFrame_OnEvent"] = noIndentEffectWoWColor,
	["BattlefieldFrame_OnLoad"] = noIndentEffectWoWColor,
	["BattlefieldFrame_Update"] = noIndentEffectWoWColor,
	["BattlefieldFrame_UpdateRandomInfo"] = noIndentEffectWoWColor,
	["BattlefieldFrame_UpdateStatus"] = noIndentEffectWoWColor,
	["BattlefieldMgrEntryInviteResponse"] = noIndentEffectWoWColor,
	["BattlefieldMgrExitRequest"] = noIndentEffectWoWColor,
	["BattlefieldMgrQueueInviteResponse"] = noIndentEffectWoWColor,
	["BattlefieldMgrQueueRequest"] = noIndentEffectWoWColor,
	["BattlefieldMinimap_LoadUI"] = noIndentEffectWoWColor,
	["BattlefieldTimerFrame_OnUpdate"] = noIndentEffectWoWColor,
	["BattlegroundShineFadeIn"] = noIndentEffectWoWColor,
	["BattlegroundShineFadeOut"] = noIndentEffectWoWColor,
	["BeginTrade"] = noIndentEffectWoWColor,
	["BetterDate"] = noIndentEffectWoWColor,
	["BindEnchant"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_Cancel"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_CancelControl"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_CheckButton_Disable"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_CheckButton_Enable"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_CheckButton_OnClick"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_CheckButton_Refresh"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_CheckButton_SetNewValue"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_Default"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_DefaultControl"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_DropDown_Refresh"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_GetCVarDefaultSafe"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_GetCVarMaxSafe"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_GetCVarMinSafe"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_GetCVarSafe"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_Okay"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_OkayControl"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_OnEvent"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_OnLoad"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_Refresh"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_RefreshControl"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_RegisterControl"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_SetCVarSafe"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_SetupControl"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_SetupDependentControl"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_Slider_Disable"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_Slider_Enable"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_Slider_OnValueChanged"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_Slider_Refresh"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_UpdateCombatText"] = noIndentEffectWoWColor,
	["BlizzardOptionsPanel_UpdateRaidPullouts"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_ApplyFilters"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_CreateActionMenu"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_CreateFilterMenu"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_CreateSpellMenu"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_CreateTabMenu"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_CreateUnitMenu"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_DisableEvent"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_EnableEvent"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_FormattingMenu"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_GenerateFullEventList"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_GenerateFullFlagList"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_HasEvent"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_InitializeFilters"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_MenuHelper"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_MessageTypesMenu"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_QuickButtonFrame_OnEvent"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_QuickButtonFrame_OnLoad"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_QuickButtonRightClick"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_QuickButton_OnClick"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_Refilter"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_RefilterUpdate"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_RefreshGlobalLinks"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_SpellMenuClick"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_UnitMenuClick"] = noIndentEffectWoWColor,
	["Blizzard_CombatLog_Update_QuickButtons"] = noIndentEffectWoWColor,
	["BonusActionBar_OnEvent"] = noIndentEffectWoWColor,
	["BonusActionBar_OnLoad"] = noIndentEffectWoWColor,
	["BonusActionBar_OnUpdate"] = noIndentEffectWoWColor,
	["BonusActionButtonDown"] = noIndentEffectWoWColor,
	["BonusActionButtonUp"] = noIndentEffectWoWColor,
	["BossTargetFrameDropDown_Initialize"] = noIndentEffectWoWColor,
	["BossTargetFrame_OnLoad"] = noIndentEffectWoWColor,
	["BuffButton_OnClick"] = noIndentEffectWoWColor,
	["BuffButton_OnLoad"] = noIndentEffectWoWColor,
	["BuffFrame_OnEvent"] = noIndentEffectWoWColor,
	["BuffFrame_OnLoad"] = noIndentEffectWoWColor,
	["BuffFrame_OnUpdate"] = noIndentEffectWoWColor,
	["BuffFrame_Update"] = noIndentEffectWoWColor,
	["BuffFrame_UpdateAllBuffAnchors"] = noIndentEffectWoWColor,
	["BuffFrame_UpdatePositions"] = noIndentEffectWoWColor,
	["BuildColoredListString"] = noIndentEffectWoWColor,
	["BuildListString"] = noIndentEffectWoWColor,
	["BuildMultilineTooltip"] = noIndentEffectWoWColor,
	["BuildNewLineListString"] = noIndentEffectWoWColor,
	["ButtonInventorySlot"] = noIndentEffectWoWColor,
	["ButtonPulse_OnUpdate"] = noIndentEffectWoWColor,
	["ButtonPulse_StopPulse"] = noIndentEffectWoWColor,
	["BuyGuildBankTab"] = noIndentEffectWoWColor,
	["BuyGuildCharter"] = noIndentEffectWoWColor,
	["BuyMerchantItem"] = noIndentEffectWoWColor,
	["BuyPetition"] = noIndentEffectWoWColor,
	["BuySkillTier"] = noIndentEffectWoWColor,
	["BuyStableSlot"] = noIndentEffectWoWColor,
	["BuyTrainerService"] = noIndentEffectWoWColor,
	["BuybackItem"] = noIndentEffectWoWColor,
	["COMBAT_TEXT_SCROLL_FUNCTION"] = noIndentEffectWoWColor,
	["CalculateAuctionDeposit"] = noIndentEffectWoWColor,
	["CalendarAddEvent"] = noIndentEffectWoWColor,
	["CalendarCanAddEvent"] = noIndentEffectWoWColor,
	["CalendarCanSendInvite"] = noIndentEffectWoWColor,
	["CalendarCloseEvent"] = noIndentEffectWoWColor,
	["CalendarContextDeselectEvent"] = noIndentEffectWoWColor,
	["CalendarContextEventCanComplain"] = noIndentEffectWoWColor,
	["CalendarContextEventCanEdit"] = noIndentEffectWoWColor,
	["CalendarContextEventClipboard"] = noIndentEffectWoWColor,
	["CalendarContextEventComplain"] = noIndentEffectWoWColor,
	["CalendarContextEventCopy"] = noIndentEffectWoWColor,
	["CalendarContextEventGetCalendarType"] = noIndentEffectWoWColor,
	["CalendarContextEventPaste"] = noIndentEffectWoWColor,
	["CalendarContextEventRemove"] = noIndentEffectWoWColor,
	["CalendarContextEventSignUp"] = noIndentEffectWoWColor,
	["CalendarContextGetEventIndex"] = noIndentEffectWoWColor,
	["CalendarContextInviteAvailable"] = noIndentEffectWoWColor,
	["CalendarContextInviteDecline"] = noIndentEffectWoWColor,
	["CalendarContextInviteIsPending"] = noIndentEffectWoWColor,
	["CalendarContextInviteModeratorStatus"] = noIndentEffectWoWColor,
	["CalendarContextInviteRemove"] = noIndentEffectWoWColor,
	["CalendarContextInviteStatus"] = noIndentEffectWoWColor,
	["CalendarContextInviteTentative"] = noIndentEffectWoWColor,
	["CalendarContextInviteType"] = noIndentEffectWoWColor,
	["CalendarContextSelectEvent"] = noIndentEffectWoWColor,
	["CalendarDefaultGuildFilter"] = noIndentEffectWoWColor,
	["CalendarEventAvailable"] = noIndentEffectWoWColor,
	["CalendarEventCanEdit"] = noIndentEffectWoWColor,
	["CalendarEventCanModerate"] = noIndentEffectWoWColor,
	["CalendarEventClearAutoApprove"] = noIndentEffectWoWColor,
	["CalendarEventClearLocked"] = noIndentEffectWoWColor,
	["CalendarEventClearModerator"] = noIndentEffectWoWColor,
	["CalendarEventDecline"] = noIndentEffectWoWColor,
	["CalendarEventGetCalendarType"] = noIndentEffectWoWColor,
	["CalendarEventGetInvite"] = noIndentEffectWoWColor,
	["CalendarEventGetInviteResponseTime"] = noIndentEffectWoWColor,
	["CalendarEventGetInviteSortCriterion"] = noIndentEffectWoWColor,
	["CalendarEventGetNumInvites"] = noIndentEffectWoWColor,
	["CalendarEventGetRepeatOptions"] = noIndentEffectWoWColor,
	["CalendarEventGetSelectedInvite"] = noIndentEffectWoWColor,
	["CalendarEventGetStatusOptions"] = noIndentEffectWoWColor,
	["CalendarEventGetTextures"] = noIndentEffectWoWColor,
	["CalendarEventGetTypes"] = noIndentEffectWoWColor,
	["CalendarEventHasPendingInvite"] = noIndentEffectWoWColor,
	["CalendarEventHaveSettingsChanged"] = noIndentEffectWoWColor,
	["CalendarEventInvite"] = noIndentEffectWoWColor,
	["CalendarEventIsModerator"] = noIndentEffectWoWColor,
	["CalendarEventRemoveInvite"] = noIndentEffectWoWColor,
	["CalendarEventSelectInvite"] = noIndentEffectWoWColor,
	["CalendarEventSetAutoApprove"] = noIndentEffectWoWColor,
	["CalendarEventSetDate"] = noIndentEffectWoWColor,
	["CalendarEventSetDescription"] = noIndentEffectWoWColor,
	["CalendarEventSetLocked"] = noIndentEffectWoWColor,
	["CalendarEventSetLockoutDate"] = noIndentEffectWoWColor,
	["CalendarEventSetLockoutTime"] = noIndentEffectWoWColor,
	["CalendarEventSetModerator"] = noIndentEffectWoWColor,
	["CalendarEventSetRepeatOption"] = noIndentEffectWoWColor,
	["CalendarEventSetSize"] = noIndentEffectWoWColor,
	["CalendarEventSetStatus"] = noIndentEffectWoWColor,
	["CalendarEventSetTextureID"] = noIndentEffectWoWColor,
	["CalendarEventSetTime"] = noIndentEffectWoWColor,
	["CalendarEventSetTitle"] = noIndentEffectWoWColor,
	["CalendarEventSetType"] = noIndentEffectWoWColor,
	["CalendarEventSignUp"] = noIndentEffectWoWColor,
	["CalendarEventSortInvites"] = noIndentEffectWoWColor,
	["CalendarEventTentative"] = noIndentEffectWoWColor,
	["CalendarGetAbsMonth"] = noIndentEffectWoWColor,
	["CalendarGetDate"] = noIndentEffectWoWColor,
	["CalendarGetDayEvent"] = noIndentEffectWoWColor,
	["CalendarGetDayEventSequenceInfo"] = noIndentEffectWoWColor,
	["CalendarGetEventIndex"] = noIndentEffectWoWColor,
	["CalendarGetEventInfo"] = noIndentEffectWoWColor,
	["CalendarGetFirstPendingInvite"] = noIndentEffectWoWColor,
	["CalendarGetHolidayInfo"] = noIndentEffectWoWColor,
	["CalendarGetMaxCreateDate"] = noIndentEffectWoWColor,
	["CalendarGetMaxDate"] = noIndentEffectWoWColor,
	["CalendarGetMinDate"] = noIndentEffectWoWColor,
	["CalendarGetMinHistoryDate"] = noIndentEffectWoWColor,
	["CalendarGetMonth"] = noIndentEffectWoWColor,
	["CalendarGetMonthNames"] = noIndentEffectWoWColor,
	["CalendarGetNumDayEvents"] = noIndentEffectWoWColor,
	["CalendarGetNumPendingInvites"] = noIndentEffectWoWColor,
	["CalendarGetRaidInfo"] = noIndentEffectWoWColor,
	["CalendarGetWeekdayNames"] = noIndentEffectWoWColor,
	["CalendarIsActionPending"] = noIndentEffectWoWColor,
	["CalendarMassInviteArenaTeam"] = noIndentEffectWoWColor,
	["CalendarMassInviteGuild"] = noIndentEffectWoWColor,
	["CalendarNewEvent"] = noIndentEffectWoWColor,
	["CalendarNewGuildAnnouncement"] = noIndentEffectWoWColor,
	["CalendarNewGuildEvent"] = noIndentEffectWoWColor,
	["CalendarOpenEvent"] = noIndentEffectWoWColor,
	["CalendarRemoveEvent"] = noIndentEffectWoWColor,
	["CalendarSetAbsMonth"] = noIndentEffectWoWColor,
	["CalendarSetMonth"] = noIndentEffectWoWColor,
	["CalendarUpdateEvent"] = noIndentEffectWoWColor,
	["Calendar_LoadUI"] = noIndentEffectWoWColor,
	["CallCompanion"] = noIndentEffectWoWColor,
	["CallRestrictedClosure"] = noIndentEffectWoWColor,
	["CameraOrSelectOrMoveStart"] = noIndentEffectWoWColor,
	["CameraOrSelectOrMoveStop"] = noIndentEffectWoWColor,
	["CameraZoomIn"] = noIndentEffectWoWColor,
	["CameraZoomOut"] = noIndentEffectWoWColor,
	["CanAlterSkin"] = noIndentEffectWoWColor,
	["CanCancelAuction"] = noIndentEffectWoWColor,
	["CanChangePlayerDifficulty"] = noIndentEffectWoWColor,
	["CanComplainChat"] = noIndentEffectWoWColor,
	["CanComplainInboxItem"] = noIndentEffectWoWColor,
	["CanCooperateWithToon"] = noIndentEffectWoWColor,
	["CanCreateFilters"] = noIndentEffectWoWColor,
	["CanEditGuildEvent"] = noIndentEffectWoWColor,
	["CanEditGuildInfo"] = noIndentEffectWoWColor,
	["CanEditGuildTabInfo"] = noIndentEffectWoWColor,
	["CanEditMOTD"] = noIndentEffectWoWColor,
	["CanEditOfficerNote"] = noIndentEffectWoWColor,
	["CanEditPublicNote"] = noIndentEffectWoWColor,
	["CanEjectPassengerFromSeat"] = noIndentEffectWoWColor,
	["CanExitVehicle"] = noIndentEffectWoWColor,
	["CanGrantLevel"] = noIndentEffectWoWColor,
	["CanGroupInvite"] = noIndentEffectWoWColor,
	["CanGuildBankRepair"] = noIndentEffectWoWColor,
	["CanGuildDemote"] = noIndentEffectWoWColor,
	["CanGuildInvite"] = noIndentEffectWoWColor,
	["CanGuildPromote"] = noIndentEffectWoWColor,
	["CanGuildRemove"] = noIndentEffectWoWColor,
	["CanHearthAndResurrectFromArea"] = noIndentEffectWoWColor,
	["CanInspect"] = noIndentEffectWoWColor,
	["CanJoinBattlefieldAsGroup"] = noIndentEffectWoWColor,
	["CanMapChangeDifficulty"] = noIndentEffectWoWColor,
	["CanMerchantRepair"] = noIndentEffectWoWColor,
	["CanOpenPanels"] = noIndentEffectWoWColor,
	["CanPartyLFGBackfill"] = noIndentEffectWoWColor,
	["CanQueueForWintergrasp"] = noIndentEffectWoWColor,
	["CanResetTutorials"] = noIndentEffectWoWColor,
	["CanSendAuctionQuery"] = noIndentEffectWoWColor,
	["CanShowAchievementUI"] = noIndentEffectWoWColor,
	["CanShowCenterUIPanel"] = noIndentEffectWoWColor,
	["CanShowResetInstances"] = noIndentEffectWoWColor,
	["CanShowRightUIPanel"] = noIndentEffectWoWColor,
	["CanShowUIPanels"] = noIndentEffectWoWColor,
	["CanSignPetition"] = noIndentEffectWoWColor,
	["CanSummonFriend"] = noIndentEffectWoWColor,
	["CanSwitchVehicleSeat"] = noIndentEffectWoWColor,
	["CanSwitchVehicleSeats"] = noIndentEffectWoWColor,
	["CanUseEquipmentSets"] = noIndentEffectWoWColor,
	["CanViewOfficerNote"] = noIndentEffectWoWColor,
	["CanWithdrawGuildBankMoney"] = noIndentEffectWoWColor,
	["CancelAreaSpiritHeal"] = noIndentEffectWoWColor,
	["CancelAuction"] = noIndentEffectWoWColor,
	["CancelBarberShop"] = noIndentEffectWoWColor,
	["CancelDuel"] = noIndentEffectWoWColor,
	["CancelItemTempEnchantment"] = noIndentEffectWoWColor,
	["CancelLogout"] = noIndentEffectWoWColor,
	["CancelPendingEquip"] = noIndentEffectWoWColor,
	["CancelSell"] = noIndentEffectWoWColor,
	["CancelShapeshiftForm"] = noIndentEffectWoWColor,
	["CancelSkillUps"] = noIndentEffectWoWColor,
	["CancelSummon"] = noIndentEffectWoWColor,
	["CancelTrade"] = noIndentEffectWoWColor,
	["CancelTradeAccept"] = noIndentEffectWoWColor,
	["CancelUnitBuff"] = noIndentEffectWoWColor,
	["CannotBeResurrected"] = noIndentEffectWoWColor,
	["CaptureBar_Create"] = noIndentEffectWoWColor,
	["CaptureBar_Update"] = noIndentEffectWoWColor,
	["CastPetAction"] = noIndentEffectWoWColor,
	["CastShapeshiftForm"] = noIndentEffectWoWColor,
	["CastSpell"] = noIndentEffectWoWColor,
	["CastSpellByID"] = noIndentEffectWoWColor,
	["CastSpellByName"] = noIndentEffectWoWColor,
	["CastingBarFrame_FinishSpell"] = noIndentEffectWoWColor,
	["CastingBarFrame_OnEvent"] = noIndentEffectWoWColor,
	["CastingBarFrame_OnLoad"] = noIndentEffectWoWColor,
	["CastingBarFrame_OnShow"] = noIndentEffectWoWColor,
	["CastingBarFrame_OnUpdate"] = noIndentEffectWoWColor,
	["CastingBarFrame_UpdateIsShown"] = noIndentEffectWoWColor,
	["ChangeActionBarPage"] = noIndentEffectWoWColor,
	["ChangeChatColor"] = noIndentEffectWoWColor,
	["ChangeMultiCastActionPage"] = noIndentEffectWoWColor,
	["ChangePlayerDifficulty"] = noIndentEffectWoWColor,
	["ChannelBan"] = noIndentEffectWoWColor,
	["ChannelFrameDaughterFrame_Cancel"] = noIndentEffectWoWColor,
	["ChannelFrameDaughterFrame_Okay"] = noIndentEffectWoWColor,
	["ChannelFrameDaughterFrame_OnHide"] = noIndentEffectWoWColor,
	["ChannelFrame_Desaturate"] = noIndentEffectWoWColor,
	["ChannelFrame_Join_OnClick"] = noIndentEffectWoWColor,
	["ChannelFrame_New_OnClick"] = noIndentEffectWoWColor,
	["ChannelFrame_OnEvent"] = noIndentEffectWoWColor,
	["ChannelFrame_OnLoad"] = noIndentEffectWoWColor,
	["ChannelFrame_OnUpdate"] = noIndentEffectWoWColor,
	["ChannelFrame_Update"] = noIndentEffectWoWColor,
	["ChannelFrame_UpdateJoin"] = noIndentEffectWoWColor,
	["ChannelInvite"] = noIndentEffectWoWColor,
	["ChannelKick"] = noIndentEffectWoWColor,
	["ChannelListButton_OnDragStart"] = noIndentEffectWoWColor,
	["ChannelListButton_OnDragStop"] = noIndentEffectWoWColor,
	["ChannelListDropDown_HideDropDown"] = noIndentEffectWoWColor,
	["ChannelListDropDown_Initialize"] = noIndentEffectWoWColor,
	["ChannelListDropDown_Invite"] = noIndentEffectWoWColor,
	["ChannelListDropDown_SetPassword"] = noIndentEffectWoWColor,
	["ChannelList_CountUpdate"] = noIndentEffectWoWColor,
	["ChannelList_OnClick"] = noIndentEffectWoWColor,
	["ChannelList_SetScroll"] = noIndentEffectWoWColor,
	["ChannelList_ShowDropdown"] = noIndentEffectWoWColor,
	["ChannelList_Update"] = noIndentEffectWoWColor,
	["ChannelList_UpdateHighlight"] = noIndentEffectWoWColor,
	["ChannelList_UpdateVoice"] = noIndentEffectWoWColor,
	["ChannelModerator"] = noIndentEffectWoWColor,
	["ChannelMute"] = noIndentEffectWoWColor,
	["ChannelPulloutRosterButton_OnEvent"] = noIndentEffectWoWColor,
	["ChannelPulloutRoster_DrawButton"] = noIndentEffectWoWColor,
	["ChannelPulloutRoster_GetActiveSession"] = noIndentEffectWoWColor,
	["ChannelPulloutRoster_GetSessionIDByName"] = noIndentEffectWoWColor,
	["ChannelPulloutRoster_GetSessionInfo"] = noIndentEffectWoWColor,
	["ChannelPulloutRoster_OnEvent"] = noIndentEffectWoWColor,
	["ChannelPulloutRoster_OnLoad"] = noIndentEffectWoWColor,
	["ChannelPulloutRoster_Populate"] = noIndentEffectWoWColor,
	["ChannelPulloutRoster_Scroll"] = noIndentEffectWoWColor,
	["ChannelPulloutRoster_ScrollToBottom"] = noIndentEffectWoWColor,
	["ChannelPulloutRoster_ScrollToTop"] = noIndentEffectWoWColor,
	["ChannelPulloutRoster_Sort"] = noIndentEffectWoWColor,
	["ChannelPulloutRoster_Update"] = noIndentEffectWoWColor,
	["ChannelPulloutRoster_UpdateScrollControls"] = noIndentEffectWoWColor,
	["ChannelPulloutTabDropDown_Initialize"] = noIndentEffectWoWColor,
	["ChannelPulloutTab_OnClick"] = noIndentEffectWoWColor,
	["ChannelPulloutTab_ReanchorLeft"] = noIndentEffectWoWColor,
	["ChannelPulloutTab_UpdateText"] = noIndentEffectWoWColor,
	["ChannelPullout_OnEvent"] = noIndentEffectWoWColor,
	["ChannelPullout_OnLoad"] = noIndentEffectWoWColor,
	["ChannelPullout_OnUpdate"] = noIndentEffectWoWColor,
	["ChannelPullout_SaveOpacity"] = noIndentEffectWoWColor,
	["ChannelPullout_SetOpacity"] = noIndentEffectWoWColor,
	["ChannelPullout_ShowOpacity"] = noIndentEffectWoWColor,
	["ChannelPullout_ToggleDisplay"] = noIndentEffectWoWColor,
	["ChannelRosterDropDown_Initialize"] = noIndentEffectWoWColor,
	["ChannelRosterFrame_ShowDropdown"] = noIndentEffectWoWColor,
	["ChannelRoster_OnClick"] = noIndentEffectWoWColor,
	["ChannelRoster_SetScroll"] = noIndentEffectWoWColor,
	["ChannelRoster_Update"] = noIndentEffectWoWColor,
	["ChannelRoster_UpdateVoice"] = noIndentEffectWoWColor,
	["ChannelSilenceAll"] = noIndentEffectWoWColor,
	["ChannelSilenceVoice"] = noIndentEffectWoWColor,
	["ChannelToggleAnnouncements"] = noIndentEffectWoWColor,
	["ChannelUnSilenceAll"] = noIndentEffectWoWColor,
	["ChannelUnSilenceVoice"] = noIndentEffectWoWColor,
	["ChannelUnban"] = noIndentEffectWoWColor,
	["ChannelUnmoderator"] = noIndentEffectWoWColor,
	["ChannelUnmute"] = noIndentEffectWoWColor,
	["ChannelVoiceOff"] = noIndentEffectWoWColor,
	["ChannelVoiceOn"] = noIndentEffectWoWColor,
	["CharacterAttackFrame_OnEnter"] = noIndentEffectWoWColor,
	["CharacterDamageFrame_OnEnter"] = noIndentEffectWoWColor,
	["CharacterFrameTab_OnClick"] = noIndentEffectWoWColor,
	["CharacterFrame_OnEvent"] = noIndentEffectWoWColor,
	["CharacterFrame_OnHide"] = noIndentEffectWoWColor,
	["CharacterFrame_OnLoad"] = noIndentEffectWoWColor,
	["CharacterFrame_OnShow"] = noIndentEffectWoWColor,
	["CharacterFrame_ShowSubFrame"] = noIndentEffectWoWColor,
	["CharacterFrame_TabBoundsCheck"] = noIndentEffectWoWColor,
	["CharacterMicroButton_OnEvent"] = noIndentEffectWoWColor,
	["CharacterMicroButton_OnLoad"] = noIndentEffectWoWColor,
	["CharacterMicroButton_SetNormal"] = noIndentEffectWoWColor,
	["CharacterMicroButton_SetPushed"] = noIndentEffectWoWColor,
	["CharacterModelFrame_OnMouseUp"] = noIndentEffectWoWColor,
	["CharacterRangedDamageFrame_OnEnter"] = noIndentEffectWoWColor,
	["CharacterSpellBonusDamage_OnEnter"] = noIndentEffectWoWColor,
	["CharacterSpellCritChance_OnEnter"] = noIndentEffectWoWColor,
	["ChatChannelDropDown_Initialize"] = noIndentEffectWoWColor,
	["ChatChannelDropDown_InviteToConversation"] = noIndentEffectWoWColor,
	["ChatChannelDropDown_LeaveConversation"] = noIndentEffectWoWColor,
	["ChatChannelDropDown_PopInChat"] = noIndentEffectWoWColor,
	["ChatChannelDropDown_PopOutChat"] = noIndentEffectWoWColor,
	["ChatChannelDropDown_Show"] = noIndentEffectWoWColor,
	["ChatChannelPasswordHandler"] = noIndentEffectWoWColor,
	["ChatConfigCancel_OnClick"] = noIndentEffectWoWColor,
	["ChatConfigCategory_OnClick"] = noIndentEffectWoWColor,
	["ChatConfigCombat_OnLoad"] = noIndentEffectWoWColor,
	["ChatConfigFilter_OnClick"] = noIndentEffectWoWColor,
	["ChatConfigFrame_OnEvent"] = noIndentEffectWoWColor,
	["ChatConfigFrame_OnLoad"] = noIndentEffectWoWColor,
	["ChatConfigFrame_PlayCheckboxSound"] = noIndentEffectWoWColor,
	["ChatConfig_CreateCheckboxes"] = noIndentEffectWoWColor,
	["ChatConfig_CreateColorSwatches"] = noIndentEffectWoWColor,
	["ChatConfig_CreateTieredCheckboxes"] = noIndentEffectWoWColor,
	["ChatConfig_HideCombatTabs"] = noIndentEffectWoWColor,
	["ChatConfig_MoveFilterDown"] = noIndentEffectWoWColor,
	["ChatConfig_MoveFilterUp"] = noIndentEffectWoWColor,
	["ChatConfig_ShowCombatTabs"] = noIndentEffectWoWColor,
	["ChatConfig_UpdateChatSettings"] = noIndentEffectWoWColor,
	["ChatConfig_UpdateCheckboxes"] = noIndentEffectWoWColor,
	["ChatConfig_UpdateCombatSettings"] = noIndentEffectWoWColor,
	["ChatConfig_UpdateCombatTabs"] = noIndentEffectWoWColor,
	["ChatConfig_UpdateFilterList"] = noIndentEffectWoWColor,
	["ChatConfig_UpdateSwatches"] = noIndentEffectWoWColor,
	["ChatConfig_UpdateTieredCheckboxFrame"] = noIndentEffectWoWColor,
	["ChatConfig_UpdateTieredCheckboxes"] = noIndentEffectWoWColor,
	["ChatEdit_ActivateChat"] = noIndentEffectWoWColor,
	["ChatEdit_AddHistory"] = noIndentEffectWoWColor,
	["ChatEdit_ChooseBoxForSend"] = noIndentEffectWoWColor,
	["ChatEdit_CustomTabPressed"] = noIndentEffectWoWColor,
	["ChatEdit_DeactivateChat"] = noIndentEffectWoWColor,
	["ChatEdit_ExtractBNConversation"] = noIndentEffectWoWColor,
	["ChatEdit_ExtractChannel"] = noIndentEffectWoWColor,
	["ChatEdit_ExtractTellTarget"] = noIndentEffectWoWColor,
	["ChatEdit_FocusActiveWindow"] = noIndentEffectWoWColor,
	["ChatEdit_GetActiveWindow"] = noIndentEffectWoWColor,
	["ChatEdit_GetLastActiveWindow"] = noIndentEffectWoWColor,
	["ChatEdit_GetLastTellTarget"] = noIndentEffectWoWColor,
	["ChatEdit_GetLastToldTarget"] = noIndentEffectWoWColor,
	["ChatEdit_GetNextTellTarget"] = noIndentEffectWoWColor,
	["ChatEdit_HandleChatType"] = noIndentEffectWoWColor,
	["ChatEdit_InsertLink"] = noIndentEffectWoWColor,
	["ChatEdit_LanguageShow"] = noIndentEffectWoWColor,
	["ChatEdit_OnEditFocusGained"] = noIndentEffectWoWColor,
	["ChatEdit_OnEditFocusLost"] = noIndentEffectWoWColor,
	["ChatEdit_OnEnterPressed"] = noIndentEffectWoWColor,
	["ChatEdit_OnEscapePressed"] = noIndentEffectWoWColor,
	["ChatEdit_OnEvent"] = noIndentEffectWoWColor,
	["ChatEdit_OnHide"] = noIndentEffectWoWColor,
	["ChatEdit_OnInputLanguageChanged"] = noIndentEffectWoWColor,
	["ChatEdit_OnLoad"] = noIndentEffectWoWColor,
	["ChatEdit_OnShow"] = noIndentEffectWoWColor,
	["ChatEdit_OnSpacePressed"] = noIndentEffectWoWColor,
	["ChatEdit_OnTabPressed"] = noIndentEffectWoWColor,
	["ChatEdit_OnTextChanged"] = noIndentEffectWoWColor,
	["ChatEdit_OnTextSet"] = noIndentEffectWoWColor,
	["ChatEdit_OnUpdate"] = noIndentEffectWoWColor,
	["ChatEdit_ParseText"] = noIndentEffectWoWColor,
	["ChatEdit_ResetChatType"] = noIndentEffectWoWColor,
	["ChatEdit_ResetChatTypeToSticky"] = noIndentEffectWoWColor,
	["ChatEdit_SecureTabPressed"] = noIndentEffectWoWColor,
	["ChatEdit_SendText"] = noIndentEffectWoWColor,
	["ChatEdit_SetLastActiveWindow"] = noIndentEffectWoWColor,
	["ChatEdit_SetLastTellTarget"] = noIndentEffectWoWColor,
	["ChatEdit_SetLastToldTarget"] = noIndentEffectWoWColor,
	["ChatEdit_UpdateHeader"] = noIndentEffectWoWColor,
	["ChatFrameMenu_UpdateAnchorPoint"] = noIndentEffectWoWColor,
	["ChatFrame_ActivateCombatMessages"] = noIndentEffectWoWColor,
	["ChatFrame_AddBNConversationTarget"] = noIndentEffectWoWColor,
	["ChatFrame_AddChannel"] = noIndentEffectWoWColor,
	["ChatFrame_AddMessageEventFilter"] = noIndentEffectWoWColor,
	["ChatFrame_AddMessageGroup"] = noIndentEffectWoWColor,
	["ChatFrame_AddPrivateMessageTarget"] = noIndentEffectWoWColor,
	["ChatFrame_ChatPageDown"] = noIndentEffectWoWColor,
	["ChatFrame_ChatPageUp"] = noIndentEffectWoWColor,
	["ChatFrame_ConfigEventHandler"] = noIndentEffectWoWColor,
	["ChatFrame_DisplayChatHelp"] = noIndentEffectWoWColor,
	["ChatFrame_DisplayGameTime"] = noIndentEffectWoWColor,
	["ChatFrame_DisplayGuildHelp"] = noIndentEffectWoWColor,
	["ChatFrame_DisplayHelpText"] = noIndentEffectWoWColor,
	["ChatFrame_DisplayMacroHelpText"] = noIndentEffectWoWColor,
	["ChatFrame_DisplayStartupText"] = noIndentEffectWoWColor,
	["ChatFrame_DisplayTimePlayed"] = noIndentEffectWoWColor,
	["ChatFrame_DisplayUsageError"] = noIndentEffectWoWColor,
	["ChatFrame_ExcludeBNConversationTarget"] = noIndentEffectWoWColor,
	["ChatFrame_ExcludePrivateMessageTarget"] = noIndentEffectWoWColor,
	["ChatFrame_GetMessageEventFilters"] = noIndentEffectWoWColor,
	["ChatFrame_MessageEventHandler"] = noIndentEffectWoWColor,
	["ChatFrame_OnEvent"] = noIndentEffectWoWColor,
	["ChatFrame_OnHyperlinkShow"] = noIndentEffectWoWColor,
	["ChatFrame_OnLoad"] = noIndentEffectWoWColor,
	["ChatFrame_OnMouseWheel"] = noIndentEffectWoWColor,
	["ChatFrame_OnUpdate"] = noIndentEffectWoWColor,
	["ChatFrame_OpenChat"] = noIndentEffectWoWColor,
	["ChatFrame_OpenMenu"] = noIndentEffectWoWColor,
	["ChatFrame_ReceiveAllBNConversations"] = noIndentEffectWoWColor,
	["ChatFrame_ReceiveAllPrivateMessages"] = noIndentEffectWoWColor,
	["ChatFrame_RegisterForChannels"] = noIndentEffectWoWColor,
	["ChatFrame_RegisterForMessages"] = noIndentEffectWoWColor,
	["ChatFrame_RemoveAllChannels"] = noIndentEffectWoWColor,
	["ChatFrame_RemoveAllMessageGroups"] = noIndentEffectWoWColor,
	["ChatFrame_RemoveBNConversationTarget"] = noIndentEffectWoWColor,
	["ChatFrame_RemoveChannel"] = noIndentEffectWoWColor,
	["ChatFrame_RemoveExcludeBNConversationTarget"] = noIndentEffectWoWColor,
	["ChatFrame_RemoveExcludePrivateMessageTarget"] = noIndentEffectWoWColor,
	["ChatFrame_RemoveMessageEventFilter"] = noIndentEffectWoWColor,
	["ChatFrame_RemoveMessageGroup"] = noIndentEffectWoWColor,
	["ChatFrame_RemovePrivateMessageTarget"] = noIndentEffectWoWColor,
	["ChatFrame_ReplyTell"] = noIndentEffectWoWColor,
	["ChatFrame_ReplyTell2"] = noIndentEffectWoWColor,
	["ChatFrame_ScrollDown"] = noIndentEffectWoWColor,
	["ChatFrame_ScrollToBottom"] = noIndentEffectWoWColor,
	["ChatFrame_ScrollUp"] = noIndentEffectWoWColor,
	["ChatFrame_SendTell"] = noIndentEffectWoWColor,
	["ChatFrame_SystemEventHandler"] = noIndentEffectWoWColor,
	["ChatFrame_TimeBreakDown"] = noIndentEffectWoWColor,
	["ChatHistory_GetAccessID"] = noIndentEffectWoWColor,
	["ChatHistory_GetChatType"] = noIndentEffectWoWColor,
	["ChatHistory_GetToken"] = noIndentEffectWoWColor,
	["ChatMenu_Battleground"] = noIndentEffectWoWColor,
	["ChatMenu_Emote"] = noIndentEffectWoWColor,
	["ChatMenu_Guild"] = noIndentEffectWoWColor,
	["ChatMenu_OnLoad"] = noIndentEffectWoWColor,
	["ChatMenu_OnShow"] = noIndentEffectWoWColor,
	["ChatMenu_Party"] = noIndentEffectWoWColor,
	["ChatMenu_Raid"] = noIndentEffectWoWColor,
	["ChatMenu_Reply"] = noIndentEffectWoWColor,
	["ChatMenu_Say"] = noIndentEffectWoWColor,
	["ChatMenu_SetChatType"] = noIndentEffectWoWColor,
	["ChatMenu_VoiceMacro"] = noIndentEffectWoWColor,
	["ChatMenu_Whisper"] = noIndentEffectWoWColor,
	["ChatMenu_Yell"] = noIndentEffectWoWColor,
	["ChatUnitColor_OpenColorPicker"] = noIndentEffectWoWColor,
	["Chat_GetChannelShortcutName"] = noIndentEffectWoWColor,
	["Chat_GetChatCategory"] = noIndentEffectWoWColor,
	["Chat_GetColoredChatName"] = noIndentEffectWoWColor,
	["CheckBinderDist"] = noIndentEffectWoWColor,
	["CheckInbox"] = noIndentEffectWoWColor,
	["CheckInteractDistance"] = noIndentEffectWoWColor,
	["CheckSpiritHealerDist"] = noIndentEffectWoWColor,
	["CheckTalentMasterDist"] = noIndentEffectWoWColor,
	["CinematicFrame_OnEvent"] = noIndentEffectWoWColor,
	["CinematicFrame_OnLoad"] = noIndentEffectWoWColor,
	["ClassTrainerFrame_LoadUI"] = noIndentEffectWoWColor,
	["ClearAchievementComparisonUnit"] = noIndentEffectWoWColor,
	["ClearAllLFGDungeons"] = noIndentEffectWoWColor,
	["ClearChannelWatch"] = noIndentEffectWoWColor,
	["ClearCursor"] = noIndentEffectWoWColor,
	["ClearFocus"] = noIndentEffectWoWColor,
	["ClearInspectPlayer"] = noIndentEffectWoWColor,
	["ClearLFGDungeon"] = noIndentEffectWoWColor,
	["ClearOverrideBindings"] = noIndentEffectWoWColor,
	["ClearPartyAssignment"] = noIndentEffectWoWColor,
	["ClearPendingGuildBankPermissions"] = noIndentEffectWoWColor,
	["ClearRaidMarker"] = noIndentEffectWoWColor,
	["ClearSendMail"] = noIndentEffectWoWColor,
	["ClearTarget"] = noIndentEffectWoWColor,
	["ClearTutorials"] = noIndentEffectWoWColor,
	["ClickAuctionSellItemButton"] = noIndentEffectWoWColor,
	["ClickLandmark"] = noIndentEffectWoWColor,
	["ClickPetitionButton"] = noIndentEffectWoWColor,
	["ClickSendMailItemButton"] = noIndentEffectWoWColor,
	["ClickSocketButton"] = noIndentEffectWoWColor,
	["ClickStablePet"] = noIndentEffectWoWColor,
	["ClickTargetTradeButton"] = noIndentEffectWoWColor,
	["ClickTradeButton"] = noIndentEffectWoWColor,
	["CloseAllBags"] = noIndentEffectWoWColor,
	["CloseAllWindows"] = noIndentEffectWoWColor,
	["CloseAllWindows_WithExceptions"] = noIndentEffectWoWColor,
	["CloseArenaTeamRoster"] = noIndentEffectWoWColor,
	["CloseAuctionHouse"] = noIndentEffectWoWColor,
	["CloseBackpack"] = noIndentEffectWoWColor,
	["CloseBag"] = noIndentEffectWoWColor,
	["CloseBankBagFrames"] = noIndentEffectWoWColor,
	["CloseBankFrame"] = noIndentEffectWoWColor,
	["CloseBattlefield"] = noIndentEffectWoWColor,
	["CloseChildWindows"] = noIndentEffectWoWColor,
	["CloseDropDownMenus"] = noIndentEffectWoWColor,
	["CloseGossip"] = noIndentEffectWoWColor,
	["CloseGuildBankFrame"] = noIndentEffectWoWColor,
	["CloseGuildRegistrar"] = noIndentEffectWoWColor,
	["CloseGuildRoster"] = noIndentEffectWoWColor,
	["CloseItemText"] = noIndentEffectWoWColor,
	["CloseLoot"] = noIndentEffectWoWColor,
	["CloseMail"] = noIndentEffectWoWColor,
	["CloseMenus"] = noIndentEffectWoWColor,
	["CloseMerchant"] = noIndentEffectWoWColor,
	["ClosePetStables"] = noIndentEffectWoWColor,
	["ClosePetition"] = noIndentEffectWoWColor,
	["ClosePetitionVendor"] = noIndentEffectWoWColor,
	["CloseQuest"] = noIndentEffectWoWColor,
	["CloseSocketInfo"] = noIndentEffectWoWColor,
	["CloseSpecialWindows"] = noIndentEffectWoWColor,
	["CloseTabardCreation"] = noIndentEffectWoWColor,
	["CloseTaxiMap"] = noIndentEffectWoWColor,
	["CloseTrade"] = noIndentEffectWoWColor,
	["CloseTradeSkill"] = noIndentEffectWoWColor,
	["CloseTrainer"] = noIndentEffectWoWColor,
	["CloseWindows"] = noIndentEffectWoWColor,
	["CoinPickupFrameCancel_Click"] = noIndentEffectWoWColor,
	["CoinPickupFrameLeft_Click"] = noIndentEffectWoWColor,
	["CoinPickupFrameOkay_Click"] = noIndentEffectWoWColor,
	["CoinPickupFrameRight_Click"] = noIndentEffectWoWColor,
	["CoinPickupFrame_OnChar"] = noIndentEffectWoWColor,
	["CoinPickupFrame_OnHide"] = noIndentEffectWoWColor,
	["CoinPickupFrame_OnKeyDown"] = noIndentEffectWoWColor,
	["CoinPickupFrame_OnKeyUp"] = noIndentEffectWoWColor,
	["CollapseAllFactionHeaders"] = noIndentEffectWoWColor,
	["CollapseChannelHeader"] = noIndentEffectWoWColor,
	["CollapseFactionHeader"] = noIndentEffectWoWColor,
	["CollapseQuestHeader"] = noIndentEffectWoWColor,
	["CollapseSkillHeader"] = noIndentEffectWoWColor,
	["CollapseTradeSkillSubClass"] = noIndentEffectWoWColor,
	["CollapseTrainerSkillLine"] = noIndentEffectWoWColor,
	["ColorClassesCheckBox_OnClick"] = noIndentEffectWoWColor,
	["ColorPaperDollStat"] = noIndentEffectWoWColor,
	["ColorPicker_GetPreviousValues"] = noIndentEffectWoWColor,
	["CombatConfig_Colorize_Update"] = noIndentEffectWoWColor,
	["CombatConfig_CreateCombatFilter"] = noIndentEffectWoWColor,
	["CombatConfig_DeleteCurrentCombatFilter"] = noIndentEffectWoWColor,
	["CombatConfig_Formatting_Update"] = noIndentEffectWoWColor,
	["CombatConfig_SetCombatFiltersToDefault"] = noIndentEffectWoWColor,
	["CombatConfig_SetFilterName"] = noIndentEffectWoWColor,
	["CombatConfig_Settings_Update"] = noIndentEffectWoWColor,
	["CombatFeedback_Initialize"] = noIndentEffectWoWColor,
	["CombatFeedback_OnCombatEvent"] = noIndentEffectWoWColor,
	["CombatFeedback_OnUpdate"] = noIndentEffectWoWColor,
	["CombatFeedback_StartFullscreenStatus"] = noIndentEffectWoWColor,
	["CombatFeedback_StopFullscreenStatus"] = noIndentEffectWoWColor,
	["CombatLogAddFilter"] = noIndentEffectWoWColor,
	["CombatLogAdvanceEntry"] = noIndentEffectWoWColor,
	["CombatLogClearEntries"] = noIndentEffectWoWColor,
	["CombatLogGetCurrentEntry"] = noIndentEffectWoWColor,
	["CombatLogGetNumEntries"] = noIndentEffectWoWColor,
	["CombatLogGetRetentionTime"] = noIndentEffectWoWColor,
	["CombatLogResetFilter"] = noIndentEffectWoWColor,
	["CombatLogSetCurrentEntry"] = noIndentEffectWoWColor,
	["CombatLogSetRetentionTime"] = noIndentEffectWoWColor,
	["CombatLog_AddEvent"] = noIndentEffectWoWColor,
	["CombatLog_Color_ColorArrayByEventType"] = noIndentEffectWoWColor,
	["CombatLog_Color_ColorArrayBySchool"] = noIndentEffectWoWColor,
	["CombatLog_Color_ColorArrayByUnitType"] = noIndentEffectWoWColor,
	["CombatLog_Color_ColorStringByEventType"] = noIndentEffectWoWColor,
	["CombatLog_Color_ColorStringBySchool"] = noIndentEffectWoWColor,
	["CombatLog_Color_ColorStringByUnitType"] = noIndentEffectWoWColor,
	["CombatLog_Color_FloatToText"] = noIndentEffectWoWColor,
	["CombatLog_Color_HighlightColorArray"] = noIndentEffectWoWColor,
	["CombatLog_LoadUI"] = noIndentEffectWoWColor,
	["CombatLog_Object_IsA"] = noIndentEffectWoWColor,
	["CombatLog_OnEvent"] = noIndentEffectWoWColor,
	["CombatLog_String_DamageResultString"] = noIndentEffectWoWColor,
	["CombatLog_String_GetIcon"] = noIndentEffectWoWColor,
	["CombatLog_String_GetToken"] = noIndentEffectWoWColor,
	["CombatLog_String_PowerType"] = noIndentEffectWoWColor,
	["CombatLog_String_SchoolString"] = noIndentEffectWoWColor,
	["CombatTextSetActiveUnit"] = noIndentEffectWoWColor,
	["CombatText_AddMessage"] = noIndentEffectWoWColor,
	["CombatText_ClearAnimationList"] = noIndentEffectWoWColor,
	["CombatText_FountainScroll"] = noIndentEffectWoWColor,
	["CombatText_GetAvailableString"] = noIndentEffectWoWColor,
	["CombatText_GetOldestString"] = noIndentEffectWoWColor,
	["CombatText_OnEvent"] = noIndentEffectWoWColor,
	["CombatText_OnLoad"] = noIndentEffectWoWColor,
	["CombatText_OnUpdate"] = noIndentEffectWoWColor,
	["CombatText_RemoveMessage"] = noIndentEffectWoWColor,
	["CombatText_StandardScroll"] = noIndentEffectWoWColor,
	["CombatText_UpdateDisplayedMessages"] = noIndentEffectWoWColor,
	["ComboFrame_OnEvent"] = noIndentEffectWoWColor,
	["ComboFrame_Update"] = noIndentEffectWoWColor,
	["ComboPointShineFadeIn"] = noIndentEffectWoWColor,
	["ComboPointShineFadeOut"] = noIndentEffectWoWColor,
	["CommentatorAddPlayer"] = noIndentEffectWoWColor,
	["CommentatorEnterInstance"] = noIndentEffectWoWColor,
	["CommentatorExitInstance"] = noIndentEffectWoWColor,
	["CommentatorFollowPlayer"] = noIndentEffectWoWColor,
	["CommentatorGetCamera"] = noIndentEffectWoWColor,
	["CommentatorGetCurrentMapID"] = noIndentEffectWoWColor,
	["CommentatorGetInstanceInfo"] = noIndentEffectWoWColor,
	["CommentatorGetMapInfo"] = noIndentEffectWoWColor,
	["CommentatorGetMode"] = noIndentEffectWoWColor,
	["CommentatorGetNumMaps"] = noIndentEffectWoWColor,
	["CommentatorGetNumPlayers"] = noIndentEffectWoWColor,
	["CommentatorGetPlayerInfo"] = noIndentEffectWoWColor,
	["CommentatorGetSkirmishMode"] = noIndentEffectWoWColor,
	["CommentatorGetSkirmishQueueCount"] = noIndentEffectWoWColor,
	["CommentatorGetSkirmishQueuePlayerInfo"] = noIndentEffectWoWColor,
	["CommentatorLookatPlayer"] = noIndentEffectWoWColor,
	["CommentatorRemovePlayer"] = noIndentEffectWoWColor,
	["CommentatorRequestSkirmishMode"] = noIndentEffectWoWColor,
	["CommentatorRequestSkirmishQueueData"] = noIndentEffectWoWColor,
	["CommentatorSetBattlemaster"] = noIndentEffectWoWColor,
	["CommentatorSetCamera"] = noIndentEffectWoWColor,
	["CommentatorSetCameraCollision"] = noIndentEffectWoWColor,
	["CommentatorSetMapAndInstanceIndex"] = noIndentEffectWoWColor,
	["CommentatorSetMode"] = noIndentEffectWoWColor,
	["CommentatorSetMoveSpeed"] = noIndentEffectWoWColor,
	["CommentatorSetPlayerIndex"] = noIndentEffectWoWColor,
	["CommentatorSetSkirmishMatchmakingMode"] = noIndentEffectWoWColor,
	["CommentatorSetTargetHeightOffset"] = noIndentEffectWoWColor,
	["CommentatorStartInstance"] = noIndentEffectWoWColor,
	["CommentatorStartSkirmishMatch"] = noIndentEffectWoWColor,
	["CommentatorToggleMode"] = noIndentEffectWoWColor,
	["CommentatorUpdateMapInfo"] = noIndentEffectWoWColor,
	["CommentatorUpdatePlayerInfo"] = noIndentEffectWoWColor,
	["CommentatorZoomIn"] = noIndentEffectWoWColor,
	["CommentatorZoomOut"] = noIndentEffectWoWColor,
	["CompanionButton_OnClick"] = noIndentEffectWoWColor,
	["CompanionButton_OnDrag"] = noIndentEffectWoWColor,
	["CompanionButton_OnEnter"] = noIndentEffectWoWColor,
	["CompanionButton_OnLoad"] = noIndentEffectWoWColor,
	["CompanionButton_OnModifiedClick"] = noIndentEffectWoWColor,
	["CompanionSummonButton_OnClick"] = noIndentEffectWoWColor,
	["ComplainChat"] = noIndentEffectWoWColor,
	["ComplainInboxItem"] = noIndentEffectWoWColor,
	["CompleteLFGRoleCheck"] = noIndentEffectWoWColor,
	["CompleteQuest"] = noIndentEffectWoWColor,
	["ComputePetBonus"] = noIndentEffectWoWColor,
	["ConfirmAcceptQuest"] = noIndentEffectWoWColor,
	["ConfirmBindOnUse"] = noIndentEffectWoWColor,
	["ConfirmBinder"] = noIndentEffectWoWColor,
	["ConfirmLootRoll"] = noIndentEffectWoWColor,
	["ConfirmLootSlot"] = noIndentEffectWoWColor,
	["ConfirmReadyCheck"] = noIndentEffectWoWColor,
	["ConfirmSummon"] = noIndentEffectWoWColor,
	["ConfirmTalentWipe"] = noIndentEffectWoWColor,
	["ConsoleAddMessage"] = noIndentEffectWoWColor,
	["ConsoleExec"] = noIndentEffectWoWColor,
	["ConsolePrint"] = noIndentEffectWoWColor,
	["ConsolidatedBuffs_OnEnter"] = noIndentEffectWoWColor,
	["ConsolidatedBuffs_OnHide"] = noIndentEffectWoWColor,
	["ConsolidatedBuffs_OnShow"] = noIndentEffectWoWColor,
	["ConsolidatedBuffs_OnUpdate"] = noIndentEffectWoWColor,
	["ConsolidatedBuffs_UpdateAllAnchors"] = noIndentEffectWoWColor,
	["ContainerFrameItemButton_OnClick"] = noIndentEffectWoWColor,
	["ContainerFrameItemButton_OnDrag"] = noIndentEffectWoWColor,
	["ContainerFrameItemButton_OnEnter"] = noIndentEffectWoWColor,
	["ContainerFrameItemButton_OnLoad"] = noIndentEffectWoWColor,
	["ContainerFrameItemButton_OnModifiedClick"] = noIndentEffectWoWColor,
	["ContainerFrame_GenerateFrame"] = noIndentEffectWoWColor,
	["ContainerFrame_GetExtendedPriceString"] = noIndentEffectWoWColor,
	["ContainerFrame_GetOpenFrame"] = noIndentEffectWoWColor,
	["ContainerFrame_OnEvent"] = noIndentEffectWoWColor,
	["ContainerFrame_OnHide"] = noIndentEffectWoWColor,
	["ContainerFrame_OnLoad"] = noIndentEffectWoWColor,
	["ContainerFrame_OnShow"] = noIndentEffectWoWColor,
	["ContainerFrame_Update"] = noIndentEffectWoWColor,
	["ContainerFrame_UpdateCooldown"] = noIndentEffectWoWColor,
	["ContainerFrame_UpdateCooldowns"] = noIndentEffectWoWColor,
	["ContainerFrame_UpdateLocked"] = noIndentEffectWoWColor,
	["ContainerFrame_UpdateLockedItem"] = noIndentEffectWoWColor,
	["ContainerIDToInventoryID"] = noIndentEffectWoWColor,
	["ContainerRefundItemPurchase"] = noIndentEffectWoWColor,
	["ConvertToParty"] = noIndentEffectWoWColor,
	["ConvertToRaid"] = noIndentEffectWoWColor,
	["CooldownFrame_SetTimer"] = noIndentEffectWoWColor,
	["CopyTable"] = noIndentEffectWoWColor,
	["CreateChatChannelList"] = noIndentEffectWoWColor,
	["CreateFont"] = noIndentEffectWoWColor,
	["CreateFrame"] = noIndentEffectWoWColor,
	["CreateMacro"] = noIndentEffectWoWColor,
	["CreateMiniWorldMapArrowFrame"] = noIndentEffectWoWColor,
	["CreateWorldMapArrowFrame"] = noIndentEffectWoWColor,
	["CursorCanGoInSlot"] = noIndentEffectWoWColor,
	["CursorHasItem"] = noIndentEffectWoWColor,
	["CursorHasMacro"] = noIndentEffectWoWColor,
	["CursorHasMoney"] = noIndentEffectWoWColor,
	["CursorHasSpell"] = noIndentEffectWoWColor,
	["CursorOnUpdate"] = noIndentEffectWoWColor,
	["CursorUpdate"] = noIndentEffectWoWColor,
	["DamageColor_OpenColorPicker"] = noIndentEffectWoWColor,
	["DeathKnniggetThrobFunction"] = noIndentEffectWoWColor,
	["DebuffButton_UpdateAnchors"] = noIndentEffectWoWColor,
	["DeclineArenaTeam"] = noIndentEffectWoWColor,
	["DeclineGroup"] = noIndentEffectWoWColor,
	["DeclineGuild"] = noIndentEffectWoWColor,
	["DeclineInvite"] = noIndentEffectWoWColor,
	["DeclineLevelGrant"] = noIndentEffectWoWColor,
	["DeclineName"] = noIndentEffectWoWColor,
	["DeclineQuest"] = noIndentEffectWoWColor,
	["DeclineResurrect"] = noIndentEffectWoWColor,
	["DelIgnore"] = noIndentEffectWoWColor,
	["DelMute"] = noIndentEffectWoWColor,
	["DeleteCursorItem"] = noIndentEffectWoWColor,
	["DeleteEquipmentSet"] = noIndentEffectWoWColor,
	["DeleteFile"] = noIndentEffectWoWColor,
	["DeleteGMTicket"] = noIndentEffectWoWColor,
	["DeleteInboxItem"] = noIndentEffectWoWColor,
	["DeleteMacro"] = noIndentEffectWoWColor,
	["DemoteAssistant"] = noIndentEffectWoWColor,
	["DepositGuildBankMoney"] = noIndentEffectWoWColor,
	["DescendStop"] = noIndentEffectWoWColor,
	["DestroyTotem"] = noIndentEffectWoWColor,
	["DetectWowMouse"] = noIndentEffectWoWColor,
	["DisableAddOn"] = noIndentEffectWoWColor,
	["DisableAllAddOns"] = noIndentEffectWoWColor,
	["DisablePagingButton"] = noIndentEffectWoWColor,
	["DisableSpellAutocast"] = noIndentEffectWoWColor,
	["Disable_BagButtons"] = noIndentEffectWoWColor,
	["DismissCompanion"] = noIndentEffectWoWColor,
	["Dismount"] = noIndentEffectWoWColor,
	["DisplayChannelOwner"] = noIndentEffectWoWColor,
	["DisplayChannelVoiceOff"] = noIndentEffectWoWColor,
	["DisplayChannelVoiceOn"] = noIndentEffectWoWColor,
	["DoEmote"] = noIndentEffectWoWColor,
	["DoReadyCheck"] = noIndentEffectWoWColor,
	["DoTradeSkill"] = noIndentEffectWoWColor,
	["DownloadSettings"] = noIndentEffectWoWColor,
	["DrawOneHopLines"] = noIndentEffectWoWColor,
	["DrawRouteLine"] = noIndentEffectWoWColor,
	["DressUpItemLink"] = noIndentEffectWoWColor,
	["DressUpTexturePath"] = noIndentEffectWoWColor,
	["DropCursorMoney"] = noIndentEffectWoWColor,
	["DropItemOnUnit"] = noIndentEffectWoWColor,
	["DungeonCompletionAlertFrameReward_OnEnter"] = noIndentEffectWoWColor,
	["DungeonCompletionAlertFrameReward_OnLeave"] = noIndentEffectWoWColor,
	["DungeonCompletionAlertFrameReward_SetReward"] = noIndentEffectWoWColor,
	["DungeonCompletionAlertFrame_FixAnchors"] = noIndentEffectWoWColor,
	["DungeonCompletionAlertFrame_OnLoad"] = noIndentEffectWoWColor,
	["DungeonCompletionAlertFrame_ShowAlert"] = noIndentEffectWoWColor,
	["DungeonUsesTerrainMap"] = noIndentEffectWoWColor,
	["DurabilityFrame_SetAlerts"] = noIndentEffectWoWColor,
	["DynamicScrollFrame_CreateButtons"] = noIndentEffectWoWColor,
	["DynamicScrollFrame_OnVerticalScroll"] = noIndentEffectWoWColor,
	["DynamicScrollFrame_UnlockAllHighlights"] = noIndentEffectWoWColor,
	["DynamicScrollFrame_Update"] = noIndentEffectWoWColor,
	["EasyMenu"] = noIndentEffectWoWColor,
	["EasyMenu_Initialize"] = noIndentEffectWoWColor,
	["EditBox_ClearFocus"] = noIndentEffectWoWColor,
	["EditBox_ClearHighlight"] = noIndentEffectWoWColor,
	["EditBox_HandleTabbing"] = noIndentEffectWoWColor,
	["EditBox_HighlightText"] = noIndentEffectWoWColor,
	["EditBox_SetFocus"] = noIndentEffectWoWColor,
	["EditMacro"] = noIndentEffectWoWColor,
	["EjectPassengerFromSeat"] = noIndentEffectWoWColor,
	["EmoteMenu_Click"] = noIndentEffectWoWColor,
	["EmoteMenu_OnLoad"] = noIndentEffectWoWColor,
	["EnableAddOn"] = noIndentEffectWoWColor,
	["EnableAllAddOns"] = noIndentEffectWoWColor,
	["EnablePagingButton"] = noIndentEffectWoWColor,
	["EnableSpellAutocast"] = noIndentEffectWoWColor,
	["Enable_BagButtons"] = noIndentEffectWoWColor,
	["EndBoundTradeable"] = noIndentEffectWoWColor,
	["EndRefund"] = noIndentEffectWoWColor,
	["EnumerateFrames"] = noIndentEffectWoWColor,
	["EnumerateServerChannels"] = noIndentEffectWoWColor,
	["EquipCursorItem"] = noIndentEffectWoWColor,
	["EquipItemByName"] = noIndentEffectWoWColor,
	["EquipPendingItem"] = noIndentEffectWoWColor,
	["EquipmentManagerClearIgnoredSlotsForSave"] = noIndentEffectWoWColor,
	["EquipmentManagerIgnoreSlotForSave"] = noIndentEffectWoWColor,
	["EquipmentManagerIsSlotIgnoredForSave"] = noIndentEffectWoWColor,
	["EquipmentManagerUnignoreSlotForSave"] = noIndentEffectWoWColor,
	["EquipmentManager_EquipContainerItem"] = noIndentEffectWoWColor,
	["EquipmentManager_EquipInventoryItem"] = noIndentEffectWoWColor,
	["EquipmentManager_EquipItemByLocation"] = noIndentEffectWoWColor,
	["EquipmentManager_EquipSet"] = noIndentEffectWoWColor,
	["EquipmentManager_GetItemInfoByLocation"] = noIndentEffectWoWColor,
	["EquipmentManager_OnEvent"] = noIndentEffectWoWColor,
	["EquipmentManager_PutItemInInventory"] = noIndentEffectWoWColor,
	["EquipmentManager_RunAction"] = noIndentEffectWoWColor,
	["EquipmentManager_UnequipItemInSlot"] = noIndentEffectWoWColor,
	["EquipmentManager_UnpackLocation"] = noIndentEffectWoWColor,
	["EquipmentManager_UpdateFreeBagSpace"] = noIndentEffectWoWColor,
	["EquipmentSetContainsLockedItems"] = noIndentEffectWoWColor,
	["ExhaustionTick_OnEvent"] = noIndentEffectWoWColor,
	["ExhaustionTick_OnLoad"] = noIndentEffectWoWColor,
	["ExhaustionTick_OnUpdate"] = noIndentEffectWoWColor,
	["ExhaustionToolTipText"] = noIndentEffectWoWColor,
	["ExpandAllFactionHeaders"] = noIndentEffectWoWColor,
	["ExpandChannelHeader"] = noIndentEffectWoWColor,
	["ExpandCurrencyList"] = noIndentEffectWoWColor,
	["ExpandFactionHeader"] = noIndentEffectWoWColor,
	["ExpandQuestHeader"] = noIndentEffectWoWColor,
	["ExpandSkillHeader"] = noIndentEffectWoWColor,
	["ExpandTradeSkillSubClass"] = noIndentEffectWoWColor,
	["ExpandTrainerSkillLine"] = noIndentEffectWoWColor,
	["EyeTemplate_OnUpdate"] = noIndentEffectWoWColor,
	["EyeTemplate_StartAnimating"] = noIndentEffectWoWColor,
	["EyeTemplate_StopAnimating"] = noIndentEffectWoWColor,
	["FCFChannelDropDown_OnClick"] = noIndentEffectWoWColor,
	["FCFClickAnywhereButton_OnEvent"] = noIndentEffectWoWColor,
	["FCFClickAnywhereButton_OnLoad"] = noIndentEffectWoWColor,
	["FCFClickAnywhereButton_UpdateState"] = noIndentEffectWoWColor,
	["FCFDockOverflowButton_OnClick"] = noIndentEffectWoWColor,
	["FCFDockOverflowButton_OnEvent"] = noIndentEffectWoWColor,
	["FCFDockOverflowButton_UpdatePulseState"] = noIndentEffectWoWColor,
	["FCFDockOverflowListButton_OnClick"] = noIndentEffectWoWColor,
	["FCFDockOverflowListButton_SetValue"] = noIndentEffectWoWColor,
	["FCFDockOverflowList_Update"] = noIndentEffectWoWColor,
	["FCFDockOverflow_CloseLists"] = noIndentEffectWoWColor,
	["FCFDockScrollFrame_GetLeftmostTab"] = noIndentEffectWoWColor,
	["FCFDockScrollFrame_GetScrollDistanceNeeded"] = noIndentEffectWoWColor,
	["FCFDockScrollFrame_JumpToTab"] = noIndentEffectWoWColor,
	["FCFDockScrollFrame_OnUpdate"] = noIndentEffectWoWColor,
	["FCFDock_AddChatFrame"] = noIndentEffectWoWColor,
	["FCFDock_CalculateTabSize"] = noIndentEffectWoWColor,
	["FCFDock_ForceReanchoring"] = noIndentEffectWoWColor,
	["FCFDock_GetChatFrames"] = noIndentEffectWoWColor,
	["FCFDock_GetInsertIndex"] = noIndentEffectWoWColor,
	["FCFDock_GetSelectedWindow"] = noIndentEffectWoWColor,
	["FCFDock_HasDockedChatFrame"] = noIndentEffectWoWColor,
	["FCFDock_HideInsertHighlight"] = noIndentEffectWoWColor,
	["FCFDock_OnEvent"] = noIndentEffectWoWColor,
	["FCFDock_OnLoad"] = noIndentEffectWoWColor,
	["FCFDock_OnPrimarySizeChanged"] = noIndentEffectWoWColor,
	["FCFDock_OnUpdate"] = noIndentEffectWoWColor,
	["FCFDock_PlaceInsertHighlight"] = noIndentEffectWoWColor,
	["FCFDock_RemoveChatFrame"] = noIndentEffectWoWColor,
	["FCFDock_ScrollToSelectedTab"] = noIndentEffectWoWColor,
	["FCFDock_SelectWindow"] = noIndentEffectWoWColor,
	["FCFDock_SetDirty"] = noIndentEffectWoWColor,
	["FCFDock_SetPrimary"] = noIndentEffectWoWColor,
	["FCFDock_UpdateTabs"] = noIndentEffectWoWColor,
	["FCFDropDown_LoadChannels"] = noIndentEffectWoWColor,
	["FCFDropDown_LoadChatTypes"] = noIndentEffectWoWColor,
	["FCFManager_GetNumDedicatedFrames"] = noIndentEffectWoWColor,
	["FCFManager_RegisterDedicatedFrame"] = noIndentEffectWoWColor,
	["FCFManager_ShouldSuppressMessage"] = noIndentEffectWoWColor,
	["FCFManager_UnregisterDedicatedFrame"] = noIndentEffectWoWColor,
	["FCFMessageTypeDropDown_OnClick"] = noIndentEffectWoWColor,
	["FCFMin_UpdateColors"] = noIndentEffectWoWColor,
	["FCFOptionsDropDown_Initialize"] = noIndentEffectWoWColor,
	["FCFOptionsDropDown_OnLoad"] = noIndentEffectWoWColor,
	["FCFTab_OnDragStop"] = noIndentEffectWoWColor,
	["FCFTab_OnUpdate"] = noIndentEffectWoWColor,
	["FCFTab_UpdateAlpha"] = noIndentEffectWoWColor,
	["FCFTab_UpdateColors"] = noIndentEffectWoWColor,
	["FCF_CancelFontColorSettings"] = noIndentEffectWoWColor,
	["FCF_CancelWindowColorSettings"] = noIndentEffectWoWColor,
	["FCF_Close"] = noIndentEffectWoWColor,
	["FCF_CopyChatSettings"] = noIndentEffectWoWColor,
	["FCF_CreateMinimizedFrame"] = noIndentEffectWoWColor,
	["FCF_DockFrame"] = noIndentEffectWoWColor,
	["FCF_DockUpdate"] = noIndentEffectWoWColor,
	["FCF_FadeInChatFrame"] = noIndentEffectWoWColor,
	["FCF_FadeOutChatFrame"] = noIndentEffectWoWColor,
	["FCF_FlagMinimizedPositionReset"] = noIndentEffectWoWColor,
	["FCF_FlashTab"] = noIndentEffectWoWColor,
	["FCF_GetButtonSide"] = noIndentEffectWoWColor,
	["FCF_GetChatWindowInfo"] = noIndentEffectWoWColor,
	["FCF_GetCurrentChatFrame"] = noIndentEffectWoWColor,
	["FCF_GetCurrentChatFrameID"] = noIndentEffectWoWColor,
	["FCF_GetNumActiveChatFrames"] = noIndentEffectWoWColor,
	["FCF_HideOnFadeFinished"] = noIndentEffectWoWColor,
	["FCF_IsValidChatFrame"] = noIndentEffectWoWColor,
	["FCF_LeaveConversation"] = noIndentEffectWoWColor,
	["FCF_LoadChatSubTypes"] = noIndentEffectWoWColor,
	["FCF_MaximizeFrame"] = noIndentEffectWoWColor,
	["FCF_MinimizeFrame"] = noIndentEffectWoWColor,
	["FCF_NewChatWindow"] = noIndentEffectWoWColor,
	["FCF_OnUpdate"] = noIndentEffectWoWColor,
	["FCF_OpenNewWindow"] = noIndentEffectWoWColor,
	["FCF_OpenTemporaryWindow"] = noIndentEffectWoWColor,
	["FCF_PopInWindow"] = noIndentEffectWoWColor,
	["FCF_RenameChatWindow_Popup"] = noIndentEffectWoWColor,
	["FCF_ResetAllWindows"] = noIndentEffectWoWColor,
	["FCF_ResetChatWindows"] = noIndentEffectWoWColor,
	["FCF_RestoreChatsToFrame"] = noIndentEffectWoWColor,
	["FCF_RestorePositionAndDimensions"] = noIndentEffectWoWColor,
	["FCF_SaveDock"] = noIndentEffectWoWColor,
	["FCF_SavePositionAndDimensions"] = noIndentEffectWoWColor,
	["FCF_SelectDockFrame"] = noIndentEffectWoWColor,
	["FCF_SetButtonSide"] = noIndentEffectWoWColor,
	["FCF_SetChatTypeColor"] = noIndentEffectWoWColor,
	["FCF_SetChatWindowBackGroundColor"] = noIndentEffectWoWColor,
	["FCF_SetChatWindowFontSize"] = noIndentEffectWoWColor,
	["FCF_SetChatWindowOpacity"] = noIndentEffectWoWColor,
	["FCF_SetExpandedUninteractable"] = noIndentEffectWoWColor,
	["FCF_SetLocked"] = noIndentEffectWoWColor,
	["FCF_SetTabPosition"] = noIndentEffectWoWColor,
	["FCF_SetTemporaryWindowType"] = noIndentEffectWoWColor,
	["FCF_SetUninteractable"] = noIndentEffectWoWColor,
	["FCF_SetWindowAlpha"] = noIndentEffectWoWColor,
	["FCF_SetWindowColor"] = noIndentEffectWoWColor,
	["FCF_SetWindowName"] = noIndentEffectWoWColor,
	["FCF_Set_NormalChat"] = noIndentEffectWoWColor,
	["FCF_StartAlertFlash"] = noIndentEffectWoWColor,
	["FCF_StopAlertFlash"] = noIndentEffectWoWColor,
	["FCF_StopDragging"] = noIndentEffectWoWColor,
	["FCF_StripChatMsg"] = noIndentEffectWoWColor,
	["FCF_TabCompare"] = noIndentEffectWoWColor,
	["FCF_Tab_OnClick"] = noIndentEffectWoWColor,
	["FCF_ToggleLock"] = noIndentEffectWoWColor,
	["FCF_ToggleUninteractable"] = noIndentEffectWoWColor,
	["FCF_UnDockFrame"] = noIndentEffectWoWColor,
	["FCF_UpdateButtonSide"] = noIndentEffectWoWColor,
	["FCF_UpdateDockPosition"] = noIndentEffectWoWColor,
	["FactionToggleAtWar"] = noIndentEffectWoWColor,
	["FadingFrame_OnLoad"] = noIndentEffectWoWColor,
	["FadingFrame_OnUpdate"] = noIndentEffectWoWColor,
	["FadingFrame_SetFadeInTime"] = noIndentEffectWoWColor,
	["FadingFrame_SetFadeOutTime"] = noIndentEffectWoWColor,
	["FadingFrame_SetHoldTime"] = noIndentEffectWoWColor,
	["FadingFrame_Show"] = noIndentEffectWoWColor,
	["FauxScrollFrame_GetOffset"] = noIndentEffectWoWColor,
	["FauxScrollFrame_OnVerticalScroll"] = noIndentEffectWoWColor,
	["FauxScrollFrame_SetOffset"] = noIndentEffectWoWColor,
	["FauxScrollFrame_Update"] = noIndentEffectWoWColor,
	["FillLocalizedClassList"] = noIndentEffectWoWColor,
	["FindSpellBookSlotByID"] = noIndentEffectWoWColor,
	["FlagTutorial"] = noIndentEffectWoWColor,
	["FlipCameraYaw"] = noIndentEffectWoWColor,
	["FloatingChatFrameManager_OnEvent"] = noIndentEffectWoWColor,
	["FloatingChatFrameManager_OnLoad"] = noIndentEffectWoWColor,
	["FloatingChatFrame_OnEvent"] = noIndentEffectWoWColor,
	["FloatingChatFrame_OnLoad"] = noIndentEffectWoWColor,
	["FloatingChatFrame_OnMouseScroll"] = noIndentEffectWoWColor,
	["FloatingChatFrame_Update"] = noIndentEffectWoWColor,
	["FocusFrameDropDown_Initialize"] = noIndentEffectWoWColor,
	["FocusFrame_IsLocked"] = noIndentEffectWoWColor,
	["FocusFrame_OnDragStart"] = noIndentEffectWoWColor,
	["FocusFrame_OnDragStop"] = noIndentEffectWoWColor,
	["FocusFrame_SetLock"] = noIndentEffectWoWColor,
	["FocusFrame_SetSmallSize"] = noIndentEffectWoWColor,
	["FocusUnit"] = noIndentEffectWoWColor,
	["FollowUnit"] = noIndentEffectWoWColor,
	["ForceGossip"] = noIndentEffectWoWColor,
	["ForceLogout"] = noIndentEffectWoWColor,
	["ForceQuit"] = noIndentEffectWoWColor,
	["FormatPaperDollTooltipStat"] = noIndentEffectWoWColor,
	["FrameXML_Debug"] = noIndentEffectWoWColor,
	["FriendsFrameAddFriendButton_OnClick"] = noIndentEffectWoWColor,
	["FriendsFrameBNDropDown_Initialize"] = noIndentEffectWoWColor,
	["FriendsFrameBNOfflineDropDown_Initialize"] = noIndentEffectWoWColor,
	["FriendsFrameBroadcastInput_OnClearPressed"] = noIndentEffectWoWColor,
	["FriendsFrameBroadcastInput_OnEnterPressed"] = noIndentEffectWoWColor,
	["FriendsFrameBroadcastInput_OnEscapePressed"] = noIndentEffectWoWColor,
	["FriendsFrameBroadcastInput_UpdateDisplay"] = noIndentEffectWoWColor,
	["FriendsFrameDropDown_Initialize"] = noIndentEffectWoWColor,
	["FriendsFrameFriendButton_OnClick"] = noIndentEffectWoWColor,
	["FriendsFrameGuildStatusButton_OnClick"] = noIndentEffectWoWColor,
	["FriendsFrameIgnoreButton_OnClick"] = noIndentEffectWoWColor,
	["FriendsFrameMuteButton_OnClick"] = noIndentEffectWoWColor,
	["FriendsFrameOfflineDropDown_Initialize"] = noIndentEffectWoWColor,
	["FriendsFramePendingScrollFrame_AdjustScroll"] = noIndentEffectWoWColor,
	["FriendsFrameSendMessageButton_OnClick"] = noIndentEffectWoWColor,
	["FriendsFrameStatusDropDown_Initialize"] = noIndentEffectWoWColor,
	["FriendsFrameStatusDropDown_OnLoad"] = noIndentEffectWoWColor,
	["FriendsFrameStatusDropDown_OnShow"] = noIndentEffectWoWColor,
	["FriendsFrameStatusDropDown_ShowTooltip"] = noIndentEffectWoWColor,
	["FriendsFrameStatusDropDown_Update"] = noIndentEffectWoWColor,
	["FriendsFrameTooltip_SetLine"] = noIndentEffectWoWColor,
	["FriendsFrameTooltip_Show"] = noIndentEffectWoWColor,
	["FriendsFrameUnsquelchButton_OnClick"] = noIndentEffectWoWColor,
	["FriendsFrameWhoButton_OnClick"] = noIndentEffectWoWColor,
	["FriendsFrame_CheckBattlenetStatus"] = noIndentEffectWoWColor,
	["FriendsFrame_ClickSummonButton"] = noIndentEffectWoWColor,
	["FriendsFrame_GetLastOnline"] = noIndentEffectWoWColor,
	["FriendsFrame_GetTopButton"] = noIndentEffectWoWColor,
	["FriendsFrame_GroupInvite"] = noIndentEffectWoWColor,
	["FriendsFrame_OnEvent"] = noIndentEffectWoWColor,
	["FriendsFrame_OnHide"] = noIndentEffectWoWColor,
	["FriendsFrame_OnLoad"] = noIndentEffectWoWColor,
	["FriendsFrame_OnShow"] = noIndentEffectWoWColor,
	["FriendsFrame_RemoveFriend"] = noIndentEffectWoWColor,
	["FriendsFrame_SelectFriend"] = noIndentEffectWoWColor,
	["FriendsFrame_SelectSquelched"] = noIndentEffectWoWColor,
	["FriendsFrame_SendMessage"] = noIndentEffectWoWColor,
	["FriendsFrame_SetButton"] = noIndentEffectWoWColor,
	["FriendsFrame_SetOnlineStatus"] = noIndentEffectWoWColor,
	["FriendsFrame_ShowBNDropdown"] = noIndentEffectWoWColor,
	["FriendsFrame_ShowDropdown"] = noIndentEffectWoWColor,
	["FriendsFrame_ShowSubFrame"] = noIndentEffectWoWColor,
	["FriendsFrame_SummonButton_OnEvent"] = noIndentEffectWoWColor,
	["FriendsFrame_SummonButton_OnShow"] = noIndentEffectWoWColor,
	["FriendsFrame_SummonButton_Update"] = noIndentEffectWoWColor,
	["FriendsFrame_UnBlock"] = noIndentEffectWoWColor,
	["FriendsFrame_UnIgnore"] = noIndentEffectWoWColor,
	["FriendsFrame_UnMute"] = noIndentEffectWoWColor,
	["FriendsFrame_Update"] = noIndentEffectWoWColor,
	["FriendsFriendsButton_OnClick"] = noIndentEffectWoWColor,
	["FriendsFriendsFrameDropDown_Initialize"] = noIndentEffectWoWColor,
	["FriendsFriendsFrameDropDown_OnClick"] = noIndentEffectWoWColor,
	["FriendsFriendsFrame_Close"] = noIndentEffectWoWColor,
	["FriendsFriendsFrame_OnEvent"] = noIndentEffectWoWColor,
	["FriendsFriendsFrame_Reset"] = noIndentEffectWoWColor,
	["FriendsFriendsFrame_SendRequest"] = noIndentEffectWoWColor,
	["FriendsFriendsFrame_Show"] = noIndentEffectWoWColor,
	["FriendsFriendsList_Update"] = noIndentEffectWoWColor,
	["FriendsList_Update"] = noIndentEffectWoWColor,
	["GMChatFrame_LoadUI"] = noIndentEffectWoWColor,
	["GMReportLag"] = noIndentEffectWoWColor,
	["GMRequestPlayerInfo"] = noIndentEffectWoWColor,
	["GMResponseNeedMoreHelp"] = noIndentEffectWoWColor,
	["GMResponseResolve"] = noIndentEffectWoWColor,
	["GMSurveyAnswer"] = noIndentEffectWoWColor,
	["GMSurveyAnswerSubmit"] = noIndentEffectWoWColor,
	["GMSurveyCommentSubmit"] = noIndentEffectWoWColor,
	["GMSurveyFrame_LoadUI"] = noIndentEffectWoWColor,
	["GMSurveyNumAnswers"] = noIndentEffectWoWColor,
	["GMSurveyQuestion"] = noIndentEffectWoWColor,
	["GMSurveySubmit"] = noIndentEffectWoWColor,
	["GameMovieFinished"] = noIndentEffectWoWColor,
	["GameTimeFrame_OnClick"] = noIndentEffectWoWColor,
	["GameTimeFrame_OnEnter"] = noIndentEffectWoWColor,
	["GameTimeFrame_OnEvent"] = noIndentEffectWoWColor,
	["GameTimeFrame_OnLoad"] = noIndentEffectWoWColor,
	["GameTimeFrame_OnUpdate"] = noIndentEffectWoWColor,
	["GameTimeFrame_SetDate"] = noIndentEffectWoWColor,
	["GameTime_ComputeMilitaryTime"] = noIndentEffectWoWColor,
	["GameTime_ComputeMinutes"] = noIndentEffectWoWColor,
	["GameTime_ComputeStandardTime"] = noIndentEffectWoWColor,
	["GameTime_GetFormattedTime"] = noIndentEffectWoWColor,
	["GameTime_GetGameTime"] = noIndentEffectWoWColor,
	["GameTime_GetLocalTime"] = noIndentEffectWoWColor,
	["GameTime_GetTime"] = noIndentEffectWoWColor,
	["GameTime_UpdateTooltip"] = noIndentEffectWoWColor,
	["GameTooltip_AddNewbieTip"] = noIndentEffectWoWColor,
	["GameTooltip_ClearMoney"] = noIndentEffectWoWColor,
	["GameTooltip_ClearStatusBars"] = noIndentEffectWoWColor,
	["GameTooltip_Hide"] = noIndentEffectWoWColor,
	["GameTooltip_HideResetCursor"] = noIndentEffectWoWColor,
	["GameTooltip_OnHide"] = noIndentEffectWoWColor,
	["GameTooltip_OnLoad"] = noIndentEffectWoWColor,
	["GameTooltip_OnTooltipAddMoney"] = noIndentEffectWoWColor,
	["GameTooltip_OnUpdate"] = noIndentEffectWoWColor,
	["GameTooltip_SetDefaultAnchor"] = noIndentEffectWoWColor,
	["GameTooltip_ShowCompareItem"] = noIndentEffectWoWColor,
	["GameTooltip_ShowStatusBar"] = noIndentEffectWoWColor,
	["GameTooltip_UnitColor"] = noIndentEffectWoWColor,
	["GearManagerDialogDeleteSet_OnClick"] = noIndentEffectWoWColor,
	["GearManagerDialogEquipSet_OnClick"] = noIndentEffectWoWColor,
	["GearManagerDialogPopupCancel_OnClick"] = noIndentEffectWoWColor,
	["GearManagerDialogPopupOkay_OnClick"] = noIndentEffectWoWColor,
	["GearManagerDialogPopupOkay_Update"] = noIndentEffectWoWColor,
	["GearManagerDialogPopup_OnHide"] = noIndentEffectWoWColor,
	["GearManagerDialogPopup_OnLoad"] = noIndentEffectWoWColor,
	["GearManagerDialogPopup_OnShow"] = noIndentEffectWoWColor,
	["GearManagerDialogPopup_Update"] = noIndentEffectWoWColor,
	["GearManagerDialogSaveSet_OnClick"] = noIndentEffectWoWColor,
	["GearManagerDialog_OnEvent"] = noIndentEffectWoWColor,
	["GearManagerDialog_OnHide"] = noIndentEffectWoWColor,
	["GearManagerDialog_OnLoad"] = noIndentEffectWoWColor,
	["GearManagerDialog_OnShow"] = noIndentEffectWoWColor,
	["GearManagerDialog_Update"] = noIndentEffectWoWColor,
	["GearSetButton_OnClick"] = noIndentEffectWoWColor,
	["GearSetButton_OnEnter"] = noIndentEffectWoWColor,
	["GearSetPopupButton_OnClick"] = noIndentEffectWoWColor,
	["GetAbandonQuestItems"] = noIndentEffectWoWColor,
	["GetAbandonQuestName"] = noIndentEffectWoWColor,
	["GetAccountExpansionLevel"] = noIndentEffectWoWColor,
	["GetAchievementCategory"] = noIndentEffectWoWColor,
	["GetAchievementComparisonInfo"] = noIndentEffectWoWColor,
	["GetAchievementCriteriaInfo"] = noIndentEffectWoWColor,
	["GetAchievementInfo"] = noIndentEffectWoWColor,
	["GetAchievementInfoFromCriteria"] = noIndentEffectWoWColor,
	["GetAchievementLink"] = noIndentEffectWoWColor,
	["GetAchievementNumCriteria"] = noIndentEffectWoWColor,
	["GetAchievementNumRewards"] = noIndentEffectWoWColor,
	["GetAchievementReward"] = noIndentEffectWoWColor,
	["GetActionAutocast"] = noIndentEffectWoWColor,
	["GetActionBarPage"] = noIndentEffectWoWColor,
	["GetActionBarToggles"] = noIndentEffectWoWColor,
	["GetActionCooldown"] = noIndentEffectWoWColor,
	["GetActionCount"] = noIndentEffectWoWColor,
	["GetActionInfo"] = noIndentEffectWoWColor,
	["GetActionText"] = noIndentEffectWoWColor,
	["GetActionTexture"] = noIndentEffectWoWColor,
	["GetActiveLevel"] = noIndentEffectWoWColor,
	["GetActiveTalentGroup"] = noIndentEffectWoWColor,
	["GetActiveTitle"] = noIndentEffectWoWColor,
	["GetActiveVoiceChannel"] = noIndentEffectWoWColor,
	["GetAddOnCPUUsage"] = noIndentEffectWoWColor,
	["GetAddOnDependencies"] = noIndentEffectWoWColor,
	["GetAddOnInfo"] = noIndentEffectWoWColor,
	["GetAddOnMemoryUsage"] = noIndentEffectWoWColor,
	["GetAddOnMetadata"] = noIndentEffectWoWColor,
	["GetAdjustedSkillPoints"] = noIndentEffectWoWColor,
	["GetAllowLowLevelRaid"] = noIndentEffectWoWColor,
	["GetAreaSpiritHealerTime"] = noIndentEffectWoWColor,
	["GetArenaCurrency"] = noIndentEffectWoWColor,
	["GetArenaTeam"] = noIndentEffectWoWColor,
	["GetArenaTeamGdfInfo"] = noIndentEffectWoWColor,
	["GetArenaTeamRosterInfo"] = noIndentEffectWoWColor,
	["GetArenaTeamRosterSelection"] = noIndentEffectWoWColor,
	["GetArenaTeamRosterShowOffline"] = noIndentEffectWoWColor,
	["GetArmorPenetration"] = noIndentEffectWoWColor,
	["GetAttackPowerForStat"] = noIndentEffectWoWColor,
	["GetAuctionHouseDepositRate"] = noIndentEffectWoWColor,
	["GetAuctionInvTypes"] = noIndentEffectWoWColor,
	["GetAuctionItemClasses"] = noIndentEffectWoWColor,
	["GetAuctionItemInfo"] = noIndentEffectWoWColor,
	["GetAuctionItemLink"] = noIndentEffectWoWColor,
	["GetAuctionItemSubClasses"] = noIndentEffectWoWColor,
	["GetAuctionItemTimeLeft"] = noIndentEffectWoWColor,
	["GetAuctionSellItemInfo"] = noIndentEffectWoWColor,
	["GetAuctionSort"] = noIndentEffectWoWColor,
	["GetAutoCompletePresenceID"] = noIndentEffectWoWColor,
	["GetAutoCompleteResults"] = noIndentEffectWoWColor,
	["GetAvailableLevel"] = noIndentEffectWoWColor,
	["GetAvailableQuestInfo"] = noIndentEffectWoWColor,
	["GetAvailableRoles"] = noIndentEffectWoWColor,
	["GetAvailableTitle"] = noIndentEffectWoWColor,
	["GetBackgroundTexCoordsForRole"] = noIndentEffectWoWColor,
	["GetBackpackCurrencyInfo"] = noIndentEffectWoWColor,
	["GetBackpackFrame"] = noIndentEffectWoWColor,
	["GetBagName"] = noIndentEffectWoWColor,
	["GetBankSlotCost"] = noIndentEffectWoWColor,
	["GetBarberShopStyleInfo"] = noIndentEffectWoWColor,
	["GetBarberShopTotalCost"] = noIndentEffectWoWColor,
	["GetBaseMip"] = noIndentEffectWoWColor,
	["GetBattlefieldArenaFaction"] = noIndentEffectWoWColor,
	["GetBattlefieldEstimatedWaitTime"] = noIndentEffectWoWColor,
	["GetBattlefieldFlagPosition"] = noIndentEffectWoWColor,
	["GetBattlefieldInfo"] = noIndentEffectWoWColor,
	["GetBattlefieldInstanceExpiration"] = noIndentEffectWoWColor,
	["GetBattlefieldInstanceInfo"] = noIndentEffectWoWColor,
	["GetBattlefieldInstanceRunTime"] = noIndentEffectWoWColor,
	["GetBattlefieldMapIconScale"] = noIndentEffectWoWColor,
	["GetBattlefieldPortExpiration"] = noIndentEffectWoWColor,
	["GetBattlefieldPosition"] = noIndentEffectWoWColor,
	["GetBattlefieldScore"] = noIndentEffectWoWColor,
	["GetBattlefieldStatData"] = noIndentEffectWoWColor,
	["GetBattlefieldStatInfo"] = noIndentEffectWoWColor,
	["GetBattlefieldStatus"] = noIndentEffectWoWColor,
	["GetBattlefieldTeamInfo"] = noIndentEffectWoWColor,
	["GetBattlefieldTimeWaited"] = noIndentEffectWoWColor,
	["GetBattlefieldVehicleInfo"] = noIndentEffectWoWColor,
	["GetBattlefieldWinner"] = noIndentEffectWoWColor,
	["GetBattlegroundInfo"] = noIndentEffectWoWColor,
	["GetBidderAuctionItems"] = noIndentEffectWoWColor,
	["GetBillingTimeRested"] = noIndentEffectWoWColor,
	["GetBindLocation"] = noIndentEffectWoWColor,
	["GetBinding"] = noIndentEffectWoWColor,
	["GetBindingAction"] = noIndentEffectWoWColor,
	["GetBindingByKey"] = noIndentEffectWoWColor,
	["GetBindingFromClick"] = noIndentEffectWoWColor,
	["GetBindingKey"] = noIndentEffectWoWColor,
	["GetBindingText"] = noIndentEffectWoWColor,
	["GetBlockChance"] = noIndentEffectWoWColor,
	["GetBonusBarOffset"] = noIndentEffectWoWColor,
	["GetBuildInfo"] = noIndentEffectWoWColor,
	["GetBuybackItemInfo"] = noIndentEffectWoWColor,
	["GetBuybackItemLink"] = noIndentEffectWoWColor,
	["GetCVar"] = noIndentEffectWoWColor,
	["GetCVarAbsoluteMax"] = noIndentEffectWoWColor,
	["GetCVarAbsoluteMin"] = noIndentEffectWoWColor,
	["GetCVarBool"] = noIndentEffectWoWColor,
	["GetCVarDefault"] = noIndentEffectWoWColor,
	["GetCVarInfo"] = noIndentEffectWoWColor,
	["GetCVarMax"] = noIndentEffectWoWColor,
	["GetCVarMin"] = noIndentEffectWoWColor,
	["GetCategoryInfo"] = noIndentEffectWoWColor,
	["GetCategoryList"] = noIndentEffectWoWColor,
	["GetCategoryNumAchievements"] = noIndentEffectWoWColor,
	["GetChannelDisplayInfo"] = noIndentEffectWoWColor,
	["GetChannelList"] = noIndentEffectWoWColor,
	["GetChannelName"] = noIndentEffectWoWColor,
	["GetChannelRosterInfo"] = noIndentEffectWoWColor,
	["GetChatTypeIndex"] = noIndentEffectWoWColor,
	["GetChatUnitColor"] = noIndentEffectWoWColor,
	["GetChatWindowChannels"] = noIndentEffectWoWColor,
	["GetChatWindowInfo"] = noIndentEffectWoWColor,
	["GetChatWindowMessages"] = noIndentEffectWoWColor,
	["GetChatWindowSavedDimensions"] = noIndentEffectWoWColor,
	["GetChatWindowSavedPosition"] = noIndentEffectWoWColor,
	["GetClickFrame"] = noIndentEffectWoWColor,
	["GetCoinIcon"] = noIndentEffectWoWColor,
	["GetCoinText"] = noIndentEffectWoWColor,
	["GetCoinTextureString"] = noIndentEffectWoWColor,
	["GetColoredName"] = noIndentEffectWoWColor,
	["GetCombatRating"] = noIndentEffectWoWColor,
	["GetCombatRatingBonus"] = noIndentEffectWoWColor,
	["GetComboPoints"] = noIndentEffectWoWColor,
	["GetCompanionCooldown"] = noIndentEffectWoWColor,
	["GetCompanionInfo"] = noIndentEffectWoWColor,
	["GetComparisonAchievementPoints"] = noIndentEffectWoWColor,
	["GetComparisonCategoryNumAchievements"] = noIndentEffectWoWColor,
	["GetComparisonStatistic"] = noIndentEffectWoWColor,
	["GetContainerFreeSlots"] = noIndentEffectWoWColor,
	["GetContainerItemCooldown"] = noIndentEffectWoWColor,
	["GetContainerItemDurability"] = noIndentEffectWoWColor,
	["GetContainerItemGems"] = noIndentEffectWoWColor,
	["GetContainerItemID"] = noIndentEffectWoWColor,
	["GetContainerItemInfo"] = noIndentEffectWoWColor,
	["GetContainerItemLink"] = noIndentEffectWoWColor,
	["GetContainerItemPurchaseInfo"] = noIndentEffectWoWColor,
	["GetContainerItemPurchaseItem"] = noIndentEffectWoWColor,
	["GetContainerItemQuestInfo"] = noIndentEffectWoWColor,
	["GetContainerNumFreeSlots"] = noIndentEffectWoWColor,
	["GetContainerNumSlots"] = noIndentEffectWoWColor,
	["GetCorpseMapPosition"] = noIndentEffectWoWColor,
	["GetCorpseRecoveryDelay"] = noIndentEffectWoWColor,
	["GetCritChance"] = noIndentEffectWoWColor,
	["GetCritChanceFromAgility"] = noIndentEffectWoWColor,
	["GetCurrencyListInfo"] = noIndentEffectWoWColor,
	["GetCurrencyListSize"] = noIndentEffectWoWColor,
	["GetCurrentArenaSeason"] = noIndentEffectWoWColor,
	["GetCurrentBindingSet"] = noIndentEffectWoWColor,
	["GetCurrentGuildBankTab"] = noIndentEffectWoWColor,
	["GetCurrentKeyBoardFocus"] = noIndentEffectWoWColor,
	["GetCurrentMapAreaID"] = noIndentEffectWoWColor,
	["GetCurrentMapContinent"] = noIndentEffectWoWColor,
	["GetCurrentMapDungeonLevel"] = noIndentEffectWoWColor,
	["GetCurrentMapZone"] = noIndentEffectWoWColor,
	["GetCurrentMultisampleFormat"] = noIndentEffectWoWColor,
	["GetCurrentResolution"] = noIndentEffectWoWColor,
	["GetCurrentTitle"] = noIndentEffectWoWColor,
	["GetCursorInfo"] = noIndentEffectWoWColor,
	["GetCursorMoney"] = noIndentEffectWoWColor,
	["GetCursorPosition"] = noIndentEffectWoWColor,
	["GetDailyQuestsCompleted"] = noIndentEffectWoWColor,
	["GetDamageBonusStat"] = noIndentEffectWoWColor,
	["GetDeathReleasePosition"] = noIndentEffectWoWColor,
	["GetDebugStats"] = noIndentEffectWoWColor,
	["GetDebugZoneMap"] = noIndentEffectWoWColor,
	["GetDefaultLanguage"] = noIndentEffectWoWColor,
	["GetDenominationsFromCopper"] = noIndentEffectWoWColor,
	["GetDodgeBlockParryChanceFromDefense"] = noIndentEffectWoWColor,
	["GetDodgeChance"] = noIndentEffectWoWColor,
	["GetDungeonDifficulty"] = noIndentEffectWoWColor,
	["GetDungeonNameWithDifficulty"] = noIndentEffectWoWColor,
	["GetEquipmentSetIconInfo"] = noIndentEffectWoWColor,
	["GetEquipmentSetInfo"] = noIndentEffectWoWColor,
	["GetEquipmentSetInfoByName"] = noIndentEffectWoWColor,
	["GetEquipmentSetItemIDs"] = noIndentEffectWoWColor,
	["GetEquipmentSetLocations"] = noIndentEffectWoWColor,
	["GetEventCPUUsage"] = noIndentEffectWoWColor,
	["GetExistingLocales"] = noIndentEffectWoWColor,
	["GetExistingSocketInfo"] = noIndentEffectWoWColor,
	["GetExistingSocketLink"] = noIndentEffectWoWColor,
	["GetExpansionLevel"] = noIndentEffectWoWColor,
	["GetExpertise"] = noIndentEffectWoWColor,
	["GetExpertisePercent"] = noIndentEffectWoWColor,
	["GetExtendedItemInfo"] = noIndentEffectWoWColor,
	["GetFacialHairCustomization"] = noIndentEffectWoWColor,
	["GetFactionInfo"] = noIndentEffectWoWColor,
	["GetFactionInfoByID"] = noIndentEffectWoWColor,
	["GetFarclip"] = noIndentEffectWoWColor,
	["GetFirstTradeSkill"] = noIndentEffectWoWColor,
	["GetFixedLink"] = noIndentEffectWoWColor,
	["GetFrameCPUUsage"] = noIndentEffectWoWColor,
	["GetFrameHandle"] = noIndentEffectWoWColor,
	["GetFrameHandleFrame"] = noIndentEffectWoWColor,
	["GetFramerate"] = noIndentEffectWoWColor,
	["GetFramesRegisteredForEvent"] = noIndentEffectWoWColor,
	["GetFriendInfo"] = noIndentEffectWoWColor,
	["GetFullRaidList"] = noIndentEffectWoWColor,
	["GetFunctionCPUUsage"] = noIndentEffectWoWColor,
	["GetGMStatus"] = noIndentEffectWoWColor,
	["GetGMTicket"] = noIndentEffectWoWColor,
	["GetGMTicketCategories"] = noIndentEffectWoWColor,
	["GetGameTime"] = noIndentEffectWoWColor,
	["GetGamma"] = noIndentEffectWoWColor,
	["GetGlyphLink"] = noIndentEffectWoWColor,
	["GetGlyphSocketInfo"] = noIndentEffectWoWColor,
	["GetGossipActiveQuests"] = noIndentEffectWoWColor,
	["GetGossipAvailableQuests"] = noIndentEffectWoWColor,
	["GetGossipOptions"] = noIndentEffectWoWColor,
	["GetGossipText"] = noIndentEffectWoWColor,
	["GetGreetingText"] = noIndentEffectWoWColor,
	["GetGroupPreviewTalentPointsSpent"] = noIndentEffectWoWColor,
	["GetGuildBankItemInfo"] = noIndentEffectWoWColor,
	["GetGuildBankItemLink"] = noIndentEffectWoWColor,
	["GetGuildBankMoney"] = noIndentEffectWoWColor,
	["GetGuildBankMoneyTransaction"] = noIndentEffectWoWColor,
	["GetGuildBankTabCost"] = noIndentEffectWoWColor,
	["GetGuildBankTabInfo"] = noIndentEffectWoWColor,
	["GetGuildBankTabPermissions"] = noIndentEffectWoWColor,
	["GetGuildBankText"] = noIndentEffectWoWColor,
	["GetGuildBankTransaction"] = noIndentEffectWoWColor,
	["GetGuildBankWithdrawLimit"] = noIndentEffectWoWColor,
	["GetGuildBankWithdrawMoney"] = noIndentEffectWoWColor,
	["GetGuildCharterCost"] = noIndentEffectWoWColor,
	["GetGuildEventInfo"] = noIndentEffectWoWColor,
	["GetGuildInfo"] = noIndentEffectWoWColor,
	["GetGuildInfoText"] = noIndentEffectWoWColor,
	["GetGuildRosterInfo"] = noIndentEffectWoWColor,
	["GetGuildRosterLastOnline"] = noIndentEffectWoWColor,
	["GetGuildRosterMOTD"] = noIndentEffectWoWColor,
	["GetGuildRosterSelection"] = noIndentEffectWoWColor,
	["GetGuildRosterShowOffline"] = noIndentEffectWoWColor,
	["GetGuildTabardFileNames"] = noIndentEffectWoWColor,
	["GetHairCustomization"] = noIndentEffectWoWColor,
	["GetHolidayBGHonorCurrencyBonuses"] = noIndentEffectWoWColor,
	["GetHonorCurrency"] = noIndentEffectWoWColor,
	["GetIgnoreName"] = noIndentEffectWoWColor,
	["GetInboxHeaderInfo"] = noIndentEffectWoWColor,
	["GetInboxInvoiceInfo"] = noIndentEffectWoWColor,
	["GetInboxItem"] = noIndentEffectWoWColor,
	["GetInboxItemLink"] = noIndentEffectWoWColor,
	["GetInboxNumItems"] = noIndentEffectWoWColor,
	["GetInboxText"] = noIndentEffectWoWColor,
	["GetInspectArenaTeamData"] = noIndentEffectWoWColor,
	["GetInspectHonorData"] = noIndentEffectWoWColor,
	["GetInstanceBootTimeRemaining"] = noIndentEffectWoWColor,
	["GetInstanceDifficulty"] = noIndentEffectWoWColor,
	["GetInstanceInfo"] = noIndentEffectWoWColor,
	["GetInstanceLockTimeRemaining"] = noIndentEffectWoWColor,
	["GetInstanceLockTimeRemainingEncounter"] = noIndentEffectWoWColor,
	["GetInventoryAlertStatus"] = noIndentEffectWoWColor,
	["GetInventoryItemBroken"] = noIndentEffectWoWColor,
	["GetInventoryItemCooldown"] = noIndentEffectWoWColor,
	["GetInventoryItemCount"] = noIndentEffectWoWColor,
	["GetInventoryItemDurability"] = noIndentEffectWoWColor,
	["GetInventoryItemGems"] = noIndentEffectWoWColor,
	["GetInventoryItemID"] = noIndentEffectWoWColor,
	["GetInventoryItemLink"] = noIndentEffectWoWColor,
	["GetInventoryItemQuality"] = noIndentEffectWoWColor,
	["GetInventoryItemTexture"] = noIndentEffectWoWColor,
	["GetInventoryItemsForSlot"] = noIndentEffectWoWColor,
	["GetInventorySlotInfo"] = noIndentEffectWoWColor,
	["GetItemCooldown"] = noIndentEffectWoWColor,
	["GetItemCount"] = noIndentEffectWoWColor,
	["GetItemFamily"] = noIndentEffectWoWColor,
	["GetItemGem"] = noIndentEffectWoWColor,
	["GetItemIcon"] = noIndentEffectWoWColor,
	["GetItemInfo"] = noIndentEffectWoWColor,
	["GetItemQualityColor"] = noIndentEffectWoWColor,
	["GetItemSpell"] = noIndentEffectWoWColor,
	["GetItemStatDelta"] = noIndentEffectWoWColor,
	["GetItemStats"] = noIndentEffectWoWColor,
	["GetItemUniqueness"] = noIndentEffectWoWColor,
	["GetKeyRingSize"] = noIndentEffectWoWColor,
	["GetKnownSlotFromHighestRankSlot"] = noIndentEffectWoWColor,
	["GetLFDChoiceCollapseState"] = noIndentEffectWoWColor,
	["GetLFDChoiceEnabledState"] = noIndentEffectWoWColor,
	["GetLFDChoiceInfo"] = noIndentEffectWoWColor,
	["GetLFDChoiceLockedState"] = noIndentEffectWoWColor,
	["GetLFDChoiceOrder"] = noIndentEffectWoWColor,
	["GetLFDLockInfo"] = noIndentEffectWoWColor,
	["GetLFDLockPlayerCount"] = noIndentEffectWoWColor,
	["GetLFGBootProposal"] = noIndentEffectWoWColor,
	["GetLFGCompletionReward"] = noIndentEffectWoWColor,
	["GetLFGCompletionRewardItem"] = noIndentEffectWoWColor,
	["GetLFGDeserterExpiration"] = noIndentEffectWoWColor,
	["GetLFGDungeonInfo"] = noIndentEffectWoWColor,
	["GetLFGDungeonRewardInfo"] = noIndentEffectWoWColor,
	["GetLFGDungeonRewardLink"] = noIndentEffectWoWColor,
	["GetLFGDungeonRewards"] = noIndentEffectWoWColor,
	["GetLFGInfoLocal"] = noIndentEffectWoWColor,
	["GetLFGInfoServer"] = noIndentEffectWoWColor,
	["GetLFGMode"] = noIndentEffectWoWColor,
	["GetLFGProposal"] = noIndentEffectWoWColor,
	["GetLFGProposalEncounter"] = noIndentEffectWoWColor,
	["GetLFGProposalMember"] = noIndentEffectWoWColor,
	["GetLFGQueueStats"] = noIndentEffectWoWColor,
	["GetLFGQueuedList"] = noIndentEffectWoWColor,
	["GetLFGRandomCooldownExpiration"] = noIndentEffectWoWColor,
	["GetLFGRandomDungeonInfo"] = noIndentEffectWoWColor,
	["GetLFGRoleUpdate"] = noIndentEffectWoWColor,
	["GetLFGRoleUpdateMember"] = noIndentEffectWoWColor,
	["GetLFGRoleUpdateSlot"] = noIndentEffectWoWColor,
	["GetLFGRoles"] = noIndentEffectWoWColor,
	["GetLFGTypes"] = noIndentEffectWoWColor,
	["GetLFRChoiceOrder"] = noIndentEffectWoWColor,
	["GetLanguageByIndex"] = noIndentEffectWoWColor,
	["GetLastQueueStatusIndex"] = noIndentEffectWoWColor,
	["GetLatestCompletedAchievements"] = noIndentEffectWoWColor,
	["GetLatestCompletedComparisonAchievements"] = noIndentEffectWoWColor,
	["GetLatestThreeSenders"] = noIndentEffectWoWColor,
	["GetLatestUpdatedComparisonStats"] = noIndentEffectWoWColor,
	["GetLatestUpdatedStats"] = noIndentEffectWoWColor,
	["GetLocale"] = noIndentEffectWoWColor,
	["GetLootMethod"] = noIndentEffectWoWColor,
	["GetLootRollItemInfo"] = noIndentEffectWoWColor,
	["GetLootRollItemLink"] = noIndentEffectWoWColor,
	["GetLootRollTimeLeft"] = noIndentEffectWoWColor,
	["GetLootSlotInfo"] = noIndentEffectWoWColor,
	["GetLootSlotLink"] = noIndentEffectWoWColor,
	["GetLootThreshold"] = noIndentEffectWoWColor,
	["GetMacroBody"] = noIndentEffectWoWColor,
	["GetMacroIconInfo"] = noIndentEffectWoWColor,
	["GetMacroIndexByName"] = noIndentEffectWoWColor,
	["GetMacroInfo"] = noIndentEffectWoWColor,
	["GetMacroItem"] = noIndentEffectWoWColor,
	["GetMacroItemIconInfo"] = noIndentEffectWoWColor,
	["GetMacroSpell"] = noIndentEffectWoWColor,
	["GetManaRegen"] = noIndentEffectWoWColor,
	["GetManagedEnvironment"] = noIndentEffectWoWColor,
	["GetMapContinents"] = noIndentEffectWoWColor,
	["GetMapDebugObjectInfo"] = noIndentEffectWoWColor,
	["GetMapInfo"] = noIndentEffectWoWColor,
	["GetMapLandmarkInfo"] = noIndentEffectWoWColor,
	["GetMapOverlayInfo"] = noIndentEffectWoWColor,
	["GetMapZones"] = noIndentEffectWoWColor,
	["GetMasterLootCandidate"] = noIndentEffectWoWColor,
	["GetMaterialTextColors"] = noIndentEffectWoWColor,
	["GetMaxArenaCurrency"] = noIndentEffectWoWColor,
	["GetMaxCombatRatingBonus"] = noIndentEffectWoWColor,
	["GetMaxDailyQuests"] = noIndentEffectWoWColor,
	["GetMaxUIPanelsWidth"] = noIndentEffectWoWColor,
	["GetMerchantItemCostInfo"] = noIndentEffectWoWColor,
	["GetMerchantItemCostItem"] = noIndentEffectWoWColor,
	["GetMerchantItemInfo"] = noIndentEffectWoWColor,
	["GetMerchantItemLink"] = noIndentEffectWoWColor,
	["GetMerchantItemMaxStack"] = noIndentEffectWoWColor,
	["GetMerchantNumItems"] = noIndentEffectWoWColor,
	["GetMessageTypeColor"] = noIndentEffectWoWColor,
	["GetMessageTypeState"] = noIndentEffectWoWColor,
	["GetMinigameState"] = noIndentEffectWoWColor,
	["GetMinigameType"] = noIndentEffectWoWColor,
	["GetMinimapZoneText"] = noIndentEffectWoWColor,
	["GetMirrorTimerInfo"] = noIndentEffectWoWColor,
	["GetMirrorTimerProgress"] = noIndentEffectWoWColor,
	["GetModifiedClick"] = noIndentEffectWoWColor,
	["GetModifiedClickAction"] = noIndentEffectWoWColor,
	["GetMoney"] = noIndentEffectWoWColor,
	["GetMoneyString"] = noIndentEffectWoWColor,
	["GetMouseButtonClicked"] = noIndentEffectWoWColor,
	["GetMouseButtonName"] = noIndentEffectWoWColor,
	["GetMouseFocus"] = noIndentEffectWoWColor,
	["GetMovieResolution"] = noIndentEffectWoWColor,
	["GetMultiCastBarOffset"] = noIndentEffectWoWColor,
	["GetMultiCastTotemSpells"] = noIndentEffectWoWColor,
	["GetMultisampleFormats"] = noIndentEffectWoWColor,
	["GetMuteName"] = noIndentEffectWoWColor,
	["GetMuteStatus"] = noIndentEffectWoWColor,
	["GetNetStats"] = noIndentEffectWoWColor,
	["GetNewSocketInfo"] = noIndentEffectWoWColor,
	["GetNewSocketLink"] = noIndentEffectWoWColor,
	["GetNextAchievement"] = noIndentEffectWoWColor,
	["GetNextCompleatedTutorial"] = noIndentEffectWoWColor,
	["GetNextStableSlotCost"] = noIndentEffectWoWColor,
	["GetNumActiveQuests"] = noIndentEffectWoWColor,
	["GetNumAddOns"] = noIndentEffectWoWColor,
	["GetNumArenaOpponents"] = noIndentEffectWoWColor,
	["GetNumArenaTeamMembers"] = noIndentEffectWoWColor,
	["GetNumAuctionItems"] = noIndentEffectWoWColor,
	["GetNumAvailableQuests"] = noIndentEffectWoWColor,
	["GetNumBankSlots"] = noIndentEffectWoWColor,
	["GetNumBattlefieldFlagPositions"] = noIndentEffectWoWColor,
	["GetNumBattlefieldPositions"] = noIndentEffectWoWColor,
	["GetNumBattlefieldScores"] = noIndentEffectWoWColor,
	["GetNumBattlefieldStats"] = noIndentEffectWoWColor,
	["GetNumBattlefieldVehicles"] = noIndentEffectWoWColor,
	["GetNumBattlefields"] = noIndentEffectWoWColor,
	["GetNumBattlegroundTypes"] = noIndentEffectWoWColor,
	["GetNumBindings"] = noIndentEffectWoWColor,
	["GetNumBuybackItems"] = noIndentEffectWoWColor,
	["GetNumChannelMembers"] = noIndentEffectWoWColor,
	["GetNumCompanions"] = noIndentEffectWoWColor,
	["GetNumComparisonCompletedAchievements"] = noIndentEffectWoWColor,
	["GetNumCompletedAchievements"] = noIndentEffectWoWColor,
	["GetNumDeclensionSets"] = noIndentEffectWoWColor,
	["GetNumDisplayChannels"] = noIndentEffectWoWColor,
	["GetNumDungeonMapLevels"] = noIndentEffectWoWColor,
	["GetNumEquipmentSets"] = noIndentEffectWoWColor,
	["GetNumFactions"] = noIndentEffectWoWColor,
	["GetNumFrames"] = noIndentEffectWoWColor,
	["GetNumFriends"] = noIndentEffectWoWColor,
	["GetNumGlyphSockets"] = noIndentEffectWoWColor,
	["GetNumGossipActiveQuests"] = noIndentEffectWoWColor,
	["GetNumGossipAvailableQuests"] = noIndentEffectWoWColor,
	["GetNumGossipOptions"] = noIndentEffectWoWColor,
	["GetNumGuildBankMoneyTransactions"] = noIndentEffectWoWColor,
	["GetNumGuildBankTabs"] = noIndentEffectWoWColor,
	["GetNumGuildBankTransactions"] = noIndentEffectWoWColor,
	["GetNumGuildEvents"] = noIndentEffectWoWColor,
	["GetNumGuildMembers"] = noIndentEffectWoWColor,
	["GetNumIgnores"] = noIndentEffectWoWColor,
	["GetNumLanguages"] = noIndentEffectWoWColor,
	["GetNumLootItems"] = noIndentEffectWoWColor,
	["GetNumMacroIcons"] = noIndentEffectWoWColor,
	["GetNumMacroItemIcons"] = noIndentEffectWoWColor,
	["GetNumMacros"] = noIndentEffectWoWColor,
	["GetNumMapDebugObjects"] = noIndentEffectWoWColor,
	["GetNumMapLandmarks"] = noIndentEffectWoWColor,
	["GetNumMapOverlays"] = noIndentEffectWoWColor,
	["GetNumModifiedClickActions"] = noIndentEffectWoWColor,
	["GetNumMutes"] = noIndentEffectWoWColor,
	["GetNumPackages"] = noIndentEffectWoWColor,
	["GetNumPartyMembers"] = noIndentEffectWoWColor,
	["GetNumPetitionItems"] = noIndentEffectWoWColor,
	["GetNumPetitionNames"] = noIndentEffectWoWColor,
	["GetNumQuestChoices"] = noIndentEffectWoWColor,
	["GetNumQuestItemDrops"] = noIndentEffectWoWColor,
	["GetNumQuestItems"] = noIndentEffectWoWColor,
	["GetNumQuestLeaderBoards"] = noIndentEffectWoWColor,
	["GetNumQuestLogChoices"] = noIndentEffectWoWColor,
	["GetNumQuestLogEntries"] = noIndentEffectWoWColor,
	["GetNumQuestLogRewardFactions"] = noIndentEffectWoWColor,
	["GetNumQuestLogRewards"] = noIndentEffectWoWColor,
	["GetNumQuestRewards"] = noIndentEffectWoWColor,
	["GetNumQuestWatches"] = noIndentEffectWoWColor,
	["GetNumRaidMembers"] = noIndentEffectWoWColor,
	["GetNumRandomDungeons"] = noIndentEffectWoWColor,
	["GetNumRoutes"] = noIndentEffectWoWColor,
	["GetNumSavedInstances"] = noIndentEffectWoWColor,
	["GetNumShapeshiftForms"] = noIndentEffectWoWColor,
	["GetNumSkillLines"] = noIndentEffectWoWColor,
	["GetNumSockets"] = noIndentEffectWoWColor,
	["GetNumSpellTabs"] = noIndentEffectWoWColor,
	["GetNumStablePets"] = noIndentEffectWoWColor,
	["GetNumStableSlots"] = noIndentEffectWoWColor,
	["GetNumStationeries"] = noIndentEffectWoWColor,
	["GetNumTalentGroups"] = noIndentEffectWoWColor,
	["GetNumTalentTabs"] = noIndentEffectWoWColor,
	["GetNumTalents"] = noIndentEffectWoWColor,
	["GetNumTitles"] = noIndentEffectWoWColor,
	["GetNumTrackedAchievements"] = noIndentEffectWoWColor,
	["GetNumTrackingTypes"] = noIndentEffectWoWColor,
	["GetNumTradeSkills"] = noIndentEffectWoWColor,
	["GetNumTrainerServices"] = noIndentEffectWoWColor,
	["GetNumVoiceSessionMembersBySessionID"] = noIndentEffectWoWColor,
	["GetNumVoiceSessions"] = noIndentEffectWoWColor,
	["GetNumWatchedTokens"] = noIndentEffectWoWColor,
	["GetNumWhoResults"] = noIndentEffectWoWColor,
	["GetNumWorldStateUI"] = noIndentEffectWoWColor,
	["GetObjectiveText"] = noIndentEffectWoWColor,
	["GetOptOutOfLoot"] = noIndentEffectWoWColor,
	["GetOwnerAuctionItems"] = noIndentEffectWoWColor,
	["GetPVPDesired"] = noIndentEffectWoWColor,
	["GetPVPLifetimeStats"] = noIndentEffectWoWColor,
	["GetPVPRankInfo"] = noIndentEffectWoWColor,
	["GetPVPRankProgress"] = noIndentEffectWoWColor,
	["GetPVPSessionStats"] = noIndentEffectWoWColor,
	["GetPVPTimer"] = noIndentEffectWoWColor,
	["GetPVPYesterdayStats"] = noIndentEffectWoWColor,
	["GetPackageInfo"] = noIndentEffectWoWColor,
	["GetParryChance"] = noIndentEffectWoWColor,
	["GetPartyAssignment"] = noIndentEffectWoWColor,
	["GetPartyLFGBackfillInfo"] = noIndentEffectWoWColor,
	["GetPartyLeaderIndex"] = noIndentEffectWoWColor,
	["GetPartyMember"] = noIndentEffectWoWColor,
	["GetPetActionCooldown"] = noIndentEffectWoWColor,
	["GetPetActionInfo"] = noIndentEffectWoWColor,
	["GetPetActionSlotUsable"] = noIndentEffectWoWColor,
	["GetPetActionsUsable"] = noIndentEffectWoWColor,
	["GetPetExperience"] = noIndentEffectWoWColor,
	["GetPetFoodTypes"] = noIndentEffectWoWColor,
	["GetPetHappiness"] = noIndentEffectWoWColor,
	["GetPetIcon"] = noIndentEffectWoWColor,
	["GetPetSpellBonusDamage"] = noIndentEffectWoWColor,
	["GetPetTalentTree"] = noIndentEffectWoWColor,
	["GetPetTimeRemaining"] = noIndentEffectWoWColor,
	["GetPetitionInfo"] = noIndentEffectWoWColor,
	["GetPetitionItemInfo"] = noIndentEffectWoWColor,
	["GetPetitionNameInfo"] = noIndentEffectWoWColor,
	["GetPlayerFacing"] = noIndentEffectWoWColor,
	["GetPlayerInfoByGUID"] = noIndentEffectWoWColor,
	["GetPlayerMapPosition"] = noIndentEffectWoWColor,
	["GetPlayerTradeMoney"] = noIndentEffectWoWColor,
	["GetPossessInfo"] = noIndentEffectWoWColor,
	["GetPowerRegen"] = noIndentEffectWoWColor,
	["GetPrevCompleatedTutorial"] = noIndentEffectWoWColor,
	["GetPreviewTalentPointsSpent"] = noIndentEffectWoWColor,
	["GetPreviousAchievement"] = noIndentEffectWoWColor,
	["GetPreviousArenaSeason"] = noIndentEffectWoWColor,
	["GetProgressText"] = noIndentEffectWoWColor,
	["GetQuestBackgroundMaterial"] = noIndentEffectWoWColor,
	["GetQuestDifficultyColor"] = noIndentEffectWoWColor,
	["GetQuestGreenRange"] = noIndentEffectWoWColor,
	["GetQuestIndexForTimer"] = noIndentEffectWoWColor,
	["GetQuestIndexForWatch"] = noIndentEffectWoWColor,
	["GetQuestItemInfo"] = noIndentEffectWoWColor,
	["GetQuestItemLink"] = noIndentEffectWoWColor,
	["GetQuestLink"] = noIndentEffectWoWColor,
	["GetQuestLogChoiceInfo"] = noIndentEffectWoWColor,
	["GetQuestLogCompletionText"] = noIndentEffectWoWColor,
	["GetQuestLogGroupNum"] = noIndentEffectWoWColor,
	["GetQuestLogItemDrop"] = noIndentEffectWoWColor,
	["GetQuestLogItemLink"] = noIndentEffectWoWColor,
	["GetQuestLogLeaderBoard"] = noIndentEffectWoWColor,
	["GetQuestLogPushable"] = noIndentEffectWoWColor,
	["GetQuestLogQuestText"] = noIndentEffectWoWColor,
	["GetQuestLogRequiredMoney"] = noIndentEffectWoWColor,
	["GetQuestLogRewardArenaPoints"] = noIndentEffectWoWColor,
	["GetQuestLogRewardFactionInfo"] = noIndentEffectWoWColor,
	["GetQuestLogRewardHonor"] = noIndentEffectWoWColor,
	["GetQuestLogRewardInfo"] = noIndentEffectWoWColor,
	["GetQuestLogRewardMoney"] = noIndentEffectWoWColor,
	["GetQuestLogRewardSpell"] = noIndentEffectWoWColor,
	["GetQuestLogRewardTalents"] = noIndentEffectWoWColor,
	["GetQuestLogRewardTitle"] = noIndentEffectWoWColor,
	["GetQuestLogRewardXP"] = noIndentEffectWoWColor,
	["GetQuestLogSelection"] = noIndentEffectWoWColor,
	["GetQuestLogSpecialItemCooldown"] = noIndentEffectWoWColor,
	["GetQuestLogSpecialItemInfo"] = noIndentEffectWoWColor,
	["GetQuestLogSpellLink"] = noIndentEffectWoWColor,
	["GetQuestLogTimeLeft"] = noIndentEffectWoWColor,
	["GetQuestLogTitle"] = noIndentEffectWoWColor,
	["GetQuestMoneyToGet"] = noIndentEffectWoWColor,
	["GetQuestPOILeaderBoard"] = noIndentEffectWoWColor,
	["GetQuestResetTime"] = noIndentEffectWoWColor,
	["GetQuestReward"] = noIndentEffectWoWColor,
	["GetQuestSortIndex"] = noIndentEffectWoWColor,
	["GetQuestSpellLink"] = noIndentEffectWoWColor,
	["GetQuestText"] = noIndentEffectWoWColor,
	["GetQuestTimers"] = noIndentEffectWoWColor,
	["GetQuestWatchIndex"] = noIndentEffectWoWColor,
	["GetQuestWorldMapAreaID"] = noIndentEffectWoWColor,
	["GetQuestsCompleted"] = noIndentEffectWoWColor,
	["GetRaidDifficulty"] = noIndentEffectWoWColor,
	["GetRaidRosterInfo"] = noIndentEffectWoWColor,
	["GetRaidRosterSelection"] = noIndentEffectWoWColor,
	["GetRaidTargetIndex"] = noIndentEffectWoWColor,
	["GetRandomArgument"] = noIndentEffectWoWColor,
	["GetRandomBGHonorCurrencyBonuses"] = noIndentEffectWoWColor,
	["GetRandomDungeonBestChoice"] = noIndentEffectWoWColor,
	["GetRangedCritChance"] = noIndentEffectWoWColor,
	["GetReadonlyRestrictedTable"] = noIndentEffectWoWColor,
	["GetReadyCheckStatus"] = noIndentEffectWoWColor,
	["GetReadyCheckTimeLeft"] = noIndentEffectWoWColor,
	["GetRealNumPartyMembers"] = noIndentEffectWoWColor,
	["GetRealNumRaidMembers"] = noIndentEffectWoWColor,
	["GetRealZoneText"] = noIndentEffectWoWColor,
	["GetRealmName"] = noIndentEffectWoWColor,
	["GetRefreshRates"] = noIndentEffectWoWColor,
	["GetReleaseTimeRemaining"] = noIndentEffectWoWColor,
	["GetRepairAllCost"] = noIndentEffectWoWColor,
	["GetResSicknessDuration"] = noIndentEffectWoWColor,
	["GetRestState"] = noIndentEffectWoWColor,
	["GetRewardArenaPoints"] = noIndentEffectWoWColor,
	["GetRewardHonor"] = noIndentEffectWoWColor,
	["GetRewardMoney"] = noIndentEffectWoWColor,
	["GetRewardSpell"] = noIndentEffectWoWColor,
	["GetRewardTalents"] = noIndentEffectWoWColor,
	["GetRewardText"] = noIndentEffectWoWColor,
	["GetRewardTitle"] = noIndentEffectWoWColor,
	["GetRewardXP"] = noIndentEffectWoWColor,
	["GetRuneCooldown"] = noIndentEffectWoWColor,
	["GetRuneCount"] = noIndentEffectWoWColor,
	["GetRuneType"] = noIndentEffectWoWColor,
	["GetRunningMacro"] = noIndentEffectWoWColor,
	["GetRunningMacroButton"] = noIndentEffectWoWColor,
	["GetSavedInstanceInfo"] = noIndentEffectWoWColor,
	["GetScreenHeight"] = noIndentEffectWoWColor,
	["GetScreenHeightScale"] = noIndentEffectWoWColor,
	["GetScreenResolutions"] = noIndentEffectWoWColor,
	["GetScreenWidth"] = noIndentEffectWoWColor,
	["GetScreenWidthScale"] = noIndentEffectWoWColor,
	["GetScriptCPUUsage"] = noIndentEffectWoWColor,
	["GetSelectedAuctionItem"] = noIndentEffectWoWColor,
	["GetSelectedBattlefield"] = noIndentEffectWoWColor,
	["GetSelectedDisplayChannel"] = noIndentEffectWoWColor,
	["GetSelectedFaction"] = noIndentEffectWoWColor,
	["GetSelectedFriend"] = noIndentEffectWoWColor,
	["GetSelectedIgnore"] = noIndentEffectWoWColor,
	["GetSelectedMute"] = noIndentEffectWoWColor,
	["GetSelectedSkill"] = noIndentEffectWoWColor,
	["GetSelectedStablePet"] = noIndentEffectWoWColor,
	["GetSelectedStationeryTexture"] = noIndentEffectWoWColor,
	["GetSendMailCOD"] = noIndentEffectWoWColor,
	["GetSendMailItem"] = noIndentEffectWoWColor,
	["GetSendMailItemLink"] = noIndentEffectWoWColor,
	["GetSendMailMoney"] = noIndentEffectWoWColor,
	["GetSendMailPrice"] = noIndentEffectWoWColor,
	["GetShapeshiftForm"] = noIndentEffectWoWColor,
	["GetShapeshiftFormCooldown"] = noIndentEffectWoWColor,
	["GetShapeshiftFormInfo"] = noIndentEffectWoWColor,
	["GetShieldBlock"] = noIndentEffectWoWColor,
	["GetSkillLineInfo"] = noIndentEffectWoWColor,
	["GetSocketItemBoundTradeable"] = noIndentEffectWoWColor,
	["GetSocketItemInfo"] = noIndentEffectWoWColor,
	["GetSocketItemRefundable"] = noIndentEffectWoWColor,
	["GetSocketTypes"] = noIndentEffectWoWColor,
	["GetSpellAutocast"] = noIndentEffectWoWColor,
	["GetSpellBonusDamage"] = noIndentEffectWoWColor,
	["GetSpellBonusHealing"] = noIndentEffectWoWColor,
	["GetSpellCooldown"] = noIndentEffectWoWColor,
	["GetSpellCount"] = noIndentEffectWoWColor,
	["GetSpellCritChance"] = noIndentEffectWoWColor,
	["GetSpellCritChanceFromIntellect"] = noIndentEffectWoWColor,
	["GetSpellInfo"] = noIndentEffectWoWColor,
	["GetSpellLink"] = noIndentEffectWoWColor,
	["GetSpellName"] = noIndentEffectWoWColor,
	["GetSpellNameColor"] = noIndentEffectWoWColor,
	["GetSpellPenetration"] = noIndentEffectWoWColor,
	["GetSpellTabInfo"] = noIndentEffectWoWColor,
	["GetSpellTexture"] = noIndentEffectWoWColor,
	["GetStablePetFoodTypes"] = noIndentEffectWoWColor,
	["GetStablePetInfo"] = noIndentEffectWoWColor,
	["GetStationeryInfo"] = noIndentEffectWoWColor,
	["GetStatistic"] = noIndentEffectWoWColor,
	["GetStatisticsCategoryList"] = noIndentEffectWoWColor,
	["GetSubZoneText"] = noIndentEffectWoWColor,
	["GetSuggestedGroupNum"] = noIndentEffectWoWColor,
	["GetSummonConfirmAreaName"] = noIndentEffectWoWColor,
	["GetSummonConfirmSummoner"] = noIndentEffectWoWColor,
	["GetSummonConfirmTimeLeft"] = noIndentEffectWoWColor,
	["GetSummonFriendCooldown"] = noIndentEffectWoWColor,
	["GetTabardCreationCost"] = noIndentEffectWoWColor,
	["GetTabardInfo"] = noIndentEffectWoWColor,
	["GetTableColor"] = noIndentEffectWoWColor,
	["GetTalentInfo"] = noIndentEffectWoWColor,
	["GetTalentLink"] = noIndentEffectWoWColor,
	["GetTalentPrereqs"] = noIndentEffectWoWColor,
	["GetTalentTabInfo"] = noIndentEffectWoWColor,
	["GetTargetTradeMoney"] = noIndentEffectWoWColor,
	["GetTaxiBenchmarkMode"] = noIndentEffectWoWColor,
	["GetTerrainMip"] = noIndentEffectWoWColor,
	["GetTexCoordsByGrid"] = noIndentEffectWoWColor,
	["GetTexCoordsForRole"] = noIndentEffectWoWColor,
	["GetTexLodBias"] = noIndentEffectWoWColor,
	["GetText"] = noIndentEffectWoWColor,
	["GetThreatStatusColor"] = noIndentEffectWoWColor,
	["GetTime"] = noIndentEffectWoWColor,
	["GetTimeToWellRested"] = noIndentEffectWoWColor,
	["GetTimerTextColor"] = noIndentEffectWoWColor,
	["GetTitleName"] = noIndentEffectWoWColor,
	["GetTitleText"] = noIndentEffectWoWColor,
	["GetTotalAchievementPoints"] = noIndentEffectWoWColor,
	["GetTotemInfo"] = noIndentEffectWoWColor,
	["GetTotemTimeLeft"] = noIndentEffectWoWColor,
	["GetTrackedAchievements"] = noIndentEffectWoWColor,
	["GetTrackingInfo"] = noIndentEffectWoWColor,
	["GetTrackingTexture"] = noIndentEffectWoWColor,
	["GetTradePlayerItemInfo"] = noIndentEffectWoWColor,
	["GetTradePlayerItemLink"] = noIndentEffectWoWColor,
	["GetTradeSkillCooldown"] = noIndentEffectWoWColor,
	["GetTradeSkillDescription"] = noIndentEffectWoWColor,
	["GetTradeSkillIcon"] = noIndentEffectWoWColor,
	["GetTradeSkillInfo"] = noIndentEffectWoWColor,
	["GetTradeSkillInvSlotFilter"] = noIndentEffectWoWColor,
	["GetTradeSkillInvSlots"] = noIndentEffectWoWColor,
	["GetTradeSkillItemLevelFilter"] = noIndentEffectWoWColor,
	["GetTradeSkillItemLink"] = noIndentEffectWoWColor,
	["GetTradeSkillItemNameFilter"] = noIndentEffectWoWColor,
	["GetTradeSkillLine"] = noIndentEffectWoWColor,
	["GetTradeSkillListLink"] = noIndentEffectWoWColor,
	["GetTradeSkillNumMade"] = noIndentEffectWoWColor,
	["GetTradeSkillNumReagents"] = noIndentEffectWoWColor,
	["GetTradeSkillReagentInfo"] = noIndentEffectWoWColor,
	["GetTradeSkillReagentItemLink"] = noIndentEffectWoWColor,
	["GetTradeSkillRecipeLink"] = noIndentEffectWoWColor,
	["GetTradeSkillSelectionIndex"] = noIndentEffectWoWColor,
	["GetTradeSkillSubClassFilter"] = noIndentEffectWoWColor,
	["GetTradeSkillSubClasses"] = noIndentEffectWoWColor,
	["GetTradeSkillTools"] = noIndentEffectWoWColor,
	["GetTradeTargetItemInfo"] = noIndentEffectWoWColor,
	["GetTradeTargetItemLink"] = noIndentEffectWoWColor,
	["GetTradeskillRepeatCount"] = noIndentEffectWoWColor,
	["GetTrainerGreetingText"] = noIndentEffectWoWColor,
	["GetTrainerSelectionIndex"] = noIndentEffectWoWColor,
	["GetTrainerServiceAbilityReq"] = noIndentEffectWoWColor,
	["GetTrainerServiceCost"] = noIndentEffectWoWColor,
	["GetTrainerServiceDescription"] = noIndentEffectWoWColor,
	["GetTrainerServiceIcon"] = noIndentEffectWoWColor,
	["GetTrainerServiceInfo"] = noIndentEffectWoWColor,
	["GetTrainerServiceItemLink"] = noIndentEffectWoWColor,
	["GetTrainerServiceLevelReq"] = noIndentEffectWoWColor,
	["GetTrainerServiceNumAbilityReq"] = noIndentEffectWoWColor,
	["GetTrainerServiceSkillLine"] = noIndentEffectWoWColor,
	["GetTrainerServiceSkillReq"] = noIndentEffectWoWColor,
	["GetTrainerServiceStepIncrease"] = noIndentEffectWoWColor,
	["GetTrainerServiceStepReq"] = noIndentEffectWoWColor,
	["GetTrainerServiceTypeFilter"] = noIndentEffectWoWColor,
	["GetTrainerSkillLineFilter"] = noIndentEffectWoWColor,
	["GetTrainerSkillLines"] = noIndentEffectWoWColor,
	["GetUIPanel"] = noIndentEffectWoWColor,
	["GetUIPanelWidth"] = noIndentEffectWoWColor,
	["GetUnitHealthModifier"] = noIndentEffectWoWColor,
	["GetUnitHealthRegenRateFromSpirit"] = noIndentEffectWoWColor,
	["GetUnitManaRegenRateFromSpirit"] = noIndentEffectWoWColor,
	["GetUnitMaxHealthModifier"] = noIndentEffectWoWColor,
	["GetUnitName"] = noIndentEffectWoWColor,
	["GetUnitPitch"] = noIndentEffectWoWColor,
	["GetUnitPowerModifier"] = noIndentEffectWoWColor,
	["GetUnitSpeed"] = noIndentEffectWoWColor,
	["GetUnspentTalentPoints"] = noIndentEffectWoWColor,
	["GetVehicleUIIndicator"] = noIndentEffectWoWColor,
	["GetVehicleUIIndicatorSeat"] = noIndentEffectWoWColor,
	["GetVideoCaps"] = noIndentEffectWoWColor,
	["GetVoiceCurrentSessionID"] = noIndentEffectWoWColor,
	["GetVoiceSessionInfo"] = noIndentEffectWoWColor,
	["GetVoiceSessionMemberInfoBySessionID"] = noIndentEffectWoWColor,
	["GetVoiceStatus"] = noIndentEffectWoWColor,
	["GetWatchedFactionInfo"] = noIndentEffectWoWColor,
	["GetWaterDetail"] = noIndentEffectWoWColor,
	["GetWeaponEnchantInfo"] = noIndentEffectWoWColor,
	["GetWhoInfo"] = noIndentEffectWoWColor,
	["GetWintergraspWaitTime"] = noIndentEffectWoWColor,
	["GetWorldPVPQueueStatus"] = noIndentEffectWoWColor,
	["GetWorldStateUIInfo"] = noIndentEffectWoWColor,
	["GetXPExhaustion"] = noIndentEffectWoWColor,
	["GetZonePVPInfo"] = noIndentEffectWoWColor,
	["GetZoneText"] = noIndentEffectWoWColor,
	["GiveMasterLoot"] = noIndentEffectWoWColor,
	["GlyphFrame_LoadUI"] = noIndentEffectWoWColor,
	["GlyphMatchesSocket"] = noIndentEffectWoWColor,
	["GossipFrameActiveQuestsUpdate"] = noIndentEffectWoWColor,
	["GossipFrameAvailableQuestsUpdate"] = noIndentEffectWoWColor,
	["GossipFrameOptionsUpdate"] = noIndentEffectWoWColor,
	["GossipFrameUpdate"] = noIndentEffectWoWColor,
	["GossipFrame_OnEvent"] = noIndentEffectWoWColor,
	["GossipFrame_OnLoad"] = noIndentEffectWoWColor,
	["GossipResize"] = noIndentEffectWoWColor,
	["GossipTitleButton_OnClick"] = noIndentEffectWoWColor,
	["GrantLevel"] = noIndentEffectWoWColor,
	["GroupLootDropDown_GiveLoot"] = noIndentEffectWoWColor,
	["GroupLootDropDown_Initialize"] = noIndentEffectWoWColor,
	["GroupLootDropDown_OnLoad"] = noIndentEffectWoWColor,
	["GroupLootFrame_DisableLootButton"] = noIndentEffectWoWColor,
	["GroupLootFrame_EnableLootButton"] = noIndentEffectWoWColor,
	["GroupLootFrame_OnEvent"] = noIndentEffectWoWColor,
	["GroupLootFrame_OnHide"] = noIndentEffectWoWColor,
	["GroupLootFrame_OnShow"] = noIndentEffectWoWColor,
	["GroupLootFrame_OnUpdate"] = noIndentEffectWoWColor,
	["GroupLootFrame_OpenNewFrame"] = noIndentEffectWoWColor,
	["GuildBankFrame_LoadUI"] = noIndentEffectWoWColor,
	["GuildBankTabPermissionsTab_OnClick"] = noIndentEffectWoWColor,
	["GuildControlAddRank"] = noIndentEffectWoWColor,
	["GuildControlCheckboxUpdate"] = noIndentEffectWoWColor,
	["GuildControlDelRank"] = noIndentEffectWoWColor,
	["GuildControlGetNumRanks"] = noIndentEffectWoWColor,
	["GuildControlGetRankFlags"] = noIndentEffectWoWColor,
	["GuildControlGetRankName"] = noIndentEffectWoWColor,
	["GuildControlPopupAcceptButton_OnClick"] = noIndentEffectWoWColor,
	["GuildControlPopupFrameAddRankButton_OnUpdate"] = noIndentEffectWoWColor,
	["GuildControlPopupFrameDropDownButton_OnClick"] = noIndentEffectWoWColor,
	["GuildControlPopupFrameDropDown_Initialize"] = noIndentEffectWoWColor,
	["GuildControlPopupFrameDropDown_OnLoad"] = noIndentEffectWoWColor,
	["GuildControlPopupFrameRemoveRankButton_OnClick"] = noIndentEffectWoWColor,
	["GuildControlPopupFrameRemoveRankButton_OnUpdate"] = noIndentEffectWoWColor,
	["GuildControlPopupFrame_Initialize"] = noIndentEffectWoWColor,
	["GuildControlPopupFrame_OnEvent"] = noIndentEffectWoWColor,
	["GuildControlPopupFrame_OnHide"] = noIndentEffectWoWColor,
	["GuildControlPopupFrame_OnLoad"] = noIndentEffectWoWColor,
	["GuildControlPopupFrame_OnShow"] = noIndentEffectWoWColor,
	["GuildControlPopup_UpdateDepositCheckBox"] = noIndentEffectWoWColor,
	["GuildControlPopupframe_Update"] = noIndentEffectWoWColor,
	["GuildControlSaveRank"] = noIndentEffectWoWColor,
	["GuildControlSetRank"] = noIndentEffectWoWColor,
	["GuildControlSetRankFlag"] = noIndentEffectWoWColor,
	["GuildDemote"] = noIndentEffectWoWColor,
	["GuildDisband"] = noIndentEffectWoWColor,
	["GuildEventLog_Update"] = noIndentEffectWoWColor,
	["GuildFrameControlButton_OnUpdate"] = noIndentEffectWoWColor,
	["GuildFrameGuildListToggleButton_OnClick"] = noIndentEffectWoWColor,
	["GuildFramePopup_HideAll"] = noIndentEffectWoWColor,
	["GuildFramePopup_Show"] = noIndentEffectWoWColor,
	["GuildFrame_GetLastOnline"] = noIndentEffectWoWColor,
	["GuildInfo"] = noIndentEffectWoWColor,
	["GuildInvite"] = noIndentEffectWoWColor,
	["GuildLeave"] = noIndentEffectWoWColor,
	["GuildPromote"] = noIndentEffectWoWColor,
	["GuildRegistrar_OnShow"] = noIndentEffectWoWColor,
	["GuildRegistrar_ShowPurchaseFrame"] = noIndentEffectWoWColor,
	["GuildRoster"] = noIndentEffectWoWColor,
	["GuildRosterSetOfficerNote"] = noIndentEffectWoWColor,
	["GuildRosterSetPublicNote"] = noIndentEffectWoWColor,
	["GuildSetLeader"] = noIndentEffectWoWColor,
	["GuildSetMOTD"] = noIndentEffectWoWColor,
	["GuildStatus_Update"] = noIndentEffectWoWColor,
	["GuildUninvite"] = noIndentEffectWoWColor,
	["HandleModifiedItemClick"] = noIndentEffectWoWColor,
	["HasAction"] = noIndentEffectWoWColor,
	["HasCompletedAnyAchievement"] = noIndentEffectWoWColor,
	["HasDebugZoneMap"] = noIndentEffectWoWColor,
	["HasFilledPetition"] = noIndentEffectWoWColor,
	["HasFullControl"] = noIndentEffectWoWColor,
	["HasInspectHonorData"] = noIndentEffectWoWColor,
	["HasKey"] = noIndentEffectWoWColor,
	["HasLFGRestrictions"] = noIndentEffectWoWColor,
	["HasMessageType"] = noIndentEffectWoWColor,
	["HasMessageTypeGroup"] = noIndentEffectWoWColor,
	["HasMultiCastActionBar"] = noIndentEffectWoWColor,
	["HasMultiCastActionPage"] = noIndentEffectWoWColor,
	["HasNewMail"] = noIndentEffectWoWColor,
	["HasPetSpells"] = noIndentEffectWoWColor,
	["HasPetUI"] = noIndentEffectWoWColor,
	["HasSoulstone"] = noIndentEffectWoWColor,
	["HasWandEquipped"] = noIndentEffectWoWColor,
	["HealthBar_OnValueChanged"] = noIndentEffectWoWColor,
	["HearthAndResurrectFromArea"] = noIndentEffectWoWColor,
	["HelpFrameGMTalk_OnShow"] = noIndentEffectWoWColor,
	["HelpFrameOpenTicketCancel_OnClick"] = noIndentEffectWoWColor,
	["HelpFrameOpenTicketSubmit_OnClick"] = noIndentEffectWoWColor,
	["HelpFrameReportIssue_OnShow"] = noIndentEffectWoWColor,
	["HelpFrameStuck_OnShow"] = noIndentEffectWoWColor,
	["HelpFrameViewResponseButton_OnLoad"] = noIndentEffectWoWColor,
	["HelpFrameViewResponseIssueResolved_OnClick"] = noIndentEffectWoWColor,
	["HelpFrameViewResponseMoreHelp_OnClick"] = noIndentEffectWoWColor,
	["HelpFrame_HaveGMResponse"] = noIndentEffectWoWColor,
	["HelpFrame_HaveGMTicket"] = noIndentEffectWoWColor,
	["HelpFrame_IsGMTicketQueueActive"] = noIndentEffectWoWColor,
	["HelpFrame_OnEvent"] = noIndentEffectWoWColor,
	["HelpFrame_OnHide"] = noIndentEffectWoWColor,
	["HelpFrame_OnLoad"] = noIndentEffectWoWColor,
	["HelpFrame_OnShow"] = noIndentEffectWoWColor,
	["HelpFrame_PopAllFrames"] = noIndentEffectWoWColor,
	["HelpFrame_PopFrame"] = noIndentEffectWoWColor,
	["HelpFrame_ShowFrame"] = noIndentEffectWoWColor,
	["HelpReportLag"] = noIndentEffectWoWColor,
	["HideBonusActionBar"] = noIndentEffectWoWColor,
	["HideDropDownMenu"] = noIndentEffectWoWColor,
	["HideMultiCastActionBar"] = noIndentEffectWoWColor,
	["HideParentPanel"] = noIndentEffectWoWColor,
	["HidePartyFrame"] = noIndentEffectWoWColor,
	["HidePetActionBar"] = noIndentEffectWoWColor,
	["HideRepairCursor"] = noIndentEffectWoWColor,
	["HideTextStatusBarText"] = noIndentEffectWoWColor,
	["HideUIPanel"] = noIndentEffectWoWColor,
	["HideWatchedReputationBarText"] = noIndentEffectWoWColor,
	["HonorFrame_OnEvent"] = noIndentEffectWoWColor,
	["HonorFrame_OnLoad"] = noIndentEffectWoWColor,
	["HonorFrame_Update"] = noIndentEffectWoWColor,
	["HybridScrollFrameScrollButton_OnClick"] = noIndentEffectWoWColor,
	["HybridScrollFrameScrollButton_OnUpdate"] = noIndentEffectWoWColor,
	["HybridScrollFrameScrollChild_OnLoad"] = noIndentEffectWoWColor,
	["HybridScrollFrame_CollapseButton"] = noIndentEffectWoWColor,
	["HybridScrollFrame_CreateButtons"] = noIndentEffectWoWColor,
	["HybridScrollFrame_ExpandButton"] = noIndentEffectWoWColor,
	["HybridScrollFrame_GetOffset"] = noIndentEffectWoWColor,
	["HybridScrollFrame_OnLoad"] = noIndentEffectWoWColor,
	["HybridScrollFrame_OnMouseWheel"] = noIndentEffectWoWColor,
	["HybridScrollFrame_OnValueChanged"] = noIndentEffectWoWColor,
	["HybridScrollFrame_SetOffset"] = noIndentEffectWoWColor,
	["HybridScrollFrame_Update"] = noIndentEffectWoWColor,
	["HybridScrollFrame_UpdateButtonStates"] = noIndentEffectWoWColor,
	["IgnoreList_SetHeader"] = noIndentEffectWoWColor,
	["IgnoreList_Update"] = noIndentEffectWoWColor,
	["InCinematic"] = noIndentEffectWoWColor,
	["InCombatLockdown"] = noIndentEffectWoWColor,
	["InGuildCheck"] = noIndentEffectWoWColor,
	["InRepairMode"] = noIndentEffectWoWColor,
	["InboxFrameItem_OnEnter"] = noIndentEffectWoWColor,
	["InboxFrame_OnClick"] = noIndentEffectWoWColor,
	["InboxFrame_OnModifiedClick"] = noIndentEffectWoWColor,
	["InboxFrame_Update"] = noIndentEffectWoWColor,
	["InboxGetMoreMail"] = noIndentEffectWoWColor,
	["InboxItemCanDelete"] = noIndentEffectWoWColor,
	["InboxNextPage"] = noIndentEffectWoWColor,
	["InboxPrevPage"] = noIndentEffectWoWColor,
	["InitWorldMapPing"] = noIndentEffectWoWColor,
	["InitiateRolePoll"] = noIndentEffectWoWColor,
	["InitiateTrade"] = noIndentEffectWoWColor,
	["InspectAchievements"] = noIndentEffectWoWColor,
	["InspectFrame_LoadUI"] = noIndentEffectWoWColor,
	["InspectUnit"] = noIndentEffectWoWColor,
	["InstanceLock_OnEnter"] = noIndentEffectWoWColor,
	["InteractUnit"] = noIndentEffectWoWColor,
	["InterfaceAddOnsList_Update"] = noIndentEffectWoWColor,
	["InterfaceCategoryList_Update"] = noIndentEffectWoWColor,
	["InterfaceOptionsActionBarsPanel_OnEvent"] = noIndentEffectWoWColor,
	["InterfaceOptionsActionBarsPanel_OnLoad"] = noIndentEffectWoWColor,
	["InterfaceOptionsBattlenetPanel_OnLoad"] = noIndentEffectWoWColor,
	["InterfaceOptionsBuffsPanel_OnEvent"] = noIndentEffectWoWColor,
	["InterfaceOptionsBuffsPanel_OnLoad"] = noIndentEffectWoWColor,
	["InterfaceOptionsCameraPanelStyleDropDown_Initialize"] = noIndentEffectWoWColor,
	["InterfaceOptionsCameraPanelStyleDropDown_OnClick"] = noIndentEffectWoWColor,
	["InterfaceOptionsCameraPanelStyleDropDown_OnEvent"] = noIndentEffectWoWColor,
	["InterfaceOptionsCameraPanel_OnEvent"] = noIndentEffectWoWColor,
	["InterfaceOptionsCameraPanel_OnLoad"] = noIndentEffectWoWColor,
	["InterfaceOptionsCombatPanelFocusCastKeyDropDown_Initialize"] = noIndentEffectWoWColor,
	["InterfaceOptionsCombatPanelFocusCastKeyDropDown_OnClick"] = noIndentEffectWoWColor,
	["InterfaceOptionsCombatPanelFocusCastKeyDropDown_OnEvent"] = noIndentEffectWoWColor,
	["InterfaceOptionsCombatPanelSelfCastKeyDropDown_Initialize"] = noIndentEffectWoWColor,
	["InterfaceOptionsCombatPanelSelfCastKeyDropDown_OnClick"] = noIndentEffectWoWColor,
	["InterfaceOptionsCombatPanelSelfCastKeyDropDown_OnEvent"] = noIndentEffectWoWColor,
	["InterfaceOptionsCombatPanelTOTDropDown_Initialize"] = noIndentEffectWoWColor,
	["InterfaceOptionsCombatPanelTOTDropDown_OnClick"] = noIndentEffectWoWColor,
	["InterfaceOptionsCombatPanelTOTDropDown_OnEvent"] = noIndentEffectWoWColor,
	["InterfaceOptionsCombatTextPanelFCTDropDown_Initialize"] = noIndentEffectWoWColor,
	["InterfaceOptionsCombatTextPanelFCTDropDown_OnClick"] = noIndentEffectWoWColor,
	["InterfaceOptionsCombatTextPanelFCTDropDown_OnEvent"] = noIndentEffectWoWColor,
	["InterfaceOptionsCombatTextPanel_OnEvent"] = noIndentEffectWoWColor,
	["InterfaceOptionsCombatTextPanel_OnLoad"] = noIndentEffectWoWColor,
	["InterfaceOptionsControlsPanelAutoLootKeyDropDown_Initialize"] = noIndentEffectWoWColor,
	["InterfaceOptionsControlsPanelAutoLootKeyDropDown_OnClick"] = noIndentEffectWoWColor,
	["InterfaceOptionsControlsPanelAutoLootKeyDropDown_OnEvent"] = noIndentEffectWoWColor,
	["InterfaceOptionsControlsPanelAutoLootKeyDropDown_Update"] = noIndentEffectWoWColor,
	["InterfaceOptionsDisplayPanelAggroWarningDisplay_Initialize"] = noIndentEffectWoWColor,
	["InterfaceOptionsDisplayPanelAggroWarningDisplay_OnClick"] = noIndentEffectWoWColor,
	["InterfaceOptionsDisplayPanelAggroWarningDisplay_OnEvent"] = noIndentEffectWoWColor,
	["InterfaceOptionsDisplayPanelPreviewTalentChanges_SetFunc"] = noIndentEffectWoWColor,
	["InterfaceOptionsDisplayPanelShowAggroPercentage_SetFunc"] = noIndentEffectWoWColor,
	["InterfaceOptionsDisplayPanelShowClock_SetFunc"] = noIndentEffectWoWColor,
	["InterfaceOptionsDisplayPanelWorldPVPObjectiveDisplay_Initialize"] = noIndentEffectWoWColor,
	["InterfaceOptionsDisplayPanelWorldPVPObjectiveDisplay_OnClick"] = noIndentEffectWoWColor,
	["InterfaceOptionsDisplayPanelWorldPVPObjectiveDisplay_OnEvent"] = noIndentEffectWoWColor,
	["InterfaceOptionsDisplayPanel_OnEvent"] = noIndentEffectWoWColor,
	["InterfaceOptionsDisplayPanel_OnLoad"] = noIndentEffectWoWColor,
	["InterfaceOptionsFrameCancel_OnClick"] = noIndentEffectWoWColor,
	["InterfaceOptionsFrameDefaults_OnClick"] = noIndentEffectWoWColor,
	["InterfaceOptionsFrameOkay_OnClick"] = noIndentEffectWoWColor,
	["InterfaceOptionsFrame_InitializeUVars"] = noIndentEffectWoWColor,
	["InterfaceOptionsFrame_LoadUVars"] = noIndentEffectWoWColor,
	["InterfaceOptionsFrame_OnEvent"] = noIndentEffectWoWColor,
	["InterfaceOptionsFrame_OnHide"] = noIndentEffectWoWColor,
	["InterfaceOptionsFrame_OnLoad"] = noIndentEffectWoWColor,
	["InterfaceOptionsFrame_OnShow"] = noIndentEffectWoWColor,
	["InterfaceOptionsFrame_OpenToCategory"] = noIndentEffectWoWColor,
	["InterfaceOptionsFrame_SetAllToDefaults"] = noIndentEffectWoWColor,
	["InterfaceOptionsFrame_SetCurrentToDefaults"] = noIndentEffectWoWColor,
	["InterfaceOptionsFrame_Show"] = noIndentEffectWoWColor,
	["InterfaceOptionsFrame_TabOnClick"] = noIndentEffectWoWColor,
	["InterfaceOptionsLanguagesPanelLocaleDropDown_Initialize"] = noIndentEffectWoWColor,
	["InterfaceOptionsLanguagesPanelLocaleDropDown_InitializeHelper"] = noIndentEffectWoWColor,
	["InterfaceOptionsLanguagesPanelLocaleDropDown_OnClick"] = noIndentEffectWoWColor,
	["InterfaceOptionsLanguagesPanelLocaleDropDown_OnEvent"] = noIndentEffectWoWColor,
	["InterfaceOptionsLanguagesPanel_OnLoad"] = noIndentEffectWoWColor,
	["InterfaceOptionsListButton_OnClick"] = noIndentEffectWoWColor,
	["InterfaceOptionsListButton_ToggleSubCategories"] = noIndentEffectWoWColor,
	["InterfaceOptionsList_DisplayPanel"] = noIndentEffectWoWColor,
	["InterfaceOptionsMousePanelClickMoveStyleDropDown_Initialize"] = noIndentEffectWoWColor,
	["InterfaceOptionsMousePanelClickMoveStyleDropDown_OnClick"] = noIndentEffectWoWColor,
	["InterfaceOptionsMousePanelClickMoveStyleDropDown_OnEvent"] = noIndentEffectWoWColor,
	["InterfaceOptionsObjectivesPanel_OnEvent"] = noIndentEffectWoWColor,
	["InterfaceOptionsObjectivesPanel_OnLoad"] = noIndentEffectWoWColor,
	["InterfaceOptionsOptionsFrame_RefreshAddOns"] = noIndentEffectWoWColor,
	["InterfaceOptionsOptionsFrame_RefreshCategories"] = noIndentEffectWoWColor,
	["InterfaceOptionsPanel_CheckButton_OnClick"] = noIndentEffectWoWColor,
	["InterfaceOptionsPanel_CheckButton_Update"] = noIndentEffectWoWColor,
	["InterfaceOptionsPanel_OnLoad"] = noIndentEffectWoWColor,
	["InterfaceOptionsSocialPanelChatMouseScroll_SetScrolling"] = noIndentEffectWoWColor,
	["InterfaceOptionsSocialPanelChatStyle_Initialize"] = noIndentEffectWoWColor,
	["InterfaceOptionsSocialPanelChatStyle_OnClick"] = noIndentEffectWoWColor,
	["InterfaceOptionsSocialPanelChatStyle_OnEvent"] = noIndentEffectWoWColor,
	["InterfaceOptionsSocialPanelChatStyle_SetChatStyle"] = noIndentEffectWoWColor,
	["InterfaceOptionsSocialPanelConversationMode_Initialize"] = noIndentEffectWoWColor,
	["InterfaceOptionsSocialPanelConversationMode_OnClick"] = noIndentEffectWoWColor,
	["InterfaceOptionsSocialPanelConversationMode_OnEvent"] = noIndentEffectWoWColor,
	["InterfaceOptionsSocialPanelProfanityFilter_SyncWithBattlenet"] = noIndentEffectWoWColor,
	["InterfaceOptionsSocialPanelProfanityFilter_UpdateDisplay"] = noIndentEffectWoWColor,
	["InterfaceOptionsSocialPanelTimestamps_AddTimestampFormat"] = noIndentEffectWoWColor,
	["InterfaceOptionsSocialPanelTimestamps_Initialize"] = noIndentEffectWoWColor,
	["InterfaceOptionsSocialPanelTimestamps_OnClick"] = noIndentEffectWoWColor,
	["InterfaceOptionsSocialPanelTimestamps_OnEvent"] = noIndentEffectWoWColor,
	["InterfaceOptionsSocialPanel_OnEvent"] = noIndentEffectWoWColor,
	["InterfaceOptionsSocialPanel_OnLoad"] = noIndentEffectWoWColor,
	["InterfaceOptions_AddCategory"] = noIndentEffectWoWColor,
	["InterfaceOptions_UpdateMultiActionBars"] = noIndentEffectWoWColor,
	["InviteUnit"] = noIndentEffectWoWColor,
	["IsActionInRange"] = noIndentEffectWoWColor,
	["IsActiveBattlefieldArena"] = noIndentEffectWoWColor,
	["IsActiveQuestTrivial"] = noIndentEffectWoWColor,
	["IsAddOnLoadOnDemand"] = noIndentEffectWoWColor,
	["IsAddOnLoaded"] = noIndentEffectWoWColor,
	["IsAlreadyInQueue"] = noIndentEffectWoWColor,
	["IsAltKeyDown"] = noIndentEffectWoWColor,
	["IsArenaTeamCaptain"] = noIndentEffectWoWColor,
	["IsAtStableMaster"] = noIndentEffectWoWColor,
	["IsAttackAction"] = noIndentEffectWoWColor,
	["IsAttackSpell"] = noIndentEffectWoWColor,
	["IsAuctionSortReversed"] = noIndentEffectWoWColor,
	["IsAutoRepeatAction"] = noIndentEffectWoWColor,
	["IsAutoRepeatSpell"] = noIndentEffectWoWColor,
	["IsAvailableQuestTrivial"] = noIndentEffectWoWColor,
	["IsBNLogin"] = noIndentEffectWoWColor,
	["IsBagOpen"] = noIndentEffectWoWColor,
	["IsBattlefieldArena"] = noIndentEffectWoWColor,
	["IsClassColoringMessageType"] = noIndentEffectWoWColor,
	["IsCombatLog"] = noIndentEffectWoWColor,
	["IsConsumableAction"] = noIndentEffectWoWColor,
	["IsConsumableItem"] = noIndentEffectWoWColor,
	["IsConsumableSpell"] = noIndentEffectWoWColor,
	["IsControlKeyDown"] = noIndentEffectWoWColor,
	["IsCurrentAction"] = noIndentEffectWoWColor,
	["IsCurrentItem"] = noIndentEffectWoWColor,
	["IsCurrentQuestFailed"] = noIndentEffectWoWColor,
	["IsCurrentSpell"] = noIndentEffectWoWColor,
	["IsDebugBuild"] = noIndentEffectWoWColor,
	["IsDesaturateSupported"] = noIndentEffectWoWColor,
	["IsDisplayChannelModerator"] = noIndentEffectWoWColor,
	["IsDisplayChannelOwner"] = noIndentEffectWoWColor,
	["IsDressableItem"] = noIndentEffectWoWColor,
	["IsEquippableItem"] = noIndentEffectWoWColor,
	["IsEquippedAction"] = noIndentEffectWoWColor,
	["IsEquippedItem"] = noIndentEffectWoWColor,
	["IsEquippedItemType"] = noIndentEffectWoWColor,
	["IsFactionInactive"] = noIndentEffectWoWColor,
	["IsFalling"] = noIndentEffectWoWColor,
	["IsFishingLoot"] = noIndentEffectWoWColor,
	["IsFlyableArea"] = noIndentEffectWoWColor,
	["IsFlying"] = noIndentEffectWoWColor,
	["IsFrameHandle"] = noIndentEffectWoWColor,
	["IsGuildLeader"] = noIndentEffectWoWColor,
	["IsHarmfulItem"] = noIndentEffectWoWColor,
	["IsHarmfulSpell"] = noIndentEffectWoWColor,
	["IsHelpfulItem"] = noIndentEffectWoWColor,
	["IsHelpfulSpell"] = noIndentEffectWoWColor,
	["IsIgnored"] = noIndentEffectWoWColor,
	["IsIgnoredOrMuted"] = noIndentEffectWoWColor,
	["IsInArenaTeam"] = noIndentEffectWoWColor,
	["IsInGuild"] = noIndentEffectWoWColor,
	["IsInInstance"] = noIndentEffectWoWColor,
	["IsInLFGDungeon"] = noIndentEffectWoWColor,
	["IsIndoors"] = noIndentEffectWoWColor,
	["IsInventoryItemLocked"] = noIndentEffectWoWColor,
	["IsItemInRange"] = noIndentEffectWoWColor,
	["IsLFGDungeonJoinable"] = noIndentEffectWoWColor,
	["IsLeftAltKeyDown"] = noIndentEffectWoWColor,
	["IsLeftControlKeyDown"] = noIndentEffectWoWColor,
	["IsLeftShiftKeyDown"] = noIndentEffectWoWColor,
	["IsLinuxClient"] = noIndentEffectWoWColor,
	["IsListedInLFR"] = noIndentEffectWoWColor,
	["IsListeningForMessageType"] = noIndentEffectWoWColor,
	["IsLoggedIn"] = noIndentEffectWoWColor,
	["IsMacClient"] = noIndentEffectWoWColor,
	["IsMessageDoneBy"] = noIndentEffectWoWColor,
	["IsMessageDoneTo"] = noIndentEffectWoWColor,
	["IsModifiedClick"] = noIndentEffectWoWColor,
	["IsModifierKeyDown"] = noIndentEffectWoWColor,
	["IsMounted"] = noIndentEffectWoWColor,
	["IsMouseButtonDown"] = noIndentEffectWoWColor,
	["IsMouselooking"] = noIndentEffectWoWColor,
	["IsMuted"] = noIndentEffectWoWColor,
	["IsOptionFrameOpen"] = noIndentEffectWoWColor,
	["IsOutOfBounds"] = noIndentEffectWoWColor,
	["IsOutdoors"] = noIndentEffectWoWColor,
	["IsPVPTimerRunning"] = noIndentEffectWoWColor,
	["IsPartyLFG"] = noIndentEffectWoWColor,
	["IsPartyLeader"] = noIndentEffectWoWColor,
	["IsPassiveSpell"] = noIndentEffectWoWColor,
	["IsPetAttackAction"] = noIndentEffectWoWColor,
	["IsPetAttackActive"] = noIndentEffectWoWColor,
	["IsPlayerResolutionAvailable"] = noIndentEffectWoWColor,
	["IsPossessBarVisible"] = noIndentEffectWoWColor,
	["IsQuestCompletable"] = noIndentEffectWoWColor,
	["IsQuestFlaggedCompleted"] = noIndentEffectWoWColor,
	["IsQuestLogSpecialItemInRange"] = noIndentEffectWoWColor,
	["IsQuestWatched"] = noIndentEffectWoWColor,
	["IsRaidLeader"] = noIndentEffectWoWColor,
	["IsRaidOfficer"] = noIndentEffectWoWColor,
	["IsRealPartyLeader"] = noIndentEffectWoWColor,
	["IsRealRaidLeader"] = noIndentEffectWoWColor,
	["IsReferAFriendLinked"] = noIndentEffectWoWColor,
	["IsResting"] = noIndentEffectWoWColor,
	["IsRightAltKeyDown"] = noIndentEffectWoWColor,
	["IsRightControlKeyDown"] = noIndentEffectWoWColor,
	["IsRightShiftKeyDown"] = noIndentEffectWoWColor,
	["IsSecureCmd"] = noIndentEffectWoWColor,
	["IsSelectedSpell"] = noIndentEffectWoWColor,
	["IsShiftKeyDown"] = noIndentEffectWoWColor,
	["IsSilenced"] = noIndentEffectWoWColor,
	["IsSpellInRange"] = noIndentEffectWoWColor,
	["IsSpellKnown"] = noIndentEffectWoWColor,
	["IsStackableAction"] = noIndentEffectWoWColor,
	["IsStealthed"] = noIndentEffectWoWColor,
	["IsStereoVideoAvailable"] = noIndentEffectWoWColor,
	["IsSubZonePVPPOI"] = noIndentEffectWoWColor,
	["IsSwimming"] = noIndentEffectWoWColor,
	["IsThreatWarningEnabled"] = noIndentEffectWoWColor,
	["IsTitleKnown"] = noIndentEffectWoWColor,
	["IsTrackedAchievement"] = noIndentEffectWoWColor,
	["IsTradeSkillLinked"] = noIndentEffectWoWColor,
	["IsTradeskillTrainer"] = noIndentEffectWoWColor,
	["IsTrainerServiceSkillStep"] = noIndentEffectWoWColor,
	["IsTutorialFlagged"] = noIndentEffectWoWColor,
	["IsUnitOnQuest"] = noIndentEffectWoWColor,
	["IsUsableAction"] = noIndentEffectWoWColor,
	["IsUsableItem"] = noIndentEffectWoWColor,
	["IsUsableSpell"] = noIndentEffectWoWColor,
	["IsUsingVehicleControls"] = noIndentEffectWoWColor,
	["IsVehicleAimAngleAdjustable"] = noIndentEffectWoWColor,
	["IsVehicleAimPowerAdjustable"] = noIndentEffectWoWColor,
	["IsVoiceChatAllowed"] = noIndentEffectWoWColor,
	["IsVoiceChatAllowedByServer"] = noIndentEffectWoWColor,
	["IsVoiceChatEnabled"] = noIndentEffectWoWColor,
	["IsWindowsClient"] = noIndentEffectWoWColor,
	["IsXPUserDisabled"] = noIndentEffectWoWColor,
	["IsZoomOutAvailable"] = noIndentEffectWoWColor,
	["ItemAnim_OnAnimFinished"] = noIndentEffectWoWColor,
	["ItemAnim_OnEvent"] = noIndentEffectWoWColor,
	["ItemAnim_OnLoad"] = noIndentEffectWoWColor,
	["ItemHasRange"] = noIndentEffectWoWColor,
	["ItemSocketingFrame_LoadUI"] = noIndentEffectWoWColor,
	["ItemTextFrame_OnEvent"] = noIndentEffectWoWColor,
	["ItemTextFrame_OnLoad"] = noIndentEffectWoWColor,
	["ItemTextFrame_OnUpdate"] = noIndentEffectWoWColor,
	["ItemTextGetCreator"] = noIndentEffectWoWColor,
	["ItemTextGetItem"] = noIndentEffectWoWColor,
	["ItemTextGetMaterial"] = noIndentEffectWoWColor,
	["ItemTextGetPage"] = noIndentEffectWoWColor,
	["ItemTextGetText"] = noIndentEffectWoWColor,
	["ItemTextHasNextPage"] = noIndentEffectWoWColor,
	["ItemTextNextPage"] = noIndentEffectWoWColor,
	["ItemTextPrevPage"] = noIndentEffectWoWColor,
	["JoinBattlefield"] = noIndentEffectWoWColor,
	["JoinChannelByName"] = noIndentEffectWoWColor,
	["JoinLFG"] = noIndentEffectWoWColor,
	["JoinPermanentChannel"] = noIndentEffectWoWColor,
	["JoinTemporaryChannel"] = noIndentEffectWoWColor,
	["JumpOrAscendStart"] = noIndentEffectWoWColor,
	["KBArticle_BeginLoading"] = noIndentEffectWoWColor,
	["KBArticle_GetData"] = noIndentEffectWoWColor,
	["KBArticle_IsLoaded"] = noIndentEffectWoWColor,
	["KBQuery_BeginLoading"] = noIndentEffectWoWColor,
	["KBQuery_GetArticleHeaderCount"] = noIndentEffectWoWColor,
	["KBQuery_GetArticleHeaderData"] = noIndentEffectWoWColor,
	["KBQuery_GetTotalArticleCount"] = noIndentEffectWoWColor,
	["KBQuery_IsLoaded"] = noIndentEffectWoWColor,
	["KBSetup_BeginLoading"] = noIndentEffectWoWColor,
	["KBSetup_GetArticleHeaderCount"] = noIndentEffectWoWColor,
	["KBSetup_GetArticleHeaderData"] = noIndentEffectWoWColor,
	["KBSetup_GetCategoryCount"] = noIndentEffectWoWColor,
	["KBSetup_GetCategoryData"] = noIndentEffectWoWColor,
	["KBSetup_GetLanguageCount"] = noIndentEffectWoWColor,
	["KBSetup_GetLanguageData"] = noIndentEffectWoWColor,
	["KBSetup_GetSubCategoryCount"] = noIndentEffectWoWColor,
	["KBSetup_GetSubCategoryData"] = noIndentEffectWoWColor,
	["KBSetup_GetTotalArticleCount"] = noIndentEffectWoWColor,
	["KBSetup_IsLoaded"] = noIndentEffectWoWColor,
	["KBSystem_GetMOTD"] = noIndentEffectWoWColor,
	["KBSystem_GetServerNotice"] = noIndentEffectWoWColor,
	["KBSystem_GetServerStatus"] = noIndentEffectWoWColor,
	["KeyBindingFrame_LoadUI"] = noIndentEffectWoWColor,
	["KeyRingButtonIDToInvSlotID"] = noIndentEffectWoWColor,
	["KnowledgeBaseArticleListFrame_HideArticleList"] = noIndentEffectWoWColor,
	["KnowledgeBaseArticleListFrame_NextPage"] = noIndentEffectWoWColor,
	["KnowledgeBaseArticleListFrame_PopulateArticleList"] = noIndentEffectWoWColor,
	["KnowledgeBaseArticleListFrame_PreviousPage"] = noIndentEffectWoWColor,
	["KnowledgeBaseArticleListItem_OnClick"] = noIndentEffectWoWColor,
	["KnowledgeBaseArticleListItem_OnEnter"] = noIndentEffectWoWColor,
	["KnowledgeBaseArticleListItem_OnLeave"] = noIndentEffectWoWColor,
	["KnowledgeBaseArticleListItem_OnUpdate"] = noIndentEffectWoWColor,
	["KnowledgeBaseArticleListItem_Update"] = noIndentEffectWoWColor,
	["KnowledgeBaseErrorFrame_SetErrorMessage"] = noIndentEffectWoWColor,
	["KnowledgeBaseFrameCategoryButton_OnClick"] = noIndentEffectWoWColor,
	["KnowledgeBaseFrameCategoryDropDown_AddInfo"] = noIndentEffectWoWColor,
	["KnowledgeBaseFrameCategoryDropDown_Initialize"] = noIndentEffectWoWColor,
	["KnowledgeBaseFrameCategoryDropDown_OnLoad"] = noIndentEffectWoWColor,
	["KnowledgeBaseFrameSubCategoryButton_OnClick"] = noIndentEffectWoWColor,
	["KnowledgeBaseFrameSubCategoryDropDown_AddInfo"] = noIndentEffectWoWColor,
	["KnowledgeBaseFrameSubCategoryDropDown_Initialize"] = noIndentEffectWoWColor,
	["KnowledgeBaseFrameSubCategoryDropDown_OnLoad"] = noIndentEffectWoWColor,
	["KnowledgeBaseFrame_DisableButtons"] = noIndentEffectWoWColor,
	["KnowledgeBaseFrame_EnableButtons"] = noIndentEffectWoWColor,
	["KnowledgeBaseFrame_LoadTopIssues"] = noIndentEffectWoWColor,
	["KnowledgeBaseFrame_OnEvent"] = noIndentEffectWoWColor,
	["KnowledgeBaseFrame_OnLoad"] = noIndentEffectWoWColor,
	["KnowledgeBaseFrame_OnShow"] = noIndentEffectWoWColor,
	["KnowledgeBaseFrame_Search"] = noIndentEffectWoWColor,
	["KnowledgeBaseFrame_ShowArticleFrame"] = noIndentEffectWoWColor,
	["KnowledgeBaseFrame_ShowErrorFrame"] = noIndentEffectWoWColor,
	["KnowledgeBaseFrame_ShowSearchFrame"] = noIndentEffectWoWColor,
	["KnowledgeBaseFrame_UpdateMotd"] = noIndentEffectWoWColor,
	["KnowledgeBaseFrame_UpdateServerMessage"] = noIndentEffectWoWColor,
	["KnowledgeBaseMotdTextFrame_OnEnter"] = noIndentEffectWoWColor,
	["KnowledgeBaseMotdTextFrame_OnLeave"] = noIndentEffectWoWColor,
	["KnowledgeBaseMotdTextFrame_OnUpdate"] = noIndentEffectWoWColor,
	["KnowledgeBaseServerMessageTextFrame_OnEnter"] = noIndentEffectWoWColor,
	["KnowledgeBaseServerMessageTextFrame_OnLeave"] = noIndentEffectWoWColor,
	["KnowledgeBaseServerMessageTextFrame_OnUpdate"] = noIndentEffectWoWColor,
	["KnowledgeBaseUpdateTopPanelPositions"] = noIndentEffectWoWColor,
	["LFDConstructDeclinedMessage"] = noIndentEffectWoWColor,
	["LFDDungeonReadyDialogInstanceInfo_OnEnter"] = noIndentEffectWoWColor,
	["LFDDungeonReadyDialogReward_OnEnter"] = noIndentEffectWoWColor,
	["LFDDungeonReadyDialogReward_SetMisc"] = noIndentEffectWoWColor,
	["LFDDungeonReadyDialogReward_SetReward"] = noIndentEffectWoWColor,
	["LFDDungeonReadyDialog_UpdateInstanceInfo"] = noIndentEffectWoWColor,
	["LFDDungeonReadyDialog_UpdateRewards"] = noIndentEffectWoWColor,
	["LFDDungeonReadyPopup_OnFail"] = noIndentEffectWoWColor,
	["LFDDungeonReadyPopup_OnUpdate"] = noIndentEffectWoWColor,
	["LFDDungeonReadyPopup_Update"] = noIndentEffectWoWColor,
	["LFDDungeonReadyStatus_ResetReadyStates"] = noIndentEffectWoWColor,
	["LFDDungeonReadyStatus_UpdateIcon"] = noIndentEffectWoWColor,
	["LFDFrameRoleCheckButton_OnClick"] = noIndentEffectWoWColor,
	["LFDFrameRoleCheckButton_OnEnter"] = noIndentEffectWoWColor,
	["LFDFrame_OnEvent"] = noIndentEffectWoWColor,
	["LFDFrame_OnHide"] = noIndentEffectWoWColor,
	["LFDFrame_OnLoad"] = noIndentEffectWoWColor,
	["LFDFrame_OnShow"] = noIndentEffectWoWColor,
	["LFDFrame_UpdateBackfill"] = noIndentEffectWoWColor,
	["LFDGetNumDungeons"] = noIndentEffectWoWColor,
	["LFDList_DefaultFilterFunction"] = noIndentEffectWoWColor,
	["LFDList_SetDungeonEnabled"] = noIndentEffectWoWColor,
	["LFDList_SetHeaderCollapsed"] = noIndentEffectWoWColor,
	["LFDList_SetHeaderEnabled"] = noIndentEffectWoWColor,
	["LFDQueueFrameDungeonChoiceEnableButton_OnClick"] = noIndentEffectWoWColor,
	["LFDQueueFrameDungeonListButton_OnEnter"] = noIndentEffectWoWColor,
	["LFDQueueFrameExpandOrCollapseButton_OnClick"] = noIndentEffectWoWColor,
	["LFDQueueFrameFindGroupButton_Update"] = noIndentEffectWoWColor,
	["LFDQueueFrameRandomCooldownFrame_OnEvent"] = noIndentEffectWoWColor,
	["LFDQueueFrameRandomCooldownFrame_OnLoad"] = noIndentEffectWoWColor,
	["LFDQueueFrameRandomCooldownFrame_OnUpdate"] = noIndentEffectWoWColor,
	["LFDQueueFrameRandomCooldownFrame_Update"] = noIndentEffectWoWColor,
	["LFDQueueFrameRandom_UpdateFrame"] = noIndentEffectWoWColor,
	["LFDQueueFrameSpecificListButton_SetDungeon"] = noIndentEffectWoWColor,
	["LFDQueueFrameSpecificList_Update"] = noIndentEffectWoWColor,
	["LFDQueueFrameTypeDropDownButton_OnClick"] = noIndentEffectWoWColor,
	["LFDQueueFrameTypeDropDown_Initialize"] = noIndentEffectWoWColor,
	["LFDQueueFrameTypeDropDown_SetUp"] = noIndentEffectWoWColor,
	["LFDQueueFrame_Join"] = noIndentEffectWoWColor,
	["LFDQueueFrame_QueueForInstanceIfEnabled"] = noIndentEffectWoWColor,
	["LFDQueueFrame_SetRoles"] = noIndentEffectWoWColor,
	["LFDQueueFrame_SetType"] = noIndentEffectWoWColor,
	["LFDQueueFrame_SetTypeRandomDungeon"] = noIndentEffectWoWColor,
	["LFDQueueFrame_SetTypeSpecificDungeon"] = noIndentEffectWoWColor,
	["LFDQueueFrame_Update"] = noIndentEffectWoWColor,
	["LFDQueueFrame_UpdatePortrait"] = noIndentEffectWoWColor,
	["LFDRoleCheckPopupAccept_OnClick"] = noIndentEffectWoWColor,
	["LFDRoleCheckPopupDecline_OnClick"] = noIndentEffectWoWColor,
	["LFDRoleCheckPopupDescription_OnEnter"] = noIndentEffectWoWColor,
	["LFDRoleCheckPopup_Update"] = noIndentEffectWoWColor,
	["LFDSearchStatusPlayer_SetFound"] = noIndentEffectWoWColor,
	["LFDSearchStatus_OnEvent"] = noIndentEffectWoWColor,
	["LFDSearchStatus_OnUpdate"] = noIndentEffectWoWColor,
	["LFDSearchStatus_Update"] = noIndentEffectWoWColor,
	["LFDSearchStatus_UpdateRoles"] = noIndentEffectWoWColor,
	["LFD_CURRENT_FILTER"] = noIndentEffectWoWColor,
	["LFD_IsEmpowered"] = noIndentEffectWoWColor,
	["LFGDebug"] = noIndentEffectWoWColor,
	["LFGDungeonList_Setup"] = noIndentEffectWoWColor,
	["LFGEventFrame_OnEvent"] = noIndentEffectWoWColor,
	["LFGEventFrame_OnLoad"] = noIndentEffectWoWColor,
	["LFGGetDungeonInfoByID"] = noIndentEffectWoWColor,
	["LFGIsIDHeader"] = noIndentEffectWoWColor,
	["LFGListFilterChoices"] = noIndentEffectWoWColor,
	["LFGListRemoveCollapsedChildren"] = noIndentEffectWoWColor,
	["LFGListRemoveHeadersWithoutChildren"] = noIndentEffectWoWColor,
	["LFGListUpdateHeaderEnabledAndLockedStates"] = noIndentEffectWoWColor,
	["LFGQueueFrame_UpdateLFGDungeonList"] = noIndentEffectWoWColor,
	["LFGSpecificChoiceEnableButton_SetIsRadio"] = noIndentEffectWoWColor,
	["LFGTeleport"] = noIndentEffectWoWColor,
	["LFG_DisableRoleButton"] = noIndentEffectWoWColor,
	["LFG_EnableRoleButton"] = noIndentEffectWoWColor,
	["LFG_PermanentlyDisableRoleButton"] = noIndentEffectWoWColor,
	["LFG_UpdateAvailableRoles"] = noIndentEffectWoWColor,
	["LFG_UpdateFindGroupButtons"] = noIndentEffectWoWColor,
	["LFG_UpdateFramesIfShown"] = noIndentEffectWoWColor,
	["LFG_UpdateLockedOutPanels"] = noIndentEffectWoWColor,
	["LFG_UpdateQueuedList"] = noIndentEffectWoWColor,
	["LFG_UpdateRoleCheckboxes"] = noIndentEffectWoWColor,
	["LFG_UpdateRolesChangeable"] = noIndentEffectWoWColor,
	["LFRBrowseButton_OnClick"] = noIndentEffectWoWColor,
	["LFRBrowseButton_OnEnter"] = noIndentEffectWoWColor,
	["LFRBrowseFrameListButton_SetData"] = noIndentEffectWoWColor,
	["LFRBrowseFrameList_Update"] = noIndentEffectWoWColor,
	["LFRBrowseFrameRaidDropDownButton_OnClick"] = noIndentEffectWoWColor,
	["LFRBrowseFrameRaidDropDown_Initialize"] = noIndentEffectWoWColor,
	["LFRBrowseFrameRaidDropDown_SetUp"] = noIndentEffectWoWColor,
	["LFRBrowseFrameRefreshButton_OnUpdate"] = noIndentEffectWoWColor,
	["LFRBrowseFrame_OnLoad"] = noIndentEffectWoWColor,
	["LFRBrowseFrame_OnUpdateAlways"] = noIndentEffectWoWColor,
	["LFRBrowse_UpdateButtonStates"] = noIndentEffectWoWColor,
	["LFRFrameRoleCheckButton_OnClick"] = noIndentEffectWoWColor,
	["LFRFrame_OnEvent"] = noIndentEffectWoWColor,
	["LFRFrame_OnLoad"] = noIndentEffectWoWColor,
	["LFRFrame_SetActiveTab"] = noIndentEffectWoWColor,
	["LFRGetNumDungeons"] = noIndentEffectWoWColor,
	["LFRList_DefaultFilterFunction"] = noIndentEffectWoWColor,
	["LFRList_SetHeaderCollapsed"] = noIndentEffectWoWColor,
	["LFRList_SetHeaderEnabled"] = noIndentEffectWoWColor,
	["LFRList_SetRaidEnabled"] = noIndentEffectWoWColor,
	["LFRQueueFrameDungeonChoiceEnableButton_OnClick"] = noIndentEffectWoWColor,
	["LFRQueueFrameExpandOrCollapseButton_OnClick"] = noIndentEffectWoWColor,
	["LFRQueueFrameFindGroupButton_Update"] = noIndentEffectWoWColor,
	["LFRQueueFrameSpecificListButton_SetDungeon"] = noIndentEffectWoWColor,
	["LFRQueueFrameSpecificList_Update"] = noIndentEffectWoWColor,
	["LFRQueueFrame_Join"] = noIndentEffectWoWColor,
	["LFRQueueFrame_QueueForInstanceIfEnabled"] = noIndentEffectWoWColor,
	["LFRQueueFrame_SetRoles"] = noIndentEffectWoWColor,
	["LFRQueueFrame_Update"] = noIndentEffectWoWColor,
	["LFR_CURRENT_FILTER"] = noIndentEffectWoWColor,
	["LFR_CanQueueForLockedInstances"] = noIndentEffectWoWColor,
	["LFR_CanQueueForMultiple"] = noIndentEffectWoWColor,
	["LFR_IsEmpowered"] = noIndentEffectWoWColor,
	["LanguageMenu_Click"] = noIndentEffectWoWColor,
	["LanguageMenu_LoadLanguages"] = noIndentEffectWoWColor,
	["LanguageMenu_OnEvent"] = noIndentEffectWoWColor,
	["LanguageMenu_OnLoad"] = noIndentEffectWoWColor,
	["LearnPreviewTalents"] = noIndentEffectWoWColor,
	["LearnTalent"] = noIndentEffectWoWColor,
	["LeaveBattlefield"] = noIndentEffectWoWColor,
	["LeaveChannelByName"] = noIndentEffectWoWColor,
	["LeaveLFG"] = noIndentEffectWoWColor,
	["LeaveParty"] = noIndentEffectWoWColor,
	["ListChannelByName"] = noIndentEffectWoWColor,
	["ListChannels"] = noIndentEffectWoWColor,
	["LoadAddOn"] = noIndentEffectWoWColor,
	["LoadBindings"] = noIndentEffectWoWColor,
	["LoadMicroButtonTextures"] = noIndentEffectWoWColor,
	["Localize"] = noIndentEffectWoWColor,
	["LocalizeFrames"] = noIndentEffectWoWColor,
	["LocalizePost"] = noIndentEffectWoWColor,
	["LockMultiCastActionBar"] = noIndentEffectWoWColor,
	["LockPetActionBar"] = noIndentEffectWoWColor,
	["LoggingChat"] = noIndentEffectWoWColor,
	["LoggingCombat"] = noIndentEffectWoWColor,
	["Logout"] = noIndentEffectWoWColor,
	["LoopbackVUMeter_OnLoad"] = noIndentEffectWoWColor,
	["LoopbackVUMeter_OnUpdate"] = noIndentEffectWoWColor,
	["LootButton_OnClick"] = noIndentEffectWoWColor,
	["LootFrame_OnEvent"] = noIndentEffectWoWColor,
	["LootFrame_OnHide"] = noIndentEffectWoWColor,
	["LootFrame_OnLoad"] = noIndentEffectWoWColor,
	["LootFrame_OnShow"] = noIndentEffectWoWColor,
	["LootFrame_PageDown"] = noIndentEffectWoWColor,
	["LootFrame_PageUp"] = noIndentEffectWoWColor,
	["LootFrame_Show"] = noIndentEffectWoWColor,
	["LootFrame_Update"] = noIndentEffectWoWColor,
	["LootFrame_UpdateButton"] = noIndentEffectWoWColor,
	["LootItem_OnEnter"] = noIndentEffectWoWColor,
	["LootSlot"] = noIndentEffectWoWColor,
	["LootSlotIsCoin"] = noIndentEffectWoWColor,
	["LootSlotIsItem"] = noIndentEffectWoWColor,
	["LowHealthFrame_OnUpdate"] = noIndentEffectWoWColor,
	["LowHealthFrame_StartFlashing"] = noIndentEffectWoWColor,
	["LowHealthFrame_StopFlashing"] = noIndentEffectWoWColor,
	["LowerFrameLevel"] = noIndentEffectWoWColor,
	["MacOptionsCancelFrame_OnShow"] = noIndentEffectWoWColor,
	["MacOptionsCompressFrame_OnShow"] = noIndentEffectWoWColor,
	["MacOptionsFrameCodecDropDown_Initialize"] = noIndentEffectWoWColor,
	["MacOptionsFrameCodecDropDown_OnClick"] = noIndentEffectWoWColor,
	["MacOptionsFrameCodecDropDown_OnLoad"] = noIndentEffectWoWColor,
	["MacOptionsFrameFramerateDropDown_Initialize"] = noIndentEffectWoWColor,
	["MacOptionsFrameFramerateDropDown_OnClick"] = noIndentEffectWoWColor,
	["MacOptionsFrameFramerateDropDown_OnLoad"] = noIndentEffectWoWColor,
	["MacOptionsFrameResolutionButton_OnClick"] = noIndentEffectWoWColor,
	["MacOptionsFrameResolutionDropDown_Initialize"] = noIndentEffectWoWColor,
	["MacOptionsFrameResolutionDropDown_OnLoad"] = noIndentEffectWoWColor,
	["MacOptionsFrame_Cancel"] = noIndentEffectWoWColor,
	["MacOptionsFrame_DisableCheckBox"] = noIndentEffectWoWColor,
	["MacOptionsFrame_DisableSlider"] = noIndentEffectWoWColor,
	["MacOptionsFrame_DisableText"] = noIndentEffectWoWColor,
	["MacOptionsFrame_EnableCheckBox"] = noIndentEffectWoWColor,
	["MacOptionsFrame_Load"] = noIndentEffectWoWColor,
	["MacOptionsFrame_OnEvent"] = noIndentEffectWoWColor,
	["MacOptionsFrame_OnLoad"] = noIndentEffectWoWColor,
	["MacOptionsFrame_Save"] = noIndentEffectWoWColor,
	["MacOptionsFrame_SetDefaults"] = noIndentEffectWoWColor,
	["MacOptionsFrame_UpdateTime"] = noIndentEffectWoWColor,
	["MacroFrame_LoadUI"] = noIndentEffectWoWColor,
	["MacroFrame_SaveMacro"] = noIndentEffectWoWColor,
	["MailFrameTab_OnClick"] = noIndentEffectWoWColor,
	["MailFrame_OnEvent"] = noIndentEffectWoWColor,
	["MailFrame_OnLoad"] = noIndentEffectWoWColor,
	["MainMenuBarBackpackButton_OnEvent"] = noIndentEffectWoWColor,
	["MainMenuBarBackpackButton_UpdateFreeSlots"] = noIndentEffectWoWColor,
	["MainMenuBarPerformanceBarFrame_OnEnter"] = noIndentEffectWoWColor,
	["MainMenuBarVehicleLeaveButton_OnEvent"] = noIndentEffectWoWColor,
	["MainMenuBarVehicleLeaveButton_OnLoad"] = noIndentEffectWoWColor,
	["MainMenuBarVehicleLeaveButton_Update"] = noIndentEffectWoWColor,
	["MainMenuBar_AnimFinished"] = noIndentEffectWoWColor,
	["MainMenuBar_OnEvent"] = noIndentEffectWoWColor,
	["MainMenuBar_OnLoad"] = noIndentEffectWoWColor,
	["MainMenuBar_ToPlayerArt"] = noIndentEffectWoWColor,
	["MainMenuBar_ToVehicleArt"] = noIndentEffectWoWColor,
	["MainMenuBar_UnlockAB"] = noIndentEffectWoWColor,
	["MainMenuBar_UpdateArt"] = noIndentEffectWoWColor,
	["MainMenuBar_UpdateKeyRing"] = noIndentEffectWoWColor,
	["MainMenuExpBar_Update"] = noIndentEffectWoWColor,
	["MainMenuMicroButton_SetNormal"] = noIndentEffectWoWColor,
	["MainMenuMicroButton_SetPushed"] = noIndentEffectWoWColor,
	["MakeMinigameMove"] = noIndentEffectWoWColor,
	["ManageBackpackTokenFrame"] = noIndentEffectWoWColor,
	["MerchantFrame_ConfirmExtendedItemCost"] = noIndentEffectWoWColor,
	["MerchantFrame_ConfirmHighCostItem"] = noIndentEffectWoWColor,
	["MerchantFrame_OnEvent"] = noIndentEffectWoWColor,
	["MerchantFrame_OnHide"] = noIndentEffectWoWColor,
	["MerchantFrame_OnLoad"] = noIndentEffectWoWColor,
	["MerchantFrame_OnShow"] = noIndentEffectWoWColor,
	["MerchantFrame_ResetRefundItem"] = noIndentEffectWoWColor,
	["MerchantFrame_SetRefundItem"] = noIndentEffectWoWColor,
	["MerchantFrame_Update"] = noIndentEffectWoWColor,
	["MerchantFrame_UpdateAltCurrency"] = noIndentEffectWoWColor,
	["MerchantFrame_UpdateBuybackInfo"] = noIndentEffectWoWColor,
	["MerchantFrame_UpdateCanRepairAll"] = noIndentEffectWoWColor,
	["MerchantFrame_UpdateGuildBankRepair"] = noIndentEffectWoWColor,
	["MerchantFrame_UpdateMerchantInfo"] = noIndentEffectWoWColor,
	["MerchantFrame_UpdateRepairButtons"] = noIndentEffectWoWColor,
	["MerchantItemButton_OnClick"] = noIndentEffectWoWColor,
	["MerchantItemButton_OnEnter"] = noIndentEffectWoWColor,
	["MerchantItemButton_OnLoad"] = noIndentEffectWoWColor,
	["MerchantItemButton_OnModifiedClick"] = noIndentEffectWoWColor,
	["MerchantItemBuybackButton_OnLoad"] = noIndentEffectWoWColor,
	["MerchantNextPageButton_OnClick"] = noIndentEffectWoWColor,
	["MerchantPrevPageButton_OnClick"] = noIndentEffectWoWColor,
	["MessageFrameScrollButton_OnLoad"] = noIndentEffectWoWColor,
	["MessageFrameScrollButton_OnUpdate"] = noIndentEffectWoWColor,
	["MessageTypeColor_OpenColorPicker"] = noIndentEffectWoWColor,
	["MicroButtonTooltipText"] = noIndentEffectWoWColor,
	["MiniMapBattlefieldDropDown_Initialize"] = noIndentEffectWoWColor,
	["MiniMapBattlefieldDropDown_OnLoad"] = noIndentEffectWoWColor,
	["MiniMapBattlefieldFrame_OnUpdate"] = noIndentEffectWoWColor,
	["MiniMapBattlefieldFrame_isArena"] = noIndentEffectWoWColor,
	["MiniMapInstanceDifficulty_OnEvent"] = noIndentEffectWoWColor,
	["MiniMapLFGFrameDropDown_Update"] = noIndentEffectWoWColor,
	["MiniMapLFGFrame_OnClick"] = noIndentEffectWoWColor,
	["MiniMapLFGFrame_OnEnter"] = noIndentEffectWoWColor,
	["MiniMapLFGFrame_OnLeave"] = noIndentEffectWoWColor,
	["MiniMapLFGFrame_TeleportIn"] = noIndentEffectWoWColor,
	["MiniMapLFGFrame_TeleportOut"] = noIndentEffectWoWColor,
	["MiniMapLFG_UpdateIsShown"] = noIndentEffectWoWColor,
	["MiniMapTrackingDropDown_Initialize"] = noIndentEffectWoWColor,
	["MiniMapTrackingDropDown_OnLoad"] = noIndentEffectWoWColor,
	["MiniMapTrackingShineFadeIn"] = noIndentEffectWoWColor,
	["MiniMapTrackingShineFadeOut"] = noIndentEffectWoWColor,
	["MiniMapTracking_SetTracking"] = noIndentEffectWoWColor,
	["MiniMapTracking_Update"] = noIndentEffectWoWColor,
	["MiniMapVoiceChatDropDown_Initialize"] = noIndentEffectWoWColor,
	["MiniMapVoiceChatDropDown_OnLoad"] = noIndentEffectWoWColor,
	["MiniMapVoiceChat_Update"] = noIndentEffectWoWColor,
	["MinimapButton_OnMouseDown"] = noIndentEffectWoWColor,
	["MinimapButton_OnMouseUp"] = noIndentEffectWoWColor,
	["MinimapMailFrameUpdate"] = noIndentEffectWoWColor,
	["MinimapPing_FadeOut"] = noIndentEffectWoWColor,
	["MinimapPing_OnEvent"] = noIndentEffectWoWColor,
	["MinimapPing_OnLoad"] = noIndentEffectWoWColor,
	["MinimapPing_OnUpdate"] = noIndentEffectWoWColor,
	["Minimap_OnClick"] = noIndentEffectWoWColor,
	["Minimap_SetPing"] = noIndentEffectWoWColor,
	["Minimap_SetTooltip"] = noIndentEffectWoWColor,
	["Minimap_Update"] = noIndentEffectWoWColor,
	["Minimap_UpdateRotationSetting"] = noIndentEffectWoWColor,
	["Minimap_ZoomIn"] = noIndentEffectWoWColor,
	["Minimap_ZoomInClick"] = noIndentEffectWoWColor,
	["Minimap_ZoomOut"] = noIndentEffectWoWColor,
	["Minimap_ZoomOutClick"] = noIndentEffectWoWColor,
	["MirrorTimerFrame_OnEvent"] = noIndentEffectWoWColor,
	["MirrorTimerFrame_OnLoad"] = noIndentEffectWoWColor,
	["MirrorTimerFrame_OnUpdate"] = noIndentEffectWoWColor,
	["MirrorTimer_Show"] = noIndentEffectWoWColor,
	["Model_OnLoad"] = noIndentEffectWoWColor,
	["Model_OnUpdate"] = noIndentEffectWoWColor,
	["Model_RotateLeft"] = noIndentEffectWoWColor,
	["Model_RotateRight"] = noIndentEffectWoWColor,
	["MoneyFrame_OnEvent"] = noIndentEffectWoWColor,
	["MoneyFrame_OnLoad"] = noIndentEffectWoWColor,
	["MoneyFrame_SetType"] = noIndentEffectWoWColor,
	["MoneyFrame_Update"] = noIndentEffectWoWColor,
	["MoneyFrame_UpdateMoney"] = noIndentEffectWoWColor,
	["MoneyInputFrame_ClearFocus"] = noIndentEffectWoWColor,
	["MoneyInputFrame_GetCopper"] = noIndentEffectWoWColor,
	["MoneyInputFrame_OnShow"] = noIndentEffectWoWColor,
	["MoneyInputFrame_OnTextChanged"] = noIndentEffectWoWColor,
	["MoneyInputFrame_ResetMoney"] = noIndentEffectWoWColor,
	["MoneyInputFrame_SetCopper"] = noIndentEffectWoWColor,
	["MoneyInputFrame_SetMode"] = noIndentEffectWoWColor,
	["MoneyInputFrame_SetNextFocus"] = noIndentEffectWoWColor,
	["MoneyInputFrame_SetOnValueChangedFunc"] = noIndentEffectWoWColor,
	["MoneyInputFrame_SetPreviousFocus"] = noIndentEffectWoWColor,
	["MoneyInputFrame_SetTextColor"] = noIndentEffectWoWColor,
	["MouseIsOver"] = noIndentEffectWoWColor,
	["MouselookStart"] = noIndentEffectWoWColor,
	["MouselookStop"] = noIndentEffectWoWColor,
	["MoveAndSteerStart"] = noIndentEffectWoWColor,
	["MoveAndSteerStop"] = noIndentEffectWoWColor,
	["MoveBackwardStart"] = noIndentEffectWoWColor,
	["MoveBackwardStop"] = noIndentEffectWoWColor,
	["MoveForwardStart"] = noIndentEffectWoWColor,
	["MoveForwardStop"] = noIndentEffectWoWColor,
	["MoveViewDownStart"] = noIndentEffectWoWColor,
	["MoveViewDownStop"] = noIndentEffectWoWColor,
	["MoveViewInStart"] = noIndentEffectWoWColor,
	["MoveViewInStop"] = noIndentEffectWoWColor,
	["MoveViewLeftStart"] = noIndentEffectWoWColor,
	["MoveViewLeftStop"] = noIndentEffectWoWColor,
	["MoveViewOutStart"] = noIndentEffectWoWColor,
	["MoveViewOutStop"] = noIndentEffectWoWColor,
	["MoveViewRightStart"] = noIndentEffectWoWColor,
	["MoveViewRightStop"] = noIndentEffectWoWColor,
	["MoveViewUpStart"] = noIndentEffectWoWColor,
	["MoveViewUpStop"] = noIndentEffectWoWColor,
	["MovieFrame_OnEvent"] = noIndentEffectWoWColor,
	["MovieFrame_OnHide"] = noIndentEffectWoWColor,
	["MovieFrame_OnKeyUp"] = noIndentEffectWoWColor,
	["MovieFrame_OnLoad"] = noIndentEffectWoWColor,
	["MovieFrame_OnMovieFinished"] = noIndentEffectWoWColor,
	["MovieFrame_OnMovieHideSubtitle"] = noIndentEffectWoWColor,
	["MovieFrame_OnMovieShowSubtitle"] = noIndentEffectWoWColor,
	["MovieFrame_OnShow"] = noIndentEffectWoWColor,
	["MovieFrame_OnUpdate"] = noIndentEffectWoWColor,
	["MovieFrame_PlayMovie"] = noIndentEffectWoWColor,
	["MovieRecordingProgress_OnUpdate"] = noIndentEffectWoWColor,
	["MultiActionBarFrame_OnLoad"] = noIndentEffectWoWColor,
	["MultiActionBar_HideAllGrids"] = noIndentEffectWoWColor,
	["MultiActionBar_ShowAllGrids"] = noIndentEffectWoWColor,
	["MultiActionBar_Update"] = noIndentEffectWoWColor,
	["MultiActionBar_UpdateGrid"] = noIndentEffectWoWColor,
	["MultiActionBar_UpdateGridVisibility"] = noIndentEffectWoWColor,
	["MultiActionButtonDown"] = noIndentEffectWoWColor,
	["MultiActionButtonUp"] = noIndentEffectWoWColor,
	["MultiBar1_IsVisible"] = noIndentEffectWoWColor,
	["MultiBar2_IsVisible"] = noIndentEffectWoWColor,
	["MultiBar3_IsVisible"] = noIndentEffectWoWColor,
	["MultiBar4_IsVisible"] = noIndentEffectWoWColor,
	["MultiCastActionBarFrame_OnEvent"] = noIndentEffectWoWColor,
	["MultiCastActionBarFrame_OnLoad"] = noIndentEffectWoWColor,
	["MultiCastActionBarFrame_OnUpdate"] = noIndentEffectWoWColor,
	["MultiCastActionBarFrame_Update"] = noIndentEffectWoWColor,
	["MultiCastActionButtonDown"] = noIndentEffectWoWColor,
	["MultiCastActionButtonUp"] = noIndentEffectWoWColor,
	["MultiCastActionButton_OnEnter"] = noIndentEffectWoWColor,
	["MultiCastActionButton_OnEvent"] = noIndentEffectWoWColor,
	["MultiCastActionButton_OnLeave"] = noIndentEffectWoWColor,
	["MultiCastActionButton_OnLoad"] = noIndentEffectWoWColor,
	["MultiCastActionButton_OnPostClick"] = noIndentEffectWoWColor,
	["MultiCastActionButton_OnShow"] = noIndentEffectWoWColor,
	["MultiCastActionButton_Update"] = noIndentEffectWoWColor,
	["MultiCastFlyoutButton_OnClick"] = noIndentEffectWoWColor,
	["MultiCastFlyoutButton_OnEnter"] = noIndentEffectWoWColor,
	["MultiCastFlyoutButton_OnLeave"] = noIndentEffectWoWColor,
	["MultiCastFlyoutButton_OnLoad"] = noIndentEffectWoWColor,
	["MultiCastFlyoutButton_SetTooltip"] = noIndentEffectWoWColor,
	["MultiCastFlyoutFrameCloseButton_OnClick"] = noIndentEffectWoWColor,
	["MultiCastFlyoutFrameOpenButton_Hide"] = noIndentEffectWoWColor,
	["MultiCastFlyoutFrameOpenButton_OnClick"] = noIndentEffectWoWColor,
	["MultiCastFlyoutFrameOpenButton_OnLeave"] = noIndentEffectWoWColor,
	["MultiCastFlyoutFrameOpenButton_Show"] = noIndentEffectWoWColor,
	["MultiCastFlyoutFrame_Hide"] = noIndentEffectWoWColor,
	["MultiCastFlyoutFrame_LoadPageSpells"] = noIndentEffectWoWColor,
	["MultiCastFlyoutFrame_LoadSlotSpells"] = noIndentEffectWoWColor,
	["MultiCastFlyoutFrame_OnEnter"] = noIndentEffectWoWColor,
	["MultiCastFlyoutFrame_OnHide"] = noIndentEffectWoWColor,
	["MultiCastFlyoutFrame_OnLeave"] = noIndentEffectWoWColor,
	["MultiCastFlyoutFrame_OnShow"] = noIndentEffectWoWColor,
	["MultiCastFlyoutFrame_OnUpdate"] = noIndentEffectWoWColor,
	["MultiCastFlyoutFrame_ToggleFlyout"] = noIndentEffectWoWColor,
	["MultiCastRecallSpellButtonUp"] = noIndentEffectWoWColor,
	["MultiCastRecallSpellButton_OnClick"] = noIndentEffectWoWColor,
	["MultiCastRecallSpellButton_OnLoad"] = noIndentEffectWoWColor,
	["MultiCastRecallSpellButton_Update"] = noIndentEffectWoWColor,
	["MultiCastSlotButton_OnEnter"] = noIndentEffectWoWColor,
	["MultiCastSlotButton_OnEvent"] = noIndentEffectWoWColor,
	["MultiCastSlotButton_OnLeave"] = noIndentEffectWoWColor,
	["MultiCastSlotButton_Update"] = noIndentEffectWoWColor,
	["MultiCastSpellButton_OnEnter"] = noIndentEffectWoWColor,
	["MultiCastSpellButton_OnEvent"] = noIndentEffectWoWColor,
	["MultiCastSpellButton_OnLeave"] = noIndentEffectWoWColor,
	["MultiCastSpellButton_OnLoad"] = noIndentEffectWoWColor,
	["MultiCastSpellButton_SetTooltip"] = noIndentEffectWoWColor,
	["MultiCastSpellButton_UpdateCooldown"] = noIndentEffectWoWColor,
	["MultiCastSpellButton_UpdateState"] = noIndentEffectWoWColor,
	["MultiCastSummonSpellButtonUp"] = noIndentEffectWoWColor,
	["MultiCastSummonSpellButton_OnClick"] = noIndentEffectWoWColor,
	["MultiCastSummonSpellButton_OnEnter"] = noIndentEffectWoWColor,
	["MultiCastSummonSpellButton_OnEvent"] = noIndentEffectWoWColor,
	["MultiCastSummonSpellButton_OnLeave"] = noIndentEffectWoWColor,
	["MultiCastSummonSpellButton_OnLoad"] = noIndentEffectWoWColor,
	["MultiCastSummonSpellButton_Update"] = noIndentEffectWoWColor,
	["MultibarGrid_IsVisible"] = noIndentEffectWoWColor,
	["Multibar_EmptyFunc"] = noIndentEffectWoWColor,
	["NewGMTicket"] = noIndentEffectWoWColor,
	["NextView"] = noIndentEffectWoWColor,
	["NoPlayTime"] = noIndentEffectWoWColor,
	["NotWhileDeadError"] = noIndentEffectWoWColor,
	["NotifyInspect"] = noIndentEffectWoWColor,
	["NumTaxiNodes"] = noIndentEffectWoWColor,
	["OfferPetition"] = noIndentEffectWoWColor,
	["OffhandHasWeapon"] = noIndentEffectWoWColor,
	["OnMenuLoad"] = noIndentEffectWoWColor,
	["OpenAllBags"] = noIndentEffectWoWColor,
	["OpenBackpack"] = noIndentEffectWoWColor,
	["OpenBag"] = noIndentEffectWoWColor,
	["OpenCalendar"] = noIndentEffectWoWColor,
	["OpenCoinPickupFrame"] = noIndentEffectWoWColor,
	["OpenColorPicker"] = noIndentEffectWoWColor,
	["OpenGlyphFrame"] = noIndentEffectWoWColor,
	["OpenMailAttachment_OnClick"] = noIndentEffectWoWColor,
	["OpenMailAttachment_OnEnter"] = noIndentEffectWoWColor,
	["OpenMailFrame_OnHide"] = noIndentEffectWoWColor,
	["OpenMailFrame_UpdateButtonPositions"] = noIndentEffectWoWColor,
	["OpenMail_Delete"] = noIndentEffectWoWColor,
	["OpenMail_GetItemCounts"] = noIndentEffectWoWColor,
	["OpenMail_Reply"] = noIndentEffectWoWColor,
	["OpenMail_ReportSpam"] = noIndentEffectWoWColor,
	["OpenMail_Update"] = noIndentEffectWoWColor,
	["OpenStackSplitFrame"] = noIndentEffectWoWColor,
	["OpenTrainer"] = noIndentEffectWoWColor,
	["OpeningCinematic"] = noIndentEffectWoWColor,
	["OptionsCategoryFrame_Update"] = noIndentEffectWoWColor,
	["OptionsFrameCancel_OnClick"] = noIndentEffectWoWColor,
	["OptionsFrameDefault_OnClick"] = noIndentEffectWoWColor,
	["OptionsFrameOkay_OnClick"] = noIndentEffectWoWColor,
	["OptionsFrame_AddCategory"] = noIndentEffectWoWColor,
	["OptionsFrame_OnHide"] = noIndentEffectWoWColor,
	["OptionsFrame_OnLoad"] = noIndentEffectWoWColor,
	["OptionsFrame_OnShow"] = noIndentEffectWoWColor,
	["OptionsFrame_OpenToCategory"] = noIndentEffectWoWColor,
	["OptionsFrame_RefreshCategories"] = noIndentEffectWoWColor,
	["OptionsFrame_SetAllToDefaults"] = noIndentEffectWoWColor,
	["OptionsFrame_SetCurrentToDefaults"] = noIndentEffectWoWColor,
	["OptionsListButtonToggle_OnClick"] = noIndentEffectWoWColor,
	["OptionsListButton_OnClick"] = noIndentEffectWoWColor,
	["OptionsListButton_OnLoad"] = noIndentEffectWoWColor,
	["OptionsListButton_ToggleSubCategories"] = noIndentEffectWoWColor,
	["OptionsListScroll_Update"] = noIndentEffectWoWColor,
	["OptionsList_ClearSelection"] = noIndentEffectWoWColor,
	["OptionsList_DisplayButton"] = noIndentEffectWoWColor,
	["OptionsList_DisplayPanel"] = noIndentEffectWoWColor,
	["OptionsList_DisplayScrollBar"] = noIndentEffectWoWColor,
	["OptionsList_HideButton"] = noIndentEffectWoWColor,
	["OptionsList_HideScrollBar"] = noIndentEffectWoWColor,
	["OptionsList_OnLoad"] = noIndentEffectWoWColor,
	["OptionsList_SelectButton"] = noIndentEffectWoWColor,
	["PVPBannerCustomization_Left"] = noIndentEffectWoWColor,
	["PVPBannerCustomization_Right"] = noIndentEffectWoWColor,
	["PVPBannerFrame_OnShow"] = noIndentEffectWoWColor,
	["PVPBannerFrame_OpenColorPicker"] = noIndentEffectWoWColor,
	["PVPBannerFrame_SaveBanner"] = noIndentEffectWoWColor,
	["PVPBannerFrame_SetBannerColor"] = noIndentEffectWoWColor,
	["PVPBannerFrame_SetBorderColor"] = noIndentEffectWoWColor,
	["PVPBannerFrame_SetEmblemColor"] = noIndentEffectWoWColor,
	["PVPBattlegroundButton_OnClick"] = noIndentEffectWoWColor,
	["PVPBattlegroundFrameJoinButton_OnClick"] = noIndentEffectWoWColor,
	["PVPBattlegroundFrame_OnEvent"] = noIndentEffectWoWColor,
	["PVPBattlegroundFrame_OnHide"] = noIndentEffectWoWColor,
	["PVPBattlegroundFrame_OnLoad"] = noIndentEffectWoWColor,
	["PVPBattlegroundFrame_OnShow"] = noIndentEffectWoWColor,
	["PVPBattlegroundFrame_UpdateGroupAvailable"] = noIndentEffectWoWColor,
	["PVPBattlegroundFrame_UpdateVisible"] = noIndentEffectWoWColor,
	["PVPBattleground_GetSelectedBattlegroundInfo"] = noIndentEffectWoWColor,
	["PVPBattleground_ResetInfo"] = noIndentEffectWoWColor,
	["PVPBattleground_UpdateBattlegrounds"] = noIndentEffectWoWColor,
	["PVPBattleground_UpdateInfo"] = noIndentEffectWoWColor,
	["PVPBattleground_UpdateJoinButton"] = noIndentEffectWoWColor,
	["PVPBattleground_UpdateQueueStatus"] = noIndentEffectWoWColor,
	["PVPBattleground_UpdateRandomInfo"] = noIndentEffectWoWColor,
	["PVPDropDown_Initialize"] = noIndentEffectWoWColor,
	["PVPFrameToggleButton_OnClick"] = noIndentEffectWoWColor,
	["PVPFrame_IsJustBG"] = noIndentEffectWoWColor,
	["PVPFrame_OnEvent"] = noIndentEffectWoWColor,
	["PVPFrame_OnHide"] = noIndentEffectWoWColor,
	["PVPFrame_OnLoad"] = noIndentEffectWoWColor,
	["PVPFrame_OnShow"] = noIndentEffectWoWColor,
	["PVPFrame_SetFaction"] = noIndentEffectWoWColor,
	["PVPFrame_SetJustBG"] = noIndentEffectWoWColor,
	["PVPFrame_SetToInSeason"] = noIndentEffectWoWColor,
	["PVPFrame_SetToOffSeason"] = noIndentEffectWoWColor,
	["PVPFrame_ShowDropdown"] = noIndentEffectWoWColor,
	["PVPFrame_Update"] = noIndentEffectWoWColor,
	["PVPHonor_Update"] = noIndentEffectWoWColor,
	["PVPMicroButton_SetNormal"] = noIndentEffectWoWColor,
	["PVPMicroButton_SetPushed"] = noIndentEffectWoWColor,
	["PVPQueue_UpdateRandomInfo"] = noIndentEffectWoWColor,
	["PVPStandard_OnLoad"] = noIndentEffectWoWColor,
	["PVPTeamDetailsButton_OnClick"] = noIndentEffectWoWColor,
	["PVPTeamDetailsToggleButton_OnClick"] = noIndentEffectWoWColor,
	["PVPTeamDetails_OnHide"] = noIndentEffectWoWColor,
	["PVPTeamDetails_OnShow"] = noIndentEffectWoWColor,
	["PVPTeamDetails_Update"] = noIndentEffectWoWColor,
	["PVPTeam_OnClick"] = noIndentEffectWoWColor,
	["PVPTeam_OnEnter"] = noIndentEffectWoWColor,
	["PVPTeam_OnLeave"] = noIndentEffectWoWColor,
	["PVPTeam_OnMouseDown"] = noIndentEffectWoWColor,
	["PVPTeam_OnMouseUp"] = noIndentEffectWoWColor,
	["PVPTeam_Update"] = noIndentEffectWoWColor,
	["PanelTemplates_DeselectTab"] = noIndentEffectWoWColor,
	["PanelTemplates_DisableTab"] = noIndentEffectWoWColor,
	["PanelTemplates_EnableTab"] = noIndentEffectWoWColor,
	["PanelTemplates_GetSelectedTab"] = noIndentEffectWoWColor,
	["PanelTemplates_GetTabWidth"] = noIndentEffectWoWColor,
	["PanelTemplates_SelectTab"] = noIndentEffectWoWColor,
	["PanelTemplates_SetDisabledTabState"] = noIndentEffectWoWColor,
	["PanelTemplates_SetNumTabs"] = noIndentEffectWoWColor,
	["PanelTemplates_SetTab"] = noIndentEffectWoWColor,
	["PanelTemplates_TabResize"] = noIndentEffectWoWColor,
	["PanelTemplates_Tab_OnClick"] = noIndentEffectWoWColor,
	["PanelTemplates_UpdateTabs"] = noIndentEffectWoWColor,
	["PaperDollFormatStat"] = noIndentEffectWoWColor,
	["PaperDollFrameItemFlyoutButton_OnClick"] = noIndentEffectWoWColor,
	["PaperDollFrameItemFlyoutButton_OnEnter"] = noIndentEffectWoWColor,
	["PaperDollFrameItemFlyout_CreateButton"] = noIndentEffectWoWColor,
	["PaperDollFrameItemFlyout_DisplayButton"] = noIndentEffectWoWColor,
	["PaperDollFrameItemFlyout_DisplaySpecialButton"] = noIndentEffectWoWColor,
	["PaperDollFrameItemFlyout_Hide"] = noIndentEffectWoWColor,
	["PaperDollFrameItemFlyout_OnEvent"] = noIndentEffectWoWColor,
	["PaperDollFrameItemFlyout_OnHide"] = noIndentEffectWoWColor,
	["PaperDollFrameItemFlyout_OnShow"] = noIndentEffectWoWColor,
	["PaperDollFrameItemFlyout_OnUpdate"] = noIndentEffectWoWColor,
	["PaperDollFrameItemFlyout_Show"] = noIndentEffectWoWColor,
	["PaperDollFrameItemPopoutButton_HideAll"] = noIndentEffectWoWColor,
	["PaperDollFrameItemPopoutButton_OnClick"] = noIndentEffectWoWColor,
	["PaperDollFrameItemPopoutButton_OnLoad"] = noIndentEffectWoWColor,
	["PaperDollFrameItemPopoutButton_SetReversed"] = noIndentEffectWoWColor,
	["PaperDollFrameItemPopoutButton_ShowAll"] = noIndentEffectWoWColor,
	["PaperDollFrame_ClearIgnoredSlots"] = noIndentEffectWoWColor,
	["PaperDollFrame_GetArmorReduction"] = noIndentEffectWoWColor,
	["PaperDollFrame_IgnoreSlotsForSet"] = noIndentEffectWoWColor,
	["PaperDollFrame_OnEvent"] = noIndentEffectWoWColor,
	["PaperDollFrame_OnHide"] = noIndentEffectWoWColor,
	["PaperDollFrame_OnLoad"] = noIndentEffectWoWColor,
	["PaperDollFrame_OnShow"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetArmor"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetAttackBothHands"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetAttackPower"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetAttackSpeed"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetBlock"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetDamage"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetDefense"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetDodge"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetExpertise"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetGuild"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetLabelAndText"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetLevel"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetManaRegen"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetMeleeCritChance"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetParry"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetRangedAttack"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetRangedAttackPower"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetRangedAttackSpeed"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetRangedCritChance"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetRangedDamage"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetRating"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetResilience"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetResistances"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetSpellBonusDamage"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetSpellBonusHealing"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetSpellCritChance"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetSpellHaste"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetSpellPenetration"] = noIndentEffectWoWColor,
	["PaperDollFrame_SetStat"] = noIndentEffectWoWColor,
	["PaperDollFrame_UpdateStats"] = noIndentEffectWoWColor,
	["PaperDollItemSlotButton_OnClick"] = noIndentEffectWoWColor,
	["PaperDollItemSlotButton_OnEnter"] = noIndentEffectWoWColor,
	["PaperDollItemSlotButton_OnEvent"] = noIndentEffectWoWColor,
	["PaperDollItemSlotButton_OnHide"] = noIndentEffectWoWColor,
	["PaperDollItemSlotButton_OnLeave"] = noIndentEffectWoWColor,
	["PaperDollItemSlotButton_OnLoad"] = noIndentEffectWoWColor,
	["PaperDollItemSlotButton_OnModifiedClick"] = noIndentEffectWoWColor,
	["PaperDollItemSlotButton_OnShow"] = noIndentEffectWoWColor,
	["PaperDollItemSlotButton_Update"] = noIndentEffectWoWColor,
	["PaperDollItemSlotButton_UpdateFlyout"] = noIndentEffectWoWColor,
	["PaperDollItemSlotButton_UpdateLock"] = noIndentEffectWoWColor,
	["PaperDollStatTooltip"] = noIndentEffectWoWColor,
	["PaperDoll_IsEquippedSlot"] = noIndentEffectWoWColor,
	["PartialPlayTime"] = noIndentEffectWoWColor,
	["PartyFrameDropDown_Initialize"] = noIndentEffectWoWColor,
	["PartyFrameDropDown_OnLoad"] = noIndentEffectWoWColor,
	["PartyLFGStartBackfill"] = noIndentEffectWoWColor,
	["PartyMemberBackground_SaveOpacity"] = noIndentEffectWoWColor,
	["PartyMemberBackground_SetOpacity"] = noIndentEffectWoWColor,
	["PartyMemberBackground_ToggleOpacity"] = noIndentEffectWoWColor,
	["PartyMemberBuffTooltip_Update"] = noIndentEffectWoWColor,
	["PartyMemberFrame_OnEvent"] = noIndentEffectWoWColor,
	["PartyMemberFrame_OnLoad"] = noIndentEffectWoWColor,
	["PartyMemberFrame_OnUpdate"] = noIndentEffectWoWColor,
	["PartyMemberFrame_RefreshPetDebuffs"] = noIndentEffectWoWColor,
	["PartyMemberFrame_ToPlayerArt"] = noIndentEffectWoWColor,
	["PartyMemberFrame_ToVehicleArt"] = noIndentEffectWoWColor,
	["PartyMemberFrame_UpdateArt"] = noIndentEffectWoWColor,
	["PartyMemberFrame_UpdateAssignedRoles"] = noIndentEffectWoWColor,
	["PartyMemberFrame_UpdateLeader"] = noIndentEffectWoWColor,
	["PartyMemberFrame_UpdateMember"] = noIndentEffectWoWColor,
	["PartyMemberFrame_UpdateMemberHealth"] = noIndentEffectWoWColor,
	["PartyMemberFrame_UpdateOnlineStatus"] = noIndentEffectWoWColor,
	["PartyMemberFrame_UpdatePet"] = noIndentEffectWoWColor,
	["PartyMemberFrame_UpdatePvPStatus"] = noIndentEffectWoWColor,
	["PartyMemberFrame_UpdateReadyCheck"] = noIndentEffectWoWColor,
	["PartyMemberFrame_UpdateStatusBarText"] = noIndentEffectWoWColor,
	["PartyMemberFrame_UpdateVoiceStatus"] = noIndentEffectWoWColor,
	["PartyMemberHealthCheck"] = noIndentEffectWoWColor,
	["PendingListFrameDropDown_Initialize"] = noIndentEffectWoWColor,
	["PendingListFrameDropDown_OnLoad"] = noIndentEffectWoWColor,
	["PendingListFrame_BlockCommunication"] = noIndentEffectWoWColor,
	["PendingListFrame_OnHide"] = noIndentEffectWoWColor,
	["PendingListFrame_OnShow"] = noIndentEffectWoWColor,
	["PendingListFrame_ReportPlayer"] = noIndentEffectWoWColor,
	["PendingListFrame_ReportSpam"] = noIndentEffectWoWColor,
	["PendingList_Scroll"] = noIndentEffectWoWColor,
	["PendingList_Update"] = noIndentEffectWoWColor,
	["PendingList_UpdateTab"] = noIndentEffectWoWColor,
	["PetAbandon"] = noIndentEffectWoWColor,
	["PetActionBarFrame_IsAboveShapeshift"] = noIndentEffectWoWColor,
	["PetActionBarFrame_OnUpdate"] = noIndentEffectWoWColor,
	["PetActionBar_HideGrid"] = noIndentEffectWoWColor,
	["PetActionBar_OnEvent"] = noIndentEffectWoWColor,
	["PetActionBar_OnLoad"] = noIndentEffectWoWColor,
	["PetActionBar_ShowGrid"] = noIndentEffectWoWColor,
	["PetActionBar_Update"] = noIndentEffectWoWColor,
	["PetActionBar_UpdateCooldowns"] = noIndentEffectWoWColor,
	["PetActionBar_UpdatePositionValues"] = noIndentEffectWoWColor,
	["PetActionButtonDown"] = noIndentEffectWoWColor,
	["PetActionButtonUp"] = noIndentEffectWoWColor,
	["PetActionButton_IsFlashing"] = noIndentEffectWoWColor,
	["PetActionButton_OnClick"] = noIndentEffectWoWColor,
	["PetActionButton_OnDragStart"] = noIndentEffectWoWColor,
	["PetActionButton_OnEnter"] = noIndentEffectWoWColor,
	["PetActionButton_OnEvent"] = noIndentEffectWoWColor,
	["PetActionButton_OnLeave"] = noIndentEffectWoWColor,
	["PetActionButton_OnLoad"] = noIndentEffectWoWColor,
	["PetActionButton_OnModifiedClick"] = noIndentEffectWoWColor,
	["PetActionButton_OnReceiveDrag"] = noIndentEffectWoWColor,
	["PetActionButton_OnUpdate"] = noIndentEffectWoWColor,
	["PetActionButton_SetHotkeys"] = noIndentEffectWoWColor,
	["PetActionButton_StartFlash"] = noIndentEffectWoWColor,
	["PetActionButton_StopFlash"] = noIndentEffectWoWColor,
	["PetAggressiveMode"] = noIndentEffectWoWColor,
	["PetAttack"] = noIndentEffectWoWColor,
	["PetCanBeAbandoned"] = noIndentEffectWoWColor,
	["PetCanBeDismissed"] = noIndentEffectWoWColor,
	["PetCanBeRenamed"] = noIndentEffectWoWColor,
	["PetCastingBarFrame_OnEvent"] = noIndentEffectWoWColor,
	["PetCastingBarFrame_OnLoad"] = noIndentEffectWoWColor,
	["PetDefensiveMode"] = noIndentEffectWoWColor,
	["PetDismiss"] = noIndentEffectWoWColor,
	["PetExpBar_Update"] = noIndentEffectWoWColor,
	["PetFollow"] = noIndentEffectWoWColor,
	["PetFrameDropDown_Initialize"] = noIndentEffectWoWColor,
	["PetFrameDropDown_OnLoad"] = noIndentEffectWoWColor,
	["PetFrame_OnEvent"] = noIndentEffectWoWColor,
	["PetFrame_OnLoad"] = noIndentEffectWoWColor,
	["PetFrame_OnUpdate"] = noIndentEffectWoWColor,
	["PetFrame_SetHappiness"] = noIndentEffectWoWColor,
	["PetFrame_Update"] = noIndentEffectWoWColor,
	["PetHasActionBar"] = noIndentEffectWoWColor,
	["PetPaperDollFrame_FindCompanionIndex"] = noIndentEffectWoWColor,
	["PetPaperDollFrame_OnEvent"] = noIndentEffectWoWColor,
	["PetPaperDollFrame_OnHide"] = noIndentEffectWoWColor,
	["PetPaperDollFrame_OnLoad"] = noIndentEffectWoWColor,
	["PetPaperDollFrame_OnShow"] = noIndentEffectWoWColor,
	["PetPaperDollFrame_SetCompanionPage"] = noIndentEffectWoWColor,
	["PetPaperDollFrame_SetResistances"] = noIndentEffectWoWColor,
	["PetPaperDollFrame_SetSpellBonusDamage"] = noIndentEffectWoWColor,
	["PetPaperDollFrame_SetStats"] = noIndentEffectWoWColor,
	["PetPaperDollFrame_SetTab"] = noIndentEffectWoWColor,
	["PetPaperDollFrame_Update"] = noIndentEffectWoWColor,
	["PetPaperDollFrame_UpdateCompanionCooldowns"] = noIndentEffectWoWColor,
	["PetPaperDollFrame_UpdateCompanionPreview"] = noIndentEffectWoWColor,
	["PetPaperDollFrame_UpdateCompanions"] = noIndentEffectWoWColor,
	["PetPaperDollFrame_UpdateIsAvailable"] = noIndentEffectWoWColor,
	["PetPaperDollFrame_UpdateTabs"] = noIndentEffectWoWColor,
	["PetPassiveMode"] = noIndentEffectWoWColor,
	["PetRename"] = noIndentEffectWoWColor,
	["PetStable_NoPetsAllowed"] = noIndentEffectWoWColor,
	["PetStable_OnEvent"] = noIndentEffectWoWColor,
	["PetStable_OnLoad"] = noIndentEffectWoWColor,
	["PetStable_Update"] = noIndentEffectWoWColor,
	["PetStopAttack"] = noIndentEffectWoWColor,
	["PetWait"] = noIndentEffectWoWColor,
	["PetitionFrame_Update"] = noIndentEffectWoWColor,
	["PickupAction"] = noIndentEffectWoWColor,
	["PickupBagFromSlot"] = noIndentEffectWoWColor,
	["PickupCompanion"] = noIndentEffectWoWColor,
	["PickupContainerItem"] = noIndentEffectWoWColor,
	["PickupEquipmentSet"] = noIndentEffectWoWColor,
	["PickupEquipmentSetByName"] = noIndentEffectWoWColor,
	["PickupGuildBankItem"] = noIndentEffectWoWColor,
	["PickupGuildBankMoney"] = noIndentEffectWoWColor,
	["PickupInventoryItem"] = noIndentEffectWoWColor,
	["PickupItem"] = noIndentEffectWoWColor,
	["PickupMacro"] = noIndentEffectWoWColor,
	["PickupMerchantItem"] = noIndentEffectWoWColor,
	["PickupPetAction"] = noIndentEffectWoWColor,
	["PickupPlayerMoney"] = noIndentEffectWoWColor,
	["PickupSpell"] = noIndentEffectWoWColor,
	["PickupStablePet"] = noIndentEffectWoWColor,
	["PickupTradeMoney"] = noIndentEffectWoWColor,
	["PitchDownStart"] = noIndentEffectWoWColor,
	["PitchDownStop"] = noIndentEffectWoWColor,
	["PitchUpStart"] = noIndentEffectWoWColor,
	["PitchUpStop"] = noIndentEffectWoWColor,
	["PlaceAction"] = noIndentEffectWoWColor,
	["PlaceAuctionBid"] = noIndentEffectWoWColor,
	["PlaceGlyphInSocket"] = noIndentEffectWoWColor,
	["PlayDance"] = noIndentEffectWoWColor,
	["PlayMusic"] = noIndentEffectWoWColor,
	["PlaySound"] = noIndentEffectWoWColor,
	["PlaySoundFile"] = noIndentEffectWoWColor,
	["PlayerCanTeleport"] = noIndentEffectWoWColor,
	["PlayerFrameDropDown_Initialize"] = noIndentEffectWoWColor,
	["PlayerFrameDropDown_OnLoad"] = noIndentEffectWoWColor,
	["PlayerFrame_AnimFinished"] = noIndentEffectWoWColor,
	["PlayerFrame_AnimateOut"] = noIndentEffectWoWColor,
	["PlayerFrame_OnEvent"] = noIndentEffectWoWColor,
	["PlayerFrame_OnLoad"] = noIndentEffectWoWColor,
	["PlayerFrame_OnReceiveDrag"] = noIndentEffectWoWColor,
	["PlayerFrame_OnUpdate"] = noIndentEffectWoWColor,
	["PlayerFrame_SequenceFinished"] = noIndentEffectWoWColor,
	["PlayerFrame_SetRunicPower"] = noIndentEffectWoWColor,
	["PlayerFrame_SetupDeathKnniggetLayout"] = noIndentEffectWoWColor,
	["PlayerFrame_ToPlayerArt"] = noIndentEffectWoWColor,
	["PlayerFrame_ToVehicleArt"] = noIndentEffectWoWColor,
	["PlayerFrame_Update"] = noIndentEffectWoWColor,
	["PlayerFrame_UpdateArt"] = noIndentEffectWoWColor,
	["PlayerFrame_UpdateGroupIndicator"] = noIndentEffectWoWColor,
	["PlayerFrame_UpdateLayout"] = noIndentEffectWoWColor,
	["PlayerFrame_UpdatePartyLeader"] = noIndentEffectWoWColor,
	["PlayerFrame_UpdatePlaytime"] = noIndentEffectWoWColor,
	["PlayerFrame_UpdatePvPStatus"] = noIndentEffectWoWColor,
	["PlayerFrame_UpdateReadyCheck"] = noIndentEffectWoWColor,
	["PlayerFrame_UpdateRolesAssigned"] = noIndentEffectWoWColor,
	["PlayerFrame_UpdateStatus"] = noIndentEffectWoWColor,
	["PlayerFrame_UpdateVoiceStatus"] = noIndentEffectWoWColor,
	["PlayerIsPVPInactive"] = noIndentEffectWoWColor,
	["PlayerStatFrameLeftDropDown_Initialize"] = noIndentEffectWoWColor,
	["PlayerStatFrameLeftDropDown_OnClick"] = noIndentEffectWoWColor,
	["PlayerStatFrameLeftDropDown_OnLoad"] = noIndentEffectWoWColor,
	["PlayerStatFrameLeftDropDown_OnShow"] = noIndentEffectWoWColor,
	["PlayerStatFrameRightDropDown_Initialize"] = noIndentEffectWoWColor,
	["PlayerStatFrameRightDropDown_OnClick"] = noIndentEffectWoWColor,
	["PlayerStatFrameRightDropDown_OnLoad"] = noIndentEffectWoWColor,
	["PlayerStatFrameRightDropDown_OnShow"] = noIndentEffectWoWColor,
	["PlayerTitleButton_OnClick"] = noIndentEffectWoWColor,
	["PlayerTitleFrame_UpdateTitles"] = noIndentEffectWoWColor,
	["PlayerTitlePickerFrame_Toggle"] = noIndentEffectWoWColor,
	["PlayerTitlePickerScrollFrame_OnLoad"] = noIndentEffectWoWColor,
	["PlayerTitlePickerScrollFrame_Update"] = noIndentEffectWoWColor,
	["PositionMiniWorldMapArrowFrame"] = noIndentEffectWoWColor,
	["PositionWorldMapArrowFrame"] = noIndentEffectWoWColor,
	["PossessBar_OnEvent"] = noIndentEffectWoWColor,
	["PossessBar_OnLoad"] = noIndentEffectWoWColor,
	["PossessBar_Update"] = noIndentEffectWoWColor,
	["PossessBar_UpdateState"] = noIndentEffectWoWColor,
	["PossessButton_OnClick"] = noIndentEffectWoWColor,
	["PossessButton_OnEnter"] = noIndentEffectWoWColor,
	["PrevView"] = noIndentEffectWoWColor,
	["ProcessMapClick"] = noIndentEffectWoWColor,
	["ProcessQuestLogRewardFactions"] = noIndentEffectWoWColor,
	["PromoteToAssistant"] = noIndentEffectWoWColor,
	["PromoteToLeader"] = noIndentEffectWoWColor,
	["PurchaseSlot"] = noIndentEffectWoWColor,
	["PutItemInBackpack"] = noIndentEffectWoWColor,
	["PutItemInBag"] = noIndentEffectWoWColor,
	["PutKeyInKeyRing"] = noIndentEffectWoWColor,
	["QueryAuctionItems"] = noIndentEffectWoWColor,
	["QueryCastSequence"] = noIndentEffectWoWColor,
	["QueryGuildBankLog"] = noIndentEffectWoWColor,
	["QueryGuildBankTab"] = noIndentEffectWoWColor,
	["QueryGuildBankText"] = noIndentEffectWoWColor,
	["QueryGuildEventLog"] = noIndentEffectWoWColor,
	["QueryQuestsCompleted"] = noIndentEffectWoWColor,
	["QuestChooseRewardError"] = noIndentEffectWoWColor,
	["QuestDetailAcceptButton_OnClick"] = noIndentEffectWoWColor,
	["QuestDetailDeclineButton_OnClick"] = noIndentEffectWoWColor,
	["QuestFlagsPVP"] = noIndentEffectWoWColor,
	["QuestFrameDetailPanel_OnShow"] = noIndentEffectWoWColor,
	["QuestFrameGreetingPanel_OnShow"] = noIndentEffectWoWColor,
	["QuestFrameProgressItems_Update"] = noIndentEffectWoWColor,
	["QuestFrameProgressPanel_OnShow"] = noIndentEffectWoWColor,
	["QuestFrameRewardPanel_OnShow"] = noIndentEffectWoWColor,
	["QuestFrame_GetMaterial"] = noIndentEffectWoWColor,
	["QuestFrame_OnEvent"] = noIndentEffectWoWColor,
	["QuestFrame_OnHide"] = noIndentEffectWoWColor,
	["QuestFrame_OnLoad"] = noIndentEffectWoWColor,
	["QuestFrame_OnShow"] = noIndentEffectWoWColor,
	["QuestFrame_SetMaterial"] = noIndentEffectWoWColor,
	["QuestFrame_SetPortrait"] = noIndentEffectWoWColor,
	["QuestFrame_SetTextColor"] = noIndentEffectWoWColor,
	["QuestFrame_SetTitleTextColor"] = noIndentEffectWoWColor,
	["QuestGetAutoAccept"] = noIndentEffectWoWColor,
	["QuestGoodbyeButton_OnClick"] = noIndentEffectWoWColor,
	["QuestInfoFadingFrame_OnUpdate"] = noIndentEffectWoWColor,
	["QuestInfoItem_OnClick"] = noIndentEffectWoWColor,
	["QuestInfoTimerFrame_OnUpdate"] = noIndentEffectWoWColor,
	["QuestInfo_Display"] = noIndentEffectWoWColor,
	["QuestInfo_DoReputations"] = noIndentEffectWoWColor,
	["QuestInfo_ShowAnchor"] = noIndentEffectWoWColor,
	["QuestInfo_ShowDescriptionHeader"] = noIndentEffectWoWColor,
	["QuestInfo_ShowDescriptionText"] = noIndentEffectWoWColor,
	["QuestInfo_ShowFadingFrame"] = noIndentEffectWoWColor,
	["QuestInfo_ShowGroupSize"] = noIndentEffectWoWColor,
	["QuestInfo_ShowObjectives"] = noIndentEffectWoWColor,
	["QuestInfo_ShowObjectivesHeader"] = noIndentEffectWoWColor,
	["QuestInfo_ShowObjectivesText"] = noIndentEffectWoWColor,
	["QuestInfo_ShowRequiredMoney"] = noIndentEffectWoWColor,
	["QuestInfo_ShowRewardText"] = noIndentEffectWoWColor,
	["QuestInfo_ShowRewards"] = noIndentEffectWoWColor,
	["QuestInfo_ShowSpacer"] = noIndentEffectWoWColor,
	["QuestInfo_ShowTimer"] = noIndentEffectWoWColor,
	["QuestInfo_ShowTitle"] = noIndentEffectWoWColor,
	["QuestInfo_ToggleRewardElement"] = noIndentEffectWoWColor,
	["QuestIsDaily"] = noIndentEffectWoWColor,
	["QuestIsWeekly"] = noIndentEffectWoWColor,
	["QuestLogControlPanel_UpdatePosition"] = noIndentEffectWoWColor,
	["QuestLogControlPanel_UpdateState"] = noIndentEffectWoWColor,
	["QuestLogDetailFrame_AttachToQuestLog"] = noIndentEffectWoWColor,
	["QuestLogDetailFrame_DetachFromQuestLog"] = noIndentEffectWoWColor,
	["QuestLogDetailFrame_OnHide"] = noIndentEffectWoWColor,
	["QuestLogDetailFrame_OnLoad"] = noIndentEffectWoWColor,
	["QuestLogDetailFrame_OnShow"] = noIndentEffectWoWColor,
	["QuestLogFrameTrackButton_OnClick"] = noIndentEffectWoWColor,
	["QuestLogPushQuest"] = noIndentEffectWoWColor,
	["QuestLogScrollFrame_OnLoad"] = noIndentEffectWoWColor,
	["QuestLogShowMapPOI_UpdatePosition"] = noIndentEffectWoWColor,
	["QuestLogTitleButton_OnClick"] = noIndentEffectWoWColor,
	["QuestLogTitleButton_OnEnter"] = noIndentEffectWoWColor,
	["QuestLogTitleButton_OnEvent"] = noIndentEffectWoWColor,
	["QuestLogTitleButton_OnLeave"] = noIndentEffectWoWColor,
	["QuestLogTitleButton_OnLoad"] = noIndentEffectWoWColor,
	["QuestLogTitleButton_Resize"] = noIndentEffectWoWColor,
	["QuestLog_GetFirstSelectableQuest"] = noIndentEffectWoWColor,
	["QuestLog_OnEvent"] = noIndentEffectWoWColor,
	["QuestLog_OnHide"] = noIndentEffectWoWColor,
	["QuestLog_OnLoad"] = noIndentEffectWoWColor,
	["QuestLog_OnShow"] = noIndentEffectWoWColor,
	["QuestLog_OnUpdate"] = noIndentEffectWoWColor,
	["QuestLog_OpenToQuest"] = noIndentEffectWoWColor,
	["QuestLog_SetFirstValidSelection"] = noIndentEffectWoWColor,
	["QuestLog_SetNearestValidSelection"] = noIndentEffectWoWColor,
	["QuestLog_SetSelection"] = noIndentEffectWoWColor,
	["QuestLog_UnsetSelection"] = noIndentEffectWoWColor,
	["QuestLog_Update"] = noIndentEffectWoWColor,
	["QuestLog_UpdateMap"] = noIndentEffectWoWColor,
	["QuestLog_UpdateMapButton"] = noIndentEffectWoWColor,
	["QuestLog_UpdatePartyInfoTooltip"] = noIndentEffectWoWColor,
	["QuestLog_UpdateQuestCount"] = noIndentEffectWoWColor,
	["QuestLog_UpdateQuestDetails"] = noIndentEffectWoWColor,
	["QuestMapUpdateAllQuests"] = noIndentEffectWoWColor,
	["QuestPOIButton_OnMouseDown"] = noIndentEffectWoWColor,
	["QuestPOIButton_OnMouseUp"] = noIndentEffectWoWColor,
	["QuestPOIGetIconInfo"] = noIndentEffectWoWColor,
	["QuestPOIGetQuestIDByIndex"] = noIndentEffectWoWColor,
	["QuestPOIGetQuestIDByVisibleIndex"] = noIndentEffectWoWColor,
	["QuestPOIUpdateIcons"] = noIndentEffectWoWColor,
	["QuestPOIUpdateTexture"] = noIndentEffectWoWColor,
	["QuestPOI_DeselectButton"] = noIndentEffectWoWColor,
	["QuestPOI_DeselectButtonByParent"] = noIndentEffectWoWColor,
	["QuestPOI_DisplayButton"] = noIndentEffectWoWColor,
	["QuestPOI_HideAllButtons"] = noIndentEffectWoWColor,
	["QuestPOI_HideButtons"] = noIndentEffectWoWColor,
	["QuestPOI_SelectButton"] = noIndentEffectWoWColor,
	["QuestPOI_SelectButtonByIndex"] = noIndentEffectWoWColor,
	["QuestPOI_SelectButtonByQuestId"] = noIndentEffectWoWColor,
	["QuestPOI_SetTextColor"] = noIndentEffectWoWColor,
	["QuestProgressCompleteButton_OnClick"] = noIndentEffectWoWColor,
	["QuestRewardCancelButton_OnClick"] = noIndentEffectWoWColor,
	["QuestRewardCompleteButton_OnClick"] = noIndentEffectWoWColor,
	["QuestRewardItem_OnClick"] = noIndentEffectWoWColor,
	["QuestTitleButton_OnClick"] = noIndentEffectWoWColor,
	["Quit"] = noIndentEffectWoWColor,
	["RaidBossEmoteFrame_OnEvent"] = noIndentEffectWoWColor,
	["RaidBossEmoteFrame_OnLoad"] = noIndentEffectWoWColor,
	["RaidFrame_LoadUI"] = noIndentEffectWoWColor,
	["RaidFrame_OnEvent"] = noIndentEffectWoWColor,
	["RaidFrame_OnLoad"] = noIndentEffectWoWColor,
	["RaidFrame_Update"] = noIndentEffectWoWColor,
	["RaidInfoExtendButton_OnClick"] = noIndentEffectWoWColor,
	["RaidInfoFrame_Update"] = noIndentEffectWoWColor,
	["RaidInfoFrame_UpdateSelectedIndex"] = noIndentEffectWoWColor,
	["RaidInfoInstance_OnClick"] = noIndentEffectWoWColor,
	["RaidInfoInstance_OnEnter"] = noIndentEffectWoWColor,
	["RaidInfoInstance_OnMouseDown"] = noIndentEffectWoWColor,
	["RaidInfoInstance_OnMouseUp"] = noIndentEffectWoWColor,
	["RaidInfoScrollFrame_OnLoad"] = noIndentEffectWoWColor,
	["RaidNotice_AddMessage"] = noIndentEffectWoWColor,
	["RaidNotice_FadeInit"] = noIndentEffectWoWColor,
	["RaidNotice_OnUpdate"] = noIndentEffectWoWColor,
	["RaidNotice_SetSlot"] = noIndentEffectWoWColor,
	["RaidNotice_UpdateSlot"] = noIndentEffectWoWColor,
	["RaidOptionsFrame_UpdatePartyFrames"] = noIndentEffectWoWColor,
	["RaidWarningFrame_OnEvent"] = noIndentEffectWoWColor,
	["RaidWarningFrame_OnLoad"] = noIndentEffectWoWColor,
	["RaiseFrameLevel"] = noIndentEffectWoWColor,
	["RaiseFrameLevelByTwo"] = noIndentEffectWoWColor,
	["RandomRoll"] = noIndentEffectWoWColor,
	["ReadFile"] = noIndentEffectWoWColor,
	["ReadyCheckFrame_OnEvent"] = noIndentEffectWoWColor,
	["ReadyCheckFrame_OnHide"] = noIndentEffectWoWColor,
	["ReadyCheckFrame_OnLoad"] = noIndentEffectWoWColor,
	["ReadyCheck_Confirm"] = noIndentEffectWoWColor,
	["ReadyCheck_Finish"] = noIndentEffectWoWColor,
	["ReadyCheck_OnUpdate"] = noIndentEffectWoWColor,
	["ReadyCheck_Start"] = noIndentEffectWoWColor,
	["RealPartyIsFull"] = noIndentEffectWoWColor,
	["RecalculateGearManagerDialogPopup"] = noIndentEffectWoWColor,
	["RecentTimeDate"] = noIndentEffectWoWColor,
	["RecordLoopbackSoundButton_OnUpdate"] = noIndentEffectWoWColor,
	["RefreshAuras"] = noIndentEffectWoWColor,
	["RefreshBuffs"] = noIndentEffectWoWColor,
	["RefreshDebuffs"] = noIndentEffectWoWColor,
	["RefreshEquipmentSetIconInfo"] = noIndentEffectWoWColor,
	["RefreshLFGList"] = noIndentEffectWoWColor,
	["RefreshMoneyFrame"] = noIndentEffectWoWColor,
	["RegisterAutoHide"] = noIndentEffectWoWColor,
	["RegisterCVar"] = noIndentEffectWoWColor,
	["RegisterForSave"] = noIndentEffectWoWColor,
	["RegisterForSavePerCharacter"] = noIndentEffectWoWColor,
	["RegisterStateDriver"] = noIndentEffectWoWColor,
	["RegisterStaticConstants"] = noIndentEffectWoWColor,
	["RegisterUnitWatch"] = noIndentEffectWoWColor,
	["RejectProposal"] = noIndentEffectWoWColor,
	["ReloadUI"] = noIndentEffectWoWColor,
	["RemoveChatWindowChannel"] = noIndentEffectWoWColor,
	["RemoveChatWindowMessages"] = noIndentEffectWoWColor,
	["RemoveFriend"] = noIndentEffectWoWColor,
	["RemoveGlyphFromSocket"] = noIndentEffectWoWColor,
	["RemoveQuestWatch"] = noIndentEffectWoWColor,
	["RemoveSkillUp"] = noIndentEffectWoWColor,
	["RemoveTrackedAchievement"] = noIndentEffectWoWColor,
	["RenameEquipmentSet"] = noIndentEffectWoWColor,
	["RenamePetition"] = noIndentEffectWoWColor,
	["RepairAllItems"] = noIndentEffectWoWColor,
	["ReplaceEnchant"] = noIndentEffectWoWColor,
	["ReplaceTradeEnchant"] = noIndentEffectWoWColor,
	["RepopMe"] = noIndentEffectWoWColor,
	["ReportBug"] = noIndentEffectWoWColor,
	["ReportPlayerIsPVPAFK"] = noIndentEffectWoWColor,
	["ReportSuggestion"] = noIndentEffectWoWColor,
	["ReputationBar_DrawHorizontalLine"] = noIndentEffectWoWColor,
	["ReputationBar_DrawVerticalLine"] = noIndentEffectWoWColor,
	["ReputationBar_OnClick"] = noIndentEffectWoWColor,
	["ReputationFrame_OnEvent"] = noIndentEffectWoWColor,
	["ReputationFrame_OnLoad"] = noIndentEffectWoWColor,
	["ReputationFrame_OnShow"] = noIndentEffectWoWColor,
	["ReputationFrame_SetRowType"] = noIndentEffectWoWColor,
	["ReputationFrame_Update"] = noIndentEffectWoWColor,
	["ReputationWatchBar_Update"] = noIndentEffectWoWColor,
	["RequestBattlefieldPositions"] = noIndentEffectWoWColor,
	["RequestBattlefieldScoreData"] = noIndentEffectWoWColor,
	["RequestBattlegroundInstanceInfo"] = noIndentEffectWoWColor,
	["RequestInspectHonorData"] = noIndentEffectWoWColor,
	["RequestLFDPartyLockInfo"] = noIndentEffectWoWColor,
	["RequestLFDPlayerLockInfo"] = noIndentEffectWoWColor,
	["RequestRaidInfo"] = noIndentEffectWoWColor,
	["RequestTimePlayed"] = noIndentEffectWoWColor,
	["ResetCPUUsage"] = noIndentEffectWoWColor,
	["ResetChatColors"] = noIndentEffectWoWColor,
	["ResetChatWindows"] = noIndentEffectWoWColor,
	["ResetCursor"] = noIndentEffectWoWColor,
	["ResetDisabledAddOns"] = noIndentEffectWoWColor,
	["ResetGroupPreviewTalentPoints"] = noIndentEffectWoWColor,
	["ResetInstances"] = noIndentEffectWoWColor,
	["ResetPerformanceValues"] = noIndentEffectWoWColor,
	["ResetPreviewTalentPoints"] = noIndentEffectWoWColor,
	["ResetTutorials"] = noIndentEffectWoWColor,
	["ResetView"] = noIndentEffectWoWColor,
	["RespondInstanceLock"] = noIndentEffectWoWColor,
	["RespondMailLockSendItem"] = noIndentEffectWoWColor,
	["RestartGx"] = noIndentEffectWoWColor,
	["RestoreVideoEffectsDefaults"] = noIndentEffectWoWColor,
	["RestoreVideoResolutionDefaults"] = noIndentEffectWoWColor,
	["RestoreVideoStereoDefaults"] = noIndentEffectWoWColor,
	["ResurrectGetOfferer"] = noIndentEffectWoWColor,
	["ResurrectHasSickness"] = noIndentEffectWoWColor,
	["ResurrectHasTimer"] = noIndentEffectWoWColor,
	["RetrieveCorpse"] = noIndentEffectWoWColor,
	["ReturnInboxItem"] = noIndentEffectWoWColor,
	["RollOnLoot"] = noIndentEffectWoWColor,
	["RunBinding"] = noIndentEffectWoWColor,
	["RunMacro"] = noIndentEffectWoWColor,
	["RunMacroText"] = noIndentEffectWoWColor,
	["RunScript"] = noIndentEffectWoWColor,
	["RuneButton_OnEnter"] = noIndentEffectWoWColor,
	["RuneButton_OnLeave"] = noIndentEffectWoWColor,
	["RuneButton_OnLoad"] = noIndentEffectWoWColor,
	["RuneButton_OnUpdate"] = noIndentEffectWoWColor,
	["RuneButton_ShineFadeIn"] = noIndentEffectWoWColor,
	["RuneButton_ShineFadeOut"] = noIndentEffectWoWColor,
	["RuneButton_Update"] = noIndentEffectWoWColor,
	["RuneFrame_AddRune"] = noIndentEffectWoWColor,
	["RuneFrame_FixRunes"] = noIndentEffectWoWColor,
	["RuneFrame_OnEvent"] = noIndentEffectWoWColor,
	["RuneFrame_OnLoad"] = noIndentEffectWoWColor,
	["SaveBindings"] = noIndentEffectWoWColor,
	["SaveEquipmentSet"] = noIndentEffectWoWColor,
	["SavePendingGuildBankTabPermissions"] = noIndentEffectWoWColor,
	["SaveView"] = noIndentEffectWoWColor,
	["ScorePlayerDropDown_Cancel"] = noIndentEffectWoWColor,
	["ScorePlayerDropDown_Initialize"] = noIndentEffectWoWColor,
	["ScorePlayerDropDown_OnClick"] = noIndentEffectWoWColor,
	["ScorePlayer_OnMouseUp"] = noIndentEffectWoWColor,
	["Screenshot"] = noIndentEffectWoWColor,
	["ScrollFrameTemplate_OnMouseWheel"] = noIndentEffectWoWColor,
	["ScrollFrame_OnLoad"] = noIndentEffectWoWColor,
	["ScrollFrame_OnScrollRangeChanged"] = noIndentEffectWoWColor,
	["ScrollingEdit_OnCursorChanged"] = noIndentEffectWoWColor,
	["ScrollingEdit_OnTextChanged"] = noIndentEffectWoWColor,
	["ScrollingEdit_OnUpdate"] = noIndentEffectWoWColor,
	["SearchButton_OnUpdate"] = noIndentEffectWoWColor,
	["SearchLFGGetEncounterResults"] = noIndentEffectWoWColor,
	["SearchLFGGetJoinedID"] = noIndentEffectWoWColor,
	["SearchLFGGetNumResults"] = noIndentEffectWoWColor,
	["SearchLFGGetPartyResults"] = noIndentEffectWoWColor,
	["SearchLFGGetResults"] = noIndentEffectWoWColor,
	["SearchLFGJoin"] = noIndentEffectWoWColor,
	["SearchLFGLeave"] = noIndentEffectWoWColor,
	["SearchLFGSort"] = noIndentEffectWoWColor,
	["SeatIndicator_Pulse"] = noIndentEffectWoWColor,
	["SecondsToTime"] = noIndentEffectWoWColor,
	["SecondsToTimeAbbrev"] = noIndentEffectWoWColor,
	["SecureActionButton_OnClick"] = noIndentEffectWoWColor,
	["SecureButton_GetAttribute"] = noIndentEffectWoWColor,
	["SecureButton_GetButtonSuffix"] = noIndentEffectWoWColor,
	["SecureButton_GetEffectiveButton"] = noIndentEffectWoWColor,
	["SecureButton_GetModifiedAttribute"] = noIndentEffectWoWColor,
	["SecureButton_GetModifiedUnit"] = noIndentEffectWoWColor,
	["SecureButton_GetModifierPrefix"] = noIndentEffectWoWColor,
	["SecureButton_GetUnit"] = noIndentEffectWoWColor,
	["SecureButton_ParseModifierString"] = noIndentEffectWoWColor,
	["SecureCmdItemParse"] = noIndentEffectWoWColor,
	["SecureCmdOptionParse"] = noIndentEffectWoWColor,
	["SecureCmdUseItem"] = noIndentEffectWoWColor,
	["SecureGroupHeader_OnAttributeChanged"] = noIndentEffectWoWColor,
	["SecureGroupHeader_OnEvent"] = noIndentEffectWoWColor,
	["SecureGroupHeader_OnLoad"] = noIndentEffectWoWColor,
	["SecureGroupHeader_Update"] = noIndentEffectWoWColor,
	["SecureGroupPetHeader_OnAttributeChanged"] = noIndentEffectWoWColor,
	["SecureGroupPetHeader_OnEvent"] = noIndentEffectWoWColor,
	["SecureGroupPetHeader_OnLoad"] = noIndentEffectWoWColor,
	["SecureGroupPetHeader_Update"] = noIndentEffectWoWColor,
	["SecureHandlerExecute"] = noIndentEffectWoWColor,
	["SecureHandlerSetFrameRef"] = noIndentEffectWoWColor,
	["SecureHandlerUnwrapScript"] = noIndentEffectWoWColor,
	["SecureHandlerWrapScript"] = noIndentEffectWoWColor,
	["SecureHandler_AttributeOnAttributeChanged"] = noIndentEffectWoWColor,
	["SecureHandler_OnClick"] = noIndentEffectWoWColor,
	["SecureHandler_OnDragEvent"] = noIndentEffectWoWColor,
	["SecureHandler_OnLoad"] = noIndentEffectWoWColor,
	["SecureHandler_OnMouseUpDown"] = noIndentEffectWoWColor,
	["SecureHandler_OnMouseWheel"] = noIndentEffectWoWColor,
	["SecureHandler_OnSimpleEvent"] = noIndentEffectWoWColor,
	["SecureHandler_StateOnAttributeChanged"] = noIndentEffectWoWColor,
	["SecureUnitButton_OnClick"] = noIndentEffectWoWColor,
	["SecureUnitButton_OnLoad"] = noIndentEffectWoWColor,
	["SelectActiveQuest"] = noIndentEffectWoWColor,
	["SelectAvailableQuest"] = noIndentEffectWoWColor,
	["SelectGossipActiveQuest"] = noIndentEffectWoWColor,
	["SelectGossipAvailableQuest"] = noIndentEffectWoWColor,
	["SelectGossipOption"] = noIndentEffectWoWColor,
	["SelectPackage"] = noIndentEffectWoWColor,
	["SelectQuestLogEntry"] = noIndentEffectWoWColor,
	["SelectStationery"] = noIndentEffectWoWColor,
	["SelectTradeSkill"] = noIndentEffectWoWColor,
	["SelectTrainerService"] = noIndentEffectWoWColor,
	["SendAddonMessage"] = noIndentEffectWoWColor,
	["SendChatMessage"] = noIndentEffectWoWColor,
	["SendMail"] = noIndentEffectWoWColor,
	["SendMailAttachmentButton_OnClick"] = noIndentEffectWoWColor,
	["SendMailAttachmentButton_OnDropAny"] = noIndentEffectWoWColor,
	["SendMailAttachment_OnEnter"] = noIndentEffectWoWColor,
	["SendMailFrame_CanSend"] = noIndentEffectWoWColor,
	["SendMailFrame_Reset"] = noIndentEffectWoWColor,
	["SendMailFrame_SendMail"] = noIndentEffectWoWColor,
	["SendMailFrame_Update"] = noIndentEffectWoWColor,
	["SendMailMailButton_OnClick"] = noIndentEffectWoWColor,
	["SendMailMoneyButton_OnClick"] = noIndentEffectWoWColor,
	["SendMailRadioButton_OnClick"] = noIndentEffectWoWColor,
	["SendSystemMessage"] = noIndentEffectWoWColor,
	["SendWho"] = noIndentEffectWoWColor,
	["SetAbandonQuest"] = noIndentEffectWoWColor,
	["SetAchievementComparisonUnit"] = noIndentEffectWoWColor,
	["SetActionBarToggles"] = noIndentEffectWoWColor,
	["SetActiveTalentGroup"] = noIndentEffectWoWColor,
	["SetActiveVoiceChannel"] = noIndentEffectWoWColor,
	["SetActiveVoiceChannelBySessionID"] = noIndentEffectWoWColor,
	["SetAllowLowLevelRaid"] = noIndentEffectWoWColor,
	["SetArenaTeamRosterSelection"] = noIndentEffectWoWColor,
	["SetArenaTeamRosterShowOffline"] = noIndentEffectWoWColor,
	["SetAuctionsTabShowing"] = noIndentEffectWoWColor,
	["SetBagPortraitTexture"] = noIndentEffectWoWColor,
	["SetBaseMip"] = noIndentEffectWoWColor,
	["SetBattlefieldScoreFaction"] = noIndentEffectWoWColor,
	["SetBinding"] = noIndentEffectWoWColor,
	["SetBindingClick"] = noIndentEffectWoWColor,
	["SetBindingItem"] = noIndentEffectWoWColor,
	["SetBindingMacro"] = noIndentEffectWoWColor,
	["SetBindingSpell"] = noIndentEffectWoWColor,
	["SetButtonPulse"] = noIndentEffectWoWColor,
	["SetCVar"] = noIndentEffectWoWColor,
	["SetChannelOwner"] = noIndentEffectWoWColor,
	["SetChannelPassword"] = noIndentEffectWoWColor,
	["SetChannelWatch"] = noIndentEffectWoWColor,
	["SetChatColorNameByClass"] = noIndentEffectWoWColor,
	["SetChatMouseOverDelay"] = noIndentEffectWoWColor,
	["SetChatUnitColor"] = noIndentEffectWoWColor,
	["SetChatWindowAlpha"] = noIndentEffectWoWColor,
	["SetChatWindowColor"] = noIndentEffectWoWColor,
	["SetChatWindowDocked"] = noIndentEffectWoWColor,
	["SetChatWindowLocked"] = noIndentEffectWoWColor,
	["SetChatWindowName"] = noIndentEffectWoWColor,
	["SetChatWindowSavedDimensions"] = noIndentEffectWoWColor,
	["SetChatWindowSavedPosition"] = noIndentEffectWoWColor,
	["SetChatWindowShown"] = noIndentEffectWoWColor,
	["SetChatWindowSize"] = noIndentEffectWoWColor,
	["SetChatWindowUninteractable"] = noIndentEffectWoWColor,
	["SetConsoleKey"] = noIndentEffectWoWColor,
	["SetCurrencyBackpack"] = noIndentEffectWoWColor,
	["SetCurrencyUnused"] = noIndentEffectWoWColor,
	["SetCurrentGuildBankTab"] = noIndentEffectWoWColor,
	["SetCurrentTitle"] = noIndentEffectWoWColor,
	["SetCursor"] = noIndentEffectWoWColor,
	["SetDesaturation"] = noIndentEffectWoWColor,
	["SetDressUpBackground"] = noIndentEffectWoWColor,
	["SetDungeonDifficulty"] = noIndentEffectWoWColor,
	["SetDungeonMapLevel"] = noIndentEffectWoWColor,
	["SetEuropeanNumbers"] = noIndentEffectWoWColor,
	["SetFactionActive"] = noIndentEffectWoWColor,
	["SetFactionInactive"] = noIndentEffectWoWColor,
	["SetFarclip"] = noIndentEffectWoWColor,
	["SetFriendNotes"] = noIndentEffectWoWColor,
	["SetGamma"] = noIndentEffectWoWColor,
	["SetGuildBankTabInfo"] = noIndentEffectWoWColor,
	["SetGuildBankTabPermissions"] = noIndentEffectWoWColor,
	["SetGuildBankTabWithdraw"] = noIndentEffectWoWColor,
	["SetGuildBankText"] = noIndentEffectWoWColor,
	["SetGuildBankWithdrawLimit"] = noIndentEffectWoWColor,
	["SetGuildInfoText"] = noIndentEffectWoWColor,
	["SetGuildRosterSelection"] = noIndentEffectWoWColor,
	["SetGuildRosterShowOffline"] = noIndentEffectWoWColor,
	["SetInventoryPortraitTexture"] = noIndentEffectWoWColor,
	["SetItemButtonCount"] = noIndentEffectWoWColor,
	["SetItemButtonDesaturated"] = noIndentEffectWoWColor,
	["SetItemButtonNameFrameVertexColor"] = noIndentEffectWoWColor,
	["SetItemButtonNormalTextureVertexColor"] = noIndentEffectWoWColor,
	["SetItemButtonSlotVertexColor"] = noIndentEffectWoWColor,
	["SetItemButtonStock"] = noIndentEffectWoWColor,
	["SetItemButtonTexture"] = noIndentEffectWoWColor,
	["SetItemButtonTextureVertexColor"] = noIndentEffectWoWColor,
	["SetItemRef"] = noIndentEffectWoWColor,
	["SetLFGBootVote"] = noIndentEffectWoWColor,
	["SetLFGComment"] = noIndentEffectWoWColor,
	["SetLFGDungeon"] = noIndentEffectWoWColor,
	["SetLFGDungeonEnabled"] = noIndentEffectWoWColor,
	["SetLFGHeaderCollapsed"] = noIndentEffectWoWColor,
	["SetLFGRoles"] = noIndentEffectWoWColor,
	["SetLayoutMode"] = noIndentEffectWoWColor,
	["SetLootMethod"] = noIndentEffectWoWColor,
	["SetLootPortrait"] = noIndentEffectWoWColor,
	["SetLootThreshold"] = noIndentEffectWoWColor,
	["SetMacroItem"] = noIndentEffectWoWColor,
	["SetMacroSpell"] = noIndentEffectWoWColor,
	["SetMapByID"] = noIndentEffectWoWColor,
	["SetMapToCurrentZone"] = noIndentEffectWoWColor,
	["SetMapZoom"] = noIndentEffectWoWColor,
	["SetModifiedClick"] = noIndentEffectWoWColor,
	["SetMoneyFrameColor"] = noIndentEffectWoWColor,
	["SetMouselookOverrideBinding"] = noIndentEffectWoWColor,
	["SetMultiCastSpell"] = noIndentEffectWoWColor,
	["SetMultisampleFormat"] = noIndentEffectWoWColor,
	["SetNextBarberShopStyle"] = noIndentEffectWoWColor,
	["SetOptOutOfLoot"] = noIndentEffectWoWColor,
	["SetOverrideBinding"] = noIndentEffectWoWColor,
	["SetOverrideBindingClick"] = noIndentEffectWoWColor,
	["SetOverrideBindingItem"] = noIndentEffectWoWColor,
	["SetOverrideBindingMacro"] = noIndentEffectWoWColor,
	["SetOverrideBindingSpell"] = noIndentEffectWoWColor,
	["SetPOIIconOverlapDistance"] = noIndentEffectWoWColor,
	["SetPOIIconOverlapPushDistance"] = noIndentEffectWoWColor,
	["SetPVP"] = noIndentEffectWoWColor,
	["SetPartyAssignment"] = noIndentEffectWoWColor,
	["SetPendingGuildBankTabPermissions"] = noIndentEffectWoWColor,
	["SetPendingGuildBankTabWithdraw"] = noIndentEffectWoWColor,
	["SetPetStablePaperdoll"] = noIndentEffectWoWColor,
	["SetPortraitTexture"] = noIndentEffectWoWColor,
	["SetPortraitToTexture"] = noIndentEffectWoWColor,
	["SetRaidDifficulty"] = noIndentEffectWoWColor,
	["SetRaidRosterSelection"] = noIndentEffectWoWColor,
	["SetRaidSubgroup"] = noIndentEffectWoWColor,
	["SetRaidTarget"] = noIndentEffectWoWColor,
	["SetRaidTargetIcon"] = noIndentEffectWoWColor,
	["SetRaidTargetIconTexture"] = noIndentEffectWoWColor,
	["SetSavedInstanceExtend"] = noIndentEffectWoWColor,
	["SetScreenResolution"] = noIndentEffectWoWColor,
	["SetSelectedAuctionItem"] = noIndentEffectWoWColor,
	["SetSelectedBattlefield"] = noIndentEffectWoWColor,
	["SetSelectedDisplayChannel"] = noIndentEffectWoWColor,
	["SetSelectedFaction"] = noIndentEffectWoWColor,
	["SetSelectedFriend"] = noIndentEffectWoWColor,
	["SetSelectedIgnore"] = noIndentEffectWoWColor,
	["SetSelectedMute"] = noIndentEffectWoWColor,
	["SetSelectedSkill"] = noIndentEffectWoWColor,
	["SetSelfMuteState"] = noIndentEffectWoWColor,
	["SetSendMailCOD"] = noIndentEffectWoWColor,
	["SetSendMailMoney"] = noIndentEffectWoWColor,
	["SetSendMailShowing"] = noIndentEffectWoWColor,
	["SetSpellNameColor"] = noIndentEffectWoWColor,
	["SetTableColor"] = noIndentEffectWoWColor,
	["SetTalentButtonLocation"] = noIndentEffectWoWColor,
	["SetTargetSpellbarAspect"] = noIndentEffectWoWColor,
	["SetTaxiBenchmarkMode"] = noIndentEffectWoWColor,
	["SetTaxiMap"] = noIndentEffectWoWColor,
	["SetTerrainMip"] = noIndentEffectWoWColor,
	["SetTexLodBias"] = noIndentEffectWoWColor,
	["SetTextStatusBarText"] = noIndentEffectWoWColor,
	["SetTextStatusBarTextPrefix"] = noIndentEffectWoWColor,
	["SetTextStatusBarTextZeroText"] = noIndentEffectWoWColor,
	["SetTitleByName"] = noIndentEffectWoWColor,
	["SetTooltipMoney"] = noIndentEffectWoWColor,
	["SetTracking"] = noIndentEffectWoWColor,
	["SetTradeMoney"] = noIndentEffectWoWColor,
	["SetTradeSkillInvSlotFilter"] = noIndentEffectWoWColor,
	["SetTradeSkillItemLevelFilter"] = noIndentEffectWoWColor,
	["SetTradeSkillItemNameFilter"] = noIndentEffectWoWColor,
	["SetTradeSkillSubClassFilter"] = noIndentEffectWoWColor,
	["SetTrainerServiceTypeFilter"] = noIndentEffectWoWColor,
	["SetTrainerSkillLineFilter"] = noIndentEffectWoWColor,
	["SetUIVisibility"] = noIndentEffectWoWColor,
	["SetUpAnimation"] = noIndentEffectWoWColor,
	["SetView"] = noIndentEffectWoWColor,
	["SetWatchedFactionIndex"] = noIndentEffectWoWColor,
	["SetWaterDetail"] = noIndentEffectWoWColor,
	["SetWhoToUI"] = noIndentEffectWoWColor,
	["SetZoneText"] = noIndentEffectWoWColor,
	["SetupFullscreenScale"] = noIndentEffectWoWColor,
	["SetupUnitButtonConfiguration"] = noIndentEffectWoWColor,
	["ShapeshiftBar_ChangeForm"] = noIndentEffectWoWColor,
	["ShapeshiftBar_OnEvent"] = noIndentEffectWoWColor,
	["ShapeshiftBar_OnLoad"] = noIndentEffectWoWColor,
	["ShapeshiftBar_Update"] = noIndentEffectWoWColor,
	["ShapeshiftBar_UpdateState"] = noIndentEffectWoWColor,
	["ShiftQuestWatches"] = noIndentEffectWoWColor,
	["ShowBonusActionBar"] = noIndentEffectWoWColor,
	["ShowBuybackSellCursor"] = noIndentEffectWoWColor,
	["ShowCloak"] = noIndentEffectWoWColor,
	["ShowContainerSellCursor"] = noIndentEffectWoWColor,
	["ShowFriends"] = noIndentEffectWoWColor,
	["ShowHelm"] = noIndentEffectWoWColor,
	["ShowInspectCursor"] = noIndentEffectWoWColor,
	["ShowInventorySellCursor"] = noIndentEffectWoWColor,
	["ShowMacroFrame"] = noIndentEffectWoWColor,
	["ShowMerchantSellCursor"] = noIndentEffectWoWColor,
	["ShowMiniWorldMapArrowFrame"] = noIndentEffectWoWColor,
	["ShowMultiCastActionBar"] = noIndentEffectWoWColor,
	["ShowNumericThreat"] = noIndentEffectWoWColor,
	["ShowPartyFrame"] = noIndentEffectWoWColor,
	["ShowPetActionBar"] = noIndentEffectWoWColor,
	["ShowQuickButton"] = noIndentEffectWoWColor,
	["ShowReadyCheck"] = noIndentEffectWoWColor,
	["ShowRepairCursor"] = noIndentEffectWoWColor,
	["ShowResurrectRequest"] = noIndentEffectWoWColor,
	["ShowTextStatusBarText"] = noIndentEffectWoWColor,
	["ShowUIPanel"] = noIndentEffectWoWColor,
	["ShowWatchedReputationBarText"] = noIndentEffectWoWColor,
	["ShowWhoPanel"] = noIndentEffectWoWColor,
	["ShowWorldMapArrowFrame"] = noIndentEffectWoWColor,
	["ShowingCloak"] = noIndentEffectWoWColor,
	["ShowingHelm"] = noIndentEffectWoWColor,
	["SignPetition"] = noIndentEffectWoWColor,
	["SilenceMember"] = noIndentEffectWoWColor,
	["SitStandOrDescendStart"] = noIndentEffectWoWColor,
	["SkillBar_OnClick"] = noIndentEffectWoWColor,
	["SkillDetailFrame_SetStatusBar"] = noIndentEffectWoWColor,
	["SkillFrame_OnEvent"] = noIndentEffectWoWColor,
	["SkillFrame_OnLoad"] = noIndentEffectWoWColor,
	["SkillFrame_OnShow"] = noIndentEffectWoWColor,
	["SkillFrame_SetStatusBar"] = noIndentEffectWoWColor,
	["SkillFrame_UpdateSkills"] = noIndentEffectWoWColor,
	["SmallMoneyFrame_OnLoad"] = noIndentEffectWoWColor,
	["SocketContainerItem"] = noIndentEffectWoWColor,
	["SocketInventoryItem"] = noIndentEffectWoWColor,
	["SortArenaTeamRoster"] = noIndentEffectWoWColor,
	["SortAuctionApplySort"] = noIndentEffectWoWColor,
	["SortAuctionClearSort"] = noIndentEffectWoWColor,
	["SortAuctionItems"] = noIndentEffectWoWColor,
	["SortAuctionSetSort"] = noIndentEffectWoWColor,
	["SortBGList"] = noIndentEffectWoWColor,
	["SortBattlefieldScoreData"] = noIndentEffectWoWColor,
	["SortGuildRoster"] = noIndentEffectWoWColor,
	["SortQuestWatches"] = noIndentEffectWoWColor,
	["SortWho"] = noIndentEffectWoWColor,
	["Sound_ChatSystem_GetInputDriverNameByIndex"] = noIndentEffectWoWColor,
	["Sound_ChatSystem_GetNumInputDrivers"] = noIndentEffectWoWColor,
	["Sound_ChatSystem_GetNumOutputDrivers"] = noIndentEffectWoWColor,
	["Sound_ChatSystem_GetOutputDriverNameByIndex"] = noIndentEffectWoWColor,
	["Sound_GameSystem_GetInputDriverNameByIndex"] = noIndentEffectWoWColor,
	["Sound_GameSystem_GetNumInputDrivers"] = noIndentEffectWoWColor,
	["Sound_GameSystem_GetNumOutputDrivers"] = noIndentEffectWoWColor,
	["Sound_GameSystem_GetOutputDriverNameByIndex"] = noIndentEffectWoWColor,
	["Sound_GameSystem_RestartSoundSystem"] = noIndentEffectWoWColor,
	["Sound_MasterVolumeDown"] = noIndentEffectWoWColor,
	["Sound_MasterVolumeUp"] = noIndentEffectWoWColor,
	["Sound_ToggleMusic"] = noIndentEffectWoWColor,
	["Sound_ToggleSound"] = noIndentEffectWoWColor,
	["SpellBookFrameTabButton_OnClick"] = noIndentEffectWoWColor,
	["SpellBookFrame_HideSpells"] = noIndentEffectWoWColor,
	["SpellBookFrame_OnEvent"] = noIndentEffectWoWColor,
	["SpellBookFrame_OnHide"] = noIndentEffectWoWColor,
	["SpellBookFrame_OnLoad"] = noIndentEffectWoWColor,
	["SpellBookFrame_OnShow"] = noIndentEffectWoWColor,
	["SpellBookFrame_PlayCloseSound"] = noIndentEffectWoWColor,
	["SpellBookFrame_PlayOpenSound"] = noIndentEffectWoWColor,
	["SpellBookFrame_SetTabType"] = noIndentEffectWoWColor,
	["SpellBookFrame_ShowSpells"] = noIndentEffectWoWColor,
	["SpellBookFrame_Update"] = noIndentEffectWoWColor,
	["SpellBookFrame_UpdatePages"] = noIndentEffectWoWColor,
	["SpellBookNextPageButton_OnClick"] = noIndentEffectWoWColor,
	["SpellBookPrevPageButton_OnClick"] = noIndentEffectWoWColor,
	["SpellBookSkillLineTab_OnClick"] = noIndentEffectWoWColor,
	["SpellBook_GetAutoCastShine"] = noIndentEffectWoWColor,
	["SpellBook_GetCurrentPage"] = noIndentEffectWoWColor,
	["SpellBook_GetSpellID"] = noIndentEffectWoWColor,
	["SpellBook_GetTabInfo"] = noIndentEffectWoWColor,
	["SpellBook_ReleaseAutoCastShine"] = noIndentEffectWoWColor,
	["SpellBook_UpdatePageArrows"] = noIndentEffectWoWColor,
	["SpellButton_OnClick"] = noIndentEffectWoWColor,
	["SpellButton_OnDrag"] = noIndentEffectWoWColor,
	["SpellButton_OnEnter"] = noIndentEffectWoWColor,
	["SpellButton_OnEvent"] = noIndentEffectWoWColor,
	["SpellButton_OnHide"] = noIndentEffectWoWColor,
	["SpellButton_OnLoad"] = noIndentEffectWoWColor,
	["SpellButton_OnModifiedClick"] = noIndentEffectWoWColor,
	["SpellButton_OnShow"] = noIndentEffectWoWColor,
	["SpellButton_UpdateButton"] = noIndentEffectWoWColor,
	["SpellButton_UpdateSelection"] = noIndentEffectWoWColor,
	["SpellCanTargetGlyph"] = noIndentEffectWoWColor,
	["SpellCanTargetItem"] = noIndentEffectWoWColor,
	["SpellCanTargetUnit"] = noIndentEffectWoWColor,
	["SpellColor_OpenColorPicker"] = noIndentEffectWoWColor,
	["SpellHasRange"] = noIndentEffectWoWColor,
	["SpellIsTargeting"] = noIndentEffectWoWColor,
	["SpellStopCasting"] = noIndentEffectWoWColor,
	["SpellStopTargeting"] = noIndentEffectWoWColor,
	["SpellTargetItem"] = noIndentEffectWoWColor,
	["SpellTargetUnit"] = noIndentEffectWoWColor,
	["SplitContainerItem"] = noIndentEffectWoWColor,
	["SplitGuildBankItem"] = noIndentEffectWoWColor,
	["StablePet"] = noIndentEffectWoWColor,
	["StackSplitFrameCancel_Click"] = noIndentEffectWoWColor,
	["StackSplitFrameLeft_Click"] = noIndentEffectWoWColor,
	["StackSplitFrameOkay_Click"] = noIndentEffectWoWColor,
	["StackSplitFrameRight_Click"] = noIndentEffectWoWColor,
	["StackSplitFrame_OnChar"] = noIndentEffectWoWColor,
	["StackSplitFrame_OnHide"] = noIndentEffectWoWColor,
	["StackSplitFrame_OnKeyDown"] = noIndentEffectWoWColor,
	["StackSplitFrame_OnKeyUp"] = noIndentEffectWoWColor,
	["StartAttack"] = noIndentEffectWoWColor,
	["StartAuction"] = noIndentEffectWoWColor,
	["StartDuel"] = noIndentEffectWoWColor,
	["StaticPopupSpecial_Hide"] = noIndentEffectWoWColor,
	["StaticPopupSpecial_Show"] = noIndentEffectWoWColor,
	["StaticPopup_CollapseTable"] = noIndentEffectWoWColor,
	["StaticPopup_EditBoxOnEnterPressed"] = noIndentEffectWoWColor,
	["StaticPopup_EditBoxOnEscapePressed"] = noIndentEffectWoWColor,
	["StaticPopup_EditBoxOnTextChanged"] = noIndentEffectWoWColor,
	["StaticPopup_EscapePressed"] = noIndentEffectWoWColor,
	["StaticPopup_FindVisible"] = noIndentEffectWoWColor,
	["StaticPopup_Hide"] = noIndentEffectWoWColor,
	["StaticPopup_HideExclusive"] = noIndentEffectWoWColor,
	["StaticPopup_IsLastDisplayedFrame"] = noIndentEffectWoWColor,
	["StaticPopup_OnClick"] = noIndentEffectWoWColor,
	["StaticPopup_OnEvent"] = noIndentEffectWoWColor,
	["StaticPopup_OnHide"] = noIndentEffectWoWColor,
	["StaticPopup_OnKeyDown"] = noIndentEffectWoWColor,
	["StaticPopup_OnShow"] = noIndentEffectWoWColor,
	["StaticPopup_OnUpdate"] = noIndentEffectWoWColor,
	["StaticPopup_Resize"] = noIndentEffectWoWColor,
	["StaticPopup_SetUpPosition"] = noIndentEffectWoWColor,
	["StaticPopup_Show"] = noIndentEffectWoWColor,
	["StaticPopup_Visible"] = noIndentEffectWoWColor,
	["StationeryPopupButton_OnClick"] = noIndentEffectWoWColor,
	["StationeryPopupFrame_Update"] = noIndentEffectWoWColor,
	["StatsFrame_OnLoad"] = noIndentEffectWoWColor,
	["StatsFrame_OnUpdate"] = noIndentEffectWoWColor,
	["StopAttack"] = noIndentEffectWoWColor,
	["StopCinematic"] = noIndentEffectWoWColor,
	["StopMacro"] = noIndentEffectWoWColor,
	["StopMusic"] = noIndentEffectWoWColor,
	["StopTradeSkillRepeat"] = noIndentEffectWoWColor,
	["StopwatchCloseButton_OnClick"] = noIndentEffectWoWColor,
	["StopwatchFrame_OnDragStart"] = noIndentEffectWoWColor,
	["StopwatchFrame_OnDragStop"] = noIndentEffectWoWColor,
	["StopwatchFrame_OnEvent"] = noIndentEffectWoWColor,
	["StopwatchFrame_OnHide"] = noIndentEffectWoWColor,
	["StopwatchFrame_OnLoad"] = noIndentEffectWoWColor,
	["StopwatchFrame_OnMouseDown"] = noIndentEffectWoWColor,
	["StopwatchFrame_OnMouseUp"] = noIndentEffectWoWColor,
	["StopwatchFrame_OnShow"] = noIndentEffectWoWColor,
	["StopwatchFrame_OnUpdate"] = noIndentEffectWoWColor,
	["StopwatchPlayPauseButton_OnClick"] = noIndentEffectWoWColor,
	["StopwatchResetButton_OnClick"] = noIndentEffectWoWColor,
	["StopwatchTicker_OnUpdate"] = noIndentEffectWoWColor,
	["StopwatchTicker_Update"] = noIndentEffectWoWColor,
	["Stopwatch_Clear"] = noIndentEffectWoWColor,
	["Stopwatch_FinishCountdown"] = noIndentEffectWoWColor,
	["Stopwatch_IsPlaying"] = noIndentEffectWoWColor,
	["Stopwatch_Pause"] = noIndentEffectWoWColor,
	["Stopwatch_Play"] = noIndentEffectWoWColor,
	["Stopwatch_StartCountdown"] = noIndentEffectWoWColor,
	["Stopwatch_Toggle"] = noIndentEffectWoWColor,
	["StrafeLeftStart"] = noIndentEffectWoWColor,
	["StrafeLeftStop"] = noIndentEffectWoWColor,
	["StrafeRightStart"] = noIndentEffectWoWColor,
	["StrafeRightStop"] = noIndentEffectWoWColor,
	["Stuck"] = noIndentEffectWoWColor,
	["SubZoneText_OnLoad"] = noIndentEffectWoWColor,
	["SummonFriend"] = noIndentEffectWoWColor,
	["SummonRandomCritter"] = noIndentEffectWoWColor,
	["SwapRaidSubgroup"] = noIndentEffectWoWColor,
	["SynchronizeBNetStatus"] = noIndentEffectWoWColor,
	["TEXT"] = noIndentEffectWoWColor,
	["TabardCharacterModelFrame_OnLoad"] = noIndentEffectWoWColor,
	["TabardCharacterModelFrame_OnUpdate"] = noIndentEffectWoWColor,
	["TabardCharacterModelRotateLeftButton_OnClick"] = noIndentEffectWoWColor,
	["TabardCharacterModelRotateRightButton_OnClick"] = noIndentEffectWoWColor,
	["TabardCustomization_Left"] = noIndentEffectWoWColor,
	["TabardCustomization_Right"] = noIndentEffectWoWColor,
	["TabardFrame_OnEvent"] = noIndentEffectWoWColor,
	["TabardFrame_OnLoad"] = noIndentEffectWoWColor,
	["TabardFrame_UpdateButtons"] = noIndentEffectWoWColor,
	["TabardFrame_UpdateTextures"] = noIndentEffectWoWColor,
	["TakeInboxItem"] = noIndentEffectWoWColor,
	["TakeInboxMoney"] = noIndentEffectWoWColor,
	["TakeInboxTextItem"] = noIndentEffectWoWColor,
	["TakeScreenshot"] = noIndentEffectWoWColor,
	["TakeTaxiNode"] = noIndentEffectWoWColor,
	["TalentFrame_DrawLines"] = noIndentEffectWoWColor,
	["TalentFrame_GetArrowTexture"] = noIndentEffectWoWColor,
	["TalentFrame_GetArrowTextureCount"] = noIndentEffectWoWColor,
	["TalentFrame_GetBranchTexture"] = noIndentEffectWoWColor,
	["TalentFrame_GetBranchTextureCount"] = noIndentEffectWoWColor,
	["TalentFrame_Load"] = noIndentEffectWoWColor,
	["TalentFrame_LoadUI"] = noIndentEffectWoWColor,
	["TalentFrame_ResetArrowTextureCount"] = noIndentEffectWoWColor,
	["TalentFrame_ResetBranchTextureCount"] = noIndentEffectWoWColor,
	["TalentFrame_ResetBranches"] = noIndentEffectWoWColor,
	["TalentFrame_SetArrowTexture"] = noIndentEffectWoWColor,
	["TalentFrame_SetBranchTexture"] = noIndentEffectWoWColor,
	["TalentFrame_SetPrereqs"] = noIndentEffectWoWColor,
	["TalentFrame_Update"] = noIndentEffectWoWColor,
	["TalentFrame_UpdateSpecInfoCache"] = noIndentEffectWoWColor,
	["TalentFrame_UpdateTalentPoints"] = noIndentEffectWoWColor,
	["TalentMicroButton_OnEvent"] = noIndentEffectWoWColor,
	["TargetDirectionEnemy"] = noIndentEffectWoWColor,
	["TargetDirectionFinished"] = noIndentEffectWoWColor,
	["TargetDirectionFriend"] = noIndentEffectWoWColor,
	["TargetFrameDropDown_Initialize"] = noIndentEffectWoWColor,
	["TargetFrame_CheckClassification"] = noIndentEffectWoWColor,
	["TargetFrame_CheckDead"] = noIndentEffectWoWColor,
	["TargetFrame_CheckFaction"] = noIndentEffectWoWColor,
	["TargetFrame_CheckLevel"] = noIndentEffectWoWColor,
	["TargetFrame_CreateSpellbar"] = noIndentEffectWoWColor,
	["TargetFrame_CreateTargetofTarget"] = noIndentEffectWoWColor,
	["TargetFrame_HealthUpdate"] = noIndentEffectWoWColor,
	["TargetFrame_OnEvent"] = noIndentEffectWoWColor,
	["TargetFrame_OnHide"] = noIndentEffectWoWColor,
	["TargetFrame_OnLoad"] = noIndentEffectWoWColor,
	["TargetFrame_OnUpdate"] = noIndentEffectWoWColor,
	["TargetFrame_Update"] = noIndentEffectWoWColor,
	["TargetFrame_UpdateAuraPositions"] = noIndentEffectWoWColor,
	["TargetFrame_UpdateAuras"] = noIndentEffectWoWColor,
	["TargetFrame_UpdateBuffAnchor"] = noIndentEffectWoWColor,
	["TargetFrame_UpdateDebuffAnchor"] = noIndentEffectWoWColor,
	["TargetFrame_UpdateRaidTargetIcon"] = noIndentEffectWoWColor,
	["TargetHealthCheck"] = noIndentEffectWoWColor,
	["TargetLastEnemy"] = noIndentEffectWoWColor,
	["TargetLastFriend"] = noIndentEffectWoWColor,
	["TargetLastTarget"] = noIndentEffectWoWColor,
	["TargetNearest"] = noIndentEffectWoWColor,
	["TargetNearestEnemy"] = noIndentEffectWoWColor,
	["TargetNearestEnemyPlayer"] = noIndentEffectWoWColor,
	["TargetNearestFriend"] = noIndentEffectWoWColor,
	["TargetNearestFriendPlayer"] = noIndentEffectWoWColor,
	["TargetNearestPartyMember"] = noIndentEffectWoWColor,
	["TargetNearestRaidMember"] = noIndentEffectWoWColor,
	["TargetTotem"] = noIndentEffectWoWColor,
	["TargetUnit"] = noIndentEffectWoWColor,
	["Target_Spellbar_AdjustPosition"] = noIndentEffectWoWColor,
	["Target_Spellbar_OnEvent"] = noIndentEffectWoWColor,
	["TargetofTargetHealthCheck"] = noIndentEffectWoWColor,
	["TargetofTarget_CheckDead"] = noIndentEffectWoWColor,
	["TargetofTarget_OnHide"] = noIndentEffectWoWColor,
	["TargetofTarget_Update"] = noIndentEffectWoWColor,
	["TaxiFrame_OnEvent"] = noIndentEffectWoWColor,
	["TaxiFrame_OnLoad"] = noIndentEffectWoWColor,
	["TaxiGetDestX"] = noIndentEffectWoWColor,
	["TaxiGetDestY"] = noIndentEffectWoWColor,
	["TaxiGetSrcX"] = noIndentEffectWoWColor,
	["TaxiGetSrcY"] = noIndentEffectWoWColor,
	["TaxiNodeCost"] = noIndentEffectWoWColor,
	["TaxiNodeGetType"] = noIndentEffectWoWColor,
	["TaxiNodeName"] = noIndentEffectWoWColor,
	["TaxiNodeOnButtonEnter"] = noIndentEffectWoWColor,
	["TaxiNodePosition"] = noIndentEffectWoWColor,
	["TaxiNodeSetCurrent"] = noIndentEffectWoWColor,
	["TeleportToDebugObject"] = noIndentEffectWoWColor,
	["TempEnchantButton_OnClick"] = noIndentEffectWoWColor,
	["TempEnchantButton_OnEnter"] = noIndentEffectWoWColor,
	["TempEnchantButton_OnLoad"] = noIndentEffectWoWColor,
	["TempEnchantButton_OnUpdate"] = noIndentEffectWoWColor,
	["TemporaryEnchantFrame_Hide"] = noIndentEffectWoWColor,
	["TemporaryEnchantFrame_OnUpdate"] = noIndentEffectWoWColor,
	["TextEmoteSort"] = noIndentEffectWoWColor,
	["TextStatusBar_CapDisplayOfNumericValue"] = noIndentEffectWoWColor,
	["TextStatusBar_Initialize"] = noIndentEffectWoWColor,
	["TextStatusBar_OnEvent"] = noIndentEffectWoWColor,
	["TextStatusBar_OnValueChanged"] = noIndentEffectWoWColor,
	["TextStatusBar_UpdateTextString"] = noIndentEffectWoWColor,
	["TicketStatusFrameButton_OnClick"] = noIndentEffectWoWColor,
	["TicketStatusFrameButton_OnLoad"] = noIndentEffectWoWColor,
	["TicketStatusFrame_OnEvent"] = noIndentEffectWoWColor,
	["TicketStatusFrame_OnHide"] = noIndentEffectWoWColor,
	["TicketStatusFrame_OnLoad"] = noIndentEffectWoWColor,
	["TicketStatusFrame_OnShow"] = noIndentEffectWoWColor,
	["TicketStatusFrame_OnUpdate"] = noIndentEffectWoWColor,
	["TimeManagerAlarmAMPMDropDown_Initialize"] = noIndentEffectWoWColor,
	["TimeManagerAlarmAMPMDropDown_OnClick"] = noIndentEffectWoWColor,
	["TimeManagerAlarmAMPMDropDown_OnHide"] = noIndentEffectWoWColor,
	["TimeManagerAlarmAMPMDropDown_OnShow"] = noIndentEffectWoWColor,
	["TimeManagerAlarmEnabledButton_OnClick"] = noIndentEffectWoWColor,
	["TimeManagerAlarmEnabledButton_Update"] = noIndentEffectWoWColor,
	["TimeManagerAlarmHourDropDown_Initialize"] = noIndentEffectWoWColor,
	["TimeManagerAlarmHourDropDown_OnClick"] = noIndentEffectWoWColor,
	["TimeManagerAlarmMessageEditBox_OnEditFocusLost"] = noIndentEffectWoWColor,
	["TimeManagerAlarmMessageEditBox_OnEnterPressed"] = noIndentEffectWoWColor,
	["TimeManagerAlarmMessageEditBox_OnEscapePressed"] = noIndentEffectWoWColor,
	["TimeManagerAlarmMinuteDropDown_Initialize"] = noIndentEffectWoWColor,
	["TimeManagerAlarmMinuteDropDown_OnClick"] = noIndentEffectWoWColor,
	["TimeManagerClockButton_Hide"] = noIndentEffectWoWColor,
	["TimeManagerClockButton_OnClick"] = noIndentEffectWoWColor,
	["TimeManagerClockButton_OnEnter"] = noIndentEffectWoWColor,
	["TimeManagerClockButton_OnLeave"] = noIndentEffectWoWColor,
	["TimeManagerClockButton_OnLoad"] = noIndentEffectWoWColor,
	["TimeManagerClockButton_OnUpdate"] = noIndentEffectWoWColor,
	["TimeManagerClockButton_OnUpdateWithTooltip"] = noIndentEffectWoWColor,
	["TimeManagerClockButton_Show"] = noIndentEffectWoWColor,
	["TimeManagerClockButton_Update"] = noIndentEffectWoWColor,
	["TimeManagerClockButton_UpdateTooltip"] = noIndentEffectWoWColor,
	["TimeManagerCloseButton_OnClick"] = noIndentEffectWoWColor,
	["TimeManagerFrame_OnHide"] = noIndentEffectWoWColor,
	["TimeManagerFrame_OnLoad"] = noIndentEffectWoWColor,
	["TimeManagerFrame_OnShow"] = noIndentEffectWoWColor,
	["TimeManagerFrame_OnUpdate"] = noIndentEffectWoWColor,
	["TimeManagerLocalTimeCheck_OnClick"] = noIndentEffectWoWColor,
	["TimeManagerMilitaryTimeCheck_OnClick"] = noIndentEffectWoWColor,
	["TimeManagerStopwatchCheck_OnClick"] = noIndentEffectWoWColor,
	["TimeManager_CheckAlarm"] = noIndentEffectWoWColor,
	["TimeManager_FireAlarm"] = noIndentEffectWoWColor,
	["TimeManager_FireAlarmWarning"] = noIndentEffectWoWColor,
	["TimeManager_IsAlarmFiring"] = noIndentEffectWoWColor,
	["TimeManager_LoadUI"] = noIndentEffectWoWColor,
	["TimeManager_ShouldCheckAlarm"] = noIndentEffectWoWColor,
	["TimeManager_StartCheckingAlarm"] = noIndentEffectWoWColor,
	["TimeManager_Toggle"] = noIndentEffectWoWColor,
	["TimeManager_ToggleLocalTime"] = noIndentEffectWoWColor,
	["TimeManager_ToggleTimeFormat"] = noIndentEffectWoWColor,
	["TimeManager_TurnOffAlarm"] = noIndentEffectWoWColor,
	["TimeManager_Update"] = noIndentEffectWoWColor,
	["TimeManager_UpdateAlarmTime"] = noIndentEffectWoWColor,
	["TimeManager_UpdateTimeTicker"] = noIndentEffectWoWColor,
	["ToggleAchievementFrame"] = noIndentEffectWoWColor,
	["ToggleAutoRun"] = noIndentEffectWoWColor,
	["ToggleBackpack"] = noIndentEffectWoWColor,
	["ToggleBag"] = noIndentEffectWoWColor,
	["ToggleBattlefieldMinimap"] = noIndentEffectWoWColor,
	["ToggleCalendar"] = noIndentEffectWoWColor,
	["ToggleCharacter"] = noIndentEffectWoWColor,
	["ToggleChatChannel"] = noIndentEffectWoWColor,
	["ToggleChatColorNamesByClassGroup"] = noIndentEffectWoWColor,
	["ToggleChatMessageGroup"] = noIndentEffectWoWColor,
	["ToggleCollision"] = noIndentEffectWoWColor,
	["ToggleCollisionDisplay"] = noIndentEffectWoWColor,
	["ToggleDropDownMenu"] = noIndentEffectWoWColor,
	["ToggleFrame"] = noIndentEffectWoWColor,
	["ToggleFramerate"] = noIndentEffectWoWColor,
	["ToggleFriendsFrame"] = noIndentEffectWoWColor,
	["ToggleFriendsPanel"] = noIndentEffectWoWColor,
	["ToggleGameMenu"] = noIndentEffectWoWColor,
	["ToggleGlyphFrame"] = noIndentEffectWoWColor,
	["ToggleGuildEventLog"] = noIndentEffectWoWColor,
	["ToggleGuildInfoFrame"] = noIndentEffectWoWColor,
	["ToggleHelpFrame"] = noIndentEffectWoWColor,
	["ToggleIgnorePanel"] = noIndentEffectWoWColor,
	["ToggleKeyRing"] = noIndentEffectWoWColor,
	["ToggleLFDParentFrame"] = noIndentEffectWoWColor,
	["ToggleLFRParentFrame"] = noIndentEffectWoWColor,
	["ToggleMapFramerate"] = noIndentEffectWoWColor,
	["ToggleMessageDest"] = noIndentEffectWoWColor,
	["ToggleMessageSource"] = noIndentEffectWoWColor,
	["ToggleMessageType"] = noIndentEffectWoWColor,
	["ToggleMessageTypeGroup"] = noIndentEffectWoWColor,
	["ToggleMiniMapRotation"] = noIndentEffectWoWColor,
	["ToggleMinimap"] = noIndentEffectWoWColor,
	["TogglePVP"] = noIndentEffectWoWColor,
	["TogglePVPFrame"] = noIndentEffectWoWColor,
	["TogglePerformanceDisplay"] = noIndentEffectWoWColor,
	["TogglePerformancePause"] = noIndentEffectWoWColor,
	["TogglePerformanceValues"] = noIndentEffectWoWColor,
	["TogglePetAutocast"] = noIndentEffectWoWColor,
	["TogglePlayerBounds"] = noIndentEffectWoWColor,
	["TogglePortals"] = noIndentEffectWoWColor,
	["ToggleRun"] = noIndentEffectWoWColor,
	["ToggleSheath"] = noIndentEffectWoWColor,
	["ToggleSpellAutocast"] = noIndentEffectWoWColor,
	["ToggleSpellBook"] = noIndentEffectWoWColor,
	["ToggleStats"] = noIndentEffectWoWColor,
	["ToggleTalentFrame"] = noIndentEffectWoWColor,
	["ToggleTimeManager"] = noIndentEffectWoWColor,
	["ToggleTris"] = noIndentEffectWoWColor,
	["ToggleWorldStateScoreFrame"] = noIndentEffectWoWColor,
	["TokenButtonLinkButton_OnClick"] = noIndentEffectWoWColor,
	["TokenButton_OnClick"] = noIndentEffectWoWColor,
	["TokenButton_OnLoad"] = noIndentEffectWoWColor,
	["TokenFramePopup_CloseIfHidden"] = noIndentEffectWoWColor,
	["TokenFrame_LoadUI"] = noIndentEffectWoWColor,
	["TokenFrame_OnLoad"] = noIndentEffectWoWColor,
	["TokenFrame_OnShow"] = noIndentEffectWoWColor,
	["TokenFrame_Update"] = noIndentEffectWoWColor,
	["TokenFrame_UpdatePopup"] = noIndentEffectWoWColor,
	["TotemButton_OnClick"] = noIndentEffectWoWColor,
	["TotemButton_OnLoad"] = noIndentEffectWoWColor,
	["TotemButton_OnUpdate"] = noIndentEffectWoWColor,
	["TotemButton_Update"] = noIndentEffectWoWColor,
	["TotemFrame_OnEvent"] = noIndentEffectWoWColor,
	["TotemFrame_OnLoad"] = noIndentEffectWoWColor,
	["TotemFrame_Update"] = noIndentEffectWoWColor,
	["TradeFrameCancelButton_OnClick"] = noIndentEffectWoWColor,
	["TradeFrameTradeButton_Disable"] = noIndentEffectWoWColor,
	["TradeFrameTradeButton_Enable"] = noIndentEffectWoWColor,
	["TradeFrameTradeButton_SetToEnabledState"] = noIndentEffectWoWColor,
	["TradeFrame_GetAvailableSlot"] = noIndentEffectWoWColor,
	["TradeFrame_OnEvent"] = noIndentEffectWoWColor,
	["TradeFrame_OnHide"] = noIndentEffectWoWColor,
	["TradeFrame_OnLoad"] = noIndentEffectWoWColor,
	["TradeFrame_OnMouseUp"] = noIndentEffectWoWColor,
	["TradeFrame_OnShow"] = noIndentEffectWoWColor,
	["TradeFrame_SetAcceptState"] = noIndentEffectWoWColor,
	["TradeFrame_Update"] = noIndentEffectWoWColor,
	["TradeFrame_UpdateMoney"] = noIndentEffectWoWColor,
	["TradeFrame_UpdatePlayerItem"] = noIndentEffectWoWColor,
	["TradeFrame_UpdateTargetItem"] = noIndentEffectWoWColor,
	["TradeSkillFrame_LoadUI"] = noIndentEffectWoWColor,
	["TradeSkillOnlyShowMakeable"] = noIndentEffectWoWColor,
	["TradeSkillOnlyShowSkillUps"] = noIndentEffectWoWColor,
	["TriggerTutorial"] = noIndentEffectWoWColor,
	["TurnInArenaPetition"] = noIndentEffectWoWColor,
	["TurnInGuildCharter"] = noIndentEffectWoWColor,
	["TurnInPetition"] = noIndentEffectWoWColor,
	["TurnLeftStart"] = noIndentEffectWoWColor,
	["TurnLeftStop"] = noIndentEffectWoWColor,
	["TurnOrActionStart"] = noIndentEffectWoWColor,
	["TurnOrActionStop"] = noIndentEffectWoWColor,
	["TurnRightStart"] = noIndentEffectWoWColor,
	["TurnRightStop"] = noIndentEffectWoWColor,
	["TutorialFrameNextButton_OnClick"] = noIndentEffectWoWColor,
	["TutorialFramePrevButton_OnClick"] = noIndentEffectWoWColor,
	["TutorialFrame_AlertButton_OnClick"] = noIndentEffectWoWColor,
	["TutorialFrame_CheckBadge"] = noIndentEffectWoWColor,
	["TutorialFrame_CheckNextPrevButtons"] = noIndentEffectWoWColor,
	["TutorialFrame_ClearQueue"] = noIndentEffectWoWColor,
	["TutorialFrame_ClearTextures"] = noIndentEffectWoWColor,
	["TutorialFrame_Hide"] = noIndentEffectWoWColor,
	["TutorialFrame_NewTutorial"] = noIndentEffectWoWColor,
	["TutorialFrame_OnHide"] = noIndentEffectWoWColor,
	["TutorialFrame_OnLoad"] = noIndentEffectWoWColor,
	["TutorialFrame_OnShow"] = noIndentEffectWoWColor,
	["TutorialFrame_Update"] = noIndentEffectWoWColor,
	["UIDoFramesIntersect"] = noIndentEffectWoWColor,
	["UIDropDownMenuButton_GetChecked"] = noIndentEffectWoWColor,
	["UIDropDownMenuButton_GetName"] = noIndentEffectWoWColor,
	["UIDropDownMenuButton_OnClick"] = noIndentEffectWoWColor,
	["UIDropDownMenuButton_OpenColorPicker"] = noIndentEffectWoWColor,
	["UIDropDownMenuDelegate_OnAttributeChanged"] = noIndentEffectWoWColor,
	["UIDropDownMenu_AddButton"] = noIndentEffectWoWColor,
	["UIDropDownMenu_ClearAll"] = noIndentEffectWoWColor,
	["UIDropDownMenu_CreateFrames"] = noIndentEffectWoWColor,
	["UIDropDownMenu_CreateInfo"] = noIndentEffectWoWColor,
	["UIDropDownMenu_DisableButton"] = noIndentEffectWoWColor,
	["UIDropDownMenu_DisableDropDown"] = noIndentEffectWoWColor,
	["UIDropDownMenu_EnableButton"] = noIndentEffectWoWColor,
	["UIDropDownMenu_EnableDropDown"] = noIndentEffectWoWColor,
	["UIDropDownMenu_GetCurrentDropDown"] = noIndentEffectWoWColor,
	["UIDropDownMenu_GetSelectedID"] = noIndentEffectWoWColor,
	["UIDropDownMenu_GetSelectedName"] = noIndentEffectWoWColor,
	["UIDropDownMenu_GetSelectedValue"] = noIndentEffectWoWColor,
	["UIDropDownMenu_GetText"] = noIndentEffectWoWColor,
	["UIDropDownMenu_GetValue"] = noIndentEffectWoWColor,
	["UIDropDownMenu_Initialize"] = noIndentEffectWoWColor,
	["UIDropDownMenu_InitializeHelper"] = noIndentEffectWoWColor,
	["UIDropDownMenu_IsEnabled"] = noIndentEffectWoWColor,
	["UIDropDownMenu_JustifyText"] = noIndentEffectWoWColor,
	["UIDropDownMenu_OnHide"] = noIndentEffectWoWColor,
	["UIDropDownMenu_OnUpdate"] = noIndentEffectWoWColor,
	["UIDropDownMenu_Refresh"] = noIndentEffectWoWColor,
	["UIDropDownMenu_SetAnchor"] = noIndentEffectWoWColor,
	["UIDropDownMenu_SetButtonText"] = noIndentEffectWoWColor,
	["UIDropDownMenu_SetButtonWidth"] = noIndentEffectWoWColor,
	["UIDropDownMenu_SetSelectedID"] = noIndentEffectWoWColor,
	["UIDropDownMenu_SetSelectedName"] = noIndentEffectWoWColor,
	["UIDropDownMenu_SetSelectedValue"] = noIndentEffectWoWColor,
	["UIDropDownMenu_SetText"] = noIndentEffectWoWColor,
	["UIDropDownMenu_SetWidth"] = noIndentEffectWoWColor,
	["UIDropDownMenu_StartCounting"] = noIndentEffectWoWColor,
	["UIDropDownMenu_StopCounting"] = noIndentEffectWoWColor,
	["UIErrorsFrame_OnEvent"] = noIndentEffectWoWColor,
	["UIErrorsFrame_OnLoad"] = noIndentEffectWoWColor,
	["UIFrameFade"] = noIndentEffectWoWColor,
	["UIFrameFadeIn"] = noIndentEffectWoWColor,
	["UIFrameFadeOut"] = noIndentEffectWoWColor,
	["UIFrameFadeRemoveFrame"] = noIndentEffectWoWColor,
	["UIFrameFade_OnUpdate"] = noIndentEffectWoWColor,
	["UIFrameFlash"] = noIndentEffectWoWColor,
	["UIFrameFlashRemoveFrame"] = noIndentEffectWoWColor,
	["UIFrameFlashStop"] = noIndentEffectWoWColor,
	["UIFrameFlash_OnUpdate"] = noIndentEffectWoWColor,
	["UIFrameIsFading"] = noIndentEffectWoWColor,
	["UIFrameIsFlashing"] = noIndentEffectWoWColor,
	["UIMenuButton_OnClick"] = noIndentEffectWoWColor,
	["UIMenuButton_OnEnter"] = noIndentEffectWoWColor,
	["UIMenuButton_OnLeave"] = noIndentEffectWoWColor,
	["UIMenuButton_OnLoad"] = noIndentEffectWoWColor,
	["UIMenu_AddButton"] = noIndentEffectWoWColor,
	["UIMenu_AutoSize"] = noIndentEffectWoWColor,
	["UIMenu_FinishInitializing"] = noIndentEffectWoWColor,
	["UIMenu_GetNumButtons"] = noIndentEffectWoWColor,
	["UIMenu_Initialize"] = noIndentEffectWoWColor,
	["UIMenu_OnShow"] = noIndentEffectWoWColor,
	["UIMenu_OnUpdate"] = noIndentEffectWoWColor,
	["UIMenu_StartCounting"] = noIndentEffectWoWColor,
	["UIMenu_StopCounting"] = noIndentEffectWoWColor,
	["UIParentLoadAddOn"] = noIndentEffectWoWColor,
	["UIParent_ManageFramePosition"] = noIndentEffectWoWColor,
	["UIParent_ManageFramePositions"] = noIndentEffectWoWColor,
	["UIParent_OnEvent"] = noIndentEffectWoWColor,
	["UIParent_OnLoad"] = noIndentEffectWoWColor,
	["UnSilenceMember"] = noIndentEffectWoWColor,
	["UninviteUnit"] = noIndentEffectWoWColor,
	["UnitAffectingCombat"] = noIndentEffectWoWColor,
	["UnitArmor"] = noIndentEffectWoWColor,
	["UnitAttackBothHands"] = noIndentEffectWoWColor,
	["UnitAttackPower"] = noIndentEffectWoWColor,
	["UnitAttackSpeed"] = noIndentEffectWoWColor,
	["UnitAura"] = noIndentEffectWoWColor,
	["UnitBuff"] = noIndentEffectWoWColor,
	["UnitCanAssist"] = noIndentEffectWoWColor,
	["UnitCanAttack"] = noIndentEffectWoWColor,
	["UnitCanCooperate"] = noIndentEffectWoWColor,
	["UnitCastingInfo"] = noIndentEffectWoWColor,
	["UnitChannelInfo"] = noIndentEffectWoWColor,
	["UnitCharacterPoints"] = noIndentEffectWoWColor,
	["UnitClass"] = noIndentEffectWoWColor,
	["UnitClassBase"] = noIndentEffectWoWColor,
	["UnitClassification"] = noIndentEffectWoWColor,
	["UnitControllingVehicle"] = noIndentEffectWoWColor,
	["UnitCreatureFamily"] = noIndentEffectWoWColor,
	["UnitCreatureType"] = noIndentEffectWoWColor,
	["UnitDamage"] = noIndentEffectWoWColor,
	["UnitDebuff"] = noIndentEffectWoWColor,
	["UnitDefense"] = noIndentEffectWoWColor,
	["UnitDetailedThreatSituation"] = noIndentEffectWoWColor,
	["UnitExists"] = noIndentEffectWoWColor,
	["UnitFactionGroup"] = noIndentEffectWoWColor,
	["UnitFrameHealthBar_Initialize"] = noIndentEffectWoWColor,
	["UnitFrameHealthBar_OnEvent"] = noIndentEffectWoWColor,
	["UnitFrameHealthBar_OnUpdate"] = noIndentEffectWoWColor,
	["UnitFrameHealthBar_OnValueChanged"] = noIndentEffectWoWColor,
	["UnitFrameHealthBar_Update"] = noIndentEffectWoWColor,
	["UnitFrameManaBar_Initialize"] = noIndentEffectWoWColor,
	["UnitFrameManaBar_OnEvent"] = noIndentEffectWoWColor,
	["UnitFrameManaBar_OnUpdate"] = noIndentEffectWoWColor,
	["UnitFrameManaBar_RegisterDefaultEvents"] = noIndentEffectWoWColor,
	["UnitFrameManaBar_UnregisterDefaultEvents"] = noIndentEffectWoWColor,
	["UnitFrameManaBar_Update"] = noIndentEffectWoWColor,
	["UnitFrameManaBar_UpdateType"] = noIndentEffectWoWColor,
	["UnitFramePortrait_Update"] = noIndentEffectWoWColor,
	["UnitFrameThreatIndicator_Initialize"] = noIndentEffectWoWColor,
	["UnitFrameThreatIndicator_OnEvent"] = noIndentEffectWoWColor,
	["UnitFrame_Initialize"] = noIndentEffectWoWColor,
	["UnitFrame_OnEnter"] = noIndentEffectWoWColor,
	["UnitFrame_OnEvent"] = noIndentEffectWoWColor,
	["UnitFrame_OnLeave"] = noIndentEffectWoWColor,
	["UnitFrame_SetUnit"] = noIndentEffectWoWColor,
	["UnitFrame_Update"] = noIndentEffectWoWColor,
	["UnitFrame_UpdateThreatIndicator"] = noIndentEffectWoWColor,
	["UnitFrame_UpdateTooltip"] = noIndentEffectWoWColor,
	["UnitGUID"] = noIndentEffectWoWColor,
	["UnitGroupRolesAssigned"] = noIndentEffectWoWColor,
	["UnitHasLFGDeserter"] = noIndentEffectWoWColor,
	["UnitHasLFGRandomCooldown"] = noIndentEffectWoWColor,
	["UnitHasMana"] = noIndentEffectWoWColor,
	["UnitHasRelicSlot"] = noIndentEffectWoWColor,
	["UnitHasVehicleUI"] = noIndentEffectWoWColor,
	["UnitHealth"] = noIndentEffectWoWColor,
	["UnitHealthMax"] = noIndentEffectWoWColor,
	["UnitInBattleground"] = noIndentEffectWoWColor,
	["UnitInParty"] = noIndentEffectWoWColor,
	["UnitInRaid"] = noIndentEffectWoWColor,
	["UnitInRange"] = noIndentEffectWoWColor,
	["UnitInVehicle"] = noIndentEffectWoWColor,
	["UnitInVehicleControlSeat"] = noIndentEffectWoWColor,
	["UnitIsAFK"] = noIndentEffectWoWColor,
	["UnitIsCharmed"] = noIndentEffectWoWColor,
	["UnitIsConnected"] = noIndentEffectWoWColor,
	["UnitIsControlling"] = noIndentEffectWoWColor,
	["UnitIsCorpse"] = noIndentEffectWoWColor,
	["UnitIsDND"] = noIndentEffectWoWColor,
	["UnitIsDead"] = noIndentEffectWoWColor,
	["UnitIsDeadOrGhost"] = noIndentEffectWoWColor,
	["UnitIsEnemy"] = noIndentEffectWoWColor,
	["UnitIsFeignDeath"] = noIndentEffectWoWColor,
	["UnitIsFriend"] = noIndentEffectWoWColor,
	["UnitIsGhost"] = noIndentEffectWoWColor,
	["UnitIsInMyGuild"] = noIndentEffectWoWColor,
	["UnitIsPVP"] = noIndentEffectWoWColor,
	["UnitIsPVPFreeForAll"] = noIndentEffectWoWColor,
	["UnitIsPVPSanctuary"] = noIndentEffectWoWColor,
	["UnitIsPartyLeader"] = noIndentEffectWoWColor,
	["UnitIsPlayer"] = noIndentEffectWoWColor,
	["UnitIsPossessed"] = noIndentEffectWoWColor,
	["UnitIsRaidOfficer"] = noIndentEffectWoWColor,
	["UnitIsSameServer"] = noIndentEffectWoWColor,
	["UnitIsSilenced"] = noIndentEffectWoWColor,
	["UnitIsTalking"] = noIndentEffectWoWColor,
	["UnitIsTapped"] = noIndentEffectWoWColor,
	["UnitIsTappedByAllThreatList"] = noIndentEffectWoWColor,
	["UnitIsTappedByPlayer"] = noIndentEffectWoWColor,
	["UnitIsTrivial"] = noIndentEffectWoWColor,
	["UnitIsUnit"] = noIndentEffectWoWColor,
	["UnitIsVisible"] = noIndentEffectWoWColor,
	["UnitLevel"] = noIndentEffectWoWColor,
	["UnitMana"] = noIndentEffectWoWColor,
	["UnitManaMax"] = noIndentEffectWoWColor,
	["UnitName"] = noIndentEffectWoWColor,
	["UnitOnTaxi"] = noIndentEffectWoWColor,
	["UnitPVPName"] = noIndentEffectWoWColor,
	["UnitPVPRank"] = noIndentEffectWoWColor,
	["UnitPlayerControlled"] = noIndentEffectWoWColor,
	["UnitPlayerOrPetInParty"] = noIndentEffectWoWColor,
	["UnitPlayerOrPetInRaid"] = noIndentEffectWoWColor,
	["UnitPopup_HideButtons"] = noIndentEffectWoWColor,
	["UnitPopup_OnClick"] = noIndentEffectWoWColor,
	["UnitPopup_OnUpdate"] = noIndentEffectWoWColor,
	["UnitPopup_ShowMenu"] = noIndentEffectWoWColor,
	["UnitPower"] = noIndentEffectWoWColor,
	["UnitPowerMax"] = noIndentEffectWoWColor,
	["UnitPowerType"] = noIndentEffectWoWColor,
	["UnitRace"] = noIndentEffectWoWColor,
	["UnitRangedAttack"] = noIndentEffectWoWColor,
	["UnitRangedAttackPower"] = noIndentEffectWoWColor,
	["UnitRangedDamage"] = noIndentEffectWoWColor,
	["UnitReaction"] = noIndentEffectWoWColor,
	["UnitResistance"] = noIndentEffectWoWColor,
	["UnitSelectionColor"] = noIndentEffectWoWColor,
	["UnitSex"] = noIndentEffectWoWColor,
	["UnitStat"] = noIndentEffectWoWColor,
	["UnitSwitchToVehicleSeat"] = noIndentEffectWoWColor,
	["UnitTargetsVehicleInRaidUI"] = noIndentEffectWoWColor,
	["UnitThreatSituation"] = noIndentEffectWoWColor,
	["UnitUsingVehicle"] = noIndentEffectWoWColor,
	["UnitVehicleSeatCount"] = noIndentEffectWoWColor,
	["UnitVehicleSeatInfo"] = noIndentEffectWoWColor,
	["UnitVehicleSkin"] = noIndentEffectWoWColor,
	["UnitWatchRegistered"] = noIndentEffectWoWColor,
	["UnitXP"] = noIndentEffectWoWColor,
	["UnitXPMax"] = noIndentEffectWoWColor,
	["UnlockMultiCastActionBar"] = noIndentEffectWoWColor,
	["UnlockPetActionBar"] = noIndentEffectWoWColor,
	["UnregisterAutoHide"] = noIndentEffectWoWColor,
	["UnregisterStateDriver"] = noIndentEffectWoWColor,
	["UnregisterUnitWatch"] = noIndentEffectWoWColor,
	["UnstablePet"] = noIndentEffectWoWColor,
	["UpdateAddOnCPUUsage"] = noIndentEffectWoWColor,
	["UpdateAddOnMemoryUsage"] = noIndentEffectWoWColor,
	["UpdateBagButtonHighlight"] = noIndentEffectWoWColor,
	["UpdateBagSlotStatus"] = noIndentEffectWoWColor,
	["UpdateCoinPickupFrame"] = noIndentEffectWoWColor,
	["UpdateGMTicket"] = noIndentEffectWoWColor,
	["UpdateInventoryAlertStatus"] = noIndentEffectWoWColor,
	["UpdateMapHighlight"] = noIndentEffectWoWColor,
	["UpdateMenuBarTop"] = noIndentEffectWoWColor,
	["UpdateMicroButtons"] = noIndentEffectWoWColor,
	["UpdatePaperdollStats"] = noIndentEffectWoWColor,
	["UpdatePartyMemberBackground"] = noIndentEffectWoWColor,
	["UpdateSpells"] = noIndentEffectWoWColor,
	["UpdateStackSplitFrame"] = noIndentEffectWoWColor,
	["UpdateSubCategoryEnabledState"] = noIndentEffectWoWColor,
	["UpdateUIPanelPositions"] = noIndentEffectWoWColor,
	["UpdateWorldMapArrowFrames"] = noIndentEffectWoWColor,
	["UploadSettings"] = noIndentEffectWoWColor,
	["UseAction"] = noIndentEffectWoWColor,
	["UseContainerItem"] = noIndentEffectWoWColor,
	["UseEquipmentSet"] = noIndentEffectWoWColor,
	["UseInventoryItem"] = noIndentEffectWoWColor,
	["UseItemByName"] = noIndentEffectWoWColor,
	["UseQuestLogSpecialItem"] = noIndentEffectWoWColor,
	["UseSoulstone"] = noIndentEffectWoWColor,
	["UsesGUID"] = noIndentEffectWoWColor,
	["ValidateFramePosition"] = noIndentEffectWoWColor,
	["VehicleActionButton_OnClick"] = noIndentEffectWoWColor,
	["VehicleAimDecrement"] = noIndentEffectWoWColor,
	["VehicleAimDownStart"] = noIndentEffectWoWColor,
	["VehicleAimDownStop"] = noIndentEffectWoWColor,
	["VehicleAimGetAngle"] = noIndentEffectWoWColor,
	["VehicleAimGetNormAngle"] = noIndentEffectWoWColor,
	["VehicleAimGetNormPower"] = noIndentEffectWoWColor,
	["VehicleAimIncrement"] = noIndentEffectWoWColor,
	["VehicleAimRequestAngle"] = noIndentEffectWoWColor,
	["VehicleAimRequestNormAngle"] = noIndentEffectWoWColor,
	["VehicleAimSetNormPower"] = noIndentEffectWoWColor,
	["VehicleAimUpStart"] = noIndentEffectWoWColor,
	["VehicleAimUpStop"] = noIndentEffectWoWColor,
	["VehicleCameraZoomIn"] = noIndentEffectWoWColor,
	["VehicleCameraZoomOut"] = noIndentEffectWoWColor,
	["VehicleExit"] = noIndentEffectWoWColor,
	["VehicleMenuBarPitch_OnClick"] = noIndentEffectWoWColor,
	["VehicleMenuBarPitch_OnEvent"] = noIndentEffectWoWColor,
	["VehicleMenuBarPitch_OnLoad"] = noIndentEffectWoWColor,
	["VehicleMenuBarPitch_SetValue"] = noIndentEffectWoWColor,
	["VehicleMenuBarStatusBars_ShowTooltip"] = noIndentEffectWoWColor,
	["VehicleMenuBar_MoveMicroButtons"] = noIndentEffectWoWColor,
	["VehicleMenuBar_OnEvent"] = noIndentEffectWoWColor,
	["VehicleMenuBar_OnLoad"] = noIndentEffectWoWColor,
	["VehicleMenuBar_ReleaseSkins"] = noIndentEffectWoWColor,
	["VehicleMenuBar_SetSkin"] = noIndentEffectWoWColor,
	["VehicleMenuBar_UpdateActionBars"] = noIndentEffectWoWColor,
	["VehicleNextSeat"] = noIndentEffectWoWColor,
	["VehiclePrevSeat"] = noIndentEffectWoWColor,
	["VehicleSeatIndicatorButton_OnClick"] = noIndentEffectWoWColor,
	["VehicleSeatIndicatorButton_OnEnter"] = noIndentEffectWoWColor,
	["VehicleSeatIndicatorButton_OnLeave"] = noIndentEffectWoWColor,
	["VehicleSeatIndicatorDropDown_Initialize"] = noIndentEffectWoWColor,
	["VehicleSeatIndicatorDropDown_OnClick"] = noIndentEffectWoWColor,
	["VehicleSeatIndicator_OnEvent"] = noIndentEffectWoWColor,
	["VehicleSeatIndicator_OnLoad"] = noIndentEffectWoWColor,
	["VehicleSeatIndicator_SetUpVehicle"] = noIndentEffectWoWColor,
	["VehicleSeatIndicator_UnloadTextures"] = noIndentEffectWoWColor,
	["VehicleSeatIndicator_Update"] = noIndentEffectWoWColor,
	["VideoOptionsEffectsPanelSlider_OnValueChanged"] = noIndentEffectWoWColor,
	["VideoOptionsEffectsPanel_Default"] = noIndentEffectWoWColor,
	["VideoOptionsEffectsPanel_FixupQualityLevels"] = noIndentEffectWoWColor,
	["VideoOptionsEffectsPanel_GetVideoQuality"] = noIndentEffectWoWColor,
	["VideoOptionsEffectsPanel_OnEvent"] = noIndentEffectWoWColor,
	["VideoOptionsEffectsPanel_OnLoad"] = noIndentEffectWoWColor,
	["VideoOptionsEffectsPanel_Refresh"] = noIndentEffectWoWColor,
	["VideoOptionsEffectsPanel_SetCustomQuality"] = noIndentEffectWoWColor,
	["VideoOptionsEffectsPanel_SetPresetQuality"] = noIndentEffectWoWColor,
	["VideoOptionsEffectsPanel_SetVideoQuality"] = noIndentEffectWoWColor,
	["VideoOptionsEffectsPanel_SetVideoQualityLabels"] = noIndentEffectWoWColor,
	["VideoOptionsEffectsPanel_UpdateVideoQuality"] = noIndentEffectWoWColor,
	["VideoOptionsFrameCancel_OnClick"] = noIndentEffectWoWColor,
	["VideoOptionsFrameDefault_OnClick"] = noIndentEffectWoWColor,
	["VideoOptionsFrameOkay_OnClick"] = noIndentEffectWoWColor,
	["VideoOptionsFrame_OnHide"] = noIndentEffectWoWColor,
	["VideoOptionsFrame_OnLoad"] = noIndentEffectWoWColor,
	["VideoOptionsFrame_SetAllToDefaults"] = noIndentEffectWoWColor,
	["VideoOptionsFrame_SetCurrentToDefaults"] = noIndentEffectWoWColor,
	["VideoOptionsFrame_Toggle"] = noIndentEffectWoWColor,
	["VideoOptionsPanel_Cancel"] = noIndentEffectWoWColor,
	["VideoOptionsPanel_Default"] = noIndentEffectWoWColor,
	["VideoOptionsPanel_Okay"] = noIndentEffectWoWColor,
	["VideoOptionsPanel_OnLoad"] = noIndentEffectWoWColor,
	["VideoOptionsResolutionPanelMultiSampleDropDown_Initialize"] = noIndentEffectWoWColor,
	["VideoOptionsResolutionPanelMultiSampleDropDown_OnClick"] = noIndentEffectWoWColor,
	["VideoOptionsResolutionPanelMultiSampleDropDown_OnLoad"] = noIndentEffectWoWColor,
	["VideoOptionsResolutionPanelRefreshDropDown_Initialize"] = noIndentEffectWoWColor,
	["VideoOptionsResolutionPanelRefreshDropDown_OnClick"] = noIndentEffectWoWColor,
	["VideoOptionsResolutionPanelRefreshDropDown_OnLoad"] = noIndentEffectWoWColor,
	["VideoOptionsResolutionPanelResolutionDropDown_Initialize"] = noIndentEffectWoWColor,
	["VideoOptionsResolutionPanelResolutionDropDown_LoadResolutions"] = noIndentEffectWoWColor,
	["VideoOptionsResolutionPanelResolutionDropDown_OnClick"] = noIndentEffectWoWColor,
	["VideoOptionsResolutionPanelResolutionDropDown_OnLoad"] = noIndentEffectWoWColor,
	["VideoOptionsResolutionPanel_Default"] = noIndentEffectWoWColor,
	["VideoOptionsResolutionPanel_GetMultisampleFormats"] = noIndentEffectWoWColor,
	["VideoOptionsResolutionPanel_GetRefreshRates"] = noIndentEffectWoWColor,
	["VideoOptionsResolutionPanel_OnEvent"] = noIndentEffectWoWColor,
	["VideoOptionsResolutionPanel_OnLoad"] = noIndentEffectWoWColor,
	["VideoOptionsResolutionPanel_Refresh"] = noIndentEffectWoWColor,
	["VideoOptionsResolutionPanel_RefreshGammaControls"] = noIndentEffectWoWColor,
	["VideoOptionsResolutionPanel_SetGamma"] = noIndentEffectWoWColor,
	["VideoOptionsResolutionPanel_SetWindowed"] = noIndentEffectWoWColor,
	["VideoOptionsStereoPanel_Default"] = noIndentEffectWoWColor,
	["VideoOptionsStereoPanel_OnEvent"] = noIndentEffectWoWColor,
	["VideoOptionsStereoPanel_OnLoad"] = noIndentEffectWoWColor,
	["VoiceChatShineFadeIn"] = noIndentEffectWoWColor,
	["VoiceChatShineFadeOut"] = noIndentEffectWoWColor,
	["VoiceChatTalkers_CanHide"] = noIndentEffectWoWColor,
	["VoiceChatTalkers_CreateButtons"] = noIndentEffectWoWColor,
	["VoiceChatTalkers_FadeOut"] = noIndentEffectWoWColor,
	["VoiceChatTalkers_OnEvent"] = noIndentEffectWoWColor,
	["VoiceChatTalkers_OnLoad"] = noIndentEffectWoWColor,
	["VoiceChatTalkers_OnUpdate"] = noIndentEffectWoWColor,
	["VoiceChatTalkers_ResizeFrame"] = noIndentEffectWoWColor,
	["VoiceChatTalkers_Update"] = noIndentEffectWoWColor,
	["VoiceChat_ActivatePrimaryCaptureCallback"] = noIndentEffectWoWColor,
	["VoiceChat_Animate"] = noIndentEffectWoWColor,
	["VoiceChat_GetCurrentMicrophoneSignalLevel"] = noIndentEffectWoWColor,
	["VoiceChat_IsPlayingLoopbackSound"] = noIndentEffectWoWColor,
	["VoiceChat_IsRecordingLoopbackSound"] = noIndentEffectWoWColor,
	["VoiceChat_OnUpdate"] = noIndentEffectWoWColor,
	["VoiceChat_PlayLoopbackSound"] = noIndentEffectWoWColor,
	["VoiceChat_RecordLoopbackSound"] = noIndentEffectWoWColor,
	["VoiceChat_StartCapture"] = noIndentEffectWoWColor,
	["VoiceChat_StopCapture"] = noIndentEffectWoWColor,
	["VoiceChat_StopPlayingLoopbackSound"] = noIndentEffectWoWColor,
	["VoiceChat_StopRecordingLoopbackSound"] = noIndentEffectWoWColor,
	["VoiceChat_Toggle"] = noIndentEffectWoWColor,
	["VoiceEnumerateCaptureDevices"] = noIndentEffectWoWColor,
	["VoiceEnumerateOutputDevices"] = noIndentEffectWoWColor,
	["VoiceGetCurrentCaptureDevice"] = noIndentEffectWoWColor,
	["VoiceGetCurrentOutputDevice"] = noIndentEffectWoWColor,
	["VoiceIsDisabledByClient"] = noIndentEffectWoWColor,
	["VoiceMacroMenu_Click"] = noIndentEffectWoWColor,
	["VoiceMacroMenu_OnLoad"] = noIndentEffectWoWColor,
	["VoicePushToTalkStart"] = noIndentEffectWoWColor,
	["VoicePushToTalkStop"] = noIndentEffectWoWColor,
	["VoiceSelectCaptureDevice"] = noIndentEffectWoWColor,
	["VoiceSelectOutputDevice"] = noIndentEffectWoWColor,
	["WatchFrameDropDown_Initialize"] = noIndentEffectWoWColor,
	["WatchFrameDropDown_OnHide"] = noIndentEffectWoWColor,
	["WatchFrameDropDown_OnLoad"] = noIndentEffectWoWColor,
	["WatchFrameHeaderDropDown_Initialize"] = noIndentEffectWoWColor,
	["WatchFrameHeaderDropDown_OnLoad"] = noIndentEffectWoWColor,
	["WatchFrameHeader_OnClick"] = noIndentEffectWoWColor,
	["WatchFrameItem_OnClick"] = noIndentEffectWoWColor,
	["WatchFrameItem_OnEnter"] = noIndentEffectWoWColor,
	["WatchFrameItem_OnEvent"] = noIndentEffectWoWColor,
	["WatchFrameItem_OnHide"] = noIndentEffectWoWColor,
	["WatchFrameItem_OnLoad"] = noIndentEffectWoWColor,
	["WatchFrameItem_OnShow"] = noIndentEffectWoWColor,
	["WatchFrameItem_OnUpdate"] = noIndentEffectWoWColor,
	["WatchFrameItem_UpdateCooldown"] = noIndentEffectWoWColor,
	["WatchFrameLineTemplate_OnLoad"] = noIndentEffectWoWColor,
	["WatchFrameLines_AddUpdateFunction"] = noIndentEffectWoWColor,
	["WatchFrameLines_OnUpdate"] = noIndentEffectWoWColor,
	["WatchFrameLines_RemoveUpdateFunction"] = noIndentEffectWoWColor,
	["WatchFrameLinkButtonTemplate_Highlight"] = noIndentEffectWoWColor,
	["WatchFrameLinkButtonTemplate_OnClick"] = noIndentEffectWoWColor,
	["WatchFrameLinkButtonTemplate_OnLeftClick"] = noIndentEffectWoWColor,
	["WatchFrameQuestPOI_OnClick"] = noIndentEffectWoWColor,
	["WatchFrame_AbandonQuest"] = noIndentEffectWoWColor,
	["WatchFrame_AddObjectiveHandler"] = noIndentEffectWoWColor,
	["WatchFrame_ClearDisplay"] = noIndentEffectWoWColor,
	["WatchFrame_Collapse"] = noIndentEffectWoWColor,
	["WatchFrame_CollapseExpandButton_OnClick"] = noIndentEffectWoWColor,
	["WatchFrame_DisplayQuestTimers"] = noIndentEffectWoWColor,
	["WatchFrame_DisplayTrackedAchievements"] = noIndentEffectWoWColor,
	["WatchFrame_DisplayTrackedQuests"] = noIndentEffectWoWColor,
	["WatchFrame_Expand"] = noIndentEffectWoWColor,
	["WatchFrame_GetCurrentMapQuests"] = noIndentEffectWoWColor,
	["WatchFrame_GetVisibleIndex"] = noIndentEffectWoWColor,
	["WatchFrame_HandleDisplayQuestTimers"] = noIndentEffectWoWColor,
	["WatchFrame_HandleDisplayTrackedAchievements"] = noIndentEffectWoWColor,
	["WatchFrame_HandleQuestTimerUpdate"] = noIndentEffectWoWColor,
	["WatchFrame_MoveQuest"] = noIndentEffectWoWColor,
	["WatchFrame_OnEvent"] = noIndentEffectWoWColor,
	["WatchFrame_OnLoad"] = noIndentEffectWoWColor,
	["WatchFrame_OnSizeChanged"] = noIndentEffectWoWColor,
	["WatchFrame_OnUpdate"] = noIndentEffectWoWColor,
	["WatchFrame_OpenAchievementFrame"] = noIndentEffectWoWColor,
	["WatchFrame_OpenMapToQuest"] = noIndentEffectWoWColor,
	["WatchFrame_OpenQuestLog"] = noIndentEffectWoWColor,
	["WatchFrame_QuestTimerUpdateFunction"] = noIndentEffectWoWColor,
	["WatchFrame_RemoveObjectiveHandler"] = noIndentEffectWoWColor,
	["WatchFrame_ReverseQuestObjective"] = noIndentEffectWoWColor,
	["WatchFrame_SetFilter"] = noIndentEffectWoWColor,
	["WatchFrame_SetLine"] = noIndentEffectWoWColor,
	["WatchFrame_SetSorting"] = noIndentEffectWoWColor,
	["WatchFrame_SetWidth"] = noIndentEffectWoWColor,
	["WatchFrame_ShareQuest"] = noIndentEffectWoWColor,
	["WatchFrame_StopTrackingAchievement"] = noIndentEffectWoWColor,
	["WatchFrame_StopTrackingQuest"] = noIndentEffectWoWColor,
	["WatchFrame_Update"] = noIndentEffectWoWColor,
	["WatchFrame_UpdateTimedAchievements"] = noIndentEffectWoWColor,
	["WhoFrameColumn_SetWidth"] = noIndentEffectWoWColor,
	["WhoFrameDropDownButton_OnClick"] = noIndentEffectWoWColor,
	["WhoFrameDropDown_Initialize"] = noIndentEffectWoWColor,
	["WhoFrameDropDown_OnLoad"] = noIndentEffectWoWColor,
	["WhoFrameEditBox_OnEnterPressed"] = noIndentEffectWoWColor,
	["WhoFrame_GetDefaultWhoCommand"] = noIndentEffectWoWColor,
	["WhoList_Update"] = noIndentEffectWoWColor,
	["WintergraspTimer_OnLoad"] = noIndentEffectWoWColor,
	["WintergraspTimer_OnUpdate"] = noIndentEffectWoWColor,
	["WithdrawGoldEditBox_Update"] = noIndentEffectWoWColor,
	["WithdrawGuildBankMoney"] = noIndentEffectWoWColor,
	["WorldFrame_OnLoad"] = noIndentEffectWoWColor,
	["WorldFrame_OnUpdate"] = noIndentEffectWoWColor,
	["WorldMapBlobFrame_CalculateHitTranslations"] = noIndentEffectWoWColor,
	["WorldMapBlobFrame_OnLoad"] = noIndentEffectWoWColor,
	["WorldMapBlobFrame_OnUpdate"] = noIndentEffectWoWColor,
	["WorldMapButton_OnClick"] = noIndentEffectWoWColor,
	["WorldMapButton_OnUpdate"] = noIndentEffectWoWColor,
	["WorldMapContinentButton_OnClick"] = noIndentEffectWoWColor,
	["WorldMapContinentsDropDown_Initialize"] = noIndentEffectWoWColor,
	["WorldMapContinentsDropDown_Update"] = noIndentEffectWoWColor,
	["WorldMapFrame_ChangeOpacity"] = noIndentEffectWoWColor,
	["WorldMapFrame_ClearQuestPOIs"] = noIndentEffectWoWColor,
	["WorldMapFrame_DisplayQuestPOI"] = noIndentEffectWoWColor,
	["WorldMapFrame_DisplayQuests"] = noIndentEffectWoWColor,
	["WorldMapFrame_GetQuestFrame"] = noIndentEffectWoWColor,
	["WorldMapFrame_LoadContinents"] = noIndentEffectWoWColor,
	["WorldMapFrame_LoadZones"] = noIndentEffectWoWColor,
	["WorldMapFrame_OnEvent"] = noIndentEffectWoWColor,
	["WorldMapFrame_OnHide"] = noIndentEffectWoWColor,
	["WorldMapFrame_OnKeyDown"] = noIndentEffectWoWColor,
	["WorldMapFrame_OnLoad"] = noIndentEffectWoWColor,
	["WorldMapFrame_OnShow"] = noIndentEffectWoWColor,
	["WorldMapFrame_OnUpdate"] = noIndentEffectWoWColor,
	["WorldMapFrame_PingPlayerPosition"] = noIndentEffectWoWColor,
	["WorldMapFrame_ResetFrameLevels"] = noIndentEffectWoWColor,
	["WorldMapFrame_ResetQuestColors"] = noIndentEffectWoWColor,
	["WorldMapFrame_ReverseQuestObjective"] = noIndentEffectWoWColor,
	["WorldMapFrame_SaveOpacity"] = noIndentEffectWoWColor,
	["WorldMapFrame_SelectQuestById"] = noIndentEffectWoWColor,
	["WorldMapFrame_SelectQuestFrame"] = noIndentEffectWoWColor,
	["WorldMapFrame_SetFullMapView"] = noIndentEffectWoWColor,
	["WorldMapFrame_SetMapName"] = noIndentEffectWoWColor,
	["WorldMapFrame_SetMiniMode"] = noIndentEffectWoWColor,
	["WorldMapFrame_SetOpacity"] = noIndentEffectWoWColor,
	["WorldMapFrame_SetPOIMaxBounds"] = noIndentEffectWoWColor,
	["WorldMapFrame_SetQuestMapView"] = noIndentEffectWoWColor,
	["WorldMapFrame_ToggleAdvanced"] = noIndentEffectWoWColor,
	["WorldMapFrame_ToggleWindowSize"] = noIndentEffectWoWColor,
	["WorldMapFrame_Update"] = noIndentEffectWoWColor,
	["WorldMapFrame_UpdateMap"] = noIndentEffectWoWColor,
	["WorldMapFrame_UpdateQuests"] = noIndentEffectWoWColor,
	["WorldMapFrame_UpdateUnits"] = noIndentEffectWoWColor,
	["WorldMapLevelButton_OnClick"] = noIndentEffectWoWColor,
	["WorldMapLevelDown_OnClick"] = noIndentEffectWoWColor,
	["WorldMapLevelDropDown_Initialize"] = noIndentEffectWoWColor,
	["WorldMapLevelDropDown_Update"] = noIndentEffectWoWColor,
	["WorldMapLevelUp_OnClick"] = noIndentEffectWoWColor,
	["WorldMapPOI_OnClick"] = noIndentEffectWoWColor,
	["WorldMapPOI_OnEnter"] = noIndentEffectWoWColor,
	["WorldMapPOI_OnLeave"] = noIndentEffectWoWColor,
	["WorldMapQuestFrame_OnEnter"] = noIndentEffectWoWColor,
	["WorldMapQuestFrame_OnLeave"] = noIndentEffectWoWColor,
	["WorldMapQuestFrame_OnMouseDown"] = noIndentEffectWoWColor,
	["WorldMapQuestFrame_OnMouseUp"] = noIndentEffectWoWColor,
	["WorldMapQuestFrame_UpdateMouseOver"] = noIndentEffectWoWColor,
	["WorldMapQuestPOI_OnClick"] = noIndentEffectWoWColor,
	["WorldMapQuestPOI_OnEnter"] = noIndentEffectWoWColor,
	["WorldMapQuestPOI_OnLeave"] = noIndentEffectWoWColor,
	["WorldMapQuestPOI_SetTooltip"] = noIndentEffectWoWColor,
	["WorldMapQuestShowObjectives_AdjustPosition"] = noIndentEffectWoWColor,
	["WorldMapQuestShowObjectives_Toggle"] = noIndentEffectWoWColor,
	["WorldMapTitleButton_OnClick"] = noIndentEffectWoWColor,
	["WorldMapTitleButton_OnDragStart"] = noIndentEffectWoWColor,
	["WorldMapTitleButton_OnDragStop"] = noIndentEffectWoWColor,
	["WorldMapTitleButton_OnLoad"] = noIndentEffectWoWColor,
	["WorldMapTitleDropDown_Initialize"] = noIndentEffectWoWColor,
	["WorldMapTitleDropDown_ToggleLock"] = noIndentEffectWoWColor,
	["WorldMapTitleDropDown_ToggleOpacity"] = noIndentEffectWoWColor,
	["WorldMapTrackQuest_Toggle"] = noIndentEffectWoWColor,
	["WorldMapUnitDropDown_Initialize"] = noIndentEffectWoWColor,
	["WorldMapUnitDropDown_OnClick"] = noIndentEffectWoWColor,
	["WorldMapUnitDropDown_ReportAll_OnClick"] = noIndentEffectWoWColor,
	["WorldMapUnit_OnEnter"] = noIndentEffectWoWColor,
	["WorldMapUnit_OnEvent"] = noIndentEffectWoWColor,
	["WorldMapUnit_OnHide"] = noIndentEffectWoWColor,
	["WorldMapUnit_OnLeave"] = noIndentEffectWoWColor,
	["WorldMapUnit_OnLoad"] = noIndentEffectWoWColor,
	["WorldMapUnit_OnMouseUp"] = noIndentEffectWoWColor,
	["WorldMapUnit_OnShow"] = noIndentEffectWoWColor,
	["WorldMapUnit_Update"] = noIndentEffectWoWColor,
	["WorldMapZoneButton_OnClick"] = noIndentEffectWoWColor,
	["WorldMapZoneDropDown_Initialize"] = noIndentEffectWoWColor,
	["WorldMapZoneDropDown_Update"] = noIndentEffectWoWColor,
	["WorldMapZoneMinimapDropDown_GetText"] = noIndentEffectWoWColor,
	["WorldMapZoneMinimapDropDown_Initialize"] = noIndentEffectWoWColor,
	["WorldMapZoneMinimapDropDown_OnClick"] = noIndentEffectWoWColor,
	["WorldMapZoneMinimapDropDown_Update"] = noIndentEffectWoWColor,
	["WorldMapZoomOutButton_OnClick"] = noIndentEffectWoWColor,
	["WorldMap_ClearTextures"] = noIndentEffectWoWColor,
	["WorldMap_CreatePOI"] = noIndentEffectWoWColor,
	["WorldMap_GetPOITextureCoords"] = noIndentEffectWoWColor,
	["WorldMap_GetVehicleTexture"] = noIndentEffectWoWColor,
	["WorldMap_LoadTextures"] = noIndentEffectWoWColor,
	["WorldMap_OpenToQuest"] = noIndentEffectWoWColor,
	["WorldMap_ToggleSizeDown"] = noIndentEffectWoWColor,
	["WorldMap_ToggleSizeUp"] = noIndentEffectWoWColor,
	["WorldStateAlwaysUpFrame_FilterChatMsgLoot"] = noIndentEffectWoWColor,
	["WorldStateAlwaysUpFrame_FilterChatMsgSystem"] = noIndentEffectWoWColor,
	["WorldStateAlwaysUpFrame_OnEvent"] = noIndentEffectWoWColor,
	["WorldStateAlwaysUpFrame_OnLoad"] = noIndentEffectWoWColor,
	["WorldStateAlwaysUpFrame_OnUpdate"] = noIndentEffectWoWColor,
	["WorldStateAlwaysUpFrame_StartBGChatFilter"] = noIndentEffectWoWColor,
	["WorldStateAlwaysUpFrame_StopBGChatFilter"] = noIndentEffectWoWColor,
	["WorldStateAlwaysUpFrame_Update"] = noIndentEffectWoWColor,
	["WorldStateFrame_CanShowBattlefieldMinimap"] = noIndentEffectWoWColor,
	["WorldStateFrame_ToggleBattlefieldMinimap"] = noIndentEffectWoWColor,
	["WorldStateScoreFrameTab_OnClick"] = noIndentEffectWoWColor,
	["WorldStateScoreFrame_OnLoad"] = noIndentEffectWoWColor,
	["WorldStateScoreFrame_Resize"] = noIndentEffectWoWColor,
	["WorldStateScoreFrame_Update"] = noIndentEffectWoWColor,
	["ZoneText_OnEvent"] = noIndentEffectWoWColor,
	["ZoneText_OnLoad"] = noIndentEffectWoWColor,
	["ZoomOut"] = noIndentEffectWoWColor,
	["_GetPlayerDifficultyMenuOptions"] = noIndentEffectWoWColor,
	["debugbreak"] = noIndentEffectWoWColor,
	["debugdump"] = noIndentEffectWoWColor,
	["debughook"] = noIndentEffectWoWColor,
	["debuginfo"] = noIndentEffectWoWColor,
	["debugload"] = noIndentEffectWoWColor,
	["debuglocals"] = noIndentEffectWoWColor,
	["debugprint"] = noIndentEffectWoWColor,
	["debugprofilestart"] = noIndentEffectWoWColor,
	["debugprofilestop"] = noIndentEffectWoWColor,
	["debugstack"] = noIndentEffectWoWColor,
	["debugtimestamp"] = noIndentEffectWoWColor,
	["forceinsecure"] = noIndentEffectWoWColor,
	["geterrorhandler"] = noIndentEffectWoWColor,
	["getglobal"] = noIndentEffectWoWColor,
	["getprinthandler"] = noIndentEffectWoWColor,
	["hooksecurefunc"] = noIndentEffectWoWColor,
	["issecure"] = noIndentEffectWoWColor,
	["issecurevariable"] = noIndentEffectWoWColor,
	["message"] = noIndentEffectWoWColor,
	["newproxy"] = noIndentEffectWoWColor,
	["scrub"] = noIndentEffectWoWColor,
	["securecall"] = noIndentEffectWoWColor,
	["seterrorhandler"] = noIndentEffectWoWColor,
	["setglobal"] = noIndentEffectWoWColor,
	["setprinthandler"] = noIndentEffectWoWColor,
	["strjoin"] = noIndentEffectWoWColor,
	["strlenutf8"] = noIndentEffectWoWColor,
	["strreplace"] = noIndentEffectWoWColor,
	["strrev"] = noIndentEffectWoWColor,
	["strsplit"] = noIndentEffectWoWColor,
	["strtrim"] = noIndentEffectWoWColor,
	["tContains"] = noIndentEffectWoWColor,
	["tDeleteItem"] = noIndentEffectWoWColor,
	["updateContainerFrameAnchors"] = noIndentEffectWoWColor,
	["wipe"] = noIndentEffectWoWColor,
	-- Methods and what not
	["AddDoubleLine"] = noIndentEffectMethodColor,
	["AddFontStrings"] = noIndentEffectMethodColor,
	["AddHistoryLine"] = noIndentEffectMethodColor,
	["AddLine"] = noIndentEffectMethodColor,
	["AddMessage"] = noIndentEffectMethodColor,
	["AddTexture"] = noIndentEffectMethodColor,
	["AdvanceTime"] = noIndentEffectMethodColor,
	["AllowAttributeChanges"] = noIndentEffectMethodColor,
	["AppendText"] = noIndentEffectMethodColor,
	["AtBottom"] = noIndentEffectMethodColor,
	["AtTop"] = noIndentEffectMethodColor,
	["CanChangeAttribute"] = noIndentEffectMethodColor,
	["CanChangeProtectedState"] = noIndentEffectMethodColor,
	["CanNonSpaceWrap"] = noIndentEffectMethodColor,
	["CanSaveTabardNow"] = noIndentEffectMethodColor,
	["CanWordWrap"] = noIndentEffectMethodColor,
	["Clear"] = noIndentEffectMethodColor,
	["ClearAllPoints"] = noIndentEffectMethodColor,
	["ClearFocus"] = noIndentEffectMethodColor,
	["ClearFog"] = noIndentEffectMethodColor,
	["ClearHistory"] = noIndentEffectMethodColor,
	["ClearLines"] = noIndentEffectMethodColor,
	["ClearModel"] = noIndentEffectMethodColor,
	["Click"] = noIndentEffectMethodColor,
	["CopyFontObject"] = noIndentEffectMethodColor,
	["CreateAnimation"] = noIndentEffectMethodColor,
	["CreateAnimationGroup"] = noIndentEffectMethodColor,
	["CreateControlPoint"] = noIndentEffectMethodColor,
	["CreateFontString"] = noIndentEffectMethodColor,
	["CreateTexture"] = noIndentEffectMethodColor,
	["CreateTitleRegion"] = noIndentEffectMethodColor,
	["CycleVariation"] = noIndentEffectMethodColor,
	["Disable"] = noIndentEffectMethodColor,
	["DisableDrawLayer"] = noIndentEffectMethodColor,
	["DrawQuestBlob"] = noIndentEffectMethodColor,
	["Dress"] = noIndentEffectMethodColor,
	["Enable"] = noIndentEffectMethodColor,
	["EnableDrawLayer"] = noIndentEffectMethodColor,
	["EnableJoystick"] = noIndentEffectMethodColor,
	["EnableKeyboard"] = noIndentEffectMethodColor,
	["EnableMerging"] = noIndentEffectMethodColor,
	["EnableMouse"] = noIndentEffectMethodColor,
	["EnableMouseWheel"] = noIndentEffectMethodColor,
	["EnableSmoothing"] = noIndentEffectMethodColor,
	["EnableSubtitles"] = noIndentEffectMethodColor,
	["FadeOut"] = noIndentEffectMethodColor,
	["Finish"] = noIndentEffectMethodColor,
	["GetAlpha"] = noIndentEffectMethodColor,
	["GetAltArrowKeyMode"] = noIndentEffectMethodColor,
	["GetAnchorType"] = noIndentEffectMethodColor,
	["GetAnimationGroups"] = noIndentEffectMethodColor,
	["GetAnimations"] = noIndentEffectMethodColor,
	["GetAttribute"] = noIndentEffectMethodColor,
	["GetBackdrop"] = noIndentEffectMethodColor,
	["GetBackdropBorderColor"] = noIndentEffectMethodColor,
	["GetBackdropColor"] = noIndentEffectMethodColor,
	["GetBlendMode"] = noIndentEffectMethodColor,
	["GetBlinkSpeed"] = noIndentEffectMethodColor,
	["GetBottom"] = noIndentEffectMethodColor,
	["GetBoundsRect"] = noIndentEffectMethodColor,
	["GetButtonState"] = noIndentEffectMethodColor,
	["GetCenter"] = noIndentEffectMethodColor,
	["GetChange"] = noIndentEffectMethodColor,
	["GetChecked"] = noIndentEffectMethodColor,
	["GetCheckedTexture"] = noIndentEffectMethodColor,
	["GetChildren"] = noIndentEffectMethodColor,
	["GetClampRectInsets"] = noIndentEffectMethodColor,
	["GetColorHSV"] = noIndentEffectMethodColor,
	["GetColorRGB"] = noIndentEffectMethodColor,
	["GetColorValueTexture"] = noIndentEffectMethodColor,
	["GetColorValueThumbTexture"] = noIndentEffectMethodColor,
	["GetColorWheelTexture"] = noIndentEffectMethodColor,
	["GetColorWheelThumbTexture"] = noIndentEffectMethodColor,
	["GetControlPoints"] = noIndentEffectMethodColor,
	["GetCurrentLine"] = noIndentEffectMethodColor,
	["GetCurrentScroll"] = noIndentEffectMethodColor,
	["GetCursorPosition"] = noIndentEffectMethodColor,
	["GetCurve"] = noIndentEffectMethodColor,
	["GetDegrees"] = noIndentEffectMethodColor,
	["GetDepth"] = noIndentEffectMethodColor,
	["GetDisabledCheckedTexture"] = noIndentEffectMethodColor,
	["GetDisabledFontObject"] = noIndentEffectMethodColor,
	["GetDisabledTexture"] = noIndentEffectMethodColor,
	["GetDontSavePosition"] = noIndentEffectMethodColor,
	["GetDrawEdge"] = noIndentEffectMethodColor,
	["GetDrawLayer"] = noIndentEffectMethodColor,
	["GetDuration"] = noIndentEffectMethodColor,
	["GetEffectiveAlpha"] = noIndentEffectMethodColor,
	["GetEffectiveDepth"] = noIndentEffectMethodColor,
	["GetEffectiveScale"] = noIndentEffectMethodColor,
	["GetElapsed"] = noIndentEffectMethodColor,
	["GetEndDelay"] = noIndentEffectMethodColor,
	["GetFacing"] = noIndentEffectMethodColor,
	["GetFadeDuration"] = noIndentEffectMethodColor,
	["GetFading"] = noIndentEffectMethodColor,
	["GetFieldSize"] = noIndentEffectMethodColor,
	["GetFogColor"] = noIndentEffectMethodColor,
	["GetFogFar"] = noIndentEffectMethodColor,
	["GetFogNear"] = noIndentEffectMethodColor,
	["GetFont"] = noIndentEffectMethodColor,
	["GetFontObject"] = noIndentEffectMethodColor,
	["GetFontString"] = noIndentEffectMethodColor,
	["GetFrameLevel"] = noIndentEffectMethodColor,
	["GetFrameStrata"] = noIndentEffectMethodColor,
	["GetHeight"] = noIndentEffectMethodColor,
	["GetHighlightFontObject"] = noIndentEffectMethodColor,
	["GetHighlightTexture"] = noIndentEffectMethodColor,
	["GetHistoryLines"] = noIndentEffectMethodColor,
	["GetHitRectInsets"] = noIndentEffectMethodColor,
	["GetHorizTile"] = noIndentEffectMethodColor,
	["GetHorizontalScroll"] = noIndentEffectMethodColor,
	["GetHorizontalScrollRange"] = noIndentEffectMethodColor,
	["GetHyperlinkFormat"] = noIndentEffectMethodColor,
	["GetHyperlinksEnabled"] = noIndentEffectMethodColor,
	["GetID"] = noIndentEffectMethodColor,
	["GetIndentedWordWrap"] = noIndentEffectMethodColor,
	["GetInitialOffset"] = noIndentEffectMethodColor,
	["GetInputLanguage"] = noIndentEffectMethodColor,
	["GetInsertMode"] = noIndentEffectMethodColor,
	["GetItem"] = noIndentEffectMethodColor,
	["GetJustifyH"] = noIndentEffectMethodColor,
	["GetJustifyV"] = noIndentEffectMethodColor,
	["GetLeft"] = noIndentEffectMethodColor,
	["GetLight"] = noIndentEffectMethodColor,
	["GetLoopState"] = noIndentEffectMethodColor,
	["GetLooping"] = noIndentEffectMethodColor,
	["GetLowerBackgroundFileName"] = noIndentEffectMethodColor,
	["GetLowerEmblemFileName"] = noIndentEffectMethodColor,
	["GetLowerEmblemTexture"] = noIndentEffectMethodColor,
	["GetMaxBytes"] = noIndentEffectMethodColor,
	["GetMaxFramerate"] = noIndentEffectMethodColor,
	["GetMaxLetters"] = noIndentEffectMethodColor,
	["GetMaxLines"] = noIndentEffectMethodColor,
	["GetMaxOrder"] = noIndentEffectMethodColor,
	["GetMaxResize"] = noIndentEffectMethodColor,
	["GetMessageInfo"] = noIndentEffectMethodColor,
	["GetMinMaxValues"] = noIndentEffectMethodColor,
	["GetMinResize"] = noIndentEffectMethodColor,
	["GetMinimumWidth"] = noIndentEffectMethodColor,
	["GetModel"] = noIndentEffectMethodColor,
	["GetModelScale"] = noIndentEffectMethodColor,
	["GetMotionScriptsWhileDisabled"] = noIndentEffectMethodColor,
	["GetName"] = noIndentEffectMethodColor,
	["GetNonBlocking"] = noIndentEffectMethodColor,
	["GetNormalFontObject"] = noIndentEffectMethodColor,
	["GetNormalTexture"] = noIndentEffectMethodColor,
	["GetNumChildren"] = noIndentEffectMethodColor,
	["GetNumLetters"] = noIndentEffectMethodColor,
	["GetNumLinesDisplayed"] = noIndentEffectMethodColor,
	["GetNumMessages"] = noIndentEffectMethodColor,
	["GetNumPoints"] = noIndentEffectMethodColor,
	["GetNumRegions"] = noIndentEffectMethodColor,
	["GetNumTooltips"] = noIndentEffectMethodColor,
	["GetNumber"] = noIndentEffectMethodColor,
	["GetObjectType"] = noIndentEffectMethodColor,
	["GetOffset"] = noIndentEffectMethodColor,
	["GetOrder"] = noIndentEffectMethodColor,
	["GetOrientation"] = noIndentEffectMethodColor,
	["GetOrigin"] = noIndentEffectMethodColor,
	["GetOwner"] = noIndentEffectMethodColor,
	["GetPadding"] = noIndentEffectMethodColor,
	["GetParent"] = noIndentEffectMethodColor,
	["GetPingPosition"] = noIndentEffectMethodColor,
	["GetPoint"] = noIndentEffectMethodColor,
	["GetPosition"] = noIndentEffectMethodColor,
	["GetProgress"] = noIndentEffectMethodColor,
	["GetProgressWithDelay"] = noIndentEffectMethodColor,
	["GetPushedTextOffset"] = noIndentEffectMethodColor,
	["GetPushedTexture"] = noIndentEffectMethodColor,
	["GetRadians"] = noIndentEffectMethodColor,
	["GetRect"] = noIndentEffectMethodColor,
	["GetRegionParent"] = noIndentEffectMethodColor,
	["GetRegions"] = noIndentEffectMethodColor,
	["GetReverse"] = noIndentEffectMethodColor,
	["GetRight"] = noIndentEffectMethodColor,
	["GetRotatesTexture"] = noIndentEffectMethodColor,
	["GetScale"] = noIndentEffectMethodColor,
	["GetScript"] = noIndentEffectMethodColor,
	["GetScrollChild"] = noIndentEffectMethodColor,
	["GetShadowColor"] = noIndentEffectMethodColor,
	["GetShadowOffset"] = noIndentEffectMethodColor,
	["GetSize"] = noIndentEffectMethodColor,
	["GetSmoothProgress"] = noIndentEffectMethodColor,
	["GetSmoothing"] = noIndentEffectMethodColor,
	["GetSpacing"] = noIndentEffectMethodColor,
	["GetSpell"] = noIndentEffectMethodColor,
	["GetStartDelay"] = noIndentEffectMethodColor,
	["GetStatusBarColor"] = noIndentEffectMethodColor,
	["GetStatusBarTexture"] = noIndentEffectMethodColor,
	["GetStringHeight"] = noIndentEffectMethodColor,
	["GetStringWidth"] = noIndentEffectMethodColor,
	["GetTexCoord"] = noIndentEffectMethodColor,
	["GetText"] = noIndentEffectMethodColor,
	["GetTextColor"] = noIndentEffectMethodColor,
	["GetTextHeight"] = noIndentEffectMethodColor,
	["GetTextInsets"] = noIndentEffectMethodColor,
	["GetTextWidth"] = noIndentEffectMethodColor,
	["GetTexture"] = noIndentEffectMethodColor,
	["GetThumbTexture"] = noIndentEffectMethodColor,
	["GetTimeVisible"] = noIndentEffectMethodColor,
	["GetTitleRegion"] = noIndentEffectMethodColor,
	["GetTooltipIndex"] = noIndentEffectMethodColor,
	["GetTop"] = noIndentEffectMethodColor,
	["GetUTF8CursorPosition"] = noIndentEffectMethodColor,
	["GetUnit"] = noIndentEffectMethodColor,
	["GetUpperBackgroundFileName"] = noIndentEffectMethodColor,
	["GetUpperEmblemFileName"] = noIndentEffectMethodColor,
	["GetUpperEmblemTexture"] = noIndentEffectMethodColor,
	["GetValue"] = noIndentEffectMethodColor,
	["GetValueStep"] = noIndentEffectMethodColor,
	["GetVertTile"] = noIndentEffectMethodColor,
	["GetVertexColor"] = noIndentEffectMethodColor,
	["GetVerticalScroll"] = noIndentEffectMethodColor,
	["GetVerticalScrollRange"] = noIndentEffectMethodColor,
	["GetWidth"] = noIndentEffectMethodColor,
	["GetZoom"] = noIndentEffectMethodColor,
	["GetZoomLevels"] = noIndentEffectMethodColor,
	["HasFocus"] = noIndentEffectMethodColor,
	["HasScript"] = noIndentEffectMethodColor,
	["Hide"] = noIndentEffectMethodColor,
	["HighlightText"] = noIndentEffectMethodColor,
	["HookScript"] = noIndentEffectMethodColor,
	["IgnoreDepth"] = noIndentEffectMethodColor,
	["InitializeTabardColors"] = noIndentEffectMethodColor,
	["Insert"] = noIndentEffectMethodColor,
	["IsAutoFocus"] = noIndentEffectMethodColor,
	["IsClampedToScreen"] = noIndentEffectMethodColor,
	["IsCountInvisibleLetters"] = noIndentEffectMethodColor,
	["IsDelaying"] = noIndentEffectMethodColor,
	["IsDesaturated"] = noIndentEffectMethodColor,
	["IsDone"] = noIndentEffectMethodColor,
	["IsDragging"] = noIndentEffectMethodColor,
	["IsEnabled"] = noIndentEffectMethodColor,
	["IsEquippedItem"] = noIndentEffectMethodColor,
	["IsEventRegistered"] = noIndentEffectMethodColor,
	["IsIgnoringDepth"] = noIndentEffectMethodColor,
	["IsInIMECompositionMode"] = noIndentEffectMethodColor,
	["IsJoystickEnabled"] = noIndentEffectMethodColor,
	["IsKeyboardEnabled"] = noIndentEffectMethodColor,
	["IsMouseEnabled"] = noIndentEffectMethodColor,
	["IsMouseOver"] = noIndentEffectMethodColor,
	["IsMouseWheelEnabled"] = noIndentEffectMethodColor,
	["IsMovable"] = noIndentEffectMethodColor,
	["IsMultiLine"] = noIndentEffectMethodColor,
	["IsNumeric"] = noIndentEffectMethodColor,
	["IsObjectType"] = noIndentEffectMethodColor,
	["IsOwned"] = noIndentEffectMethodColor,
	["IsPassword"] = noIndentEffectMethodColor,
	["IsPaused"] = noIndentEffectMethodColor,
	["IsPendingFinish"] = noIndentEffectMethodColor,
	["IsPlaying"] = noIndentEffectMethodColor,
	["IsProtected"] = noIndentEffectMethodColor,
	["IsResizable"] = noIndentEffectMethodColor,
	["IsShown"] = noIndentEffectMethodColor,
	["IsStopped"] = noIndentEffectMethodColor,
	["IsToplevel"] = noIndentEffectMethodColor,
	["IsUnit"] = noIndentEffectMethodColor,
	["IsUserPlaced"] = noIndentEffectMethodColor,
	["IsVisible"] = noIndentEffectMethodColor,
	["LockHighlight"] = noIndentEffectMethodColor,
	["Lower"] = noIndentEffectMethodColor,
	["NumLines"] = noIndentEffectMethodColor,
	["PageDown"] = noIndentEffectMethodColor,
	["PageUp"] = noIndentEffectMethodColor,
	["Pause"] = noIndentEffectMethodColor,
	["PingLocation"] = noIndentEffectMethodColor,
	["Play"] = noIndentEffectMethodColor,
	["Raise"] = noIndentEffectMethodColor,
	["RefreshUnit"] = noIndentEffectMethodColor,
	["RegisterAllEvents"] = noIndentEffectMethodColor,
	["RegisterEvent"] = noIndentEffectMethodColor,
	["RegisterForClicks"] = noIndentEffectMethodColor,
	["RegisterForDrag"] = noIndentEffectMethodColor,
	["RemoveMessagesByAccessID"] = noIndentEffectMethodColor,
	["ReplaceIconTexture"] = noIndentEffectMethodColor,
	["Save"] = noIndentEffectMethodColor,
	["ScrollDown"] = noIndentEffectMethodColor,
	["ScrollToBottom"] = noIndentEffectMethodColor,
	["ScrollToTop"] = noIndentEffectMethodColor,
	["ScrollUp"] = noIndentEffectMethodColor,
	["SetAction"] = noIndentEffectMethodColor,
	["SetAllPoints"] = noIndentEffectMethodColor,
	["SetAlpha"] = noIndentEffectMethodColor,
	["SetAlphaGradient"] = noIndentEffectMethodColor,
	["SetAltArrowKeyMode"] = noIndentEffectMethodColor,
	["SetAnchorType"] = noIndentEffectMethodColor,
	["SetAttribute"] = noIndentEffectMethodColor,
	["SetAuctionItem"] = noIndentEffectMethodColor,
	["SetAuctionSellItem"] = noIndentEffectMethodColor,
	["SetAutoFocus"] = noIndentEffectMethodColor,
	["SetBackdrop"] = noIndentEffectMethodColor,
	["SetBackdropBorderColor"] = noIndentEffectMethodColor,
	["SetBackdropColor"] = noIndentEffectMethodColor,
	["SetBackpackToken"] = noIndentEffectMethodColor,
	["SetBagItem"] = noIndentEffectMethodColor,
	["SetBlendMode"] = noIndentEffectMethodColor,
	["SetBlinkSpeed"] = noIndentEffectMethodColor,
	["SetBlipTexture"] = noIndentEffectMethodColor,
	["SetBorderAlpha"] = noIndentEffectMethodColor,
	["SetBorderScalar"] = noIndentEffectMethodColor,
	["SetBorderTexture"] = noIndentEffectMethodColor,
	["SetButtonState"] = noIndentEffectMethodColor,
	["SetBuybackItem"] = noIndentEffectMethodColor,
	["SetCamera"] = noIndentEffectMethodColor,
	["SetChange"] = noIndentEffectMethodColor,
	["SetChecked"] = noIndentEffectMethodColor,
	["SetCheckedTexture"] = noIndentEffectMethodColor,
	["SetClampRectInsets"] = noIndentEffectMethodColor,
	["SetClampedToScreen"] = noIndentEffectMethodColor,
	["SetClassBlipTexture"] = noIndentEffectMethodColor,
	["SetColorHSV"] = noIndentEffectMethodColor,
	["SetColorRGB"] = noIndentEffectMethodColor,
	["SetColorValueTexture"] = noIndentEffectMethodColor,
	["SetColorValueThumbTexture"] = noIndentEffectMethodColor,
	["SetColorWheelTexture"] = noIndentEffectMethodColor,
	["SetColorWheelThumbTexture"] = noIndentEffectMethodColor,
	["SetCooldown"] = noIndentEffectMethodColor,
	["SetCorpsePOIArrowTexture"] = noIndentEffectMethodColor,
	["SetCountInvisibleLetters"] = noIndentEffectMethodColor,
	["SetCreature"] = noIndentEffectMethodColor,
	["SetCurrencyToken"] = noIndentEffectMethodColor,
	["SetCursorPosition"] = noIndentEffectMethodColor,
	["SetCurve"] = noIndentEffectMethodColor,
	["SetDegrees"] = noIndentEffectMethodColor,
	["SetDepth"] = noIndentEffectMethodColor,
	["SetDesaturated"] = noIndentEffectMethodColor,
	["SetDisabledCheckedTexture"] = noIndentEffectMethodColor,
	["SetDisabledFontObject"] = noIndentEffectMethodColor,
	["SetDisabledTexture"] = noIndentEffectMethodColor,
	["SetDontSavePosition"] = noIndentEffectMethodColor,
	["SetDrawEdge"] = noIndentEffectMethodColor,
	["SetDrawLayer"] = noIndentEffectMethodColor,
	["SetDuration"] = noIndentEffectMethodColor,
	["SetEndDelay"] = noIndentEffectMethodColor,
	["SetEquipmentSet"] = noIndentEffectMethodColor,
	["SetExistingSocketGem"] = noIndentEffectMethodColor,
	["SetFacing"] = noIndentEffectMethodColor,
	["SetFadeDuration"] = noIndentEffectMethodColor,
	["SetFading"] = noIndentEffectMethodColor,
	["SetFillAlpha"] = noIndentEffectMethodColor,
	["SetFillTexture"] = noIndentEffectMethodColor,
	["SetFocus"] = noIndentEffectMethodColor,
	["SetFogColor"] = noIndentEffectMethodColor,
	["SetFogFar"] = noIndentEffectMethodColor,
	["SetFogNear"] = noIndentEffectMethodColor,
	["SetFont"] = noIndentEffectMethodColor,
	["SetFontObject"] = noIndentEffectMethodColor,
	["SetFontString"] = noIndentEffectMethodColor,
	["SetFormattedText"] = noIndentEffectMethodColor,
	["SetFrameLevel"] = noIndentEffectMethodColor,
	["SetFrameStack"] = noIndentEffectMethodColor,
	["SetFrameStrata"] = noIndentEffectMethodColor,
	["SetGlow"] = noIndentEffectMethodColor,
	["SetGlyph"] = noIndentEffectMethodColor,
	["SetGradient"] = noIndentEffectMethodColor,
	["SetGradientAlpha"] = noIndentEffectMethodColor,
	["SetGuildBankItem"] = noIndentEffectMethodColor,
	["SetHeight"] = noIndentEffectMethodColor,
	["SetHighlightFontObject"] = noIndentEffectMethodColor,
	["SetHighlightTexture"] = noIndentEffectMethodColor,
	["SetHistoryLines"] = noIndentEffectMethodColor,
	["SetHitRectInsets"] = noIndentEffectMethodColor,
	["SetHorizTile"] = noIndentEffectMethodColor,
	["SetHorizontalScroll"] = noIndentEffectMethodColor,
	["SetHyperlink"] = noIndentEffectMethodColor,
	["SetHyperlinkCompareItem"] = noIndentEffectMethodColor,
	["SetHyperlinkFormat"] = noIndentEffectMethodColor,
	["SetHyperlinksEnabled"] = noIndentEffectMethodColor,
	["SetID"] = noIndentEffectMethodColor,
	["SetIconTexture"] = noIndentEffectMethodColor,
	["SetInboxItem"] = noIndentEffectMethodColor,
	["SetIndentedWordWrap"] = noIndentEffectMethodColor,
	["SetInitialOffset"] = noIndentEffectMethodColor,
	["SetInsertMode"] = noIndentEffectMethodColor,
	["SetInventoryItem"] = noIndentEffectMethodColor,
	["SetJustifyH"] = noIndentEffectMethodColor,
	["SetJustifyV"] = noIndentEffectMethodColor,
	["SetLFGCompletionReward"] = noIndentEffectMethodColor,
	["SetLFGDungeonReward"] = noIndentEffectMethodColor,
	["SetLight"] = noIndentEffectMethodColor,
	["SetLooping"] = noIndentEffectMethodColor,
	["SetLootItem"] = noIndentEffectMethodColor,
	["SetLootRollItem"] = noIndentEffectMethodColor,
	["SetMaskTexture"] = noIndentEffectMethodColor,
	["SetMaxBytes"] = noIndentEffectMethodColor,
	["SetMaxFramerate"] = noIndentEffectMethodColor,
	["SetMaxLetters"] = noIndentEffectMethodColor,
	["SetMaxLines"] = noIndentEffectMethodColor,
	["SetMaxResize"] = noIndentEffectMethodColor,
	["SetMerchantCostItem"] = noIndentEffectMethodColor,
	["SetMerchantItem"] = noIndentEffectMethodColor,
	["SetMergeThreshold"] = noIndentEffectMethodColor,
	["SetMinMaxValues"] = noIndentEffectMethodColor,
	["SetMinResize"] = noIndentEffectMethodColor,
	["SetMinimumWidth"] = noIndentEffectMethodColor,
	["SetModel"] = noIndentEffectMethodColor,
	["SetModelScale"] = noIndentEffectMethodColor,
	["SetMotionScriptsWhileDisabled"] = noIndentEffectMethodColor,
	["SetMovable"] = noIndentEffectMethodColor,
	["SetMultiLine"] = noIndentEffectMethodColor,
	["SetNonBlocking"] = noIndentEffectMethodColor,
	["SetNonSpaceWrap"] = noIndentEffectMethodColor,
	["SetNormalFontObject"] = noIndentEffectMethodColor,
	["SetNormalTexture"] = noIndentEffectMethodColor,
	["SetNumSplinePoints"] = noIndentEffectMethodColor,
	["SetNumber"] = noIndentEffectMethodColor,
	["SetNumeric"] = noIndentEffectMethodColor,
	["SetOffset"] = noIndentEffectMethodColor,
	["SetOrder"] = noIndentEffectMethodColor,
	["SetOrientation"] = noIndentEffectMethodColor,
	["SetOrigin"] = noIndentEffectMethodColor,
	["SetOwner"] = noIndentEffectMethodColor,
	["SetPOIArrowTexture"] = noIndentEffectMethodColor,
	["SetPadding"] = noIndentEffectMethodColor,
	["SetParent"] = noIndentEffectMethodColor,
	["SetPassword"] = noIndentEffectMethodColor,
	["SetPetAction"] = noIndentEffectMethodColor,
	["SetPlayerTexture"] = noIndentEffectMethodColor,
	["SetPlayerTextureHeight"] = noIndentEffectMethodColor,
	["SetPlayerTextureWidth"] = noIndentEffectMethodColor,
	["SetPoint"] = noIndentEffectMethodColor,
	["SetPosition"] = noIndentEffectMethodColor,
	["SetPossession"] = noIndentEffectMethodColor,
	["SetPushedTextOffset"] = noIndentEffectMethodColor,
	["SetPushedTexture"] = noIndentEffectMethodColor,
	["SetQuestItem"] = noIndentEffectMethodColor,
	["SetQuestLogItem"] = noIndentEffectMethodColor,
	["SetQuestLogRewardSpell"] = noIndentEffectMethodColor,
	["SetQuestLogSpecialItem"] = noIndentEffectMethodColor,
	["SetQuestRewardSpell"] = noIndentEffectMethodColor,
	["SetRadians"] = noIndentEffectMethodColor,
	["SetResizable"] = noIndentEffectMethodColor,
	["SetReverse"] = noIndentEffectMethodColor,
	["SetRotatesTexture"] = noIndentEffectMethodColor,
	["SetRotation"] = noIndentEffectMethodColor,
	["SetScale"] = noIndentEffectMethodColor,
	["SetScript"] = noIndentEffectMethodColor,
	["SetScrollChild"] = noIndentEffectMethodColor,
	["SetScrollOffset"] = noIndentEffectMethodColor,
	["SetSendMailItem"] = noIndentEffectMethodColor,
	["SetSequence"] = noIndentEffectMethodColor,
	["SetSequenceTime"] = noIndentEffectMethodColor,
	["SetShadowColor"] = noIndentEffectMethodColor,
	["SetShadowOffset"] = noIndentEffectMethodColor,
	["SetShapeshift"] = noIndentEffectMethodColor,
	["SetSize"] = noIndentEffectMethodColor,
	["SetSmoothProgress"] = noIndentEffectMethodColor,
	["SetSmoothing"] = noIndentEffectMethodColor,
	["SetSocketGem"] = noIndentEffectMethodColor,
	["SetSocketedItem"] = noIndentEffectMethodColor,
	["SetSpacing"] = noIndentEffectMethodColor,
	["SetSpell"] = noIndentEffectMethodColor,
	["SetSpellByID"] = noIndentEffectMethodColor,
	["SetStartDelay"] = noIndentEffectMethodColor,
	["SetStaticPOIArrowTexture"] = noIndentEffectMethodColor,
	["SetStatusBarColor"] = noIndentEffectMethodColor,
	["SetStatusBarTexture"] = noIndentEffectMethodColor,
	["SetTalent"] = noIndentEffectMethodColor,
	["SetTexCoord"] = noIndentEffectMethodColor,
	["SetText"] = noIndentEffectMethodColor,
	["SetTextColor"] = noIndentEffectMethodColor,
	["SetTextHeight"] = noIndentEffectMethodColor,
	["SetTextInsets"] = noIndentEffectMethodColor,
	["SetTexture"] = noIndentEffectMethodColor,
	["SetThumbTexture"] = noIndentEffectMethodColor,
	["SetTimeVisible"] = noIndentEffectMethodColor,
	["SetToplevel"] = noIndentEffectMethodColor,
	["SetTotem"] = noIndentEffectMethodColor,
	["SetTracking"] = noIndentEffectMethodColor,
	["SetTradePlayerItem"] = noIndentEffectMethodColor,
	["SetTradeSkillItem"] = noIndentEffectMethodColor,
	["SetTradeTargetItem"] = noIndentEffectMethodColor,
	["SetTrainerService"] = noIndentEffectMethodColor,
	["SetUnit"] = noIndentEffectMethodColor,
	["SetUnitAura"] = noIndentEffectMethodColor,
	["SetUnitBuff"] = noIndentEffectMethodColor,
	["SetUnitDebuff"] = noIndentEffectMethodColor,
	["SetUserPlaced"] = noIndentEffectMethodColor,
	["SetValue"] = noIndentEffectMethodColor,
	["SetValueStep"] = noIndentEffectMethodColor,
	["SetVertTile"] = noIndentEffectMethodColor,
	["SetVertexColor"] = noIndentEffectMethodColor,
	["SetVerticalScroll"] = noIndentEffectMethodColor,
	["SetWidth"] = noIndentEffectMethodColor,
	["SetWordWrap"] = noIndentEffectMethodColor,
	["SetZoom"] = noIndentEffectMethodColor,
	["Show"] = noIndentEffectMethodColor,
	["StartMovie"] = noIndentEffectMethodColor,
	["StartMoving"] = noIndentEffectMethodColor,
	["StartSizing"] = noIndentEffectMethodColor,
	["Stop"] = noIndentEffectMethodColor,
	["StopAnimating"] = noIndentEffectMethodColor,
	["StopMovie"] = noIndentEffectMethodColor,
	["StopMovingOrSizing"] = noIndentEffectMethodColor,
	["ToggleInputLanguage"] = noIndentEffectMethodColor,
	["TryOn"] = noIndentEffectMethodColor,
	["Undress"] = noIndentEffectMethodColor,
	["UnlockHighlight"] = noIndentEffectMethodColor,
	["UnregisterAllEvents"] = noIndentEffectMethodColor,
	["UnregisterEvent"] = noIndentEffectMethodColor,
	["UpdateColorByID"] = noIndentEffectMethodColor,
	["UpdateMouseOverTooltip"] = noIndentEffectMethodColor,
	["UpdateQuestPOI"] = noIndentEffectMethodColor,
	["UpdateScrollChildRect"] = noIndentEffectMethodColor,
	-- Events and stuff
	["ADDON_LOADED"] = noIndentEffectEventColor,
	["Ace2_AddonDisabled"] = noIndentEffectEventColor,
	["Ace2_AddonEnabled"] = noIndentEffectEventColor,
	["AceEvent20EditBox"] = noIndentEffectEventColor,
	["AceEvent20Frame"] = noIndentEffectEventColor,
	["AceEvent_FullyInitialized"] = noIndentEffectEventColor,
	["AceLibrary"] = noIndentEffectEventColor,
	["AcquireDBNamespace"] = noIndentEffectEventColor,
	["CHAT_MSG_ADDON"] = noIndentEffectEventColor,
	["CHAT_MSG_CHANNEL"] = noIndentEffectEventColor,
	["CHAT_MSG_CHANNEL_JOIN"] = noIndentEffectEventColor,
	["CHAT_MSG_CHANNEL_LEAVE"] = noIndentEffectEventColor,
	["CHAT_MSG_CHANNEL_LIST"] = noIndentEffectEventColor,
	["CHAT_MSG_CHANNEL_NOTICE"] = noIndentEffectEventColor,
	["CHAT_MSG_SYSTEM"] = noIndentEffectEventColor,
	["CallMethodOnAllModules"] = noIndentEffectEventColor,
	["CancelAllCombatSchedules"] = noIndentEffectEventColor,
	["CancelAllScheduledEvents"] = noIndentEffectEventColor,
	["CancelScheduledEvent"] = noIndentEffectEventColor,
	["ChatThrottleLib"] = noIndentEffectEventColor,
	["Classpool"] = noIndentEffectEventColor,
	["CopyProfileFrom"] = noIndentEffectEventColor,
	["CustomDebug"] = noIndentEffectEventColor,
	["CustomLevelDebug"] = noIndentEffectEventColor,
	["CustomPrint"] = noIndentEffectEventColor,
	["Debug"] = noIndentEffectEventColor,
	["DeleteProfile"] = noIndentEffectEventColor,
	["Despool"] = noIndentEffectEventColor,
	["Enqueue"] = noIndentEffectEventColor,
	["Execute"] = noIndentEffectEventColor,
	["Factory"] = noIndentEffectEventColor,
	["GetAceOptionsDataTable"] = noIndentEffectEventColor,
	["GetDebugLevel"] = noIndentEffectEventColor,
	["GetDebugPrefix"] = noIndentEffectEventColor,
	["GetInstance"] = noIndentEffectEventColor,
	["GetLibrary"] = noIndentEffectEventColor,
	["GetLibraryVersion"] = noIndentEffectEventColor,
	["GetLocalizedCategory"] = noIndentEffectEventColor,
	["GetModule"] = noIndentEffectEventColor,
	["GetProfile"] = noIndentEffectEventColor,
	["HasInstance"] = noIndentEffectEventColor,
	["HasModule"] = noIndentEffectEventColor,
	["Hook"] = noIndentEffectEventColor,
	["HookReport"] = noIndentEffectEventColor,
	["HookScript"] = noIndentEffectEventColor,
	["Hook_SendAddonMessage"] = noIndentEffectEventColor,
	["Hook_SendChatMessage"] = noIndentEffectEventColor,
	["Init"] = noIndentEffectEventColor,
	["InitializeAddon"] = noIndentEffectEventColor,
	["InitializeDB"] = noIndentEffectEventColor,
	["InjectAceOptionsTable"] = noIndentEffectEventColor,
	["IsActive"] = noIndentEffectEventColor,
	["IsBucketEventRegistered"] = noIndentEffectEventColor,
	["IsCommRegistered"] = noIndentEffectEventColor,
	["IsDebugging"] = noIndentEffectEventColor,
	["IsEventRegistered"] = noIndentEffectEventColor,
	["IsEventScheduled"] = noIndentEffectEventColor,
	["IsFullyInitialized"] = noIndentEffectEventColor,
	["IsHooked"] = noIndentEffectEventColor,
	["IsModule"] = noIndentEffectEventColor,
	["IsModuleActive"] = noIndentEffectEventColor,
	["IsNewVersion"] = noIndentEffectEventColor,
	["IsTabCompletionRegistered"] = noIndentEffectEventColor,
	["IsUserInChannel"] = noIndentEffectEventColor,
	["IterateLibraries"] = noIndentEffectEventColor,
	["IterateModules"] = noIndentEffectEventColor,
	["IterateModulesWithMethod"] = noIndentEffectEventColor,
	["LevelDebug"] = noIndentEffectEventColor,
	["LibStub"] = noIndentEffectEventColor,
	["ManualDisable"] = noIndentEffectEventColor,
	["ManualEnable"] = noIndentEffectEventColor,
	["NewLibrary"] = noIndentEffectEventColor,
	["NewModule"] = noIndentEffectEventColor,
	["ORIG_SendAddonMessage"] = noIndentEffectEventColor,
	["ORIG_SendChatMessage"] = noIndentEffectEventColor,
	["OnEmbedDisable"] = noIndentEffectEventColor,
	["OnEmbedInitialize"] = noIndentEffectEventColor,
	["OnEmbedProfileDisable"] = noIndentEffectEventColor,
	["OnEvent"] = noIndentEffectEventColor,
	["OnInstanceInit"] = noIndentEffectEventColor,
	["OnManualEmbed"] = noIndentEffectEventColor,
	["OnTabPressed"] = noIndentEffectEventColor,
	["OnUpdate"] = noIndentEffectEventColor,
	["PLAYER_GUILD_UPDATE"] = noIndentEffectEventColor,
	["PLAYER_LOGIN"] = noIndentEffectEventColor,
	["PLAYER_LOGOUT"] = noIndentEffectEventColor,
	["PLAYER_REGEN_DISABLED"] = noIndentEffectEventColor,
	["PLAYER_REGEN_ENABLED"] = noIndentEffectEventColor,
	["Print"] = noIndentEffectEventColor,
	["PrintComma"] = noIndentEffectEventColor,
	["PrintLiteral"] = noIndentEffectEventColor,
	["QueryAddonVersion"] = noIndentEffectEventColor,
	["Register"] = noIndentEffectEventColor,
	["RegisterAddonVersionReceptor"] = noIndentEffectEventColor,
	["RegisterAllEvents"] = noIndentEffectEventColor,
	["RegisterBucketEvent"] = noIndentEffectEventColor,
	["RegisterChatCommand"] = noIndentEffectEventColor,
	["RegisterComm"] = noIndentEffectEventColor,
	["RegisterDB"] = noIndentEffectEventColor,
	["RegisterDefaults"] = noIndentEffectEventColor,
	["RegisterEvent"] = noIndentEffectEventColor,
	["RegisterMemoizations"] = noIndentEffectEventColor,
	["RegisterTabCompletion"] = noIndentEffectEventColor,
	["ResetDB"] = noIndentEffectEventColor,
	["ScheduleEvent"] = noIndentEffectEventColor,
	["ScheduleLeaveCombatAction"] = noIndentEffectEventColor,
	["ScheduleRepeatingEvent"] = noIndentEffectEventColor,
	["SecureHook"] = noIndentEffectEventColor,
	["SecureHookScript"] = noIndentEffectEventColor,
	["SendAddonMessage"] = noIndentEffectEventColor,
	["SendChatMessage"] = noIndentEffectEventColor,
	["SendCommMessage"] = noIndentEffectEventColor,
	["SendPrioritizedCommMessage"] = noIndentEffectEventColor,
	["SetCommPrefix"] = noIndentEffectEventColor,
	["SetDebugLevel"] = noIndentEffectEventColor,
	["SetDebugging"] = noIndentEffectEventColor,
	["SetDefaultCommPriority"] = noIndentEffectEventColor,
	["SetModuleClass"] = noIndentEffectEventColor,
	["SetModuleDefaultState"] = noIndentEffectEventColor,
	["SetModuleMixins"] = noIndentEffectEventColor,
	["SetProfile"] = noIndentEffectEventColor,
	["TabCompleteInfo"] = noIndentEffectEventColor,
	["ToString"] = noIndentEffectEventColor,
	["ToggleActive"] = noIndentEffectEventColor,
	["ToggleModuleActive"] = noIndentEffectEventColor,
	["TriggerEvent"] = noIndentEffectEventColor,
	["Unhook"] = noIndentEffectEventColor,
	["UnhookAll"] = noIndentEffectEventColor,
	["UnregisterAllBucketEvents"] = noIndentEffectEventColor,
	["UnregisterAllComms"] = noIndentEffectEventColor,
	["UnregisterAllEvents"] = noIndentEffectEventColor,
	["UnregisterBucketEvent"] = noIndentEffectEventColor,
	["UnregisterComm"] = noIndentEffectEventColor,
	["UnregisterEvent"] = noIndentEffectEventColor,
	["UnregisterTabCompletion"] = noIndentEffectEventColor,
	["UpdateAvail"] = noIndentEffectEventColor,
	["ZONE_CHANGED_NEW_AREA"] = noIndentEffectEventColor,
	["argCheck"] = noIndentEffectEventColor,
	["embed"] = noIndentEffectEventColor,
	["error"] = noIndentEffectEventColor,
	["inherits"] = noIndentEffectEventColor,
	["keybindingValidateFunc"] = noIndentEffectEventColor,
	["new"] = noIndentEffectEventColor,
	["pcall"] = noIndentEffectEventColor,
	-- Ace Stuff
	["Ace3"] = noIndentEffectAceColor,
	["AceAddon30Frame"] = noIndentEffectAceColor,
	["AceComm30Frame"] = noIndentEffectAceColor,
	["AceEvent30Frame"] = noIndentEffectAceColor,
	["AceTimer30Frame"] = noIndentEffectAceColor,
	["AddToBlizOptions"] = noIndentEffectAceColor,
	["CancelAllTimers"] = noIndentEffectAceColor,
	["CancelTimer"] = noIndentEffectAceColor,
	["ChatThrottleLib"] = noIndentEffectAceColor,
	["ClearFocus"] = noIndentEffectAceColor,
	["Close"] = noIndentEffectAceColor,
	["CloseAll"] = noIndentEffectAceColor,
	["ConfigTableChanged"] = noIndentEffectAceColor,
	["Create"] = noIndentEffectAceColor,
	["CreateChatCommand"] = noIndentEffectAceColor,
	["Deserialize"] = noIndentEffectAceColor,
	["Despool"] = noIndentEffectAceColor,
	["Disable"] = noIndentEffectAceColor,
	["DisableAddon"] = noIndentEffectAceColor,
	["DisableModule"] = noIndentEffectAceColor,
	["Embed"] = noIndentEffectAceColor,
	["EmbedLibraries"] = noIndentEffectAceColor,
	["EmbedLibrary"] = noIndentEffectAceColor,
	["Enable"] = noIndentEffectAceColor,
	["EnableAddon"] = noIndentEffectAceColor,
	["EnableModule"] = noIndentEffectAceColor,
	["Enqueue"] = noIndentEffectAceColor,
	["FeedGroup"] = noIndentEffectAceColor,
	["GetAddon"] = noIndentEffectAceColor,
	["GetArgs"] = noIndentEffectAceColor,
	["GetChatCommandOptions"] = noIndentEffectAceColor,
	["GetLayout"] = noIndentEffectAceColor,
	["GetLibrary"] = noIndentEffectAceColor,
	["GetLocale"] = noIndentEffectAceColor,
	["GetModule"] = noIndentEffectAceColor,
	["GetName"] = noIndentEffectAceColor,
	["GetNextWidgetNum"] = noIndentEffectAceColor,
	["GetOptionsTable"] = noIndentEffectAceColor,
	["GetStatusTable"] = noIndentEffectAceColor,
	["GetWidgetCount"] = noIndentEffectAceColor,
	["GetWidgetVersion"] = noIndentEffectAceColor,
	["HandleCommand"] = noIndentEffectAceColor,
	["Hook"] = noIndentEffectAceColor,
	["HookScript"] = noIndentEffectAceColor,
	["Hook_SendAddonMessage"] = noIndentEffectAceColor,
	["Hook_SendChatMessage"] = noIndentEffectAceColor,
	["Init"] = noIndentEffectAceColor,
	["InitializeAddon"] = noIndentEffectAceColor,
	["IsEnabled"] = noIndentEffectAceColor,
	["IsHooked"] = noIndentEffectAceColor,
	["IsModule"] = noIndentEffectAceColor,
	["IsTabCompletionRegistered"] = noIndentEffectAceColor,
	["IterateAddonStatus"] = noIndentEffectAceColor,
	["IterateAddons"] = noIndentEffectAceColor,
	["IterateChatCommands"] = noIndentEffectAceColor,
	["IterateEmbeds"] = noIndentEffectAceColor,
	["IterateEmbedsOnAddon"] = noIndentEffectAceColor,
	["IterateLibraries"] = noIndentEffectAceColor,
	["IterateModules"] = noIndentEffectAceColor,
	["IterateModulesOfAddon"] = noIndentEffectAceColor,
	["IterateOptionsTables"] = noIndentEffectAceColor,
	["LibStub"] = noIndentEffectAceColor,
	["New"] = noIndentEffectAceColor,
	["NewAddon"] = noIndentEffectAceColor,
	["NewLibrary"] = noIndentEffectAceColor,
	["NewLocale"] = noIndentEffectAceColor,
	["NewModule"] = noIndentEffectAceColor,
	["NotifyChange"] = noIndentEffectAceColor,
	["OnEmbedDisable"] = noIndentEffectAceColor,
	["OnEmbedEnable"] = noIndentEffectAceColor,
	["OnEvent"] = noIndentEffectAceColor,
	["OnInitialize"] = noIndentEffectAceColor,
	["OnReceiveMultipartFirst"] = noIndentEffectAceColor,
	["OnReceiveMultipartLast"] = noIndentEffectAceColor,
	["OnReceiveMultipartNext"] = noIndentEffectAceColor,
	["OnTabPressed"] = noIndentEffectAceColor,
	["OnUpdate"] = noIndentEffectAceColor,
	["Open"] = noIndentEffectAceColor,
	["Print"] = noIndentEffectAceColor,
	["PrintCmd"] = noIndentEffectAceColor,
	["Printf"] = noIndentEffectAceColor,
	["RawHook"] = noIndentEffectAceColor,
	["RawHookScript"] = noIndentEffectAceColor,
	["RegisterAsContainer"] = noIndentEffectAceColor,
	["RegisterAsWidget"] = noIndentEffectAceColor,
	["RegisterBucketEvent"] = noIndentEffectAceColor,
	["RegisterBucketMessage"] = noIndentEffectAceColor,
	["RegisterCallback"] = noIndentEffectAceColor,
	["RegisterChatCommand"] = noIndentEffectAceColor,
	["RegisterComm"] = noIndentEffectAceColor,
	["RegisterEvent"] = noIndentEffectAceColor,
	["RegisterLayout"] = noIndentEffectAceColor,
	["RegisterMessage"] = noIndentEffectAceColor,
	["RegisterOptionsTable"] = noIndentEffectAceColor,
	["RegisterTabCompletion"] = noIndentEffectAceColor,
	["RegisterWidgetType"] = noIndentEffectAceColor,
	["Release"] = noIndentEffectAceColor,
	["ScheduleRepeatingTimer"] = noIndentEffectAceColor,
	["ScheduleTimer"] = noIndentEffectAceColor,
	["SecureHook"] = noIndentEffectAceColor,
	["SecureHookScript"] = noIndentEffectAceColor,
	["SelectGroup"] = noIndentEffectAceColor,
	["SendAddonMessage"] = noIndentEffectAceColor,
	["SendChatMessage"] = noIndentEffectAceColor,
	["SendCommMessage"] = noIndentEffectAceColor,
	["SendMessage"] = noIndentEffectAceColor,
	["Serialize"] = noIndentEffectAceColor,
	["SetDefaultModuleLibraries"] = noIndentEffectAceColor,
	["SetDefaultModulePrototype"] = noIndentEffectAceColor,
	["SetDefaultModuleState"] = noIndentEffectAceColor,
	["SetDefaultSize"] = noIndentEffectAceColor,
	["SetEnabledState"] = noIndentEffectAceColor,
	["SetFocus"] = noIndentEffectAceColor,
	["TimeLeft"] = noIndentEffectAceColor,
	["Unhook"] = noIndentEffectAceColor,
	["UnhookAll"] = noIndentEffectAceColor,
	["UnregisterAllBuckets"] = noIndentEffectAceColor,
	["UnregisterAllCallbacks"] = noIndentEffectAceColor,
	["UnregisterAllComm"] = noIndentEffectAceColor,
	["UnregisterAllEvents"] = noIndentEffectAceColor,
	["UnregisterAllMessages"] = noIndentEffectAceColor,
	["UnregisterBucket"] = noIndentEffectAceColor,
	["UnregisterCallback"] = noIndentEffectAceColor,
	["UnregisterChatCommand"] = noIndentEffectAceColor,
	["UnregisterComm"] = noIndentEffectAceColor,
	["UnregisterEvent"] = noIndentEffectAceColor,
	["UnregisterMessage"] = noIndentEffectAceColor,
	["UnregisterTabCompletion"] = noIndentEffectAceColor,
	["UpdateAvail"] = noIndentEffectAceColor,
	["ValidateOptionsTable"] = noIndentEffects,
	["_RegisterComm"] = noIndentEffects,
	
	}
lib.keywords = keywords

local tokenIndentation = {}
lib.tokenIndentation = tokenIndentation
tokenIndentation[tokens.TOKEN_LEFTPAREN] = indentRight
tokenIndentation[tokens.TOKEN_LEFTBRACKET] = indentRight
tokenIndentation[tokens.TOKEN_LEFTWING] = indentRight

tokenIndentation[tokens.TOKEN_RIGHTPAREN] = indentLeft
tokenIndentation[tokens.TOKEN_RIGHTBRACKET] = indentLeft
tokenIndentation[tokens.TOKEN_RIGHTWING] = indentLeft

local function fillWithTabs(n)
	return stringrep("\t", n)
end

local function fillWithSpaces(a, b)
	return stringrep(" ", a*b)
end

function lib.colorCodeCode(code, colorTable, caretPosition)
	local stopColor = colorTable and colorTable[0]
	if not stopColor then
		return code, caretPosition
	end

	local stopColorLen = stringlen(stopColor)

	tableclear(workingTable)
	local tsize = 0
	local totalLen = 0

	local numLines = 0
	local newCaretPosition
	local prevTokenWasColored = false
	local prevTokenWidth = 0
	
	local pos = 1
	local level = 0

	while true do
		if caretPosition and not newCaretPosition and pos >= caretPosition then
			if pos == caretPosition then
				newCaretPosition = totalLen
			else
				newCaretPosition = totalLen
				local diff = pos - caretPosition
				if diff > prevTokenWidth then
					diff = prevTokenWidth
				end
				if prevTokenWasColored then
					diff = diff + stopColorLen
				end
				newCaretPosition = newCaretPosition - diff
			end
		end
		
		prevTokenWasColored = false
		prevTokenWidth = 0
		
		local tokenType, nextPos = lib.nextToken(code, pos)
		
		if not tokenType then
			break
		end
		
		if tokenType == tokens.TOKEN_COLORCODE_START or tokenType == tokens.TOKEN_COLORCODE_STOP or tokenType == tokens.TOKEN_UNKNOWN then
			-- ignore color codes
			
		elseif tokenType == tokens.TOKEN_LINEBREAK or tokenType == tokens.TOKEN_WHITESPACE then
			if tokenType == tokens.TOKEN_LINEBREAK then
				numLines = numLines + 1
			end
			local str = stringsub(code, pos, nextPos - 1)
			prevTokenWidth = nextPos - pos

			tsize = tsize + 1
			workingTable[tsize] = str
			totalLen = totalLen + stringlen(str)
		else
			local str = stringsub(code, pos, nextPos - 1)
			
			prevTokenWidth = nextPos - pos
			
			-- Add coloring
			if keywords[str] then
				tokenType = tokens.TOKEN_KEYWORD
			end
			
			local color
			if stopColor then
				if colorTable[str] then
					color = colorTable[str]
				elseif keywords[str] and keywords[str][3] then
					color = keywords[str][3]
				elseif colorTable[tokenType] then
					color = colorTable[tokenType]
				elseif tokenType == tokens.TOKEN_IDENTIFIER then
					color = colorTable[tokens.TOKEN_IDENTIFIER]
				else
					color = colorTable[tokens.TOKEN_SPECIAL]
				end
			end
			
			if color then
				tsize = tsize + 1
				workingTable[tsize] = color
				tsize = tsize + 1
				workingTable[tsize] = str
				tsize = tsize + 1
				workingTable[tsize] = stopColor

				totalLen = totalLen + stringlen(color) + (nextPos - pos) + stopColorLen
				prevTokenWasColored = true
			else
				tsize = tsize + 1
				workingTable[tsize] = str

				totalLen = totalLen + stringlen(str)
			end
		end
		
		pos = nextPos
	end
	return table.concat(workingTable), newCaretPosition, numLines
end

function lib.indentCode(code, tabWidth, colorTable, caretPosition)
	local fillFunction
	if tabWidth == nil then
		tabWidth = defaultTabWidth
	end
	if tabWidth then
		fillFunction = fillWithSpaces
	else
		fillFunction = fillWithTabs
	end
	
	tableclear(workingTable)
	local tsize = 0
	local totalLen = 0

	tableclear(workingTable2)
	local tsize2 = 0
	local totalLen2 = 0


	local stopColor = colorTable and colorTable[0]
	local stopColorLen = not stopColor or stringlen(stopColor)

	local newCaretPosition
	local newCaretPositionFinalized = false
	local prevTokenWasColored = false
	local prevTokenWidth = 0
	
	local pos = 1
	local level = 0
	
	local hitNonWhitespace = false
	local hitIndentRight = false
	local preIndent = 0
	local postIndent = 0
	while true do
		if caretPosition and not newCaretPosition and pos >= caretPosition then
			if pos == caretPosition then
				newCaretPosition = totalLen + totalLen2
			else
				newCaretPosition = totalLen + totalLen2
				local diff = pos - caretPosition
				if diff > prevTokenWidth then
					diff = prevTokenWidth
				end
				if prevTokenWasColored then
					diff = diff + stopColorLen
				end
				newCaretPosition = newCaretPosition - diff
			end
		end
		
		prevTokenWasColored = false
		prevTokenWidth = 0
		
		local tokenType, nextPos = lib.nextToken(code, pos)
		
		if not tokenType or tokenType == tokens.TOKEN_LINEBREAK then
			level = level + preIndent
			if level < 0 then level = 0 end
			
			local s = fillFunction(level, tabWidth)

			tsize = tsize + 1
			workingTable[tsize] = s
			totalLen = totalLen + stringlen(s)
			
			if newCaretPosition and not newCaretPositionFinalized then
				newCaretPosition = newCaretPosition + stringlen(s)
				newCaretPositionFinalized = true
			end
			

			for k, v in next,workingTable2 do
				tsize = tsize + 1
				workingTable[tsize] = v
				totalLen = totalLen + stringlen(v)
			end

			if not tokenType then
				break
			end
			
			tsize = tsize + 1
			workingTable[tsize] = stringsub(code, pos, nextPos - 1)
			totalLen = totalLen + nextPos - pos

			level = level + postIndent
			if level < 0 then level = 0 end
			
			tableclear(workingTable2)
			tsize2 = 0
			totalLen2 = 0

			hitNonWhitespace = false
			hitIndentRight = false
			preIndent = 0
			postIndent = 0
		elseif tokenType == tokens.TOKEN_WHITESPACE then
			if hitNonWhitespace then
				prevTokenWidth = nextPos - pos
				
				tsize2 = tsize2 + 1
				local s = stringsub(code, pos, nextPos - 1)
				workingTable2[tsize2] = s
				totalLen2 = totalLen2 + stringlen(s)
			end
		elseif tokenType == tokens.TOKEN_COLORCODE_START or tokenType == tokens.TOKEN_COLORCODE_STOP or tokenType == tokens.TOKEN_UNKNOWN then
			-- skip these, though they shouldn't be encountered here anyway
		else
			hitNonWhitespace = true
			
			local str = stringsub(code, pos, nextPos - 1)
			
			prevTokenWidth = nextPos - pos
			
			-- See if this is an indent-modifier
			local indentTable
			if tokenType == tokens.TOKEN_IDENTIFIER then
				indentTable = keywords[str]
			else
				indentTable = tokenIndentation[tokenType]
			end
			
			if indentTable then
				if hitIndentRight then
					postIndent = postIndent + indentTable[1] + indentTable[2]
				else
					local pre = indentTable[1]
					local post = indentTable[2]
					if post > 0 then
						hitIndentRight = true
					end
					preIndent = preIndent + pre
					postIndent = postIndent + post
				end
			end
			
			-- Add coloring
			if keywords[str] then
				tokenType = tokens.TOKEN_KEYWORD
			end
			
			local color
			if stopColor then
				if colorTable[str] then
					color = colorTable[str]
				elseif keywords[str] and keywords[str][3] then
					color = keywords[str][3]
				elseif colorTable[tokenType] then
					color = colorTable[tokenType]
				elseif tokenType == tokens.TOKEN_IDENTIFIER then
					color = colorTable[tokens.TOKEN_IDENTIFIER]
				else
					color = colorTable[tokens.TOKEN_SPECIAL]
				end
			end
			
			if color then
				tsize2 = tsize2 + 1
				workingTable2[tsize2] = color
				totalLen2 = totalLen2 + stringlen(color)

				tsize2 = tsize2 + 1
				workingTable2[tsize2] = str
				totalLen2 = totalLen2 + nextPos - pos

				tsize2 = tsize2 + 1
				workingTable2[tsize2] = stopColor
				totalLen2 = totalLen2 + stopColorLen

				prevTokenWasColored = true
			else
				tsize2 = tsize2 + 1
				workingTable2[tsize2] = str
				totalLen2 = totalLen2 + nextPos - pos

			end
		end
		pos = nextPos
	end
	return table.concat(workingTable), newCaretPosition
end



-- WoW specific code:
local GetTime = GetTime

local editboxSetText
local editboxGetText

function lib.stripWowColors(code)

	-- HACK!
	-- This is a fix for a bug, where an unfinished string causes a lot of newlines to be created.
	-- The reason for the bug, is that a |r\n\n gets converted to \n\n|r after the next indent-run
	-- The fix is to remove those last two linebreaks when stripping
	code = stringgsub(code, "|r\n\n$", "|r")
	
	tableclear(workingTable)
	local tsize = 0

	local pos = 1

	local prevVertical = false
	local even = true
	local selectionStart = 1

	while true do
		local byte = stringbyte(code, pos)
		if not byte then
			break
		end
		if byte == bytes.BYTE_VERTICAL then
			even = not even
			prevVertical = true
		else
			if prevVertical and not even then
				if byte == bytes.BYTE_c then
					
					if pos - 2 >= selectionStart then
						tsize = tsize + 1
						workingTable[tsize] = stringsub(code, selectionStart, pos - 2)
					end
					
					pos = pos + 8
					selectionStart = pos + 1
				elseif byte == bytes.BYTE_r then

					if pos - 2 >= selectionStart then
						tsize = tsize + 1
						workingTable[tsize] = stringsub(code, selectionStart, pos - 2)
					end
					selectionStart = pos + 1
				end
			end
			prevVertical = false
			even = true
		end
		pos = pos + 1
	end
	if pos >= selectionStart then
		tsize = tsize + 1
		workingTable[tsize] = stringsub(code, selectionStart, pos - 1)
	end
	return table.concat(workingTable)
end

function lib.decode(code)
	if code then
		code = lib.stripWowColors(code)
		code = stringgsub(code, "||", "|")
	end
	return code or ""
end

function lib.encode(code)
	if code then
		code = stringgsub(code, "|", "||")
	end
	return code or ""
end

function lib.stripWowColorsWithPos(code, pos)
	code = stringinsert(code, pos, "\2")
	code = lib.stripWowColors(code)
	pos = stringfind(code, "\2", 1, 1)
	code = stringdelete(code, pos, pos)
	return code, pos
end

-- returns the padded code, and true if modified, false if unmodified
local linebreak = stringbyte("\n")
function lib.padWithLinebreaks(code)
	do
		return code, false
	end

	local len = stringlen(code)
	if stringbyte(code, len) == linebreak then
		if stringbyte(code, len - 1) == linebreak then
            return code, false
		end
		return code .. "\n", true
	end
	return code .. "\n\n", true

end

local defaultTabWidth = 2
local defaultColorTable

-- Data tables
-- No weak table magic, since editboxes can never be removed in WoW
local enabled = {}
local dirty = {}

local editboxIndentCache = {}
local decodeCache = {}
local editboxStringCache = {}
local editboxNumLinesCache = {}

function lib.coloredGetText(editbox)
	return editboxGetText(editbox)
end

function lib.colorCodeEditbox(editbox)
	dirty[editbox] = nil

	local colorTable = editbox.faiap_colorTable or defaultColorTable
	local tabWidth = editbox.faiap_tabWidth

	local orgCode = editboxGetText(editbox)
	local prevCode = editboxStringCache[editbox]
	if prevCode == orgCode then
		return
	end
	
	local pos = editbox:GetCursorPosition()
	
	local code
	code, pos = lib.stripWowColorsWithPos(orgCode, pos)

	colorTable[0] = "|r"
	
	local newCode, newPos, numLines = lib.colorCodeCode(code, colorTable, pos)
	if editbox:IsMultiLine() then
		newCode = lib.padWithLinebreaks(newCode)
	end

	editboxStringCache[editbox] = newCode
	if orgCode ~= newCode then
		decodeCache[editbox] = nil
		local stringlenNewCode = stringlen(newCode)

		editboxSetText(editbox, newCode)
		if newPos then
			if newPos < 0 then newPos = 0 end
			if newPos > stringlenNewCode then newPos = stringlenNewCode end
			
			editbox:SetCursorPosition(newPos)
		end
	end
	
	if editboxNumLinesCache[editbox] ~= numLines then
		lib.indentEditbox(editbox)
	end
	editboxNumLinesCache[editbox] = numLines
end

function lib.indentEditbox(editbox)
	dirty[editbox] = nil

	local colorTable = editbox.faiap_colorTable or defaultColorTable
	local tabWidth = editbox.faiap_tabWidth

	local orgCode = editboxGetText(editbox)
	local prevCode = editboxIndentCache[editbox]
	if prevCode == orgCode then
		return
	end

	local pos = editbox:GetCursorPosition()
	
	local code
	code, pos = lib.stripWowColorsWithPos(orgCode, pos)

	colorTable[0] = "|r"
	local newCode, newPos = lib.indentCode(code, tabWidth, colorTable, pos)
	if editbox:IsMultiLine() then 
		newCode = lib.padWithLinebreaks(newCode)
	end

	editboxIndentCache[editbox] = newCode
	if code ~= newCode then
		decodeCache[editbox] = nil

		local stringlenNewCode = stringlen(newCode)

		editboxSetText(editbox, newCode)

		if newPos then
			if newPos < 0 then newPos = 0 end
			if newPos > stringlenNewCode then newPos = stringlenNewCode end
			
			editbox:SetCursorPosition(newPos)
		end
	end
end

local function hookHandler(editbox, handler, newFun)
	local oldFun = editbox:GetScript(handler)
	if oldFun == newFun then
		-- already hooked, ignore it
		return
	end
	editbox["faiap_old_" .. handler] = oldFun
	editbox:SetScript(handler, newFun)
end

local function textChangedHook(editbox, ...)
	local oldFun = editbox["faiap_old_OnTextChanged"]
	if oldFun then
		oldFun(editbox, ...)
	end
	if enabled[editbox] then
		dirty[editbox] = GetTime()
	end
end

local function tabPressedHook(editbox, ...)
	local oldFun = editbox["faiap_old_OnTabPressed"]
	if oldFun then
		oldFun(editbox, ...)
	end
	if enabled[editbox] then
		return lib.indentEditbox(editbox)
	end
end

local function onUpdateHook(editbox, ...)
	local oldFun = editbox["faiap_old_OnUpdate"]
	if oldFun then
		oldFun(editbox, ...)
	end
	if enabled[editbox] then
		local now = GetTime()
		local lastUpdate = dirty[editbox] or now
		if now - lastUpdate > 0.2 then
			decodeCache[editbox] = nil
			return lib.colorCodeEditbox(editbox)
		end
	end
end

local function newGetText(editbox, raw)
	if raw then
		return lib.decode(editboxGetText(editbox))
	end

	local decoded = decodeCache[editbox]
	if not decoded then
		decoded = lib.decode(editboxGetText(editbox))
		decodeCache[editbox] = decoded
	end
	return decoded or ""
end

local function newSetText(editbox, text)
	decodeCache[editbox] = nil
	if text then
		local encoded = lib.encode(text)

		return editboxSetText(editbox, encoded)
	end
end

function lib.enable(editbox, colorTable, tabWidth)
	if not editboxSetText then
		editboxSetText = editbox.SetText
		editboxGetText = editbox.GetText
	end

	local modified
	if editbox.faiap_colorTable ~= colorTable then
		editbox.faiap_colorTable = colorTable
		modified = true
	end
	if editbox.faiap_tabWidth ~= tabWidth then
		editbox.faiap_tabWidth = tabWidth
		modified = true
	end

	if enabled[editbox] then
		if modified then
			lib.indentEditbox(editbox)
		end
		return
	end

	-- Editbox is possibly hooked, but disabled
	enabled[editbox] = true

	editbox.oldMaxBytes = editbox:GetMaxBytes()
	editbox.oldMaxLetters = editbox:GetMaxLetters()
	editbox:SetMaxBytes(0)
	editbox:SetMaxLetters(0)

	editbox.GetText = newGetText
	editbox.SetText = newSetText

	hookHandler(editbox, "OnTextChanged", textChangedHook)
	hookHandler(editbox, "OnTabPressed", tabPressedHook)      
	hookHandler(editbox, "OnUpdate", onUpdateHook)      

	lib.indentEditbox(editbox)
end

-- Deprecated function
lib.addSmartCode = lib.enable

function lib.disable(editbox)
	if not enabled[editbox] then
		return
	end
	enabled[editbox] = nil

	-- revert settings for max bytes / letters
	editbox:SetMaxBytes(editbox.oldMaxBytes)
	editbox:SetMaxLetters(editbox.oldMaxLetters)

	-- try a real unhooking, if possible
	if editbox:GetScript("OnTextChanged") == textChangedHook then
		editbox:SetScript("OnTextChanged", editbox.faiap_old_OnTextChanged)
		editbox.faiap_old_OnTextChanged = nil
	end

	if editbox:GetScript("OnTabPressed") == tabPressedHook then
		editbox:SetScript("OnTabPressed", editbox.faiap_old_OnTabPressed)
		editbox.faiap_old_OnTabPressed = nil
	end

	if editbox:GetScript("OnUpdate") == onUpdateHook then
		editbox:SetScript("OnUpdate", editbox.faiap_old_OnUpdate)
		editbox.faiap_old_OnUpdate = nil
	end

	editbox.GetText = nil
	editbox.SetText = nil

	-- change the text back to unformatted
	editbox:SetText(newGetText(editbox))

	-- clear caches
	editboxIndentCache[editbox] = nil
	decodeCache[editbox] = nil
	editboxStringCache[editbox] = nil
	editboxNumLinesCache[editbox] = nil
end


-- ****************************************************************************
-- * Colors defined @514                                                      *
-- ****************************************************************************

defaultColorTable = {
	[tokens.TOKEN_SPECIAL] = "|c00ff99ff",
	[tokens.TOKEN_KEYWORD] = "|c006666ff",
	[tokens.TOKEN_COMMENT_SHORT] = "|c00999999",
	[tokens.TOKEN_COMMENT_LONG] = "|c00999999",
	
	[tokens.TOKEN_STRING] = stringColor,
	[".."] = stringColor,

	["..."] = tableColor,
	["{"] = tableColor,
	["}"] = tableColor,
	["["] = tableColor,
	["]"] = tableColor,

	[tokens.TOKEN_NUMBER] = arithmeticColor,
	["+"] = arithmeticColor,
	["-"] = arithmeticColor,
	["/"] = arithmeticColor,
	["*"] = arithmeticColor,

	["=="] = logicColor1,
	["<"] = logicColor1,
	["<="] = logicColor1,
	[">"] = logicColor1,
	[">="] = logicColor1,
	["~="] = logicColor1,

	["and"] = logicColor2,
	["or"] = logicColor2,
	["not"] = logicColor2,

	[0] = "|r",

	}
lib.defaultColorTable = defaultColorTable
